/* Automatically @generated by tree-sitter */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 282
#define LARGE_STATE_COUNT 2
#define SYMBOL_COUNT 143
#define ALIAS_COUNT 0
#define TOKEN_COUNT 73
#define EXTERNAL_TOKEN_COUNT 6
#define FIELD_COUNT 23
#define MAX_ALIAS_SEQUENCE_LENGTH 7
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 70
#define SUPERTYPE_COUNT 4

enum ts_symbol_identifiers {
  sym_identifier = 1,
  sym_hash_bang_line = 2,
  anon_sym_return = 3,
  anon_sym_SEMI = 4,
  anon_sym_EQ = 5,
  anon_sym_COMMA = 6,
  anon_sym_COLON_COLON = 7,
  sym_break_statement = 8,
  anon_sym_goto = 9,
  anon_sym_do = 10,
  anon_sym_end = 11,
  anon_sym_while = 12,
  anon_sym_repeat = 13,
  anon_sym_until = 14,
  anon_sym_if = 15,
  anon_sym_then = 16,
  anon_sym_elseif = 17,
  anon_sym_else = 18,
  anon_sym_for = 19,
  anon_sym_in = 20,
  anon_sym_function = 21,
  anon_sym_local = 22,
  anon_sym_global = 23,
  anon_sym_DOT = 24,
  anon_sym_COLON = 25,
  anon_sym_STAR = 26,
  anon_sym_LT = 27,
  anon_sym_GT = 28,
  sym_nil = 29,
  sym_false = 30,
  sym_true = 31,
  sym_number = 32,
  anon_sym_DQUOTE = 33,
  anon_sym_SQUOTE = 34,
  aux_sym__doublequote_string_content_token1 = 35,
  aux_sym__singlequote_string_content_token1 = 36,
  sym_escape_sequence = 37,
  sym_vararg_expression = 38,
  anon_sym_LPAREN = 39,
  anon_sym_RPAREN = 40,
  anon_sym_LBRACK = 41,
  anon_sym_RBRACK = 42,
  anon_sym_LBRACE = 43,
  anon_sym_RBRACE = 44,
  anon_sym_or = 45,
  anon_sym_and = 46,
  anon_sym_LT_EQ = 47,
  anon_sym_EQ_EQ = 48,
  anon_sym_TILDE_EQ = 49,
  anon_sym_GT_EQ = 50,
  anon_sym_PIPE = 51,
  anon_sym_TILDE = 52,
  anon_sym_AMP = 53,
  anon_sym_LT_LT = 54,
  anon_sym_GT_GT = 55,
  anon_sym_PLUS = 56,
  anon_sym_DASH = 57,
  anon_sym_SLASH = 58,
  anon_sym_SLASH_SLASH = 59,
  anon_sym_PERCENT = 60,
  anon_sym_DOT_DOT = 61,
  anon_sym_CARET = 62,
  anon_sym_not = 63,
  anon_sym_POUND = 64,
  anon_sym_DASH_DASH = 65,
  aux_sym_comment_token1 = 66,
  sym__block_comment_start = 67,
  sym__block_comment_content = 68,
  sym__block_comment_end = 69,
  sym__block_string_start = 70,
  sym__block_string_content = 71,
  sym__block_string_end = 72,
  sym_chunk = 73,
  sym__block = 74,
  sym_statement = 75,
  sym_return_statement = 76,
  sym_empty_statement = 77,
  sym_assignment_statement = 78,
  sym__variable_assignment_varlist = 79,
  sym__variable_assignment_explist = 80,
  sym_label_statement = 81,
  sym_goto_statement = 82,
  sym_do_statement = 83,
  sym_while_statement = 84,
  sym_repeat_statement = 85,
  sym_if_statement = 86,
  sym_elseif_statement = 87,
  sym_else_statement = 88,
  sym_for_statement = 89,
  sym_for_generic_clause = 90,
  sym_for_numeric_clause = 91,
  sym__name_list = 92,
  sym_declaration = 93,
  sym_function_declaration = 94,
  sym__local_function_declaration = 95,
  sym__global_function_declaration = 96,
  sym__function_name = 97,
  sym__function_name_prefix_expression = 98,
  sym__function_name_dot_index_expression = 99,
  sym__function_name_method_index_expression = 100,
  sym_variable_declaration = 101,
  sym__global_variable_declaration = 102,
  sym__variable_assignment = 103,
  sym__att_name_list = 104,
  sym__global_implicit_variable_declaration = 105,
  sym__attrib = 106,
  sym__expression_list = 107,
  sym_expression = 108,
  sym_string = 109,
  sym__quote_string = 110,
  aux_sym__doublequote_string_content = 111,
  aux_sym__singlequote_string_content = 112,
  sym__block_string = 113,
  sym_function_definition = 114,
  sym__function_body = 115,
  sym_parameters = 116,
  sym__parameter_list = 117,
  sym__vararg_parameter = 118,
  sym__prefix_expression = 119,
  sym_variable = 120,
  sym_bracket_index_expression = 121,
  sym_dot_index_expression = 122,
  sym_function_call = 123,
  sym_method_index_expression = 124,
  sym_arguments = 125,
  sym_parenthesized_expression = 126,
  sym_table_constructor = 127,
  sym__field_list = 128,
  sym__field_sep = 129,
  sym_field = 130,
  sym_binary_expression = 131,
  sym_unary_expression = 132,
  sym_comment = 133,
  sym__contextual_keyword = 134,
  aux_sym_chunk_repeat1 = 135,
  aux_sym__variable_assignment_varlist_repeat1 = 136,
  aux_sym__variable_assignment_explist_repeat1 = 137,
  aux_sym_if_statement_repeat1 = 138,
  aux_sym__name_list_repeat1 = 139,
  aux_sym__att_name_list_repeat1 = 140,
  aux_sym__expression_list_repeat1 = 141,
  aux_sym__field_list_repeat1 = 142,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [sym_hash_bang_line] = "hash_bang_line",
  [anon_sym_return] = "return",
  [anon_sym_SEMI] = ";",
  [anon_sym_EQ] = "=",
  [anon_sym_COMMA] = ",",
  [anon_sym_COLON_COLON] = "::",
  [sym_break_statement] = "break_statement",
  [anon_sym_goto] = "goto",
  [anon_sym_do] = "do",
  [anon_sym_end] = "end",
  [anon_sym_while] = "while",
  [anon_sym_repeat] = "repeat",
  [anon_sym_until] = "until",
  [anon_sym_if] = "if",
  [anon_sym_then] = "then",
  [anon_sym_elseif] = "elseif",
  [anon_sym_else] = "else",
  [anon_sym_for] = "for",
  [anon_sym_in] = "in",
  [anon_sym_function] = "function",
  [anon_sym_local] = "local",
  [anon_sym_global] = "global",
  [anon_sym_DOT] = ".",
  [anon_sym_COLON] = ":",
  [anon_sym_STAR] = "*",
  [anon_sym_LT] = "<",
  [anon_sym_GT] = ">",
  [sym_nil] = "nil",
  [sym_false] = "false",
  [sym_true] = "true",
  [sym_number] = "number",
  [anon_sym_DQUOTE] = "\"",
  [anon_sym_SQUOTE] = "'",
  [aux_sym__doublequote_string_content_token1] = "_doublequote_string_content_token1",
  [aux_sym__singlequote_string_content_token1] = "_singlequote_string_content_token1",
  [sym_escape_sequence] = "escape_sequence",
  [sym_vararg_expression] = "vararg_expression",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_or] = "or",
  [anon_sym_and] = "and",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_TILDE_EQ] = "~=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_PIPE] = "|",
  [anon_sym_TILDE] = "~",
  [anon_sym_AMP] = "&",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_SLASH] = "/",
  [anon_sym_SLASH_SLASH] = "//",
  [anon_sym_PERCENT] = "%",
  [anon_sym_DOT_DOT] = "..",
  [anon_sym_CARET] = "^",
  [anon_sym_not] = "not",
  [anon_sym_POUND] = "#",
  [anon_sym_DASH_DASH] = "--",
  [aux_sym_comment_token1] = "comment_content",
  [sym__block_comment_start] = "[[",
  [sym__block_comment_content] = "comment_content",
  [sym__block_comment_end] = "]]",
  [sym__block_string_start] = "[[",
  [sym__block_string_content] = "string_content",
  [sym__block_string_end] = "]]",
  [sym_chunk] = "chunk",
  [sym__block] = "block",
  [sym_statement] = "statement",
  [sym_return_statement] = "return_statement",
  [sym_empty_statement] = "empty_statement",
  [sym_assignment_statement] = "assignment_statement",
  [sym__variable_assignment_varlist] = "variable_list",
  [sym__variable_assignment_explist] = "expression_list",
  [sym_label_statement] = "label_statement",
  [sym_goto_statement] = "goto_statement",
  [sym_do_statement] = "do_statement",
  [sym_while_statement] = "while_statement",
  [sym_repeat_statement] = "repeat_statement",
  [sym_if_statement] = "if_statement",
  [sym_elseif_statement] = "elseif_statement",
  [sym_else_statement] = "else_statement",
  [sym_for_statement] = "for_statement",
  [sym_for_generic_clause] = "for_generic_clause",
  [sym_for_numeric_clause] = "for_numeric_clause",
  [sym__name_list] = "variable_list",
  [sym_declaration] = "declaration",
  [sym_function_declaration] = "function_declaration",
  [sym__local_function_declaration] = "function_declaration",
  [sym__global_function_declaration] = "function_declaration",
  [sym__function_name] = "_function_name",
  [sym__function_name_prefix_expression] = "_function_name_prefix_expression",
  [sym__function_name_dot_index_expression] = "dot_index_expression",
  [sym__function_name_method_index_expression] = "method_index_expression",
  [sym_variable_declaration] = "variable_declaration",
  [sym__global_variable_declaration] = "variable_declaration",
  [sym__variable_assignment] = "assignment_statement",
  [sym__att_name_list] = "variable_list",
  [sym__global_implicit_variable_declaration] = "implicit_variable_declaration",
  [sym__attrib] = "attribute",
  [sym__expression_list] = "expression_list",
  [sym_expression] = "expression",
  [sym_string] = "string",
  [sym__quote_string] = "_quote_string",
  [aux_sym__doublequote_string_content] = "_doublequote_string_content",
  [aux_sym__singlequote_string_content] = "_singlequote_string_content",
  [sym__block_string] = "_block_string",
  [sym_function_definition] = "function_definition",
  [sym__function_body] = "_function_body",
  [sym_parameters] = "parameters",
  [sym__parameter_list] = "_parameter_list",
  [sym__vararg_parameter] = "_vararg_parameter",
  [sym__prefix_expression] = "_prefix_expression",
  [sym_variable] = "variable",
  [sym_bracket_index_expression] = "bracket_index_expression",
  [sym_dot_index_expression] = "dot_index_expression",
  [sym_function_call] = "function_call",
  [sym_method_index_expression] = "method_index_expression",
  [sym_arguments] = "arguments",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_table_constructor] = "table_constructor",
  [sym__field_list] = "_field_list",
  [sym__field_sep] = "_field_sep",
  [sym_field] = "field",
  [sym_binary_expression] = "binary_expression",
  [sym_unary_expression] = "unary_expression",
  [sym_comment] = "comment",
  [sym__contextual_keyword] = "_contextual_keyword",
  [aux_sym_chunk_repeat1] = "chunk_repeat1",
  [aux_sym__variable_assignment_varlist_repeat1] = "_variable_assignment_varlist_repeat1",
  [aux_sym__variable_assignment_explist_repeat1] = "_variable_assignment_explist_repeat1",
  [aux_sym_if_statement_repeat1] = "if_statement_repeat1",
  [aux_sym__name_list_repeat1] = "_name_list_repeat1",
  [aux_sym__att_name_list_repeat1] = "_att_name_list_repeat1",
  [aux_sym__expression_list_repeat1] = "_expression_list_repeat1",
  [aux_sym__field_list_repeat1] = "_field_list_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [sym_hash_bang_line] = sym_hash_bang_line,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [sym_break_statement] = sym_break_statement,
  [anon_sym_goto] = anon_sym_goto,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_repeat] = anon_sym_repeat,
  [anon_sym_until] = anon_sym_until,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_then] = anon_sym_then,
  [anon_sym_elseif] = anon_sym_elseif,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_local] = anon_sym_local,
  [anon_sym_global] = anon_sym_global,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT] = anon_sym_GT,
  [sym_nil] = sym_nil,
  [sym_false] = sym_false,
  [sym_true] = sym_true,
  [sym_number] = sym_number,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [aux_sym__doublequote_string_content_token1] = aux_sym__doublequote_string_content_token1,
  [aux_sym__singlequote_string_content_token1] = aux_sym__singlequote_string_content_token1,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_vararg_expression] = sym_vararg_expression,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_or] = anon_sym_or,
  [anon_sym_and] = anon_sym_and,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_TILDE_EQ] = anon_sym_TILDE_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_SLASH_SLASH] = anon_sym_SLASH_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_not] = anon_sym_not,
  [anon_sym_POUND] = anon_sym_POUND,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [aux_sym_comment_token1] = sym__block_comment_content,
  [sym__block_comment_start] = sym__block_comment_start,
  [sym__block_comment_content] = sym__block_comment_content,
  [sym__block_comment_end] = sym__block_comment_end,
  [sym__block_string_start] = sym__block_comment_start,
  [sym__block_string_content] = sym__block_string_content,
  [sym__block_string_end] = sym__block_comment_end,
  [sym_chunk] = sym_chunk,
  [sym__block] = sym__block,
  [sym_statement] = sym_statement,
  [sym_return_statement] = sym_return_statement,
  [sym_empty_statement] = sym_empty_statement,
  [sym_assignment_statement] = sym_assignment_statement,
  [sym__variable_assignment_varlist] = sym__variable_assignment_varlist,
  [sym__variable_assignment_explist] = sym__variable_assignment_explist,
  [sym_label_statement] = sym_label_statement,
  [sym_goto_statement] = sym_goto_statement,
  [sym_do_statement] = sym_do_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_repeat_statement] = sym_repeat_statement,
  [sym_if_statement] = sym_if_statement,
  [sym_elseif_statement] = sym_elseif_statement,
  [sym_else_statement] = sym_else_statement,
  [sym_for_statement] = sym_for_statement,
  [sym_for_generic_clause] = sym_for_generic_clause,
  [sym_for_numeric_clause] = sym_for_numeric_clause,
  [sym__name_list] = sym__variable_assignment_varlist,
  [sym_declaration] = sym_declaration,
  [sym_function_declaration] = sym_function_declaration,
  [sym__local_function_declaration] = sym_function_declaration,
  [sym__global_function_declaration] = sym_function_declaration,
  [sym__function_name] = sym__function_name,
  [sym__function_name_prefix_expression] = sym__function_name_prefix_expression,
  [sym__function_name_dot_index_expression] = sym_dot_index_expression,
  [sym__function_name_method_index_expression] = sym_method_index_expression,
  [sym_variable_declaration] = sym_variable_declaration,
  [sym__global_variable_declaration] = sym_variable_declaration,
  [sym__variable_assignment] = sym_assignment_statement,
  [sym__att_name_list] = sym__variable_assignment_varlist,
  [sym__global_implicit_variable_declaration] = sym__global_implicit_variable_declaration,
  [sym__attrib] = sym__attrib,
  [sym__expression_list] = sym__variable_assignment_explist,
  [sym_expression] = sym_expression,
  [sym_string] = sym_string,
  [sym__quote_string] = sym__quote_string,
  [aux_sym__doublequote_string_content] = aux_sym__doublequote_string_content,
  [aux_sym__singlequote_string_content] = aux_sym__singlequote_string_content,
  [sym__block_string] = sym__block_string,
  [sym_function_definition] = sym_function_definition,
  [sym__function_body] = sym__function_body,
  [sym_parameters] = sym_parameters,
  [sym__parameter_list] = sym__parameter_list,
  [sym__vararg_parameter] = sym__vararg_parameter,
  [sym__prefix_expression] = sym__prefix_expression,
  [sym_variable] = sym_variable,
  [sym_bracket_index_expression] = sym_bracket_index_expression,
  [sym_dot_index_expression] = sym_dot_index_expression,
  [sym_function_call] = sym_function_call,
  [sym_method_index_expression] = sym_method_index_expression,
  [sym_arguments] = sym_arguments,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_table_constructor] = sym_table_constructor,
  [sym__field_list] = sym__field_list,
  [sym__field_sep] = sym__field_sep,
  [sym_field] = sym_field,
  [sym_binary_expression] = sym_binary_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym_comment] = sym_comment,
  [sym__contextual_keyword] = sym__contextual_keyword,
  [aux_sym_chunk_repeat1] = aux_sym_chunk_repeat1,
  [aux_sym__variable_assignment_varlist_repeat1] = aux_sym__variable_assignment_varlist_repeat1,
  [aux_sym__variable_assignment_explist_repeat1] = aux_sym__variable_assignment_explist_repeat1,
  [aux_sym_if_statement_repeat1] = aux_sym_if_statement_repeat1,
  [aux_sym__name_list_repeat1] = aux_sym__name_list_repeat1,
  [aux_sym__att_name_list_repeat1] = aux_sym__att_name_list_repeat1,
  [aux_sym__expression_list_repeat1] = aux_sym__expression_list_repeat1,
  [aux_sym__field_list_repeat1] = aux_sym__field_list_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_hash_bang_line] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_goto] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_repeat] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_until] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_then] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_elseif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_local] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_global] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [sym_nil] = {
    .visible = true,
    .named = true,
  },
  [sym_false] = {
    .visible = true,
    .named = true,
  },
  [sym_true] = {
    .visible = true,
    .named = true,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__doublequote_string_content_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__singlequote_string_content_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_vararg_expression] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_not] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_comment_token1] = {
    .visible = true,
    .named = true,
  },
  [sym__block_comment_start] = {
    .visible = true,
    .named = false,
  },
  [sym__block_comment_content] = {
    .visible = true,
    .named = true,
  },
  [sym__block_comment_end] = {
    .visible = true,
    .named = false,
  },
  [sym__block_string_start] = {
    .visible = true,
    .named = false,
  },
  [sym__block_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym__block_string_end] = {
    .visible = true,
    .named = false,
  },
  [sym_chunk] = {
    .visible = true,
    .named = true,
  },
  [sym__block] = {
    .visible = true,
    .named = true,
  },
  [sym_statement] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_empty_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__variable_assignment_varlist] = {
    .visible = true,
    .named = true,
  },
  [sym__variable_assignment_explist] = {
    .visible = true,
    .named = true,
  },
  [sym_label_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_goto_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_do_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_repeat_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_elseif_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_else_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_generic_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_for_numeric_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__name_list] = {
    .visible = true,
    .named = true,
  },
  [sym_declaration] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_function_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__local_function_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__global_function_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__function_name] = {
    .visible = false,
    .named = true,
  },
  [sym__function_name_prefix_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__function_name_dot_index_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__function_name_method_index_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__global_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__variable_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym__att_name_list] = {
    .visible = true,
    .named = true,
  },
  [sym__global_implicit_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__attrib] = {
    .visible = true,
    .named = true,
  },
  [sym__expression_list] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym__quote_string] = {
    .visible = false,
    .named = true,
  },
  [aux_sym__doublequote_string_content] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__singlequote_string_content] = {
    .visible = false,
    .named = false,
  },
  [sym__block_string] = {
    .visible = false,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__function_body] = {
    .visible = false,
    .named = true,
  },
  [sym_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym__parameter_list] = {
    .visible = false,
    .named = true,
  },
  [sym__vararg_parameter] = {
    .visible = false,
    .named = true,
  },
  [sym__prefix_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_variable] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_bracket_index_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_dot_index_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_method_index_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_table_constructor] = {
    .visible = true,
    .named = true,
  },
  [sym__field_list] = {
    .visible = false,
    .named = true,
  },
  [sym__field_sep] = {
    .visible = false,
    .named = true,
  },
  [sym_field] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym__contextual_keyword] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_chunk_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__variable_assignment_varlist_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__variable_assignment_explist_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__name_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__att_name_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__expression_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__field_list_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_alternative = 1,
  field_arguments = 2,
  field_attribute = 3,
  field_body = 4,
  field_clause = 5,
  field_condition = 6,
  field_consequence = 7,
  field_content = 8,
  field_end = 9,
  field_field = 10,
  field_global_declaration = 11,
  field_left = 12,
  field_local_declaration = 13,
  field_method = 14,
  field_name = 15,
  field_operand = 16,
  field_operator = 17,
  field_parameters = 18,
  field_right = 19,
  field_start = 20,
  field_step = 21,
  field_table = 22,
  field_value = 23,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alternative] = "alternative",
  [field_arguments] = "arguments",
  [field_attribute] = "attribute",
  [field_body] = "body",
  [field_clause] = "clause",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_content] = "content",
  [field_end] = "end",
  [field_field] = "field",
  [field_global_declaration] = "global_declaration",
  [field_left] = "left",
  [field_local_declaration] = "local_declaration",
  [field_method] = "method",
  [field_name] = "name",
  [field_operand] = "operand",
  [field_operator] = "operator",
  [field_parameters] = "parameters",
  [field_right] = "right",
  [field_start] = "start",
  [field_step] = "step",
  [field_table] = "table",
  [field_value] = "value",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 2},
  [2] = {.index = 2, .length = 4},
  [3] = {.index = 6, .length = 4},
  [4] = {.index = 10, .length = 1},
  [5] = {.index = 11, .length = 1},
  [6] = {.index = 12, .length = 2},
  [7] = {.index = 14, .length = 1},
  [8] = {.index = 15, .length = 2},
  [9] = {.index = 17, .length = 3},
  [10] = {.index = 20, .length = 2},
  [11] = {.index = 22, .length = 2},
  [12] = {.index = 24, .length = 1},
  [13] = {.index = 25, .length = 2},
  [14] = {.index = 27, .length = 2},
  [15] = {.index = 29, .length = 2},
  [16] = {.index = 31, .length = 3},
  [17] = {.index = 34, .length = 2},
  [18] = {.index = 36, .length = 2},
  [19] = {.index = 38, .length = 1},
  [20] = {.index = 39, .length = 2},
  [21] = {.index = 41, .length = 1},
  [22] = {.index = 42, .length = 1},
  [23] = {.index = 43, .length = 3},
  [24] = {.index = 46, .length = 2},
  [25] = {.index = 48, .length = 3},
  [26] = {.index = 51, .length = 2},
  [27] = {.index = 53, .length = 1},
  [28] = {.index = 54, .length = 3},
  [29] = {.index = 57, .length = 2},
  [30] = {.index = 59, .length = 2},
  [31] = {.index = 61, .length = 1},
  [32] = {.index = 62, .length = 2},
  [33] = {.index = 64, .length = 1},
  [34] = {.index = 65, .length = 1},
  [35] = {.index = 31, .length = 3},
  [36] = {.index = 66, .length = 3},
  [37] = {.index = 69, .length = 1},
  [38] = {.index = 70, .length = 2},
  [39] = {.index = 72, .length = 1},
  [40] = {.index = 73, .length = 1},
  [41] = {.index = 74, .length = 3},
  [42] = {.index = 77, .length = 4},
  [43] = {.index = 81, .length = 4},
  [44] = {.index = 85, .length = 4},
  [45] = {.index = 89, .length = 3},
  [46] = {.index = 92, .length = 4},
  [47] = {.index = 96, .length = 2},
  [48] = {.index = 98, .length = 1},
  [49] = {.index = 99, .length = 2},
  [50] = {.index = 101, .length = 2},
  [51] = {.index = 103, .length = 2},
  [52] = {.index = 105, .length = 2},
  [53] = {.index = 107, .length = 2},
  [54] = {.index = 109, .length = 2},
  [55] = {.index = 111, .length = 2},
  [56] = {.index = 113, .length = 2},
  [57] = {.index = 115, .length = 2},
  [58] = {.index = 117, .length = 5},
  [59] = {.index = 122, .length = 1},
  [60] = {.index = 123, .length = 2},
  [61] = {.index = 125, .length = 2},
  [62] = {.index = 127, .length = 3},
  [63] = {.index = 130, .length = 3},
  [64] = {.index = 133, .length = 3},
  [65] = {.index = 136, .length = 4},
  [66] = {.index = 140, .length = 3},
  [67] = {.index = 143, .length = 3},
  [68] = {.index = 146, .length = 4},
  [69] = {.index = 150, .length = 5},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_global_declaration, 0, .inherited = true},
    {field_local_declaration, 0, .inherited = true},
  [2] =
    {field_body, 0, .inherited = true},
    {field_local_declaration, 0},
    {field_name, 0, .inherited = true},
    {field_parameters, 0, .inherited = true},
  [6] =
    {field_body, 0, .inherited = true},
    {field_global_declaration, 0},
    {field_name, 0, .inherited = true},
    {field_parameters, 0, .inherited = true},
  [10] =
    {field_local_declaration, 0},
  [11] =
    {field_global_declaration, 0},
  [12] =
    {field_attribute, 0, .inherited = true},
    {field_global_declaration, 0},
  [14] =
    {field_name, 0},
  [15] =
    {field_content, 1},
    {field_start, 0},
  [17] =
    {field_content, 0, .inherited = true},
    {field_end, 0, .inherited = true},
    {field_start, 0, .inherited = true},
  [20] =
    {field_field, 0, .inherited = true},
    {field_table, 0, .inherited = true},
  [22] =
    {field_method, 0, .inherited = true},
    {field_table, 0, .inherited = true},
  [24] =
    {field_operator, 1, .inherited = true},
  [25] =
    {field_attribute, 1, .inherited = true},
    {field_name, 1, .inherited = true},
  [27] =
    {field_arguments, 1},
    {field_name, 0},
  [29] =
    {field_name, 0},
    {field_name, 1, .inherited = true},
  [31] =
    {field_content, 1},
    {field_end, 2},
    {field_start, 0},
  [34] =
    {field_body, 1, .inherited = true},
    {field_parameters, 1, .inherited = true},
  [36] =
    {field_end, 1},
    {field_start, 0},
  [38] =
    {field_value, 0},
  [39] =
    {field_operand, 1},
    {field_operator, 0},
  [41] =
    {field_body, 1},
  [42] =
    {field_condition, 2},
  [43] =
    {field_body, 2, .inherited = true},
    {field_name, 1},
    {field_parameters, 2, .inherited = true},
  [46] =
    {field_attribute, 1},
    {field_name, 0},
  [48] =
    {field_attribute, 1, .inherited = true},
    {field_name, 0},
    {field_name, 1, .inherited = true},
  [51] =
    {field_attribute, 0},
    {field_name, 1},
  [53] =
    {field_attribute, 1},
  [54] =
    {field_name, 0, .inherited = true},
    {field_operator, 1},
    {field_value, 2, .inherited = true},
  [57] =
    {field_field, 2},
    {field_table, 0},
  [59] =
    {field_method, 2},
    {field_table, 0},
  [61] =
    {field_name, 1},
  [62] =
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
  [64] =
    {field_name, 0, .inherited = true},
  [65] =
    {field_parameters, 0},
  [66] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [69] =
    {field_condition, 1},
  [70] =
    {field_body, 1},
    {field_condition, 3},
  [72] =
    {field_alternative, 0},
  [73] =
    {field_clause, 1},
  [74] =
    {field_body, 3, .inherited = true},
    {field_name, 2},
    {field_parameters, 3, .inherited = true},
  [77] =
    {field_attribute, 1},
    {field_attribute, 2, .inherited = true},
    {field_name, 0},
    {field_name, 2, .inherited = true},
  [81] =
    {field_attribute, 0, .inherited = true},
    {field_attribute, 1, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
  [85] =
    {field_attribute, 0, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_operator, 1},
    {field_value, 2, .inherited = true},
  [89] =
    {field_attribute, 0},
    {field_attribute, 2},
    {field_name, 1},
  [92] =
    {field_attribute, 0},
    {field_attribute, 2, .inherited = true},
    {field_name, 1},
    {field_name, 2, .inherited = true},
  [96] =
    {field_value, 0},
    {field_value, 1, .inherited = true},
  [98] =
    {field_name, 1, .inherited = true},
  [99] =
    {field_body, 1},
    {field_parameters, 0},
  [101] =
    {field_name, 0},
    {field_value, 2},
  [103] =
    {field_body, 3},
    {field_condition, 1},
  [105] =
    {field_condition, 1},
    {field_consequence, 3},
  [107] =
    {field_alternative, 3},
    {field_condition, 1},
  [109] =
    {field_alternative, 3, .inherited = true},
    {field_condition, 1},
  [111] =
    {field_alternative, 0, .inherited = true},
    {field_alternative, 1, .inherited = true},
  [113] =
    {field_body, 3},
    {field_clause, 1},
  [115] =
    {field_attribute, 2},
    {field_name, 1},
  [117] =
    {field_attribute, 0},
    {field_attribute, 2},
    {field_attribute, 3, .inherited = true},
    {field_name, 1},
    {field_name, 3, .inherited = true},
  [122] =
    {field_value, 1},
  [123] =
    {field_value, 0, .inherited = true},
    {field_value, 1, .inherited = true},
  [125] =
    {field_name, 0},
    {field_name, 2, .inherited = true},
  [127] =
    {field_alternative, 4},
    {field_condition, 1},
    {field_consequence, 3},
  [130] =
    {field_alternative, 4, .inherited = true},
    {field_condition, 1},
    {field_consequence, 3},
  [133] =
    {field_alternative, 3, .inherited = true},
    {field_alternative, 4},
    {field_condition, 1},
  [136] =
    {field_end, 4},
    {field_name, 0},
    {field_operator, 1},
    {field_start, 2},
  [140] =
    {field_name, 0},
    {field_name, 1, .inherited = true},
    {field_name, 3, .inherited = true},
  [143] =
    {field_name, 1},
    {field_operator, 3},
    {field_value, 4},
  [146] =
    {field_alternative, 4, .inherited = true},
    {field_alternative, 5},
    {field_condition, 1},
    {field_consequence, 3},
  [150] =
    {field_end, 4},
    {field_name, 0},
    {field_operator, 1},
    {field_start, 2},
    {field_step, 6},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [35] = {
    [1] = sym__block_string_content,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  aux_sym__doublequote_string_content, 2,
    aux_sym__doublequote_string_content,
    sym__block_string_content,
  aux_sym__singlequote_string_content, 2,
    aux_sym__singlequote_string_content,
    sym__block_string_content,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 18,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 19,
  [31] = 6,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 17,
  [40] = 40,
  [41] = 14,
  [42] = 42,
  [43] = 43,
  [44] = 15,
  [45] = 16,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 61,
  [63] = 60,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 139,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 150,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 159,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 169,
  [170] = 170,
  [171] = 171,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 179,
  [180] = 180,
  [181] = 181,
  [182] = 182,
  [183] = 183,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 188,
  [189] = 189,
  [190] = 190,
  [191] = 191,
  [192] = 192,
  [193] = 193,
  [194] = 194,
  [195] = 195,
  [196] = 196,
  [197] = 193,
  [198] = 198,
  [199] = 199,
  [200] = 200,
  [201] = 201,
  [202] = 202,
  [203] = 203,
  [204] = 202,
  [205] = 203,
  [206] = 196,
  [207] = 207,
  [208] = 208,
  [209] = 209,
  [210] = 210,
  [211] = 211,
  [212] = 212,
  [213] = 213,
  [214] = 214,
  [215] = 215,
  [216] = 216,
  [217] = 217,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 222,
  [223] = 223,
  [224] = 224,
  [225] = 225,
  [226] = 226,
  [227] = 227,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 231,
  [232] = 232,
  [233] = 233,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 237,
  [238] = 238,
  [239] = 239,
  [240] = 240,
  [241] = 241,
  [242] = 242,
  [243] = 243,
  [244] = 244,
  [245] = 245,
  [246] = 246,
  [247] = 247,
  [248] = 248,
  [249] = 249,
  [250] = 250,
  [251] = 251,
  [252] = 252,
  [253] = 253,
  [254] = 254,
  [255] = 255,
  [256] = 256,
  [257] = 257,
  [258] = 258,
  [259] = 259,
  [260] = 260,
  [261] = 261,
  [262] = 262,
  [263] = 263,
  [264] = 264,
  [265] = 265,
  [266] = 266,
  [267] = 267,
  [268] = 268,
  [269] = 269,
  [270] = 270,
  [271] = 271,
  [272] = 272,
  [273] = 273,
  [274] = 232,
  [275] = 275,
  [276] = 276,
  [277] = 242,
  [278] = 275,
  [279] = 279,
  [280] = 280,
  [281] = 281,
};

static const TSSymbol ts_supertype_symbols[SUPERTYPE_COUNT] = {
  sym_declaration,
  sym_expression,
  sym_statement,
  sym_variable,
};

static const TSMapSlice ts_supertype_map_slices[] = {
  [sym_declaration] = {.index = 0, .length = 6},
  [sym_expression] = {.index = 6, .length = 13},
  [sym_statement] = {.index = 19, .length = 12},
  [sym_variable] = {.index = 31, .length = 4},
};

static const TSSymbol ts_supertype_map_entries[] = {
  [0] =
    sym__global_function_declaration,
    sym__global_implicit_variable_declaration,
    sym__global_variable_declaration,
    sym__local_function_declaration,
    sym_function_declaration,
    sym_variable_declaration,
  [6] =
    sym_binary_expression,
    sym_false,
    sym_function_call,
    sym_function_definition,
    sym_nil,
    sym_number,
    sym_parenthesized_expression,
    sym_string,
    sym_table_constructor,
    sym_true,
    sym_unary_expression,
    sym_vararg_expression,
    sym_variable,
  [19] =
    sym_assignment_statement,
    sym_break_statement,
    sym_declaration,
    sym_do_statement,
    sym_empty_statement,
    sym_for_statement,
    sym_function_call,
    sym_goto_statement,
    sym_if_statement,
    sym_label_statement,
    sym_repeat_statement,
    sym_while_statement,
  [31] =
    anon_sym_global,
    sym_bracket_index_expression,
    sym_dot_index_expression,
    sym_identifier,
};

static const TSCharacterRange sym_escape_sequence_character_set_1[] = {
  {'\n', '\n'}, {'"', '"'}, {'\'', '\''}, {'0', '9'}, {'\\', '\\'}, {'a', 'b'}, {'f', 'f'}, {'n', 'n'},
  {'r', 'r'}, {'t', 'v'}, {'x', 'x'}, {'z', 'z'},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(21);
      ADVANCE_MAP(
        '"', 42,
        '#', 78,
        '%', 75,
        '&', 68,
        '\'', 43,
        '(', 55,
        ')', 56,
        '*', 30,
        '+', 71,
        ',', 25,
        '-', 72,
        '.', 28,
        '/', 73,
        '0', 35,
        ':', 29,
        ';', 23,
        '<', 31,
        '=', 24,
        '>', 33,
        '[', 57,
        '\\', 6,
        ']', 58,
        '^', 77,
        '{', 59,
        '|', 65,
        '}', 60,
        '~', 67,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(18);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(36);
      if (lookahead > ' ' &&
          (lookahead < '{' || 0x9f < lookahead)) ADVANCE(79);
      END_STATE();
    case 1:
      if (lookahead == '"') ADVANCE(42);
      if (lookahead == '-') ADVANCE(45);
      if (lookahead == '\\') ADVANCE(6);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(44);
      if (lookahead != 0) ADVANCE(46);
      END_STATE();
    case 2:
      if (lookahead == '\'') ADVANCE(43);
      if (lookahead == '-') ADVANCE(48);
      if (lookahead == '\\') ADVANCE(6);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(47);
      if (lookahead != 0) ADVANCE(49);
      END_STATE();
    case 3:
      if (lookahead == '.') ADVANCE(4);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(38);
      END_STATE();
    case 4:
      if (lookahead == '.') ADVANCE(54);
      END_STATE();
    case 5:
      if (lookahead == '.') ADVANCE(15);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(37);
      END_STATE();
    case 6:
      if (lookahead == 'u') ADVANCE(7);
      if (lookahead == 'x') ADVANCE(17);
      if (lookahead == 'z') ADVANCE(51);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(53);
      if (set_contains(sym_escape_sequence_character_set_1, 12, lookahead)) ADVANCE(50);
      END_STATE();
    case 7:
      if (lookahead == '{') ADVANCE(16);
      END_STATE();
    case 8:
      if (lookahead == '}') ADVANCE(50);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(8);
      END_STATE();
    case 9:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(13);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(41);
      END_STATE();
    case 10:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(34);
      END_STATE();
    case 11:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(10);
      END_STATE();
    case 12:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(39);
      END_STATE();
    case 13:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(41);
      END_STATE();
    case 14:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(50);
      END_STATE();
    case 15:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(40);
      END_STATE();
    case 16:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(8);
      END_STATE();
    case 17:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(14);
      END_STATE();
    case 18:
      if (eof) ADVANCE(21);
      ADVANCE_MAP(
        '"', 42,
        '#', 78,
        '%', 75,
        '&', 68,
        '\'', 43,
        '(', 55,
        ')', 56,
        '*', 30,
        '+', 71,
        ',', 25,
        '-', 72,
        '.', 28,
        '/', 73,
        '0', 35,
        ':', 29,
        ';', 23,
        '<', 31,
        '=', 24,
        '>', 33,
        '[', 57,
        ']', 58,
        '^', 77,
        '{', 59,
        '|', 65,
        '}', 60,
        '~', 67,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(18);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(36);
      if (lookahead > ' ' &&
          (lookahead < '[' || '^' < lookahead) &&
          (lookahead < '{' || 0x9f < lookahead)) ADVANCE(79);
      END_STATE();
    case 19:
      if (eof) ADVANCE(21);
      ADVANCE_MAP(
        '"', 42,
        '#', 78,
        '\'', 43,
        '(', 55,
        ')', 56,
        '-', 72,
        '.', 3,
        '0', 35,
        ';', 23,
        '>', 32,
        '[', 57,
        '{', 59,
        '}', 60,
        '~', 66,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(19);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(36);
      if (lookahead > ' ' &&
          (lookahead < '%' || '>' < lookahead) &&
          (lookahead < '[' || '^' < lookahead) &&
          (lookahead < '{' || 0x9f < lookahead)) ADVANCE(79);
      END_STATE();
    case 20:
      if (eof) ADVANCE(21);
      ADVANCE_MAP(
        '"', 42,
        '#', 22,
        '%', 75,
        '&', 68,
        '\'', 43,
        '(', 55,
        ')', 56,
        '*', 30,
        '+', 71,
        ',', 25,
        '-', 72,
        '.', 27,
        '/', 73,
        ':', 29,
        ';', 23,
        '<', 31,
        '=', 24,
        '>', 33,
        '[', 57,
        ']', 58,
        '^', 77,
        '{', 59,
        '|', 65,
        '}', 60,
        '~', 67,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(20);
      if (lookahead > ' ' &&
          (lookahead < '%' || '>' < lookahead) &&
          (lookahead < '[' || '^' < lookahead) &&
          (lookahead < '{' || 0x9f < lookahead)) ADVANCE(79);
      END_STATE();
    case 21:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 22:
      ACCEPT_TOKEN(sym_hash_bang_line);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(22);
      END_STATE();
    case 23:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 24:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(62);
      END_STATE();
    case 25:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 26:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(76);
      END_STATE();
    case 28:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(76);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(38);
      END_STATE();
    case 29:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(26);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(69);
      if (lookahead == '=') ADVANCE(61);
      END_STATE();
    case 32:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 33:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(64);
      if (lookahead == '>') ADVANCE(70);
      END_STATE();
    case 34:
      ACCEPT_TOKEN(sym_number);
      END_STATE();
    case 35:
      ACCEPT_TOKEN(sym_number);
      ADVANCE_MAP(
        '.', 38,
        'B', 12,
        'b', 12,
        'E', 9,
        'e', 9,
        'I', 34,
        'i', 34,
        'L', 10,
        'l', 10,
        'U', 11,
        'u', 11,
        'X', 5,
        'x', 5,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(36);
      END_STATE();
    case 36:
      ACCEPT_TOKEN(sym_number);
      ADVANCE_MAP(
        '.', 38,
        'E', 9,
        'e', 9,
        'I', 34,
        'i', 34,
        'L', 10,
        'l', 10,
        'U', 11,
        'u', 11,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(36);
      END_STATE();
    case 37:
      ACCEPT_TOKEN(sym_number);
      ADVANCE_MAP(
        '.', 40,
        'I', 34,
        'i', 34,
        'L', 10,
        'l', 10,
        'P', 9,
        'p', 9,
        'U', 11,
        'u', 11,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(37);
      END_STATE();
    case 38:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(9);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(34);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(38);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(34);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(10);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(11);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(39);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(34);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(9);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(40);
      END_STATE();
    case 41:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(34);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(41);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(aux_sym__doublequote_string_content_token1);
      if (lookahead == '-') ADVANCE(45);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(44);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(46);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(aux_sym__doublequote_string_content_token1);
      if (lookahead == '-') ADVANCE(46);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(46);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(aux_sym__doublequote_string_content_token1);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(46);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(aux_sym__singlequote_string_content_token1);
      if (lookahead == '-') ADVANCE(48);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(47);
      if (lookahead != 0 &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(49);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(aux_sym__singlequote_string_content_token1);
      if (lookahead == '-') ADVANCE(49);
      if (lookahead != 0 &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(49);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(aux_sym__singlequote_string_content_token1);
      if (lookahead != 0 &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(49);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(51);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(50);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(52);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(sym_vararg_expression);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(anon_sym_TILDE_EQ);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (lookahead == '=') ADVANCE(63);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(80);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '/') ADVANCE(74);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(anon_sym_POUND);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead > ' ' &&
          lookahead != '"' &&
          lookahead != '#' &&
          (lookahead < '%' || '/' < lookahead) &&
          (lookahead < ':' || '>' < lookahead) &&
          (lookahead < '[' || '^' < lookahead) &&
          (lookahead < '{' || 0x9f < lookahead)) ADVANCE(79);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(84);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(aux_sym_comment_token1);
      if (lookahead == '-') ADVANCE(83);
      if (lookahead == '\t' ||
          lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(82);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(84);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(aux_sym_comment_token1);
      if (lookahead == '-') ADVANCE(81);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(84);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(aux_sym_comment_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(84);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'a', 1,
        'b', 2,
        'd', 3,
        'e', 4,
        'f', 5,
        'g', 6,
        'i', 7,
        'l', 8,
        'n', 9,
        'o', 10,
        'r', 11,
        't', 12,
        'u', 13,
        'w', 14,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      if (lookahead == 'n') ADVANCE(15);
      END_STATE();
    case 2:
      if (lookahead == 'r') ADVANCE(16);
      END_STATE();
    case 3:
      if (lookahead == 'o') ADVANCE(17);
      END_STATE();
    case 4:
      if (lookahead == 'l') ADVANCE(18);
      if (lookahead == 'n') ADVANCE(19);
      END_STATE();
    case 5:
      if (lookahead == 'a') ADVANCE(20);
      if (lookahead == 'o') ADVANCE(21);
      if (lookahead == 'u') ADVANCE(22);
      END_STATE();
    case 6:
      if (lookahead == 'l') ADVANCE(23);
      if (lookahead == 'o') ADVANCE(24);
      END_STATE();
    case 7:
      if (lookahead == 'f') ADVANCE(25);
      if (lookahead == 'n') ADVANCE(26);
      END_STATE();
    case 8:
      if (lookahead == 'o') ADVANCE(27);
      END_STATE();
    case 9:
      if (lookahead == 'i') ADVANCE(28);
      if (lookahead == 'o') ADVANCE(29);
      END_STATE();
    case 10:
      if (lookahead == 'r') ADVANCE(30);
      END_STATE();
    case 11:
      if (lookahead == 'e') ADVANCE(31);
      END_STATE();
    case 12:
      if (lookahead == 'h') ADVANCE(32);
      if (lookahead == 'r') ADVANCE(33);
      END_STATE();
    case 13:
      if (lookahead == 'n') ADVANCE(34);
      END_STATE();
    case 14:
      if (lookahead == 'h') ADVANCE(35);
      END_STATE();
    case 15:
      if (lookahead == 'd') ADVANCE(36);
      END_STATE();
    case 16:
      if (lookahead == 'e') ADVANCE(37);
      END_STATE();
    case 17:
      ACCEPT_TOKEN(anon_sym_do);
      END_STATE();
    case 18:
      if (lookahead == 's') ADVANCE(38);
      END_STATE();
    case 19:
      if (lookahead == 'd') ADVANCE(39);
      END_STATE();
    case 20:
      if (lookahead == 'l') ADVANCE(40);
      END_STATE();
    case 21:
      if (lookahead == 'r') ADVANCE(41);
      END_STATE();
    case 22:
      if (lookahead == 'n') ADVANCE(42);
      END_STATE();
    case 23:
      if (lookahead == 'o') ADVANCE(43);
      END_STATE();
    case 24:
      if (lookahead == 't') ADVANCE(44);
      END_STATE();
    case 25:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 26:
      ACCEPT_TOKEN(anon_sym_in);
      END_STATE();
    case 27:
      if (lookahead == 'c') ADVANCE(45);
      END_STATE();
    case 28:
      if (lookahead == 'l') ADVANCE(46);
      END_STATE();
    case 29:
      if (lookahead == 't') ADVANCE(47);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(anon_sym_or);
      END_STATE();
    case 31:
      if (lookahead == 'p') ADVANCE(48);
      if (lookahead == 't') ADVANCE(49);
      END_STATE();
    case 32:
      if (lookahead == 'e') ADVANCE(50);
      END_STATE();
    case 33:
      if (lookahead == 'u') ADVANCE(51);
      END_STATE();
    case 34:
      if (lookahead == 't') ADVANCE(52);
      END_STATE();
    case 35:
      if (lookahead == 'i') ADVANCE(53);
      END_STATE();
    case 36:
      ACCEPT_TOKEN(anon_sym_and);
      END_STATE();
    case 37:
      if (lookahead == 'a') ADVANCE(54);
      END_STATE();
    case 38:
      if (lookahead == 'e') ADVANCE(55);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(anon_sym_end);
      END_STATE();
    case 40:
      if (lookahead == 's') ADVANCE(56);
      END_STATE();
    case 41:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 42:
      if (lookahead == 'c') ADVANCE(57);
      END_STATE();
    case 43:
      if (lookahead == 'b') ADVANCE(58);
      END_STATE();
    case 44:
      if (lookahead == 'o') ADVANCE(59);
      END_STATE();
    case 45:
      if (lookahead == 'a') ADVANCE(60);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(sym_nil);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(anon_sym_not);
      END_STATE();
    case 48:
      if (lookahead == 'e') ADVANCE(61);
      END_STATE();
    case 49:
      if (lookahead == 'u') ADVANCE(62);
      END_STATE();
    case 50:
      if (lookahead == 'n') ADVANCE(63);
      END_STATE();
    case 51:
      if (lookahead == 'e') ADVANCE(64);
      END_STATE();
    case 52:
      if (lookahead == 'i') ADVANCE(65);
      END_STATE();
    case 53:
      if (lookahead == 'l') ADVANCE(66);
      END_STATE();
    case 54:
      if (lookahead == 'k') ADVANCE(67);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(anon_sym_else);
      if (lookahead == 'i') ADVANCE(68);
      END_STATE();
    case 56:
      if (lookahead == 'e') ADVANCE(69);
      END_STATE();
    case 57:
      if (lookahead == 't') ADVANCE(70);
      END_STATE();
    case 58:
      if (lookahead == 'a') ADVANCE(71);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_goto);
      END_STATE();
    case 60:
      if (lookahead == 'l') ADVANCE(72);
      END_STATE();
    case 61:
      if (lookahead == 'a') ADVANCE(73);
      END_STATE();
    case 62:
      if (lookahead == 'r') ADVANCE(74);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(anon_sym_then);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(sym_true);
      END_STATE();
    case 65:
      if (lookahead == 'l') ADVANCE(75);
      END_STATE();
    case 66:
      if (lookahead == 'e') ADVANCE(76);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(sym_break_statement);
      END_STATE();
    case 68:
      if (lookahead == 'f') ADVANCE(77);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(sym_false);
      END_STATE();
    case 70:
      if (lookahead == 'i') ADVANCE(78);
      END_STATE();
    case 71:
      if (lookahead == 'l') ADVANCE(79);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(anon_sym_local);
      END_STATE();
    case 73:
      if (lookahead == 't') ADVANCE(80);
      END_STATE();
    case 74:
      if (lookahead == 'n') ADVANCE(81);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_until);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(anon_sym_elseif);
      END_STATE();
    case 78:
      if (lookahead == 'o') ADVANCE(82);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_global);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_repeat);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 82:
      if (lookahead == 'n') ADVANCE(83);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 20, .external_lex_state = 2},
  [2] = {.lex_state = 20, .external_lex_state = 3},
  [3] = {.lex_state = 20, .external_lex_state = 3},
  [4] = {.lex_state = 20, .external_lex_state = 3},
  [5] = {.lex_state = 20, .external_lex_state = 3},
  [6] = {.lex_state = 20, .external_lex_state = 3},
  [7] = {.lex_state = 20, .external_lex_state = 3},
  [8] = {.lex_state = 20, .external_lex_state = 3},
  [9] = {.lex_state = 20, .external_lex_state = 3},
  [10] = {.lex_state = 20, .external_lex_state = 3},
  [11] = {.lex_state = 20, .external_lex_state = 3},
  [12] = {.lex_state = 20, .external_lex_state = 3},
  [13] = {.lex_state = 20, .external_lex_state = 3},
  [14] = {.lex_state = 20, .external_lex_state = 3},
  [15] = {.lex_state = 20, .external_lex_state = 3},
  [16] = {.lex_state = 20, .external_lex_state = 3},
  [17] = {.lex_state = 20, .external_lex_state = 3},
  [18] = {.lex_state = 20, .external_lex_state = 3},
  [19] = {.lex_state = 20, .external_lex_state = 3},
  [20] = {.lex_state = 0, .external_lex_state = 2},
  [21] = {.lex_state = 0, .external_lex_state = 2},
  [22] = {.lex_state = 0, .external_lex_state = 2},
  [23] = {.lex_state = 0, .external_lex_state = 2},
  [24] = {.lex_state = 0, .external_lex_state = 2},
  [25] = {.lex_state = 0, .external_lex_state = 2},
  [26] = {.lex_state = 0, .external_lex_state = 2},
  [27] = {.lex_state = 0, .external_lex_state = 2},
  [28] = {.lex_state = 0, .external_lex_state = 2},
  [29] = {.lex_state = 0, .external_lex_state = 2},
  [30] = {.lex_state = 0, .external_lex_state = 2},
  [31] = {.lex_state = 0, .external_lex_state = 2},
  [32] = {.lex_state = 0, .external_lex_state = 2},
  [33] = {.lex_state = 0, .external_lex_state = 2},
  [34] = {.lex_state = 0, .external_lex_state = 2},
  [35] = {.lex_state = 0, .external_lex_state = 2},
  [36] = {.lex_state = 0, .external_lex_state = 2},
  [37] = {.lex_state = 0, .external_lex_state = 2},
  [38] = {.lex_state = 0, .external_lex_state = 2},
  [39] = {.lex_state = 0, .external_lex_state = 2},
  [40] = {.lex_state = 0, .external_lex_state = 2},
  [41] = {.lex_state = 0, .external_lex_state = 2},
  [42] = {.lex_state = 0, .external_lex_state = 2},
  [43] = {.lex_state = 0, .external_lex_state = 2},
  [44] = {.lex_state = 0, .external_lex_state = 2},
  [45] = {.lex_state = 0, .external_lex_state = 2},
  [46] = {.lex_state = 0, .external_lex_state = 2},
  [47] = {.lex_state = 0, .external_lex_state = 2},
  [48] = {.lex_state = 0, .external_lex_state = 2},
  [49] = {.lex_state = 0, .external_lex_state = 2},
  [50] = {.lex_state = 0, .external_lex_state = 2},
  [51] = {.lex_state = 0, .external_lex_state = 2},
  [52] = {.lex_state = 0, .external_lex_state = 2},
  [53] = {.lex_state = 0, .external_lex_state = 2},
  [54] = {.lex_state = 0, .external_lex_state = 2},
  [55] = {.lex_state = 0, .external_lex_state = 2},
  [56] = {.lex_state = 0, .external_lex_state = 2},
  [57] = {.lex_state = 0, .external_lex_state = 2},
  [58] = {.lex_state = 0, .external_lex_state = 2},
  [59] = {.lex_state = 0, .external_lex_state = 2},
  [60] = {.lex_state = 19, .external_lex_state = 3},
  [61] = {.lex_state = 19, .external_lex_state = 3},
  [62] = {.lex_state = 19, .external_lex_state = 3},
  [63] = {.lex_state = 19, .external_lex_state = 3},
  [64] = {.lex_state = 19, .external_lex_state = 3},
  [65] = {.lex_state = 19, .external_lex_state = 3},
  [66] = {.lex_state = 19, .external_lex_state = 3},
  [67] = {.lex_state = 19, .external_lex_state = 3},
  [68] = {.lex_state = 19, .external_lex_state = 3},
  [69] = {.lex_state = 19, .external_lex_state = 3},
  [70] = {.lex_state = 19, .external_lex_state = 3},
  [71] = {.lex_state = 19, .external_lex_state = 3},
  [72] = {.lex_state = 19, .external_lex_state = 3},
  [73] = {.lex_state = 19, .external_lex_state = 3},
  [74] = {.lex_state = 19, .external_lex_state = 3},
  [75] = {.lex_state = 19, .external_lex_state = 3},
  [76] = {.lex_state = 20, .external_lex_state = 3},
  [77] = {.lex_state = 19, .external_lex_state = 3},
  [78] = {.lex_state = 19, .external_lex_state = 3},
  [79] = {.lex_state = 19, .external_lex_state = 3},
  [80] = {.lex_state = 19, .external_lex_state = 3},
  [81] = {.lex_state = 19, .external_lex_state = 3},
  [82] = {.lex_state = 19, .external_lex_state = 3},
  [83] = {.lex_state = 19, .external_lex_state = 3},
  [84] = {.lex_state = 19, .external_lex_state = 3},
  [85] = {.lex_state = 19, .external_lex_state = 3},
  [86] = {.lex_state = 19, .external_lex_state = 3},
  [87] = {.lex_state = 19, .external_lex_state = 3},
  [88] = {.lex_state = 19, .external_lex_state = 3},
  [89] = {.lex_state = 19, .external_lex_state = 3},
  [90] = {.lex_state = 19, .external_lex_state = 3},
  [91] = {.lex_state = 19, .external_lex_state = 3},
  [92] = {.lex_state = 19, .external_lex_state = 3},
  [93] = {.lex_state = 19, .external_lex_state = 3},
  [94] = {.lex_state = 19, .external_lex_state = 3},
  [95] = {.lex_state = 19, .external_lex_state = 3},
  [96] = {.lex_state = 19, .external_lex_state = 3},
  [97] = {.lex_state = 19, .external_lex_state = 3},
  [98] = {.lex_state = 19, .external_lex_state = 3},
  [99] = {.lex_state = 0, .external_lex_state = 2},
  [100] = {.lex_state = 0, .external_lex_state = 2},
  [101] = {.lex_state = 20, .external_lex_state = 3},
  [102] = {.lex_state = 0, .external_lex_state = 2},
  [103] = {.lex_state = 0, .external_lex_state = 2},
  [104] = {.lex_state = 0, .external_lex_state = 2},
  [105] = {.lex_state = 0, .external_lex_state = 2},
  [106] = {.lex_state = 0, .external_lex_state = 2},
  [107] = {.lex_state = 0, .external_lex_state = 2},
  [108] = {.lex_state = 0, .external_lex_state = 2},
  [109] = {.lex_state = 0, .external_lex_state = 2},
  [110] = {.lex_state = 0, .external_lex_state = 2},
  [111] = {.lex_state = 0, .external_lex_state = 2},
  [112] = {.lex_state = 0, .external_lex_state = 2},
  [113] = {.lex_state = 0, .external_lex_state = 2},
  [114] = {.lex_state = 0, .external_lex_state = 2},
  [115] = {.lex_state = 0, .external_lex_state = 2},
  [116] = {.lex_state = 0, .external_lex_state = 2},
  [117] = {.lex_state = 0, .external_lex_state = 2},
  [118] = {.lex_state = 0, .external_lex_state = 2},
  [119] = {.lex_state = 0, .external_lex_state = 2},
  [120] = {.lex_state = 0, .external_lex_state = 2},
  [121] = {.lex_state = 0, .external_lex_state = 2},
  [122] = {.lex_state = 0, .external_lex_state = 2},
  [123] = {.lex_state = 0, .external_lex_state = 2},
  [124] = {.lex_state = 0, .external_lex_state = 2},
  [125] = {.lex_state = 0, .external_lex_state = 2},
  [126] = {.lex_state = 0, .external_lex_state = 2},
  [127] = {.lex_state = 0, .external_lex_state = 2},
  [128] = {.lex_state = 0, .external_lex_state = 2},
  [129] = {.lex_state = 0, .external_lex_state = 2},
  [130] = {.lex_state = 0, .external_lex_state = 2},
  [131] = {.lex_state = 0, .external_lex_state = 2},
  [132] = {.lex_state = 0, .external_lex_state = 2},
  [133] = {.lex_state = 0, .external_lex_state = 2},
  [134] = {.lex_state = 0, .external_lex_state = 2},
  [135] = {.lex_state = 0, .external_lex_state = 2},
  [136] = {.lex_state = 0, .external_lex_state = 2},
  [137] = {.lex_state = 0, .external_lex_state = 2},
  [138] = {.lex_state = 0, .external_lex_state = 2},
  [139] = {.lex_state = 0, .external_lex_state = 2},
  [140] = {.lex_state = 0, .external_lex_state = 2},
  [141] = {.lex_state = 0, .external_lex_state = 2},
  [142] = {.lex_state = 0, .external_lex_state = 2},
  [143] = {.lex_state = 0, .external_lex_state = 2},
  [144] = {.lex_state = 0, .external_lex_state = 2},
  [145] = {.lex_state = 0, .external_lex_state = 2},
  [146] = {.lex_state = 0, .external_lex_state = 2},
  [147] = {.lex_state = 0, .external_lex_state = 2},
  [148] = {.lex_state = 0, .external_lex_state = 2},
  [149] = {.lex_state = 0, .external_lex_state = 2},
  [150] = {.lex_state = 0, .external_lex_state = 2},
  [151] = {.lex_state = 0, .external_lex_state = 2},
  [152] = {.lex_state = 0, .external_lex_state = 2},
  [153] = {.lex_state = 0, .external_lex_state = 2},
  [154] = {.lex_state = 0, .external_lex_state = 2},
  [155] = {.lex_state = 0, .external_lex_state = 2},
  [156] = {.lex_state = 0, .external_lex_state = 2},
  [157] = {.lex_state = 0, .external_lex_state = 2},
  [158] = {.lex_state = 0, .external_lex_state = 2},
  [159] = {.lex_state = 0, .external_lex_state = 2},
  [160] = {.lex_state = 0, .external_lex_state = 2},
  [161] = {.lex_state = 0, .external_lex_state = 2},
  [162] = {.lex_state = 0, .external_lex_state = 2},
  [163] = {.lex_state = 0, .external_lex_state = 2},
  [164] = {.lex_state = 0, .external_lex_state = 2},
  [165] = {.lex_state = 0, .external_lex_state = 2},
  [166] = {.lex_state = 19, .external_lex_state = 3},
  [167] = {.lex_state = 20, .external_lex_state = 3},
  [168] = {.lex_state = 0, .external_lex_state = 2},
  [169] = {.lex_state = 0, .external_lex_state = 2},
  [170] = {.lex_state = 20, .external_lex_state = 3},
  [171] = {.lex_state = 0, .external_lex_state = 2},
  [172] = {.lex_state = 20, .external_lex_state = 3},
  [173] = {.lex_state = 0, .external_lex_state = 2},
  [174] = {.lex_state = 0, .external_lex_state = 3},
  [175] = {.lex_state = 20, .external_lex_state = 3},
  [176] = {.lex_state = 0, .external_lex_state = 2},
  [177] = {.lex_state = 20, .external_lex_state = 3},
  [178] = {.lex_state = 0, .external_lex_state = 2},
  [179] = {.lex_state = 0, .external_lex_state = 2},
  [180] = {.lex_state = 0, .external_lex_state = 2},
  [181] = {.lex_state = 0, .external_lex_state = 2},
  [182] = {.lex_state = 0, .external_lex_state = 2},
  [183] = {.lex_state = 0, .external_lex_state = 2},
  [184] = {.lex_state = 0, .external_lex_state = 2},
  [185] = {.lex_state = 0, .external_lex_state = 2},
  [186] = {.lex_state = 0, .external_lex_state = 2},
  [187] = {.lex_state = 0, .external_lex_state = 3},
  [188] = {.lex_state = 0, .external_lex_state = 2},
  [189] = {.lex_state = 0, .external_lex_state = 2},
  [190] = {.lex_state = 0, .external_lex_state = 2},
  [191] = {.lex_state = 19, .external_lex_state = 2},
  [192] = {.lex_state = 0, .external_lex_state = 2},
  [193] = {.lex_state = 2, .external_lex_state = 2},
  [194] = {.lex_state = 0, .external_lex_state = 2},
  [195] = {.lex_state = 0, .external_lex_state = 2},
  [196] = {.lex_state = 1, .external_lex_state = 2},
  [197] = {.lex_state = 2, .external_lex_state = 2},
  [198] = {.lex_state = 1, .external_lex_state = 2},
  [199] = {.lex_state = 2, .external_lex_state = 2},
  [200] = {.lex_state = 0, .external_lex_state = 2},
  [201] = {.lex_state = 0, .external_lex_state = 2},
  [202] = {.lex_state = 1, .external_lex_state = 2},
  [203] = {.lex_state = 2, .external_lex_state = 2},
  [204] = {.lex_state = 1, .external_lex_state = 2},
  [205] = {.lex_state = 2, .external_lex_state = 2},
  [206] = {.lex_state = 1, .external_lex_state = 2},
  [207] = {.lex_state = 0, .external_lex_state = 2},
  [208] = {.lex_state = 2, .external_lex_state = 2},
  [209] = {.lex_state = 0, .external_lex_state = 2},
  [210] = {.lex_state = 1, .external_lex_state = 2},
  [211] = {.lex_state = 0, .external_lex_state = 2},
  [212] = {.lex_state = 0, .external_lex_state = 2},
  [213] = {.lex_state = 0, .external_lex_state = 2},
  [214] = {.lex_state = 19, .external_lex_state = 2},
  [215] = {.lex_state = 0, .external_lex_state = 2},
  [216] = {.lex_state = 0, .external_lex_state = 2},
  [217] = {.lex_state = 0, .external_lex_state = 2},
  [218] = {.lex_state = 0, .external_lex_state = 2},
  [219] = {.lex_state = 0, .external_lex_state = 2},
  [220] = {.lex_state = 0, .external_lex_state = 2},
  [221] = {.lex_state = 19, .external_lex_state = 2},
  [222] = {.lex_state = 0, .external_lex_state = 2},
  [223] = {.lex_state = 0, .external_lex_state = 2},
  [224] = {.lex_state = 0, .external_lex_state = 2},
  [225] = {.lex_state = 20, .external_lex_state = 2},
  [226] = {.lex_state = 20, .external_lex_state = 2},
  [227] = {.lex_state = 20, .external_lex_state = 2},
  [228] = {.lex_state = 20, .external_lex_state = 2},
  [229] = {.lex_state = 0, .external_lex_state = 2},
  [230] = {.lex_state = 0, .external_lex_state = 2},
  [231] = {.lex_state = 0, .external_lex_state = 2},
  [232] = {.lex_state = 0, .external_lex_state = 4},
  [233] = {.lex_state = 0, .external_lex_state = 2},
  [234] = {.lex_state = 0, .external_lex_state = 2},
  [235] = {.lex_state = 0, .external_lex_state = 2},
  [236] = {.lex_state = 0, .external_lex_state = 2},
  [237] = {.lex_state = 19, .external_lex_state = 2},
  [238] = {.lex_state = 0, .external_lex_state = 2},
  [239] = {.lex_state = 0, .external_lex_state = 2},
  [240] = {.lex_state = 0, .external_lex_state = 2},
  [241] = {.lex_state = 0, .external_lex_state = 2},
  [242] = {.lex_state = 0, .external_lex_state = 2},
  [243] = {.lex_state = 0, .external_lex_state = 2},
  [244] = {.lex_state = 0, .external_lex_state = 2},
  [245] = {.lex_state = 0, .external_lex_state = 2},
  [246] = {.lex_state = 0, .external_lex_state = 2},
  [247] = {.lex_state = 0, .external_lex_state = 2},
  [248] = {.lex_state = 0, .external_lex_state = 2},
  [249] = {.lex_state = 0, .external_lex_state = 2},
  [250] = {.lex_state = 0, .external_lex_state = 2},
  [251] = {.lex_state = 0, .external_lex_state = 2},
  [252] = {.lex_state = 0, .external_lex_state = 5},
  [253] = {.lex_state = 0, .external_lex_state = 6},
  [254] = {.lex_state = 0, .external_lex_state = 2},
  [255] = {.lex_state = 0, .external_lex_state = 2},
  [256] = {.lex_state = 0, .external_lex_state = 2},
  [257] = {.lex_state = 0, .external_lex_state = 2},
  [258] = {.lex_state = 0, .external_lex_state = 2},
  [259] = {.lex_state = 0, .external_lex_state = 2},
  [260] = {.lex_state = 0, .external_lex_state = 2},
  [261] = {.lex_state = 0, .external_lex_state = 2},
  [262] = {.lex_state = 0, .external_lex_state = 2},
  [263] = {.lex_state = 0, .external_lex_state = 2},
  [264] = {.lex_state = 82, .external_lex_state = 2},
  [265] = {.lex_state = 0, .external_lex_state = 2},
  [266] = {.lex_state = 0, .external_lex_state = 2},
  [267] = {.lex_state = 0, .external_lex_state = 2},
  [268] = {.lex_state = 0, .external_lex_state = 2},
  [269] = {.lex_state = 0, .external_lex_state = 2},
  [270] = {.lex_state = 0, .external_lex_state = 2},
  [271] = {.lex_state = 0, .external_lex_state = 2},
  [272] = {.lex_state = 0, .external_lex_state = 2},
  [273] = {.lex_state = 0, .external_lex_state = 2},
  [274] = {.lex_state = 0, .external_lex_state = 4},
  [275] = {.lex_state = 0, .external_lex_state = 7},
  [276] = {.lex_state = 0, .external_lex_state = 2},
  [277] = {.lex_state = 0, .external_lex_state = 2},
  [278] = {.lex_state = 0, .external_lex_state = 7},
  [279] = {.lex_state = 0, .external_lex_state = 2},
  [280] = {(TSStateId)(-1),},
  [281] = {(TSStateId)(-1),},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [sym_comment] = STATE(0),
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [sym_break_statement] = ACTIONS(1),
    [anon_sym_goto] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_end] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_repeat] = ACTIONS(1),
    [anon_sym_until] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_then] = ACTIONS(1),
    [anon_sym_elseif] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_local] = ACTIONS(1),
    [anon_sym_global] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [sym_nil] = ACTIONS(1),
    [sym_false] = ACTIONS(1),
    [sym_true] = ACTIONS(1),
    [sym_number] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_or] = ACTIONS(1),
    [anon_sym_and] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_TILDE_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_SLASH_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_DOT_DOT] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_not] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(1),
    [anon_sym_DASH_DASH] = ACTIONS(3),
    [sym__block_comment_start] = ACTIONS(5),
    [sym__block_comment_content] = ACTIONS(1),
    [sym__block_comment_end] = ACTIONS(1),
    [sym__block_string_start] = ACTIONS(1),
    [sym__block_string_content] = ACTIONS(1),
    [sym__block_string_end] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_chunk] = STATE(263),
    [sym_statement] = STATE(161),
    [sym_return_statement] = STATE(261),
    [sym_empty_statement] = STATE(160),
    [sym_assignment_statement] = STATE(160),
    [sym__variable_assignment_varlist] = STATE(255),
    [sym_label_statement] = STATE(160),
    [sym_goto_statement] = STATE(160),
    [sym_do_statement] = STATE(160),
    [sym_while_statement] = STATE(160),
    [sym_repeat_statement] = STATE(160),
    [sym_if_statement] = STATE(160),
    [sym_for_statement] = STATE(160),
    [sym_declaration] = STATE(132),
    [sym_function_declaration] = STATE(134),
    [sym__local_function_declaration] = STATE(137),
    [sym__global_function_declaration] = STATE(139),
    [sym_variable_declaration] = STATE(131),
    [sym__global_variable_declaration] = STATE(142),
    [sym__global_implicit_variable_declaration] = STATE(143),
    [sym__prefix_expression] = STATE(170),
    [sym_variable] = STATE(172),
    [sym_bracket_index_expression] = STATE(2),
    [sym_dot_index_expression] = STATE(2),
    [sym_function_call] = STATE(101),
    [sym_method_index_expression] = STATE(174),
    [sym_parenthesized_expression] = STATE(177),
    [sym_comment] = STATE(1),
    [sym__contextual_keyword] = STATE(2),
    [aux_sym_chunk_repeat1] = STATE(55),
    [ts_builtin_sym_end] = ACTIONS(7),
    [sym_identifier] = ACTIONS(9),
    [sym_hash_bang_line] = ACTIONS(11),
    [anon_sym_return] = ACTIONS(13),
    [anon_sym_SEMI] = ACTIONS(15),
    [anon_sym_COLON_COLON] = ACTIONS(17),
    [sym_break_statement] = ACTIONS(19),
    [anon_sym_goto] = ACTIONS(21),
    [anon_sym_do] = ACTIONS(23),
    [anon_sym_while] = ACTIONS(25),
    [anon_sym_repeat] = ACTIONS(27),
    [anon_sym_if] = ACTIONS(29),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_function] = ACTIONS(33),
    [anon_sym_local] = ACTIONS(35),
    [anon_sym_global] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(3),
    [sym__block_comment_start] = ACTIONS(5),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(2), 1,
      sym_comment,
    ACTIONS(41), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(43), 27,
      anon_sym_return,
      anon_sym_EQ,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [68] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(3), 1,
      sym_comment,
    ACTIONS(45), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(47), 27,
      anon_sym_return,
      anon_sym_EQ,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [136] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(4), 1,
      sym_comment,
    ACTIONS(49), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(51), 27,
      anon_sym_return,
      anon_sym_EQ,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [204] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(5), 1,
      sym_comment,
    ACTIONS(53), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(55), 27,
      anon_sym_return,
      anon_sym_EQ,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [272] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(6), 1,
      sym_comment,
    ACTIONS(59), 26,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(57), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
  [339] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(7), 1,
      sym_comment,
    ACTIONS(65), 2,
      anon_sym_DOT,
      anon_sym_COLON,
    ACTIONS(67), 6,
      sym__block_string_start,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
    ACTIONS(61), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(63), 24,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [410] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(8), 1,
      sym_comment,
    ACTIONS(71), 26,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(69), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
  [477] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(9), 1,
      sym_comment,
    ACTIONS(75), 26,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(73), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
  [544] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(10), 1,
      sym_comment,
    ACTIONS(79), 26,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(77), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
  [611] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(11), 1,
      sym_comment,
    ACTIONS(83), 26,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(81), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
  [678] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(12), 1,
      sym_comment,
    ACTIONS(87), 26,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(85), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
  [745] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(13), 1,
      sym_comment,
    ACTIONS(91), 26,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(89), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
  [812] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(14), 1,
      sym_comment,
    ACTIONS(95), 26,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(93), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
  [879] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(15), 1,
      sym_comment,
    ACTIONS(99), 26,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(97), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
  [946] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(16), 1,
      sym_comment,
    ACTIONS(95), 26,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(93), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
  [1013] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(17), 1,
      sym_comment,
    ACTIONS(103), 26,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(101), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
  [1080] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(18), 1,
      sym_comment,
    ACTIONS(107), 26,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(105), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
  [1147] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(19), 1,
      sym_comment,
    ACTIONS(111), 26,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
    ACTIONS(109), 27,
      sym__block_string_start,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
  [1214] = 43,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(15), 1,
      anon_sym_SEMI,
    ACTIONS(17), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19), 1,
      sym_break_statement,
    ACTIONS(21), 1,
      anon_sym_goto,
    ACTIONS(23), 1,
      anon_sym_do,
    ACTIONS(25), 1,
      anon_sym_while,
    ACTIONS(27), 1,
      anon_sym_repeat,
    ACTIONS(29), 1,
      anon_sym_if,
    ACTIONS(31), 1,
      anon_sym_for,
    ACTIONS(33), 1,
      anon_sym_function,
    ACTIONS(35), 1,
      anon_sym_local,
    ACTIONS(37), 1,
      anon_sym_global,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(113), 1,
      anon_sym_return,
    ACTIONS(115), 1,
      anon_sym_end,
    ACTIONS(117), 1,
      anon_sym_elseif,
    ACTIONS(119), 1,
      anon_sym_else,
    STATE(20), 1,
      sym_comment,
    STATE(21), 1,
      aux_sym_chunk_repeat1,
    STATE(101), 1,
      sym_function_call,
    STATE(131), 1,
      sym_variable_declaration,
    STATE(132), 1,
      sym_declaration,
    STATE(134), 1,
      sym_function_declaration,
    STATE(137), 1,
      sym__local_function_declaration,
    STATE(139), 1,
      sym__global_function_declaration,
    STATE(142), 1,
      sym__global_variable_declaration,
    STATE(143), 1,
      sym__global_implicit_variable_declaration,
    STATE(161), 1,
      sym_statement,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(172), 1,
      sym_variable,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(177), 1,
      sym_parenthesized_expression,
    STATE(179), 1,
      aux_sym_if_statement_repeat1,
    STATE(180), 1,
      sym__block,
    STATE(194), 1,
      sym_return_statement,
    STATE(213), 1,
      sym_elseif_statement,
    STATE(233), 1,
      sym_else_statement,
    STATE(255), 1,
      sym__variable_assignment_varlist,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(160), 9,
      sym_empty_statement,
      sym_assignment_statement,
      sym_label_statement,
      sym_goto_statement,
      sym_do_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_if_statement,
      sym_for_statement,
  [1354] = 37,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(15), 1,
      anon_sym_SEMI,
    ACTIONS(17), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19), 1,
      sym_break_statement,
    ACTIONS(21), 1,
      anon_sym_goto,
    ACTIONS(23), 1,
      anon_sym_do,
    ACTIONS(25), 1,
      anon_sym_while,
    ACTIONS(27), 1,
      anon_sym_repeat,
    ACTIONS(29), 1,
      anon_sym_if,
    ACTIONS(31), 1,
      anon_sym_for,
    ACTIONS(33), 1,
      anon_sym_function,
    ACTIONS(35), 1,
      anon_sym_local,
    ACTIONS(37), 1,
      anon_sym_global,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(113), 1,
      anon_sym_return,
    STATE(21), 1,
      sym_comment,
    STATE(22), 1,
      aux_sym_chunk_repeat1,
    STATE(101), 1,
      sym_function_call,
    STATE(131), 1,
      sym_variable_declaration,
    STATE(132), 1,
      sym_declaration,
    STATE(134), 1,
      sym_function_declaration,
    STATE(137), 1,
      sym__local_function_declaration,
    STATE(139), 1,
      sym__global_function_declaration,
    STATE(142), 1,
      sym__global_variable_declaration,
    STATE(143), 1,
      sym__global_implicit_variable_declaration,
    STATE(161), 1,
      sym_statement,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(172), 1,
      sym_variable,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(177), 1,
      sym_parenthesized_expression,
    STATE(192), 1,
      sym_return_statement,
    STATE(255), 1,
      sym__variable_assignment_varlist,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    ACTIONS(121), 4,
      anon_sym_end,
      anon_sym_until,
      anon_sym_elseif,
      anon_sym_else,
    STATE(160), 9,
      sym_empty_statement,
      sym_assignment_statement,
      sym_label_statement,
      sym_goto_statement,
      sym_do_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_if_statement,
      sym_for_statement,
  [1479] = 35,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(123), 1,
      ts_builtin_sym_end,
    ACTIONS(125), 1,
      sym_identifier,
    ACTIONS(130), 1,
      anon_sym_SEMI,
    ACTIONS(133), 1,
      anon_sym_COLON_COLON,
    ACTIONS(136), 1,
      sym_break_statement,
    ACTIONS(139), 1,
      anon_sym_goto,
    ACTIONS(142), 1,
      anon_sym_do,
    ACTIONS(145), 1,
      anon_sym_while,
    ACTIONS(148), 1,
      anon_sym_repeat,
    ACTIONS(151), 1,
      anon_sym_if,
    ACTIONS(154), 1,
      anon_sym_for,
    ACTIONS(157), 1,
      anon_sym_function,
    ACTIONS(160), 1,
      anon_sym_local,
    ACTIONS(163), 1,
      anon_sym_global,
    ACTIONS(166), 1,
      anon_sym_LPAREN,
    STATE(101), 1,
      sym_function_call,
    STATE(131), 1,
      sym_variable_declaration,
    STATE(132), 1,
      sym_declaration,
    STATE(134), 1,
      sym_function_declaration,
    STATE(137), 1,
      sym__local_function_declaration,
    STATE(139), 1,
      sym__global_function_declaration,
    STATE(142), 1,
      sym__global_variable_declaration,
    STATE(143), 1,
      sym__global_implicit_variable_declaration,
    STATE(161), 1,
      sym_statement,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(172), 1,
      sym_variable,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(177), 1,
      sym_parenthesized_expression,
    STATE(255), 1,
      sym__variable_assignment_varlist,
    STATE(22), 2,
      sym_comment,
      aux_sym_chunk_repeat1,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    ACTIONS(128), 5,
      anon_sym_return,
      anon_sym_end,
      anon_sym_until,
      anon_sym_elseif,
      anon_sym_else,
    STATE(160), 9,
      sym_empty_statement,
      sym_assignment_statement,
      sym_label_statement,
      sym_goto_statement,
      sym_do_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_if_statement,
      sym_for_statement,
  [1600] = 38,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(15), 1,
      anon_sym_SEMI,
    ACTIONS(17), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19), 1,
      sym_break_statement,
    ACTIONS(21), 1,
      anon_sym_goto,
    ACTIONS(23), 1,
      anon_sym_do,
    ACTIONS(25), 1,
      anon_sym_while,
    ACTIONS(27), 1,
      anon_sym_repeat,
    ACTIONS(29), 1,
      anon_sym_if,
    ACTIONS(31), 1,
      anon_sym_for,
    ACTIONS(33), 1,
      anon_sym_function,
    ACTIONS(35), 1,
      anon_sym_local,
    ACTIONS(37), 1,
      anon_sym_global,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(113), 1,
      anon_sym_return,
    STATE(21), 1,
      aux_sym_chunk_repeat1,
    STATE(23), 1,
      sym_comment,
    STATE(101), 1,
      sym_function_call,
    STATE(131), 1,
      sym_variable_declaration,
    STATE(132), 1,
      sym_declaration,
    STATE(134), 1,
      sym_function_declaration,
    STATE(137), 1,
      sym__local_function_declaration,
    STATE(139), 1,
      sym__global_function_declaration,
    STATE(142), 1,
      sym__global_variable_declaration,
    STATE(143), 1,
      sym__global_implicit_variable_declaration,
    STATE(161), 1,
      sym_statement,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(172), 1,
      sym_variable,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(177), 1,
      sym_parenthesized_expression,
    STATE(194), 1,
      sym_return_statement,
    STATE(224), 1,
      sym__block,
    STATE(255), 1,
      sym__variable_assignment_varlist,
    ACTIONS(169), 3,
      anon_sym_end,
      anon_sym_elseif,
      anon_sym_else,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(160), 9,
      sym_empty_statement,
      sym_assignment_statement,
      sym_label_statement,
      sym_goto_statement,
      sym_do_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_if_statement,
      sym_for_statement,
  [1727] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(24), 1,
      sym_comment,
    ACTIONS(105), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(107), 24,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [1787] = 13,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    STATE(25), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(171), 13,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
    ACTIONS(173), 22,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      sym_identifier,
  [1863] = 17,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    STATE(26), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(171), 8,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(173), 19,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_or,
      anon_sym_and,
      sym_identifier,
  [1947] = 18,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(199), 1,
      anon_sym_and,
    STATE(27), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(171), 8,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(173), 18,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_or,
      sym_identifier,
  [2033] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(189), 1,
      anon_sym_CARET,
    STATE(28), 1,
      sym_comment,
    ACTIONS(171), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(173), 24,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [2095] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(29), 1,
      sym_comment,
    ACTIONS(201), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(203), 24,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [2155] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(30), 1,
      sym_comment,
    ACTIONS(109), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(111), 24,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [2215] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(31), 1,
      sym_comment,
    ACTIONS(57), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(59), 24,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [2275] = 15,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    STATE(32), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(171), 12,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(173), 21,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      sym_identifier,
  [2355] = 14,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    STATE(33), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(171), 13,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
    ACTIONS(173), 21,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      sym_identifier,
  [2433] = 12,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    STATE(34), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(171), 14,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(173), 22,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      sym_identifier,
  [2507] = 11,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    STATE(35), 1,
      sym_comment,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(171), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(173), 22,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      sym_identifier,
  [2579] = 8,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(189), 1,
      anon_sym_CARET,
    STATE(36), 1,
      sym_comment,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(171), 18,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(173), 23,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      sym_identifier,
  [2645] = 11,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    STATE(37), 1,
      sym_comment,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(171), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(173), 22,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      sym_identifier,
  [2717] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(189), 1,
      anon_sym_CARET,
    STATE(38), 1,
      sym_comment,
    ACTIONS(171), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(173), 24,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [2779] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(39), 1,
      sym_comment,
    ACTIONS(101), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(103), 24,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [2839] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(40), 1,
      sym_comment,
    ACTIONS(61), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(63), 24,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [2899] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(41), 1,
      sym_comment,
    ACTIONS(93), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(95), 24,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [2959] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(42), 1,
      sym_comment,
    ACTIONS(205), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(207), 24,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [3019] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(43), 1,
      sym_comment,
    ACTIONS(209), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(211), 24,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [3079] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(44), 1,
      sym_comment,
    ACTIONS(97), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(99), 24,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [3139] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(45), 1,
      sym_comment,
    ACTIONS(93), 22,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
    ACTIONS(95), 24,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [3199] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(189), 1,
      anon_sym_CARET,
    STATE(46), 1,
      sym_comment,
    ACTIONS(213), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(215), 24,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_then,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
      sym_identifier,
  [3261] = 38,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(15), 1,
      anon_sym_SEMI,
    ACTIONS(17), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19), 1,
      sym_break_statement,
    ACTIONS(21), 1,
      anon_sym_goto,
    ACTIONS(23), 1,
      anon_sym_do,
    ACTIONS(25), 1,
      anon_sym_while,
    ACTIONS(27), 1,
      anon_sym_repeat,
    ACTIONS(29), 1,
      anon_sym_if,
    ACTIONS(31), 1,
      anon_sym_for,
    ACTIONS(33), 1,
      anon_sym_function,
    ACTIONS(35), 1,
      anon_sym_local,
    ACTIONS(37), 1,
      anon_sym_global,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(113), 1,
      anon_sym_return,
    ACTIONS(217), 1,
      anon_sym_end,
    STATE(21), 1,
      aux_sym_chunk_repeat1,
    STATE(47), 1,
      sym_comment,
    STATE(101), 1,
      sym_function_call,
    STATE(131), 1,
      sym_variable_declaration,
    STATE(132), 1,
      sym_declaration,
    STATE(134), 1,
      sym_function_declaration,
    STATE(137), 1,
      sym__local_function_declaration,
    STATE(139), 1,
      sym__global_function_declaration,
    STATE(142), 1,
      sym__global_variable_declaration,
    STATE(143), 1,
      sym__global_implicit_variable_declaration,
    STATE(161), 1,
      sym_statement,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(172), 1,
      sym_variable,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(177), 1,
      sym_parenthesized_expression,
    STATE(194), 1,
      sym_return_statement,
    STATE(255), 1,
      sym__variable_assignment_varlist,
    STATE(269), 1,
      sym__block,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(160), 9,
      sym_empty_statement,
      sym_assignment_statement,
      sym_label_statement,
      sym_goto_statement,
      sym_do_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_if_statement,
      sym_for_statement,
  [3386] = 38,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(15), 1,
      anon_sym_SEMI,
    ACTIONS(17), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19), 1,
      sym_break_statement,
    ACTIONS(21), 1,
      anon_sym_goto,
    ACTIONS(23), 1,
      anon_sym_do,
    ACTIONS(25), 1,
      anon_sym_while,
    ACTIONS(27), 1,
      anon_sym_repeat,
    ACTIONS(29), 1,
      anon_sym_if,
    ACTIONS(31), 1,
      anon_sym_for,
    ACTIONS(33), 1,
      anon_sym_function,
    ACTIONS(35), 1,
      anon_sym_local,
    ACTIONS(37), 1,
      anon_sym_global,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(113), 1,
      anon_sym_return,
    ACTIONS(219), 1,
      anon_sym_until,
    STATE(21), 1,
      aux_sym_chunk_repeat1,
    STATE(48), 1,
      sym_comment,
    STATE(101), 1,
      sym_function_call,
    STATE(131), 1,
      sym_variable_declaration,
    STATE(132), 1,
      sym_declaration,
    STATE(134), 1,
      sym_function_declaration,
    STATE(137), 1,
      sym__local_function_declaration,
    STATE(139), 1,
      sym__global_function_declaration,
    STATE(142), 1,
      sym__global_variable_declaration,
    STATE(143), 1,
      sym__global_implicit_variable_declaration,
    STATE(161), 1,
      sym_statement,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(172), 1,
      sym_variable,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(177), 1,
      sym_parenthesized_expression,
    STATE(194), 1,
      sym_return_statement,
    STATE(241), 1,
      sym__block,
    STATE(255), 1,
      sym__variable_assignment_varlist,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(160), 9,
      sym_empty_statement,
      sym_assignment_statement,
      sym_label_statement,
      sym_goto_statement,
      sym_do_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_if_statement,
      sym_for_statement,
  [3511] = 38,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(15), 1,
      anon_sym_SEMI,
    ACTIONS(17), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19), 1,
      sym_break_statement,
    ACTIONS(21), 1,
      anon_sym_goto,
    ACTIONS(23), 1,
      anon_sym_do,
    ACTIONS(25), 1,
      anon_sym_while,
    ACTIONS(27), 1,
      anon_sym_repeat,
    ACTIONS(29), 1,
      anon_sym_if,
    ACTIONS(31), 1,
      anon_sym_for,
    ACTIONS(33), 1,
      anon_sym_function,
    ACTIONS(35), 1,
      anon_sym_local,
    ACTIONS(37), 1,
      anon_sym_global,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(113), 1,
      anon_sym_return,
    ACTIONS(221), 1,
      anon_sym_end,
    STATE(21), 1,
      aux_sym_chunk_repeat1,
    STATE(49), 1,
      sym_comment,
    STATE(101), 1,
      sym_function_call,
    STATE(131), 1,
      sym_variable_declaration,
    STATE(132), 1,
      sym_declaration,
    STATE(134), 1,
      sym_function_declaration,
    STATE(137), 1,
      sym__local_function_declaration,
    STATE(139), 1,
      sym__global_function_declaration,
    STATE(142), 1,
      sym__global_variable_declaration,
    STATE(143), 1,
      sym__global_implicit_variable_declaration,
    STATE(161), 1,
      sym_statement,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(172), 1,
      sym_variable,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(177), 1,
      sym_parenthesized_expression,
    STATE(194), 1,
      sym_return_statement,
    STATE(234), 1,
      sym__block,
    STATE(255), 1,
      sym__variable_assignment_varlist,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(160), 9,
      sym_empty_statement,
      sym_assignment_statement,
      sym_label_statement,
      sym_goto_statement,
      sym_do_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_if_statement,
      sym_for_statement,
  [3636] = 38,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(15), 1,
      anon_sym_SEMI,
    ACTIONS(17), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19), 1,
      sym_break_statement,
    ACTIONS(21), 1,
      anon_sym_goto,
    ACTIONS(23), 1,
      anon_sym_do,
    ACTIONS(25), 1,
      anon_sym_while,
    ACTIONS(27), 1,
      anon_sym_repeat,
    ACTIONS(29), 1,
      anon_sym_if,
    ACTIONS(31), 1,
      anon_sym_for,
    ACTIONS(33), 1,
      anon_sym_function,
    ACTIONS(35), 1,
      anon_sym_local,
    ACTIONS(37), 1,
      anon_sym_global,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(113), 1,
      anon_sym_return,
    ACTIONS(223), 1,
      anon_sym_end,
    STATE(21), 1,
      aux_sym_chunk_repeat1,
    STATE(50), 1,
      sym_comment,
    STATE(101), 1,
      sym_function_call,
    STATE(131), 1,
      sym_variable_declaration,
    STATE(132), 1,
      sym_declaration,
    STATE(134), 1,
      sym_function_declaration,
    STATE(137), 1,
      sym__local_function_declaration,
    STATE(139), 1,
      sym__global_function_declaration,
    STATE(142), 1,
      sym__global_variable_declaration,
    STATE(143), 1,
      sym__global_implicit_variable_declaration,
    STATE(161), 1,
      sym_statement,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(172), 1,
      sym_variable,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(177), 1,
      sym_parenthesized_expression,
    STATE(194), 1,
      sym_return_statement,
    STATE(255), 1,
      sym__variable_assignment_varlist,
    STATE(279), 1,
      sym__block,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(160), 9,
      sym_empty_statement,
      sym_assignment_statement,
      sym_label_statement,
      sym_goto_statement,
      sym_do_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_if_statement,
      sym_for_statement,
  [3761] = 38,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(15), 1,
      anon_sym_SEMI,
    ACTIONS(17), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19), 1,
      sym_break_statement,
    ACTIONS(21), 1,
      anon_sym_goto,
    ACTIONS(23), 1,
      anon_sym_do,
    ACTIONS(25), 1,
      anon_sym_while,
    ACTIONS(27), 1,
      anon_sym_repeat,
    ACTIONS(29), 1,
      anon_sym_if,
    ACTIONS(31), 1,
      anon_sym_for,
    ACTIONS(33), 1,
      anon_sym_function,
    ACTIONS(35), 1,
      anon_sym_local,
    ACTIONS(37), 1,
      anon_sym_global,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(113), 1,
      anon_sym_return,
    ACTIONS(225), 1,
      anon_sym_end,
    STATE(21), 1,
      aux_sym_chunk_repeat1,
    STATE(51), 1,
      sym_comment,
    STATE(101), 1,
      sym_function_call,
    STATE(131), 1,
      sym_variable_declaration,
    STATE(132), 1,
      sym_declaration,
    STATE(134), 1,
      sym_function_declaration,
    STATE(137), 1,
      sym__local_function_declaration,
    STATE(139), 1,
      sym__global_function_declaration,
    STATE(142), 1,
      sym__global_variable_declaration,
    STATE(143), 1,
      sym__global_implicit_variable_declaration,
    STATE(161), 1,
      sym_statement,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(172), 1,
      sym_variable,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(177), 1,
      sym_parenthesized_expression,
    STATE(194), 1,
      sym_return_statement,
    STATE(255), 1,
      sym__variable_assignment_varlist,
    STATE(270), 1,
      sym__block,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(160), 9,
      sym_empty_statement,
      sym_assignment_statement,
      sym_label_statement,
      sym_goto_statement,
      sym_do_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_if_statement,
      sym_for_statement,
  [3886] = 38,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(15), 1,
      anon_sym_SEMI,
    ACTIONS(17), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19), 1,
      sym_break_statement,
    ACTIONS(21), 1,
      anon_sym_goto,
    ACTIONS(23), 1,
      anon_sym_do,
    ACTIONS(25), 1,
      anon_sym_while,
    ACTIONS(27), 1,
      anon_sym_repeat,
    ACTIONS(29), 1,
      anon_sym_if,
    ACTIONS(31), 1,
      anon_sym_for,
    ACTIONS(33), 1,
      anon_sym_function,
    ACTIONS(35), 1,
      anon_sym_local,
    ACTIONS(37), 1,
      anon_sym_global,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(113), 1,
      anon_sym_return,
    ACTIONS(227), 1,
      anon_sym_end,
    STATE(21), 1,
      aux_sym_chunk_repeat1,
    STATE(52), 1,
      sym_comment,
    STATE(101), 1,
      sym_function_call,
    STATE(131), 1,
      sym_variable_declaration,
    STATE(132), 1,
      sym_declaration,
    STATE(134), 1,
      sym_function_declaration,
    STATE(137), 1,
      sym__local_function_declaration,
    STATE(139), 1,
      sym__global_function_declaration,
    STATE(142), 1,
      sym__global_variable_declaration,
    STATE(143), 1,
      sym__global_implicit_variable_declaration,
    STATE(161), 1,
      sym_statement,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(172), 1,
      sym_variable,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(177), 1,
      sym_parenthesized_expression,
    STATE(194), 1,
      sym_return_statement,
    STATE(255), 1,
      sym__variable_assignment_varlist,
    STATE(271), 1,
      sym__block,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(160), 9,
      sym_empty_statement,
      sym_assignment_statement,
      sym_label_statement,
      sym_goto_statement,
      sym_do_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_if_statement,
      sym_for_statement,
  [4011] = 37,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_return,
    ACTIONS(15), 1,
      anon_sym_SEMI,
    ACTIONS(17), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19), 1,
      sym_break_statement,
    ACTIONS(21), 1,
      anon_sym_goto,
    ACTIONS(23), 1,
      anon_sym_do,
    ACTIONS(25), 1,
      anon_sym_while,
    ACTIONS(27), 1,
      anon_sym_repeat,
    ACTIONS(29), 1,
      anon_sym_if,
    ACTIONS(31), 1,
      anon_sym_for,
    ACTIONS(33), 1,
      anon_sym_function,
    ACTIONS(35), 1,
      anon_sym_local,
    ACTIONS(37), 1,
      anon_sym_global,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(229), 1,
      ts_builtin_sym_end,
    STATE(53), 1,
      sym_comment,
    STATE(54), 1,
      aux_sym_chunk_repeat1,
    STATE(101), 1,
      sym_function_call,
    STATE(131), 1,
      sym_variable_declaration,
    STATE(132), 1,
      sym_declaration,
    STATE(134), 1,
      sym_function_declaration,
    STATE(137), 1,
      sym__local_function_declaration,
    STATE(139), 1,
      sym__global_function_declaration,
    STATE(142), 1,
      sym__global_variable_declaration,
    STATE(143), 1,
      sym__global_implicit_variable_declaration,
    STATE(161), 1,
      sym_statement,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(172), 1,
      sym_variable,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(177), 1,
      sym_parenthesized_expression,
    STATE(255), 1,
      sym__variable_assignment_varlist,
    STATE(266), 1,
      sym_return_statement,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(160), 9,
      sym_empty_statement,
      sym_assignment_statement,
      sym_label_statement,
      sym_goto_statement,
      sym_do_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_if_statement,
      sym_for_statement,
  [4133] = 37,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_return,
    ACTIONS(15), 1,
      anon_sym_SEMI,
    ACTIONS(17), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19), 1,
      sym_break_statement,
    ACTIONS(21), 1,
      anon_sym_goto,
    ACTIONS(23), 1,
      anon_sym_do,
    ACTIONS(25), 1,
      anon_sym_while,
    ACTIONS(27), 1,
      anon_sym_repeat,
    ACTIONS(29), 1,
      anon_sym_if,
    ACTIONS(31), 1,
      anon_sym_for,
    ACTIONS(33), 1,
      anon_sym_function,
    ACTIONS(35), 1,
      anon_sym_local,
    ACTIONS(37), 1,
      anon_sym_global,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(231), 1,
      ts_builtin_sym_end,
    STATE(22), 1,
      aux_sym_chunk_repeat1,
    STATE(54), 1,
      sym_comment,
    STATE(101), 1,
      sym_function_call,
    STATE(131), 1,
      sym_variable_declaration,
    STATE(132), 1,
      sym_declaration,
    STATE(134), 1,
      sym_function_declaration,
    STATE(137), 1,
      sym__local_function_declaration,
    STATE(139), 1,
      sym__global_function_declaration,
    STATE(142), 1,
      sym__global_variable_declaration,
    STATE(143), 1,
      sym__global_implicit_variable_declaration,
    STATE(161), 1,
      sym_statement,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(172), 1,
      sym_variable,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(177), 1,
      sym_parenthesized_expression,
    STATE(245), 1,
      sym_return_statement,
    STATE(255), 1,
      sym__variable_assignment_varlist,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(160), 9,
      sym_empty_statement,
      sym_assignment_statement,
      sym_label_statement,
      sym_goto_statement,
      sym_do_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_if_statement,
      sym_for_statement,
  [4255] = 37,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_return,
    ACTIONS(15), 1,
      anon_sym_SEMI,
    ACTIONS(17), 1,
      anon_sym_COLON_COLON,
    ACTIONS(19), 1,
      sym_break_statement,
    ACTIONS(21), 1,
      anon_sym_goto,
    ACTIONS(23), 1,
      anon_sym_do,
    ACTIONS(25), 1,
      anon_sym_while,
    ACTIONS(27), 1,
      anon_sym_repeat,
    ACTIONS(29), 1,
      anon_sym_if,
    ACTIONS(31), 1,
      anon_sym_for,
    ACTIONS(33), 1,
      anon_sym_function,
    ACTIONS(35), 1,
      anon_sym_local,
    ACTIONS(37), 1,
      anon_sym_global,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(229), 1,
      ts_builtin_sym_end,
    STATE(22), 1,
      aux_sym_chunk_repeat1,
    STATE(55), 1,
      sym_comment,
    STATE(101), 1,
      sym_function_call,
    STATE(131), 1,
      sym_variable_declaration,
    STATE(132), 1,
      sym_declaration,
    STATE(134), 1,
      sym_function_declaration,
    STATE(137), 1,
      sym__local_function_declaration,
    STATE(139), 1,
      sym__global_function_declaration,
    STATE(142), 1,
      sym__global_variable_declaration,
    STATE(143), 1,
      sym__global_implicit_variable_declaration,
    STATE(161), 1,
      sym_statement,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(172), 1,
      sym_variable,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(177), 1,
      sym_parenthesized_expression,
    STATE(255), 1,
      sym__variable_assignment_varlist,
    STATE(266), 1,
      sym_return_statement,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(160), 9,
      sym_empty_statement,
      sym_assignment_statement,
      sym_label_statement,
      sym_goto_statement,
      sym_do_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_if_statement,
      sym_for_statement,
  [4377] = 21,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(199), 1,
      anon_sym_and,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    ACTIONS(239), 1,
      anon_sym_or,
    STATE(56), 1,
      sym_comment,
    STATE(128), 1,
      aux_sym__variable_assignment_explist_repeat1,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(233), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(235), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [4466] = 19,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(199), 1,
      anon_sym_and,
    ACTIONS(239), 1,
      anon_sym_or,
    STATE(57), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(241), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(243), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [4550] = 19,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(199), 1,
      anon_sym_and,
    ACTIONS(239), 1,
      anon_sym_or,
    STATE(58), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(245), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(247), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [4633] = 19,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(199), 1,
      anon_sym_and,
    ACTIONS(239), 1,
      anon_sym_or,
    STATE(59), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(249), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(251), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [4716] = 26,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(253), 1,
      anon_sym_SEMI,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(60), 1,
      sym_comment,
    STATE(100), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(182), 1,
      sym__expression_list,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    ACTIONS(255), 4,
      anon_sym_end,
      anon_sym_until,
      anon_sym_elseif,
      anon_sym_else,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [4811] = 28,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    ACTIONS(277), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_LBRACK,
    ACTIONS(281), 1,
      anon_sym_RBRACE,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(61), 1,
      sym_comment,
    STATE(76), 1,
      sym__contextual_keyword,
    STATE(105), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(188), 1,
      sym_field,
    STATE(242), 1,
      sym__field_list,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    STATE(2), 2,
      sym_bracket_index_expression,
      sym_dot_index_expression,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [4908] = 28,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    ACTIONS(277), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_LBRACK,
    ACTIONS(283), 1,
      anon_sym_RBRACE,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(62), 1,
      sym_comment,
    STATE(76), 1,
      sym__contextual_keyword,
    STATE(105), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(188), 1,
      sym_field,
    STATE(277), 1,
      sym__field_list,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    STATE(2), 2,
      sym_bracket_index_expression,
      sym_dot_index_expression,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [5005] = 26,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(253), 1,
      anon_sym_SEMI,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    ACTIONS(285), 1,
      ts_builtin_sym_end,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(63), 1,
      sym_comment,
    STATE(100), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(182), 1,
      sym__expression_list,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [5097] = 27,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    ACTIONS(277), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_LBRACK,
    ACTIONS(287), 1,
      anon_sym_RBRACE,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(64), 1,
      sym_comment,
    STATE(76), 1,
      sym__contextual_keyword,
    STATE(105), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(211), 1,
      sym_field,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    STATE(2), 2,
      sym_bracket_index_expression,
      sym_dot_index_expression,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [5191] = 27,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    ACTIONS(277), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_LBRACK,
    ACTIONS(289), 1,
      anon_sym_RBRACE,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(65), 1,
      sym_comment,
    STATE(76), 1,
      sym__contextual_keyword,
    STATE(105), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(211), 1,
      sym_field,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    STATE(2), 2,
      sym_bracket_index_expression,
      sym_dot_index_expression,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [5285] = 26,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    ACTIONS(277), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_LBRACK,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(66), 1,
      sym_comment,
    STATE(76), 1,
      sym__contextual_keyword,
    STATE(105), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(211), 1,
      sym_field,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    STATE(2), 2,
      sym_bracket_index_expression,
      sym_dot_index_expression,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [5376] = 24,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(56), 1,
      sym_expression,
    STATE(67), 1,
      sym_comment,
    STATE(136), 1,
      sym__variable_assignment_explist,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [5462] = 24,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(56), 1,
      sym_expression,
    STATE(68), 1,
      sym_comment,
    STATE(149), 1,
      sym__variable_assignment_explist,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [5548] = 24,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    ACTIONS(291), 1,
      anon_sym_RPAREN,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(69), 1,
      sym_comment,
    STATE(104), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [5634] = 24,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(70), 1,
      sym_comment,
    STATE(100), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(231), 1,
      sym__expression_list,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [5720] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(71), 1,
      sym_comment,
    STATE(99), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [5803] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(27), 1,
      sym_expression,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(72), 1,
      sym_comment,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [5886] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(73), 1,
      sym_comment,
    STATE(127), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [5969] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(74), 1,
      sym_comment,
    STATE(118), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [6052] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(75), 1,
      sym_comment,
    STATE(120), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [6135] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(293), 1,
      anon_sym_EQ,
    STATE(76), 1,
      sym_comment,
    ACTIONS(43), 6,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_TILDE,
      anon_sym_DASH,
      anon_sym_SLASH,
    ACTIONS(41), 26,
      sym__block_string_start,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_or,
      anon_sym_and,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
      anon_sym_CARET,
  [6184] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(77), 1,
      sym_comment,
    STATE(125), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [6267] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(78), 1,
      sym_comment,
    STATE(124), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [6350] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(58), 1,
      sym_expression,
    STATE(79), 1,
      sym_comment,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [6433] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(80), 1,
      sym_comment,
    STATE(119), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [6516] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(28), 1,
      sym_expression,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(81), 1,
      sym_comment,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [6599] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(57), 1,
      sym_expression,
    STATE(82), 1,
      sym_comment,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [6682] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(32), 1,
      sym_expression,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(83), 1,
      sym_comment,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [6765] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(26), 1,
      sym_expression,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(84), 1,
      sym_comment,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [6848] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(85), 1,
      sym_comment,
    STATE(123), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [6931] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(86), 1,
      sym_comment,
    STATE(115), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [7014] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(33), 1,
      sym_expression,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(87), 1,
      sym_comment,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [7097] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(25), 1,
      sym_expression,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(88), 1,
      sym_comment,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [7180] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(89), 1,
      sym_comment,
    STATE(108), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [7263] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(38), 1,
      sym_expression,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(90), 1,
      sym_comment,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [7346] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(34), 1,
      sym_expression,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(91), 1,
      sym_comment,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [7429] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(92), 1,
      sym_comment,
    STATE(126), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [7512] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(93), 1,
      sym_comment,
    STATE(106), 1,
      sym_expression,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [7595] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(35), 1,
      sym_expression,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(94), 1,
      sym_comment,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [7678] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(36), 1,
      sym_expression,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(95), 1,
      sym_comment,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [7761] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(37), 1,
      sym_expression,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(96), 1,
      sym_comment,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [7844] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(46), 1,
      sym_expression,
    STATE(97), 1,
      sym_comment,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [7927] = 23,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(257), 1,
      anon_sym_function,
    ACTIONS(259), 1,
      anon_sym_global,
    ACTIONS(265), 1,
      anon_sym_DQUOTE,
    ACTIONS(267), 1,
      anon_sym_SQUOTE,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(275), 1,
      sym__block_string_start,
    STATE(41), 1,
      sym__quote_string,
    STATE(45), 1,
      sym__block_string,
    STATE(59), 1,
      sym_expression,
    STATE(98), 1,
      sym_comment,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(174), 1,
      sym_method_index_expression,
    ACTIONS(263), 2,
      sym_number,
      sym_vararg_expression,
    ACTIONS(271), 2,
      anon_sym_TILDE,
      anon_sym_POUND,
    ACTIONS(273), 2,
      anon_sym_DASH,
      anon_sym_not,
    ACTIONS(261), 3,
      sym_nil,
      sym_false,
      sym_true,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
    STATE(7), 3,
      sym_variable,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(40), 5,
      sym_string,
      sym_function_definition,
      sym_table_constructor,
      sym_binary_expression,
      sym_unary_expression,
  [8010] = 19,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(297), 1,
      anon_sym_else,
    ACTIONS(299), 1,
      anon_sym_or,
    ACTIONS(301), 1,
      anon_sym_and,
    STATE(99), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(295), 8,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_do,
      anon_sym_end,
      anon_sym_until,
      anon_sym_elseif,
      anon_sym_RPAREN,
  [8082] = 21,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(299), 1,
      anon_sym_or,
    ACTIONS(301), 1,
      anon_sym_and,
    ACTIONS(305), 1,
      anon_sym_COMMA,
    ACTIONS(307), 1,
      anon_sym_else,
    STATE(100), 1,
      sym_comment,
    STATE(176), 1,
      aux_sym__expression_list_repeat1,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(303), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_end,
      anon_sym_until,
      anon_sym_elseif,
  [8158] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(65), 1,
      anon_sym_COLON,
    STATE(101), 1,
      sym_comment,
    ACTIONS(309), 3,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
    ACTIONS(67), 7,
      sym__block_string_start,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
    ACTIONS(311), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [8203] = 9,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(317), 1,
      anon_sym_COMMA,
    ACTIONS(319), 1,
      anon_sym_LT,
    STATE(102), 1,
      sym_comment,
    STATE(113), 1,
      aux_sym__att_name_list_repeat1,
    STATE(116), 1,
      sym__attrib,
    ACTIONS(313), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(315), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [8250] = 9,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(317), 1,
      anon_sym_COMMA,
    ACTIONS(319), 1,
      anon_sym_LT,
    STATE(103), 1,
      sym_comment,
    STATE(110), 1,
      sym__attrib,
    STATE(111), 1,
      aux_sym__att_name_list_repeat1,
    ACTIONS(321), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(323), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [8297] = 20,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(299), 1,
      anon_sym_or,
    ACTIONS(301), 1,
      anon_sym_and,
    ACTIONS(305), 1,
      anon_sym_COMMA,
    ACTIONS(325), 1,
      anon_sym_RPAREN,
    STATE(104), 1,
      sym_comment,
    STATE(212), 1,
      aux_sym__expression_list_repeat1,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [8365] = 18,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(299), 1,
      anon_sym_or,
    ACTIONS(301), 1,
      anon_sym_and,
    STATE(105), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(327), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [8429] = 18,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(299), 1,
      anon_sym_or,
    ACTIONS(301), 1,
      anon_sym_and,
    STATE(106), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(329), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [8493] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(319), 1,
      anon_sym_LT,
    STATE(107), 1,
      sym_comment,
    STATE(122), 1,
      sym__attrib,
    ACTIONS(331), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(333), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [8535] = 18,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(299), 1,
      anon_sym_or,
    ACTIONS(301), 1,
      anon_sym_and,
    STATE(108), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(335), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [8599] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(317), 1,
      anon_sym_COMMA,
    STATE(109), 1,
      sym_comment,
    STATE(117), 1,
      aux_sym__att_name_list_repeat1,
    ACTIONS(337), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(339), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [8640] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(317), 1,
      anon_sym_COMMA,
    STATE(110), 1,
      sym_comment,
    STATE(112), 1,
      aux_sym__att_name_list_repeat1,
    ACTIONS(341), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(343), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [8681] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(317), 1,
      anon_sym_COMMA,
    STATE(111), 1,
      sym_comment,
    STATE(117), 1,
      aux_sym__att_name_list_repeat1,
    ACTIONS(345), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(347), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [8722] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(317), 1,
      anon_sym_COMMA,
    STATE(112), 1,
      sym_comment,
    STATE(117), 1,
      aux_sym__att_name_list_repeat1,
    ACTIONS(349), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(351), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [8763] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(317), 1,
      anon_sym_COMMA,
    STATE(113), 1,
      sym_comment,
    STATE(117), 1,
      aux_sym__att_name_list_repeat1,
    ACTIONS(353), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(355), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [8804] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(114), 1,
      sym_comment,
    ACTIONS(357), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
    ACTIONS(359), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [8841] = 19,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(299), 1,
      anon_sym_or,
    ACTIONS(301), 1,
      anon_sym_and,
    ACTIONS(361), 1,
      anon_sym_COMMA,
    ACTIONS(363), 1,
      anon_sym_do,
    STATE(115), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [8906] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(317), 1,
      anon_sym_COMMA,
    STATE(109), 1,
      aux_sym__att_name_list_repeat1,
    STATE(116), 1,
      sym_comment,
    ACTIONS(365), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(367), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [8947] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(373), 1,
      anon_sym_COMMA,
    STATE(117), 2,
      sym_comment,
      aux_sym__att_name_list_repeat1,
    ACTIONS(369), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(371), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [8986] = 18,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(299), 1,
      anon_sym_or,
    ACTIONS(301), 1,
      anon_sym_and,
    ACTIONS(376), 1,
      anon_sym_RBRACK,
    STATE(118), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [9048] = 18,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(299), 1,
      anon_sym_or,
    ACTIONS(301), 1,
      anon_sym_and,
    ACTIONS(378), 1,
      anon_sym_then,
    STATE(119), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [9110] = 18,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(299), 1,
      anon_sym_or,
    ACTIONS(301), 1,
      anon_sym_and,
    ACTIONS(380), 1,
      anon_sym_RPAREN,
    STATE(120), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [9172] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(386), 1,
      anon_sym_COMMA,
    STATE(121), 2,
      sym_comment,
      aux_sym__variable_assignment_explist_repeat1,
    ACTIONS(382), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(384), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [9210] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(122), 1,
      sym_comment,
    ACTIONS(389), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(391), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [9246] = 18,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(299), 1,
      anon_sym_or,
    ACTIONS(301), 1,
      anon_sym_and,
    ACTIONS(393), 1,
      anon_sym_RBRACK,
    STATE(123), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [9308] = 18,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(299), 1,
      anon_sym_or,
    ACTIONS(301), 1,
      anon_sym_and,
    ACTIONS(395), 1,
      anon_sym_COMMA,
    STATE(124), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [9370] = 18,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(299), 1,
      anon_sym_or,
    ACTIONS(301), 1,
      anon_sym_and,
    ACTIONS(397), 1,
      anon_sym_do,
    STATE(125), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [9432] = 18,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(299), 1,
      anon_sym_or,
    ACTIONS(301), 1,
      anon_sym_and,
    ACTIONS(399), 1,
      anon_sym_do,
    STATE(126), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [9494] = 18,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(177), 1,
      anon_sym_AMP,
    ACTIONS(181), 1,
      anon_sym_PLUS,
    ACTIONS(183), 1,
      anon_sym_DASH,
    ACTIONS(185), 1,
      anon_sym_SLASH,
    ACTIONS(187), 1,
      anon_sym_DOT_DOT,
    ACTIONS(189), 1,
      anon_sym_CARET,
    ACTIONS(195), 1,
      anon_sym_PIPE,
    ACTIONS(197), 1,
      anon_sym_TILDE,
    ACTIONS(299), 1,
      anon_sym_or,
    ACTIONS(301), 1,
      anon_sym_and,
    ACTIONS(401), 1,
      anon_sym_then,
    STATE(127), 1,
      sym_comment,
    ACTIONS(179), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(191), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(175), 3,
      anon_sym_STAR,
      anon_sym_SLASH_SLASH,
      anon_sym_PERCENT,
    ACTIONS(193), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [9556] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(237), 1,
      anon_sym_COMMA,
    STATE(121), 1,
      aux_sym__variable_assignment_explist_repeat1,
    STATE(128), 1,
      sym_comment,
    ACTIONS(403), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(405), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [9596] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(411), 1,
      anon_sym_EQ,
    STATE(129), 1,
      sym_comment,
    ACTIONS(407), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(409), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [9633] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(411), 1,
      anon_sym_EQ,
    STATE(130), 1,
      sym_comment,
    ACTIONS(413), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(415), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [9670] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(131), 1,
      sym_comment,
    ACTIONS(417), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(419), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [9704] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(132), 1,
      sym_comment,
    ACTIONS(421), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(423), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [9738] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(133), 1,
      sym_comment,
    ACTIONS(425), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(427), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [9772] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(134), 1,
      sym_comment,
    ACTIONS(429), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(431), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [9806] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(135), 1,
      sym_comment,
    ACTIONS(433), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(435), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [9840] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(136), 1,
      sym_comment,
    ACTIONS(437), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(439), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [9874] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(137), 1,
      sym_comment,
    ACTIONS(441), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(443), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [9908] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(138), 1,
      sym_comment,
    ACTIONS(445), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(447), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [9942] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(139), 1,
      sym_comment,
    ACTIONS(449), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(451), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [9976] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(140), 1,
      sym_comment,
    ACTIONS(453), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(455), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10010] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(141), 1,
      sym_comment,
    ACTIONS(457), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(459), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10044] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(142), 1,
      sym_comment,
    ACTIONS(461), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(463), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10078] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(143), 1,
      sym_comment,
    ACTIONS(465), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(467), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10112] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(144), 1,
      sym_comment,
    ACTIONS(469), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(471), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10146] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(145), 1,
      sym_comment,
    ACTIONS(473), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(475), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10180] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(146), 1,
      sym_comment,
    ACTIONS(477), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(479), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10214] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(147), 1,
      sym_comment,
    ACTIONS(481), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(483), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10248] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(148), 1,
      sym_comment,
    ACTIONS(485), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(487), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10282] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(149), 1,
      sym_comment,
    ACTIONS(489), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(491), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10316] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(150), 1,
      sym_comment,
    ACTIONS(493), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(495), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10350] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(151), 1,
      sym_comment,
    ACTIONS(497), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(499), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10384] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(152), 1,
      sym_comment,
    ACTIONS(501), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(503), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10418] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(153), 1,
      sym_comment,
    ACTIONS(505), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(507), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10452] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(154), 1,
      sym_comment,
    ACTIONS(509), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(511), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10486] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(155), 1,
      sym_comment,
    ACTIONS(513), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(515), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10520] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(156), 1,
      sym_comment,
    ACTIONS(517), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(519), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10554] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(157), 1,
      sym_comment,
    ACTIONS(521), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(523), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10588] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(158), 1,
      sym_comment,
    ACTIONS(525), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(527), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10622] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(159), 1,
      sym_comment,
    ACTIONS(529), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(531), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10656] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(160), 1,
      sym_comment,
    ACTIONS(309), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(311), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10690] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(161), 1,
      sym_comment,
    ACTIONS(533), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(535), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10724] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(162), 1,
      sym_comment,
    ACTIONS(537), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(539), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10758] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(163), 1,
      sym_comment,
    ACTIONS(541), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(543), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10792] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(164), 1,
      sym_comment,
    ACTIONS(545), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(547), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10826] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(165), 1,
      sym_comment,
    ACTIONS(549), 4,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(551), 16,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_until,
      anon_sym_if,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10860] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(166), 1,
      sym_comment,
    ACTIONS(553), 8,
      anon_sym_function,
      anon_sym_global,
      sym_nil,
      sym_false,
      sym_true,
      anon_sym_DASH,
      anon_sym_not,
      sym_identifier,
    ACTIONS(555), 11,
      sym__block_string_start,
      sym_number,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_vararg_expression,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_TILDE,
      anon_sym_POUND,
  [10893] = 11,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(319), 1,
      anon_sym_LT,
    ACTIONS(557), 1,
      sym_identifier,
    ACTIONS(559), 1,
      anon_sym_function,
    ACTIONS(561), 1,
      anon_sym_STAR,
    STATE(129), 1,
      sym__att_name_list,
    STATE(141), 1,
      sym__variable_assignment,
    STATE(167), 1,
      sym_comment,
    STATE(230), 1,
      sym__attrib,
    ACTIONS(45), 10,
      sym__block_string_start,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [10936] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(168), 1,
      sym_comment,
    ACTIONS(565), 3,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(563), 13,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_if,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10966] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(169), 1,
      sym_comment,
    ACTIONS(569), 3,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
    ACTIONS(567), 13,
      anon_sym_return,
      sym_break_statement,
      anon_sym_goto,
      anon_sym_do,
      anon_sym_end,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_if,
      anon_sym_for,
      anon_sym_function,
      anon_sym_local,
      anon_sym_global,
      sym_identifier,
  [10996] = 15,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      anon_sym_COLON,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_LPAREN,
    ACTIONS(581), 1,
      anon_sym_LBRACK,
    ACTIONS(583), 1,
      anon_sym_LBRACE,
    ACTIONS(585), 1,
      sym__block_string_start,
    STATE(9), 1,
      sym_arguments,
    STATE(14), 1,
      sym__quote_string,
    STATE(16), 1,
      sym__block_string,
    STATE(170), 1,
      sym_comment,
    STATE(8), 2,
      sym_string,
      sym_table_constructor,
  [11043] = 11,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(39), 1,
      anon_sym_LPAREN,
    ACTIONS(259), 1,
      anon_sym_global,
    STATE(170), 1,
      sym__prefix_expression,
    STATE(171), 1,
      sym_comment,
    STATE(174), 1,
      sym_method_index_expression,
    STATE(175), 1,
      sym_variable,
    STATE(177), 2,
      sym_function_call,
      sym_parenthesized_expression,
    STATE(2), 3,
      sym_bracket_index_expression,
      sym_dot_index_expression,
      sym__contextual_keyword,
  [11080] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(587), 1,
      anon_sym_EQ,
    ACTIONS(589), 1,
      anon_sym_COMMA,
    STATE(172), 1,
      sym_comment,
    STATE(217), 1,
      aux_sym__variable_assignment_varlist_repeat1,
    ACTIONS(67), 8,
      sym__block_string_start,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [11109] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(297), 1,
      anon_sym_else,
    ACTIONS(591), 1,
      anon_sym_COMMA,
    STATE(173), 2,
      sym_comment,
      aux_sym__expression_list_repeat1,
    ACTIONS(295), 7,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_end,
      anon_sym_until,
      anon_sym_elseif,
      anon_sym_RPAREN,
  [11135] = 12,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_LPAREN,
    ACTIONS(583), 1,
      anon_sym_LBRACE,
    ACTIONS(585), 1,
      sym__block_string_start,
    STATE(9), 1,
      sym_arguments,
    STATE(14), 1,
      sym__quote_string,
    STATE(16), 1,
      sym__block_string,
    STATE(174), 1,
      sym_comment,
    STATE(8), 2,
      sym_string,
      sym_table_constructor,
  [11173] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(175), 1,
      sym_comment,
    ACTIONS(594), 2,
      anon_sym_EQ,
      anon_sym_COMMA,
    ACTIONS(67), 8,
      sym__block_string_start,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [11197] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(305), 1,
      anon_sym_COMMA,
    ACTIONS(598), 1,
      anon_sym_else,
    STATE(173), 1,
      aux_sym__expression_list_repeat1,
    STATE(176), 1,
      sym_comment,
    ACTIONS(596), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_end,
      anon_sym_until,
      anon_sym_elseif,
  [11224] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(177), 1,
      sym_comment,
    ACTIONS(67), 8,
      sym__block_string_start,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [11244] = 9,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(119), 1,
      anon_sym_else,
    ACTIONS(600), 1,
      anon_sym_end,
    ACTIONS(602), 1,
      anon_sym_elseif,
    STATE(178), 1,
      sym_comment,
    STATE(186), 1,
      aux_sym_if_statement_repeat1,
    STATE(213), 1,
      sym_elseif_statement,
    STATE(254), 1,
      sym_else_statement,
  [11272] = 9,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(119), 1,
      anon_sym_else,
    ACTIONS(602), 1,
      anon_sym_elseif,
    ACTIONS(604), 1,
      anon_sym_end,
    STATE(179), 1,
      sym_comment,
    STATE(186), 1,
      aux_sym_if_statement_repeat1,
    STATE(213), 1,
      sym_elseif_statement,
    STATE(240), 1,
      sym_else_statement,
  [11300] = 9,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(119), 1,
      anon_sym_else,
    ACTIONS(602), 1,
      anon_sym_elseif,
    ACTIONS(606), 1,
      anon_sym_end,
    STATE(178), 1,
      aux_sym_if_statement_repeat1,
    STATE(180), 1,
      sym_comment,
    STATE(213), 1,
      sym_elseif_statement,
    STATE(236), 1,
      sym_else_statement,
  [11328] = 9,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(319), 1,
      anon_sym_LT,
    ACTIONS(557), 1,
      sym_identifier,
    ACTIONS(608), 1,
      anon_sym_function,
    STATE(130), 1,
      sym__att_name_list,
    STATE(138), 1,
      sym__variable_assignment,
    STATE(181), 1,
      sym_comment,
    STATE(239), 1,
      sym__attrib,
  [11356] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(612), 1,
      anon_sym_SEMI,
    ACTIONS(614), 1,
      anon_sym_else,
    STATE(182), 1,
      sym_comment,
    ACTIONS(610), 4,
      ts_builtin_sym_end,
      anon_sym_end,
      anon_sym_until,
      anon_sym_elseif,
  [11378] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(619), 1,
      anon_sym_RBRACE,
    STATE(66), 1,
      sym__field_sep,
    ACTIONS(616), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(183), 2,
      sym_comment,
      aux_sym__field_list_repeat1,
  [11399] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(287), 1,
      anon_sym_RBRACE,
    STATE(65), 1,
      sym__field_sep,
    STATE(183), 1,
      aux_sym__field_list_repeat1,
    STATE(184), 1,
      sym_comment,
    ACTIONS(621), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [11422] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(614), 1,
      anon_sym_else,
    STATE(185), 1,
      sym_comment,
    ACTIONS(610), 4,
      ts_builtin_sym_end,
      anon_sym_end,
      anon_sym_until,
      anon_sym_elseif,
  [11441] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(623), 1,
      anon_sym_end,
    ACTIONS(625), 1,
      anon_sym_elseif,
    ACTIONS(628), 1,
      anon_sym_else,
    STATE(213), 1,
      sym_elseif_statement,
    STATE(186), 2,
      sym_comment,
      aux_sym_if_statement_repeat1,
  [11464] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(187), 1,
      sym_comment,
    ACTIONS(630), 5,
      sym__block_string_start,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [11481] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(632), 1,
      anon_sym_RBRACE,
    STATE(64), 1,
      sym__field_sep,
    STATE(184), 1,
      aux_sym__field_list_repeat1,
    STATE(188), 1,
      sym_comment,
    ACTIONS(621), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [11504] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(636), 1,
      anon_sym_else,
    STATE(189), 1,
      sym_comment,
    ACTIONS(634), 4,
      ts_builtin_sym_end,
      anon_sym_end,
      anon_sym_until,
      anon_sym_elseif,
  [11523] = 8,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(190), 1,
      sym_comment,
    STATE(222), 1,
      sym__function_name,
    STATE(226), 1,
      sym__function_name_dot_index_expression,
    STATE(227), 1,
      sym__function_name_prefix_expression,
    STATE(250), 1,
      sym__function_name_method_index_expression,
  [11548] = 8,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(640), 1,
      sym_identifier,
    ACTIONS(642), 1,
      sym_vararg_expression,
    ACTIONS(644), 1,
      anon_sym_RPAREN,
    STATE(191), 1,
      sym_comment,
    STATE(246), 1,
      sym__parameter_list,
    STATE(273), 1,
      sym__vararg_parameter,
  [11573] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(648), 1,
      anon_sym_else,
    STATE(192), 1,
      sym_comment,
    ACTIONS(646), 3,
      anon_sym_end,
      anon_sym_until,
      anon_sym_elseif,
  [11591] = 6,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(650), 1,
      anon_sym_SQUOTE,
    ACTIONS(654), 1,
      anon_sym_DASH_DASH,
    STATE(193), 1,
      sym_comment,
    STATE(199), 1,
      aux_sym__singlequote_string_content,
    ACTIONS(652), 2,
      aux_sym__singlequote_string_content_token1,
      sym_escape_sequence,
  [11611] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(121), 1,
      anon_sym_else,
    STATE(194), 1,
      sym_comment,
    ACTIONS(656), 3,
      anon_sym_end,
      anon_sym_until,
      anon_sym_elseif,
  [11629] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(658), 1,
      anon_sym_COMMA,
    ACTIONS(661), 2,
      anon_sym_in,
      anon_sym_RPAREN,
    STATE(195), 2,
      sym_comment,
      aux_sym__name_list_repeat1,
  [11647] = 6,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(654), 1,
      anon_sym_DASH_DASH,
    ACTIONS(663), 1,
      anon_sym_DQUOTE,
    STATE(196), 1,
      sym_comment,
    STATE(198), 1,
      aux_sym__doublequote_string_content,
    ACTIONS(665), 2,
      aux_sym__doublequote_string_content_token1,
      sym_escape_sequence,
  [11667] = 6,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(654), 1,
      anon_sym_DASH_DASH,
    ACTIONS(663), 1,
      anon_sym_SQUOTE,
    STATE(197), 1,
      sym_comment,
    STATE(199), 1,
      aux_sym__singlequote_string_content,
    ACTIONS(652), 2,
      aux_sym__singlequote_string_content_token1,
      sym_escape_sequence,
  [11687] = 5,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(654), 1,
      anon_sym_DASH_DASH,
    ACTIONS(667), 1,
      anon_sym_DQUOTE,
    ACTIONS(669), 2,
      aux_sym__doublequote_string_content_token1,
      sym_escape_sequence,
    STATE(198), 2,
      aux_sym__doublequote_string_content,
      sym_comment,
  [11705] = 5,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(654), 1,
      anon_sym_DASH_DASH,
    ACTIONS(672), 1,
      anon_sym_SQUOTE,
    ACTIONS(674), 2,
      aux_sym__singlequote_string_content_token1,
      sym_escape_sequence,
    STATE(199), 2,
      aux_sym__singlequote_string_content,
      sym_comment,
  [11723] = 7,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(677), 1,
      anon_sym_EQ,
    ACTIONS(679), 1,
      anon_sym_COMMA,
    ACTIONS(681), 1,
      anon_sym_in,
    STATE(200), 1,
      sym_comment,
    STATE(218), 1,
      aux_sym__name_list_repeat1,
  [11745] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(683), 1,
      sym_identifier,
    STATE(201), 1,
      sym_comment,
    STATE(260), 1,
      sym__name_list,
    STATE(247), 2,
      sym_for_generic_clause,
      sym_for_numeric_clause,
  [11765] = 6,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(654), 1,
      anon_sym_DASH_DASH,
    ACTIONS(685), 1,
      anon_sym_DQUOTE,
    STATE(196), 1,
      aux_sym__doublequote_string_content,
    STATE(202), 1,
      sym_comment,
    ACTIONS(665), 2,
      aux_sym__doublequote_string_content_token1,
      sym_escape_sequence,
  [11785] = 6,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(654), 1,
      anon_sym_DASH_DASH,
    ACTIONS(685), 1,
      anon_sym_SQUOTE,
    STATE(197), 1,
      aux_sym__singlequote_string_content,
    STATE(203), 1,
      sym_comment,
    ACTIONS(652), 2,
      aux_sym__singlequote_string_content_token1,
      sym_escape_sequence,
  [11805] = 6,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(654), 1,
      anon_sym_DASH_DASH,
    ACTIONS(687), 1,
      anon_sym_DQUOTE,
    STATE(204), 1,
      sym_comment,
    STATE(206), 1,
      aux_sym__doublequote_string_content,
    ACTIONS(665), 2,
      aux_sym__doublequote_string_content_token1,
      sym_escape_sequence,
  [11825] = 6,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(654), 1,
      anon_sym_DASH_DASH,
    ACTIONS(687), 1,
      anon_sym_SQUOTE,
    STATE(193), 1,
      aux_sym__singlequote_string_content,
    STATE(205), 1,
      sym_comment,
    ACTIONS(652), 2,
      aux_sym__singlequote_string_content_token1,
      sym_escape_sequence,
  [11845] = 6,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(650), 1,
      anon_sym_DQUOTE,
    ACTIONS(654), 1,
      anon_sym_DASH_DASH,
    STATE(198), 1,
      aux_sym__doublequote_string_content,
    STATE(206), 1,
      sym_comment,
    ACTIONS(665), 2,
      aux_sym__doublequote_string_content_token1,
      sym_escape_sequence,
  [11865] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(689), 1,
      anon_sym_EQ,
    ACTIONS(691), 1,
      anon_sym_COMMA,
    STATE(207), 2,
      sym_comment,
      aux_sym__variable_assignment_varlist_repeat1,
  [11882] = 5,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(654), 1,
      anon_sym_DASH_DASH,
    ACTIONS(694), 1,
      anon_sym_SQUOTE,
    STATE(208), 1,
      sym_comment,
    ACTIONS(696), 2,
      aux_sym__singlequote_string_content_token1,
      sym_escape_sequence,
  [11899] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(698), 1,
      anon_sym_COMMA,
    ACTIONS(700), 1,
      anon_sym_RPAREN,
    STATE(209), 1,
      sym_comment,
    STATE(215), 1,
      aux_sym__name_list_repeat1,
  [11918] = 5,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(654), 1,
      anon_sym_DASH_DASH,
    ACTIONS(702), 1,
      anon_sym_DQUOTE,
    STATE(210), 1,
      sym_comment,
    ACTIONS(704), 2,
      aux_sym__doublequote_string_content_token1,
      sym_escape_sequence,
  [11935] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(211), 1,
      sym_comment,
    ACTIONS(619), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [11950] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(305), 1,
      anon_sym_COMMA,
    ACTIONS(706), 1,
      anon_sym_RPAREN,
    STATE(173), 1,
      aux_sym__expression_list_repeat1,
    STATE(212), 1,
      sym_comment,
  [11969] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(710), 1,
      anon_sym_else,
    STATE(213), 1,
      sym_comment,
    ACTIONS(708), 2,
      anon_sym_end,
      anon_sym_elseif,
  [11986] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(642), 1,
      sym_vararg_expression,
    ACTIONS(712), 1,
      sym_identifier,
    STATE(214), 1,
      sym_comment,
    STATE(248), 1,
      sym__vararg_parameter,
  [12005] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(714), 1,
      anon_sym_COMMA,
    ACTIONS(716), 1,
      anon_sym_RPAREN,
    STATE(195), 1,
      aux_sym__name_list_repeat1,
    STATE(215), 1,
      sym_comment,
  [12024] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(718), 1,
      anon_sym_LPAREN,
    STATE(50), 1,
      sym_parameters,
    STATE(147), 1,
      sym__function_body,
    STATE(216), 1,
      sym_comment,
  [12043] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(589), 1,
      anon_sym_COMMA,
    ACTIONS(720), 1,
      anon_sym_EQ,
    STATE(207), 1,
      aux_sym__variable_assignment_varlist_repeat1,
    STATE(217), 1,
      sym_comment,
  [12062] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(679), 1,
      anon_sym_COMMA,
    ACTIONS(722), 1,
      anon_sym_in,
    STATE(195), 1,
      aux_sym__name_list_repeat1,
    STATE(218), 1,
      sym_comment,
  [12081] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(718), 1,
      anon_sym_LPAREN,
    STATE(43), 1,
      sym__function_body,
    STATE(50), 1,
      sym_parameters,
    STATE(219), 1,
      sym_comment,
  [12100] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(220), 1,
      sym_comment,
    ACTIONS(724), 3,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_RPAREN,
  [12115] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(642), 1,
      sym_vararg_expression,
    ACTIONS(712), 1,
      sym_identifier,
    STATE(221), 1,
      sym_comment,
    STATE(257), 1,
      sym__vararg_parameter,
  [12134] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(718), 1,
      anon_sym_LPAREN,
    STATE(50), 1,
      sym_parameters,
    STATE(133), 1,
      sym__function_body,
    STATE(222), 1,
      sym_comment,
  [12153] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(718), 1,
      anon_sym_LPAREN,
    STATE(50), 1,
      sym_parameters,
    STATE(150), 1,
      sym__function_body,
    STATE(223), 1,
      sym_comment,
  [12172] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(728), 1,
      anon_sym_else,
    STATE(224), 1,
      sym_comment,
    ACTIONS(726), 2,
      anon_sym_end,
      anon_sym_elseif,
  [12189] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(225), 1,
      sym_comment,
    ACTIONS(730), 3,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LPAREN,
  [12204] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(226), 1,
      sym_comment,
    ACTIONS(732), 3,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LPAREN,
  [12219] = 6,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(734), 1,
      anon_sym_DOT,
    ACTIONS(736), 1,
      anon_sym_COLON,
    ACTIONS(738), 1,
      anon_sym_LPAREN,
    STATE(227), 1,
      sym_comment,
  [12238] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    STATE(228), 1,
      sym_comment,
    ACTIONS(740), 3,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_LPAREN,
  [12253] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(742), 1,
      sym_identifier,
    ACTIONS(744), 1,
      anon_sym_RPAREN,
    STATE(229), 1,
      sym_comment,
  [12269] = 5,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(746), 1,
      sym_identifier,
    ACTIONS(748), 1,
      anon_sym_STAR,
    STATE(230), 1,
      sym_comment,
  [12285] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(750), 1,
      anon_sym_do,
    STATE(231), 1,
      sym_comment,
  [12298] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(752), 1,
      sym__block_string_end,
    STATE(232), 1,
      sym_comment,
  [12311] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(754), 1,
      anon_sym_end,
    STATE(233), 1,
      sym_comment,
  [12324] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(756), 1,
      anon_sym_end,
    STATE(234), 1,
      sym_comment,
  [12337] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(758), 1,
      sym_identifier,
    STATE(235), 1,
      sym_comment,
  [12350] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(760), 1,
      anon_sym_end,
    STATE(236), 1,
      sym_comment,
  [12363] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(762), 1,
      anon_sym_GT,
    STATE(237), 1,
      sym_comment,
  [12376] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(764), 1,
      sym_identifier,
    STATE(238), 1,
      sym_comment,
  [12389] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(746), 1,
      sym_identifier,
    STATE(239), 1,
      sym_comment,
  [12402] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(766), 1,
      anon_sym_end,
    STATE(240), 1,
      sym_comment,
  [12415] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(768), 1,
      anon_sym_until,
    STATE(241), 1,
      sym_comment,
  [12428] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(770), 1,
      anon_sym_RBRACE,
    STATE(242), 1,
      sym_comment,
  [12441] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(772), 1,
      sym_identifier,
    STATE(243), 1,
      sym_comment,
  [12454] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(774), 1,
      sym_identifier,
    STATE(244), 1,
      sym_comment,
  [12467] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(776), 1,
      ts_builtin_sym_end,
    STATE(245), 1,
      sym_comment,
  [12480] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(778), 1,
      anon_sym_RPAREN,
    STATE(246), 1,
      sym_comment,
  [12493] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(780), 1,
      anon_sym_do,
    STATE(247), 1,
      sym_comment,
  [12506] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(782), 1,
      anon_sym_RPAREN,
    STATE(248), 1,
      sym_comment,
  [12519] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(784), 1,
      anon_sym_RPAREN,
    STATE(249), 1,
      sym_comment,
  [12532] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(786), 1,
      anon_sym_LPAREN,
    STATE(250), 1,
      sym_comment,
  [12545] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(788), 1,
      sym_identifier,
    STATE(251), 1,
      sym_comment,
  [12558] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(790), 1,
      sym__block_comment_content,
    STATE(252), 1,
      sym_comment,
  [12571] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(792), 1,
      sym__block_comment_end,
    STATE(253), 1,
      sym_comment,
  [12584] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(794), 1,
      anon_sym_end,
    STATE(254), 1,
      sym_comment,
  [12597] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(796), 1,
      anon_sym_EQ,
    STATE(255), 1,
      sym_comment,
  [12610] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(798), 1,
      sym_identifier,
    STATE(256), 1,
      sym_comment,
  [12623] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(800), 1,
      anon_sym_RPAREN,
    STATE(257), 1,
      sym_comment,
  [12636] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(802), 1,
      sym_identifier,
    STATE(258), 1,
      sym_comment,
  [12649] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(804), 1,
      sym_identifier,
    STATE(259), 1,
      sym_comment,
  [12662] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(806), 1,
      anon_sym_in,
    STATE(260), 1,
      sym_comment,
  [12675] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(229), 1,
      ts_builtin_sym_end,
    STATE(261), 1,
      sym_comment,
  [12688] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(808), 1,
      sym_identifier,
    STATE(262), 1,
      sym_comment,
  [12701] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(810), 1,
      ts_builtin_sym_end,
    STATE(263), 1,
      sym_comment,
  [12714] = 4,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(654), 1,
      anon_sym_DASH_DASH,
    ACTIONS(812), 1,
      aux_sym_comment_token1,
    STATE(264), 1,
      sym_comment,
  [12727] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(814), 1,
      anon_sym_COLON_COLON,
    STATE(265), 1,
      sym_comment,
  [12740] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(231), 1,
      ts_builtin_sym_end,
    STATE(266), 1,
      sym_comment,
  [12753] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(816), 1,
      anon_sym_EQ,
    STATE(267), 1,
      sym_comment,
  [12766] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(712), 1,
      sym_identifier,
    STATE(268), 1,
      sym_comment,
  [12779] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(818), 1,
      anon_sym_end,
    STATE(269), 1,
      sym_comment,
  [12792] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(820), 1,
      anon_sym_end,
    STATE(270), 1,
      sym_comment,
  [12805] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(822), 1,
      anon_sym_end,
    STATE(271), 1,
      sym_comment,
  [12818] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(824), 1,
      sym_identifier,
    STATE(272), 1,
      sym_comment,
  [12831] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(826), 1,
      anon_sym_RPAREN,
    STATE(273), 1,
      sym_comment,
  [12844] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(828), 1,
      sym__block_string_end,
    STATE(274), 1,
      sym_comment,
  [12857] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(830), 1,
      sym__block_string_content,
    STATE(275), 1,
      sym_comment,
  [12870] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(832), 1,
      anon_sym_LPAREN,
    STATE(276), 1,
      sym_comment,
  [12883] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(834), 1,
      anon_sym_RBRACE,
    STATE(277), 1,
      sym_comment,
  [12896] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(836), 1,
      sym__block_string_content,
    STATE(278), 1,
      sym_comment,
  [12909] = 4,
    ACTIONS(3), 1,
      anon_sym_DASH_DASH,
    ACTIONS(5), 1,
      sym__block_comment_start,
    ACTIONS(838), 1,
      anon_sym_end,
    STATE(279), 1,
      sym_comment,
  [12922] = 1,
    ACTIONS(840), 1,
      ts_builtin_sym_end,
  [12926] = 1,
    ACTIONS(842), 1,
      ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2)] = 0,
  [SMALL_STATE(3)] = 68,
  [SMALL_STATE(4)] = 136,
  [SMALL_STATE(5)] = 204,
  [SMALL_STATE(6)] = 272,
  [SMALL_STATE(7)] = 339,
  [SMALL_STATE(8)] = 410,
  [SMALL_STATE(9)] = 477,
  [SMALL_STATE(10)] = 544,
  [SMALL_STATE(11)] = 611,
  [SMALL_STATE(12)] = 678,
  [SMALL_STATE(13)] = 745,
  [SMALL_STATE(14)] = 812,
  [SMALL_STATE(15)] = 879,
  [SMALL_STATE(16)] = 946,
  [SMALL_STATE(17)] = 1013,
  [SMALL_STATE(18)] = 1080,
  [SMALL_STATE(19)] = 1147,
  [SMALL_STATE(20)] = 1214,
  [SMALL_STATE(21)] = 1354,
  [SMALL_STATE(22)] = 1479,
  [SMALL_STATE(23)] = 1600,
  [SMALL_STATE(24)] = 1727,
  [SMALL_STATE(25)] = 1787,
  [SMALL_STATE(26)] = 1863,
  [SMALL_STATE(27)] = 1947,
  [SMALL_STATE(28)] = 2033,
  [SMALL_STATE(29)] = 2095,
  [SMALL_STATE(30)] = 2155,
  [SMALL_STATE(31)] = 2215,
  [SMALL_STATE(32)] = 2275,
  [SMALL_STATE(33)] = 2355,
  [SMALL_STATE(34)] = 2433,
  [SMALL_STATE(35)] = 2507,
  [SMALL_STATE(36)] = 2579,
  [SMALL_STATE(37)] = 2645,
  [SMALL_STATE(38)] = 2717,
  [SMALL_STATE(39)] = 2779,
  [SMALL_STATE(40)] = 2839,
  [SMALL_STATE(41)] = 2899,
  [SMALL_STATE(42)] = 2959,
  [SMALL_STATE(43)] = 3019,
  [SMALL_STATE(44)] = 3079,
  [SMALL_STATE(45)] = 3139,
  [SMALL_STATE(46)] = 3199,
  [SMALL_STATE(47)] = 3261,
  [SMALL_STATE(48)] = 3386,
  [SMALL_STATE(49)] = 3511,
  [SMALL_STATE(50)] = 3636,
  [SMALL_STATE(51)] = 3761,
  [SMALL_STATE(52)] = 3886,
  [SMALL_STATE(53)] = 4011,
  [SMALL_STATE(54)] = 4133,
  [SMALL_STATE(55)] = 4255,
  [SMALL_STATE(56)] = 4377,
  [SMALL_STATE(57)] = 4466,
  [SMALL_STATE(58)] = 4550,
  [SMALL_STATE(59)] = 4633,
  [SMALL_STATE(60)] = 4716,
  [SMALL_STATE(61)] = 4811,
  [SMALL_STATE(62)] = 4908,
  [SMALL_STATE(63)] = 5005,
  [SMALL_STATE(64)] = 5097,
  [SMALL_STATE(65)] = 5191,
  [SMALL_STATE(66)] = 5285,
  [SMALL_STATE(67)] = 5376,
  [SMALL_STATE(68)] = 5462,
  [SMALL_STATE(69)] = 5548,
  [SMALL_STATE(70)] = 5634,
  [SMALL_STATE(71)] = 5720,
  [SMALL_STATE(72)] = 5803,
  [SMALL_STATE(73)] = 5886,
  [SMALL_STATE(74)] = 5969,
  [SMALL_STATE(75)] = 6052,
  [SMALL_STATE(76)] = 6135,
  [SMALL_STATE(77)] = 6184,
  [SMALL_STATE(78)] = 6267,
  [SMALL_STATE(79)] = 6350,
  [SMALL_STATE(80)] = 6433,
  [SMALL_STATE(81)] = 6516,
  [SMALL_STATE(82)] = 6599,
  [SMALL_STATE(83)] = 6682,
  [SMALL_STATE(84)] = 6765,
  [SMALL_STATE(85)] = 6848,
  [SMALL_STATE(86)] = 6931,
  [SMALL_STATE(87)] = 7014,
  [SMALL_STATE(88)] = 7097,
  [SMALL_STATE(89)] = 7180,
  [SMALL_STATE(90)] = 7263,
  [SMALL_STATE(91)] = 7346,
  [SMALL_STATE(92)] = 7429,
  [SMALL_STATE(93)] = 7512,
  [SMALL_STATE(94)] = 7595,
  [SMALL_STATE(95)] = 7678,
  [SMALL_STATE(96)] = 7761,
  [SMALL_STATE(97)] = 7844,
  [SMALL_STATE(98)] = 7927,
  [SMALL_STATE(99)] = 8010,
  [SMALL_STATE(100)] = 8082,
  [SMALL_STATE(101)] = 8158,
  [SMALL_STATE(102)] = 8203,
  [SMALL_STATE(103)] = 8250,
  [SMALL_STATE(104)] = 8297,
  [SMALL_STATE(105)] = 8365,
  [SMALL_STATE(106)] = 8429,
  [SMALL_STATE(107)] = 8493,
  [SMALL_STATE(108)] = 8535,
  [SMALL_STATE(109)] = 8599,
  [SMALL_STATE(110)] = 8640,
  [SMALL_STATE(111)] = 8681,
  [SMALL_STATE(112)] = 8722,
  [SMALL_STATE(113)] = 8763,
  [SMALL_STATE(114)] = 8804,
  [SMALL_STATE(115)] = 8841,
  [SMALL_STATE(116)] = 8906,
  [SMALL_STATE(117)] = 8947,
  [SMALL_STATE(118)] = 8986,
  [SMALL_STATE(119)] = 9048,
  [SMALL_STATE(120)] = 9110,
  [SMALL_STATE(121)] = 9172,
  [SMALL_STATE(122)] = 9210,
  [SMALL_STATE(123)] = 9246,
  [SMALL_STATE(124)] = 9308,
  [SMALL_STATE(125)] = 9370,
  [SMALL_STATE(126)] = 9432,
  [SMALL_STATE(127)] = 9494,
  [SMALL_STATE(128)] = 9556,
  [SMALL_STATE(129)] = 9596,
  [SMALL_STATE(130)] = 9633,
  [SMALL_STATE(131)] = 9670,
  [SMALL_STATE(132)] = 9704,
  [SMALL_STATE(133)] = 9738,
  [SMALL_STATE(134)] = 9772,
  [SMALL_STATE(135)] = 9806,
  [SMALL_STATE(136)] = 9840,
  [SMALL_STATE(137)] = 9874,
  [SMALL_STATE(138)] = 9908,
  [SMALL_STATE(139)] = 9942,
  [SMALL_STATE(140)] = 9976,
  [SMALL_STATE(141)] = 10010,
  [SMALL_STATE(142)] = 10044,
  [SMALL_STATE(143)] = 10078,
  [SMALL_STATE(144)] = 10112,
  [SMALL_STATE(145)] = 10146,
  [SMALL_STATE(146)] = 10180,
  [SMALL_STATE(147)] = 10214,
  [SMALL_STATE(148)] = 10248,
  [SMALL_STATE(149)] = 10282,
  [SMALL_STATE(150)] = 10316,
  [SMALL_STATE(151)] = 10350,
  [SMALL_STATE(152)] = 10384,
  [SMALL_STATE(153)] = 10418,
  [SMALL_STATE(154)] = 10452,
  [SMALL_STATE(155)] = 10486,
  [SMALL_STATE(156)] = 10520,
  [SMALL_STATE(157)] = 10554,
  [SMALL_STATE(158)] = 10588,
  [SMALL_STATE(159)] = 10622,
  [SMALL_STATE(160)] = 10656,
  [SMALL_STATE(161)] = 10690,
  [SMALL_STATE(162)] = 10724,
  [SMALL_STATE(163)] = 10758,
  [SMALL_STATE(164)] = 10792,
  [SMALL_STATE(165)] = 10826,
  [SMALL_STATE(166)] = 10860,
  [SMALL_STATE(167)] = 10893,
  [SMALL_STATE(168)] = 10936,
  [SMALL_STATE(169)] = 10966,
  [SMALL_STATE(170)] = 10996,
  [SMALL_STATE(171)] = 11043,
  [SMALL_STATE(172)] = 11080,
  [SMALL_STATE(173)] = 11109,
  [SMALL_STATE(174)] = 11135,
  [SMALL_STATE(175)] = 11173,
  [SMALL_STATE(176)] = 11197,
  [SMALL_STATE(177)] = 11224,
  [SMALL_STATE(178)] = 11244,
  [SMALL_STATE(179)] = 11272,
  [SMALL_STATE(180)] = 11300,
  [SMALL_STATE(181)] = 11328,
  [SMALL_STATE(182)] = 11356,
  [SMALL_STATE(183)] = 11378,
  [SMALL_STATE(184)] = 11399,
  [SMALL_STATE(185)] = 11422,
  [SMALL_STATE(186)] = 11441,
  [SMALL_STATE(187)] = 11464,
  [SMALL_STATE(188)] = 11481,
  [SMALL_STATE(189)] = 11504,
  [SMALL_STATE(190)] = 11523,
  [SMALL_STATE(191)] = 11548,
  [SMALL_STATE(192)] = 11573,
  [SMALL_STATE(193)] = 11591,
  [SMALL_STATE(194)] = 11611,
  [SMALL_STATE(195)] = 11629,
  [SMALL_STATE(196)] = 11647,
  [SMALL_STATE(197)] = 11667,
  [SMALL_STATE(198)] = 11687,
  [SMALL_STATE(199)] = 11705,
  [SMALL_STATE(200)] = 11723,
  [SMALL_STATE(201)] = 11745,
  [SMALL_STATE(202)] = 11765,
  [SMALL_STATE(203)] = 11785,
  [SMALL_STATE(204)] = 11805,
  [SMALL_STATE(205)] = 11825,
  [SMALL_STATE(206)] = 11845,
  [SMALL_STATE(207)] = 11865,
  [SMALL_STATE(208)] = 11882,
  [SMALL_STATE(209)] = 11899,
  [SMALL_STATE(210)] = 11918,
  [SMALL_STATE(211)] = 11935,
  [SMALL_STATE(212)] = 11950,
  [SMALL_STATE(213)] = 11969,
  [SMALL_STATE(214)] = 11986,
  [SMALL_STATE(215)] = 12005,
  [SMALL_STATE(216)] = 12024,
  [SMALL_STATE(217)] = 12043,
  [SMALL_STATE(218)] = 12062,
  [SMALL_STATE(219)] = 12081,
  [SMALL_STATE(220)] = 12100,
  [SMALL_STATE(221)] = 12115,
  [SMALL_STATE(222)] = 12134,
  [SMALL_STATE(223)] = 12153,
  [SMALL_STATE(224)] = 12172,
  [SMALL_STATE(225)] = 12189,
  [SMALL_STATE(226)] = 12204,
  [SMALL_STATE(227)] = 12219,
  [SMALL_STATE(228)] = 12238,
  [SMALL_STATE(229)] = 12253,
  [SMALL_STATE(230)] = 12269,
  [SMALL_STATE(231)] = 12285,
  [SMALL_STATE(232)] = 12298,
  [SMALL_STATE(233)] = 12311,
  [SMALL_STATE(234)] = 12324,
  [SMALL_STATE(235)] = 12337,
  [SMALL_STATE(236)] = 12350,
  [SMALL_STATE(237)] = 12363,
  [SMALL_STATE(238)] = 12376,
  [SMALL_STATE(239)] = 12389,
  [SMALL_STATE(240)] = 12402,
  [SMALL_STATE(241)] = 12415,
  [SMALL_STATE(242)] = 12428,
  [SMALL_STATE(243)] = 12441,
  [SMALL_STATE(244)] = 12454,
  [SMALL_STATE(245)] = 12467,
  [SMALL_STATE(246)] = 12480,
  [SMALL_STATE(247)] = 12493,
  [SMALL_STATE(248)] = 12506,
  [SMALL_STATE(249)] = 12519,
  [SMALL_STATE(250)] = 12532,
  [SMALL_STATE(251)] = 12545,
  [SMALL_STATE(252)] = 12558,
  [SMALL_STATE(253)] = 12571,
  [SMALL_STATE(254)] = 12584,
  [SMALL_STATE(255)] = 12597,
  [SMALL_STATE(256)] = 12610,
  [SMALL_STATE(257)] = 12623,
  [SMALL_STATE(258)] = 12636,
  [SMALL_STATE(259)] = 12649,
  [SMALL_STATE(260)] = 12662,
  [SMALL_STATE(261)] = 12675,
  [SMALL_STATE(262)] = 12688,
  [SMALL_STATE(263)] = 12701,
  [SMALL_STATE(264)] = 12714,
  [SMALL_STATE(265)] = 12727,
  [SMALL_STATE(266)] = 12740,
  [SMALL_STATE(267)] = 12753,
  [SMALL_STATE(268)] = 12766,
  [SMALL_STATE(269)] = 12779,
  [SMALL_STATE(270)] = 12792,
  [SMALL_STATE(271)] = 12805,
  [SMALL_STATE(272)] = 12818,
  [SMALL_STATE(273)] = 12831,
  [SMALL_STATE(274)] = 12844,
  [SMALL_STATE(275)] = 12857,
  [SMALL_STATE(276)] = 12870,
  [SMALL_STATE(277)] = 12883,
  [SMALL_STATE(278)] = 12896,
  [SMALL_STATE(279)] = 12909,
  [SMALL_STATE(280)] = 12922,
  [SMALL_STATE(281)] = 12926,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [7] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chunk, 0, 0, 0),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(63),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(160),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(262),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(47),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(77),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(48),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(73),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(201),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(190),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(181),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(167),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [41] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable, 1, 0, 0),
  [43] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable, 1, 0, 0),
  [45] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__contextual_keyword, 1, 0, 0),
  [47] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__contextual_keyword, 1, 0, 0),
  [49] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dot_index_expression, 3, 0, 29),
  [51] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dot_index_expression, 3, 0, 29),
  [53] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bracket_index_expression, 4, 0, 29),
  [55] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bracket_index_expression, 4, 0, 29),
  [57] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_constructor, 3, 0, 0),
  [59] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table_constructor, 3, 0, 0),
  [61] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0),
  [63] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0),
  [65] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__prefix_expression, 1, 0, 0),
  [67] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__prefix_expression, 1, 0, 0),
  [69] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 1, 0, 0),
  [71] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 1, 0, 0),
  [73] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 14),
  [75] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 14),
  [77] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [79] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [81] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 3, 0, 0),
  [83] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 3, 0, 0),
  [85] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 2, 0, 0),
  [87] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 2, 0, 0),
  [89] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 4, 0, 0),
  [91] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 4, 0, 0),
  [93] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 1, 0, 9),
  [95] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 1, 0, 9),
  [97] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__quote_string, 2, 0, 18),
  [99] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__quote_string, 2, 0, 18),
  [101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_constructor, 2, 0, 0),
  [103] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_table_constructor, 2, 0, 0),
  [105] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__block_string, 3, 0, 16),
  [107] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__block_string, 3, 0, 16),
  [109] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__quote_string, 3, 0, 35),
  [111] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__quote_string, 3, 0, 35),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(60),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(145),
  [117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(80),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(49),
  [121] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__block, 1, 0, 0),
  [123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0),
  [125] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(2),
  [128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0),
  [130] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(148),
  [133] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(272),
  [136] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(160),
  [139] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(262),
  [142] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(47),
  [145] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(77),
  [148] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(48),
  [151] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(73),
  [154] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(201),
  [157] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(190),
  [160] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(181),
  [163] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(167),
  [166] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(75),
  [169] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_statement, 3, 0, 37),
  [171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 36),
  [173] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 36),
  [175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(95),
  [185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(81),
  [187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(83),
  [193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(88),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(84),
  [201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_body, 2, 0, 34),
  [203] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_body, 2, 0, 34),
  [205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_body, 3, 0, 49),
  [207] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_body, 3, 0, 49),
  [209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 2, 0, 17),
  [211] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 2, 0, 17),
  [213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 20),
  [215] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 20),
  [217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(146),
  [219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(79),
  [221] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_statement, 1, 0, 0),
  [223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(29),
  [225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(144),
  [227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(165),
  [229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chunk, 1, 0, 0),
  [231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chunk, 2, 0, 0),
  [233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variable_assignment_explist, 1, 0, 19),
  [235] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__variable_assignment_explist, 1, 0, 19),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(72),
  [241] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__variable_assignment_explist_repeat1, 2, 0, 59),
  [243] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__variable_assignment_explist_repeat1, 2, 0, 59),
  [245] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeat_statement, 3, 0, 22),
  [247] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_repeat_statement, 3, 0, 22),
  [249] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeat_statement, 4, 0, 38),
  [251] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_repeat_statement, 4, 0, 38),
  [253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [255] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 1, 0, 0),
  [257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(219),
  [259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3),
  [261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(40),
  [263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(97),
  [275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(76),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 1, 0, 0),
  [287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__field_list, 2, 0, 0),
  [289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__field_list, 3, 0, 0),
  [291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(93),
  [295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__expression_list_repeat1, 2, 0, 0),
  [297] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__expression_list_repeat1, 2, 0, 0),
  [299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression_list, 1, 0, 0),
  [305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [307] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression_list, 1, 0, 0),
  [309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1, 0, 0),
  [311] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 1, 0, 0),
  [313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__att_name_list, 2, 0, 26),
  [315] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__att_name_list, 2, 0, 26),
  [317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__att_name_list, 1, 0, 7),
  [323] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__att_name_list, 1, 0, 7),
  [325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 1, 0, 19),
  [329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 3, 0, 50),
  [331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__att_name_list_repeat1, 2, 0, 31),
  [333] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__att_name_list_repeat1, 2, 0, 31),
  [335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 5, 0, 67),
  [337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__att_name_list, 4, 0, 58),
  [339] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__att_name_list, 4, 0, 58),
  [341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__att_name_list, 2, 0, 24),
  [343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__att_name_list, 2, 0, 24),
  [345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__att_name_list, 2, 0, 25),
  [347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__att_name_list, 2, 0, 25),
  [349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__att_name_list, 3, 0, 42),
  [351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__att_name_list, 3, 0, 42),
  [353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__att_name_list, 3, 0, 46),
  [355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__att_name_list, 3, 0, 46),
  [357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__attrib, 3, 0, 0),
  [359] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__attrib, 3, 0, 0),
  [361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_numeric_clause, 5, 0, 65),
  [365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__att_name_list, 3, 0, 45),
  [367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__att_name_list, 3, 0, 45),
  [369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__att_name_list_repeat1, 2, 0, 43),
  [371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__att_name_list_repeat1, 2, 0, 43),
  [373] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__att_name_list_repeat1, 2, 0, 43), SHIFT_REPEAT(238),
  [376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [382] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__variable_assignment_explist_repeat1, 2, 0, 60),
  [384] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__variable_assignment_explist_repeat1, 2, 0, 60),
  [386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__variable_assignment_explist_repeat1, 2, 0, 60), SHIFT_REPEAT(82),
  [389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__att_name_list_repeat1, 3, 0, 57),
  [391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__att_name_list_repeat1, 3, 0, 57),
  [393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_numeric_clause, 7, 0, 69),
  [401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variable_assignment_explist, 2, 0, 47),
  [405] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__variable_assignment_explist, 2, 0, 47),
  [407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__global_variable_declaration, 2, 0, 13),
  [409] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__global_variable_declaration, 2, 0, 13),
  [411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 2, 0, 13),
  [415] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 2, 0, 13),
  [417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 1, 0, 4),
  [419] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 1, 0, 4),
  [421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1, 0, 1),
  [423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 1, 0, 1),
  [425] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 3, 0, 23),
  [427] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 3, 0, 23),
  [429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 1, 0, 0),
  [431] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 1, 0, 0),
  [433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__global_implicit_variable_declaration, 3, 0, 27),
  [435] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__global_implicit_variable_declaration, 3, 0, 27),
  [437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_statement, 3, 0, 28),
  [439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_statement, 3, 0, 28),
  [441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 1, 0, 2),
  [443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 1, 0, 2),
  [445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 2, 0, 12),
  [447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 2, 0, 12),
  [449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 1, 0, 3),
  [451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 1, 0, 3),
  [453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__global_implicit_variable_declaration, 2, 0, 0),
  [455] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__global_implicit_variable_declaration, 2, 0, 0),
  [457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__global_variable_declaration, 2, 0, 12),
  [459] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__global_variable_declaration, 2, 0, 12),
  [461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 1, 0, 5),
  [463] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 1, 0, 5),
  [465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 1, 0, 6),
  [467] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 1, 0, 6),
  [469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 4, 0, 37),
  [471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 4, 0, 37),
  [473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 37),
  [475] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 37),
  [477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_statement, 2, 0, 0),
  [479] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_statement, 2, 0, 0),
  [481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__local_function_declaration, 4, 0, 41),
  [483] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__local_function_declaration, 4, 0, 41),
  [485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_empty_statement, 1, 0, 0),
  [487] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_empty_statement, 1, 0, 0),
  [489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variable_assignment, 3, 0, 44),
  [491] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__variable_assignment, 3, 0, 44),
  [493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__global_function_declaration, 4, 0, 41),
  [495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__global_function_declaration, 4, 0, 41),
  [497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 5, 0, 51),
  [499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, 0, 51),
  [501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 52),
  [503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 52),
  [505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 53),
  [507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 53),
  [509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 54),
  [511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 54),
  [513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 5, 0, 56),
  [515] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 5, 0, 56),
  [517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 62),
  [519] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 62),
  [521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 63),
  [523] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 63),
  [525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 64),
  [527] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 64),
  [529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 68),
  [531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, 0, 68),
  [533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_chunk_repeat1, 1, 0, 0),
  [535] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_chunk_repeat1, 1, 0, 0),
  [537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_label_statement, 3, 0, 0),
  [539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_label_statement, 3, 0, 0),
  [541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_statement, 3, 0, 21),
  [543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_statement, 3, 0, 21),
  [545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_goto_statement, 2, 0, 0),
  [547] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_goto_statement, 2, 0, 0),
  [549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 4, 0, 40),
  [551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 4, 0, 40),
  [553] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__field_sep, 1, 0, 0),
  [555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__field_sep, 1, 0, 0),
  [557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(103),
  [559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(243),
  [561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [563] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameters, 3, 0, 48),
  [565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 3, 0, 48),
  [567] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameters, 2, 0, 0),
  [569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 2, 0, 0),
  [571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variable_assignment_varlist, 1, 0, 7),
  [589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [591] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__expression_list_repeat1, 2, 0, 0), SHIFT_REPEAT(71),
  [594] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__variable_assignment_varlist_repeat1, 2, 0, 31),
  [596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression_list, 2, 0, 0),
  [598] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression_list, 2, 0, 0),
  [600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(251),
  [610] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2, 0, 0),
  [612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [614] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 2, 0, 0),
  [616] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__field_list_repeat1, 2, 0, 0), SHIFT_REPEAT(166),
  [619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__field_list_repeat1, 2, 0, 0),
  [621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 55),
  [625] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 55), SHIFT_REPEAT(80),
  [628] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 55),
  [630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_index_expression, 3, 0, 30),
  [632] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__field_list, 1, 0, 0),
  [634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 3, 0, 0),
  [636] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 3, 0, 0),
  [638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [646] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__block, 2, 0, 0),
  [648] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__block, 2, 0, 0),
  [650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19),
  [652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(264),
  [656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__block, 1, 0, 0),
  [658] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__name_list_repeat1, 2, 0, 32), SHIFT_REPEAT(268),
  [661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__name_list_repeat1, 2, 0, 32),
  [663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(30),
  [665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [667] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__doublequote_string_content, 2, 0, 0),
  [669] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__doublequote_string_content, 2, 0, 0), SHIFT_REPEAT(210),
  [672] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__singlequote_string_content, 2, 0, 0),
  [674] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__singlequote_string_content, 2, 0, 0), SHIFT_REPEAT(208),
  [677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__name_list, 1, 0, 7),
  [683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(44),
  [687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15),
  [689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__variable_assignment_varlist_repeat1, 2, 0, 32),
  [691] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__variable_assignment_varlist_repeat1, 2, 0, 32), SHIFT_REPEAT(171),
  [694] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__singlequote_string_content, 1, 0, 0),
  [696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__singlequote_string_content, 1, 0, 0),
  [698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [700] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_list, 1, 0, 7),
  [702] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__doublequote_string_content, 1, 0, 0),
  [704] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__doublequote_string_content, 1, 0, 0),
  [706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [708] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 1, 0, 39),
  [710] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 1, 0, 39),
  [712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [716] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_list, 2, 0, 15),
  [718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variable_assignment_varlist, 2, 0, 15),
  [722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__name_list, 2, 0, 15),
  [724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__name_list_repeat1, 2, 0, 31),
  [726] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_statement, 4, 0, 52),
  [728] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_statement, 4, 0, 52),
  [730] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_name_prefix_expression, 1, 0, 0),
  [732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_name_prefix_expression, 1, 0, 10),
  [734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_name, 1, 0, 0),
  [740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_name_dot_index_expression, 3, 0, 29),
  [742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__vararg_parameter, 1, 0, 0),
  [746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_generic_clause, 3, 0, 33),
  [752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_statement, 2, 0, 21),
  [758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chunk, 3, 0, 0),
  [778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_list, 3, 0, 61),
  [784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__vararg_parameter, 2, 0, 31),
  [786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_name, 1, 0, 11),
  [788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_list, 4, 0, 66),
  [802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [810] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(280),
  [814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_list, 1, 0, 33),
  [828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_name_method_index_expression, 3, 0, 30),
  [834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [840] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comment, 2, 0, 8),
  [842] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comment, 3, 0, 16),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token__block_comment_start = 0,
  ts_external_token__block_comment_content = 1,
  ts_external_token__block_comment_end = 2,
  ts_external_token__block_string_start = 3,
  ts_external_token__block_string_content = 4,
  ts_external_token__block_string_end = 5,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token__block_comment_start] = sym__block_comment_start,
  [ts_external_token__block_comment_content] = sym__block_comment_content,
  [ts_external_token__block_comment_end] = sym__block_comment_end,
  [ts_external_token__block_string_start] = sym__block_string_start,
  [ts_external_token__block_string_content] = sym__block_string_content,
  [ts_external_token__block_string_end] = sym__block_string_end,
};

static const bool ts_external_scanner_states[8][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token__block_comment_start] = true,
    [ts_external_token__block_comment_content] = true,
    [ts_external_token__block_comment_end] = true,
    [ts_external_token__block_string_start] = true,
    [ts_external_token__block_string_content] = true,
    [ts_external_token__block_string_end] = true,
  },
  [2] = {
    [ts_external_token__block_comment_start] = true,
  },
  [3] = {
    [ts_external_token__block_comment_start] = true,
    [ts_external_token__block_string_start] = true,
  },
  [4] = {
    [ts_external_token__block_comment_start] = true,
    [ts_external_token__block_string_end] = true,
  },
  [5] = {
    [ts_external_token__block_comment_start] = true,
    [ts_external_token__block_comment_content] = true,
  },
  [6] = {
    [ts_external_token__block_comment_start] = true,
    [ts_external_token__block_comment_end] = true,
  },
  [7] = {
    [ts_external_token__block_comment_start] = true,
    [ts_external_token__block_string_content] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_lua_external_scanner_create(void);
void tree_sitter_lua_external_scanner_destroy(void *);
bool tree_sitter_lua_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_lua_external_scanner_serialize(void *, char *);
void tree_sitter_lua_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_lua(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .supertype_map_slices = ts_supertype_map_slices,
    .supertype_map_entries = ts_supertype_map_entries,
    .supertype_symbols = ts_supertype_symbols,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_lua_external_scanner_create,
      tree_sitter_lua_external_scanner_destroy,
      tree_sitter_lua_external_scanner_scan,
      tree_sitter_lua_external_scanner_serialize,
      tree_sitter_lua_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
    .name = "lua",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 0,
      .minor_version = 5,
      .patch_version = 0,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
