/* Automatically @generated by tree-sitter */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 115
#define LARGE_STATE_COUNT 17
#define SYMBOL_COUNT 99
#define ALIAS_COUNT 1
#define TOKEN_COUNT 61
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 2
#define MAX_ALIAS_SEQUENCE_LENGTH 5
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 14
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  aux_sym_word_token1 = 1,
  aux_sym_word_noli_token1 = 2,
  aux_sym_word_noli_token2 = 3,
  anon_sym_STAR = 4,
  anon_sym_SQUOTE = 5,
  aux_sym__word_common_token1 = 6,
  aux_sym__word_common_token2 = 7,
  anon_sym_SQUOTE2 = 8,
  aux_sym__word_common_token3 = 9,
  anon_sym_PIPE = 10,
  anon_sym_SQUOTE_PIPE_SQUOTE = 11,
  anon_sym_LBRACE = 12,
  anon_sym_LBRACE_RBRACE = 13,
  aux_sym__word_common_token4 = 14,
  anon_sym_LPAREN = 15,
  anon_sym_RPAREN = 16,
  anon_sym_LBRACK = 17,
  anon_sym_RBRACK = 18,
  anon_sym_TILDE = 19,
  anon_sym_GT = 20,
  anon_sym_COMMA = 21,
  anon_sym_DOT = 22,
  anon_sym_Note_COLON = 23,
  anon_sym_NOTE_COLON = 24,
  anon_sym_Notes_COLON = 25,
  anon_sym_Warning_COLON = 26,
  anon_sym_WARNING_COLON = 27,
  anon_sym_Deprecated = 28,
  anon_sym_DEPRECATED_COLON = 29,
  aux_sym_keycode_token1 = 30,
  aux_sym_keycode_token2 = 31,
  aux_sym_keycode_token3 = 32,
  aux_sym_keycode_token4 = 33,
  aux_sym_keycode_token5 = 34,
  anon_sym_CTRL_DASH_LBRACEchar_RBRACE = 35,
  aux_sym_keycode_token6 = 36,
  aux_sym_keycode_token7 = 37,
  aux_sym_uppercase_name_token1 = 38,
  aux_sym_uppercase_name_token2 = 39,
  anon_sym_LT = 40,
  aux_sym_codeblock_token1 = 41,
  aux_sym_codeblock_token2 = 42,
  aux_sym__blank_token1 = 43,
  aux_sym_line_li_token1 = 44,
  aux_sym_line_code_token1 = 45,
  sym_modeline = 46,
  aux_sym_h1_token1 = 47,
  aux_sym_h2_token1 = 48,
  aux_sym_tag_token1 = 49,
  anon_sym_STAR2 = 50,
  sym_url_word = 51,
  aux_sym_optionlink_token1 = 52,
  aux_sym_taglink_token1 = 53,
  anon_sym_PIPE2 = 54,
  anon_sym_BQUOTE = 55,
  aux_sym_codespan_token1 = 56,
  anon_sym_BQUOTE2 = 57,
  aux_sym_argument_token1 = 58,
  anon_sym_RBRACE = 59,
  anon_sym_QMARK = 60,
  sym_help_file = 61,
  sym__atom = 62,
  sym_word = 63,
  sym__atom_noli = 64,
  sym_word_noli = 65,
  sym__atom_common = 66,
  sym__word_common = 67,
  sym_note = 68,
  sym_keycode = 69,
  sym_uppercase_name = 70,
  sym__uppercase_words = 71,
  sym_block = 72,
  sym_codeblock = 73,
  sym__blank = 74,
  sym_line = 75,
  sym_line_li = 76,
  sym_line_code = 77,
  sym__line_noli = 78,
  sym_column_heading = 79,
  sym__column_heading = 80,
  sym_h1 = 81,
  sym_h2 = 82,
  sym_h3 = 83,
  sym_tag = 84,
  sym_url = 85,
  sym_optionlink = 86,
  sym_taglink = 87,
  sym_codespan = 88,
  sym_argument = 89,
  aux_sym_help_file_repeat1 = 90,
  aux_sym_help_file_repeat2 = 91,
  aux_sym_help_file_repeat3 = 92,
  aux_sym_uppercase_name_repeat1 = 93,
  aux_sym_block_repeat1 = 94,
  aux_sym_block_repeat2 = 95,
  aux_sym_codeblock_repeat1 = 96,
  aux_sym_line_li_repeat1 = 97,
  aux_sym_line_li_repeat2 = 98,
  alias_sym_code = 99,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [aux_sym_word_token1] = "word_token1",
  [aux_sym_word_noli_token1] = "word_noli_token1",
  [aux_sym_word_noli_token2] = "word_noli_token2",
  [anon_sym_STAR] = "*",
  [anon_sym_SQUOTE] = "'",
  [aux_sym__word_common_token1] = "_word_common_token1",
  [aux_sym__word_common_token2] = "_word_common_token2",
  [anon_sym_SQUOTE2] = "'",
  [aux_sym__word_common_token3] = "_word_common_token3",
  [anon_sym_PIPE] = "|",
  [anon_sym_SQUOTE_PIPE_SQUOTE] = "'|'",
  [anon_sym_LBRACE] = "{",
  [anon_sym_LBRACE_RBRACE] = "{}",
  [aux_sym__word_common_token4] = "_word_common_token4",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_TILDE] = "~",
  [anon_sym_GT] = ">",
  [anon_sym_COMMA] = ",",
  [anon_sym_DOT] = ".",
  [anon_sym_Note_COLON] = "Note:",
  [anon_sym_NOTE_COLON] = "NOTE:",
  [anon_sym_Notes_COLON] = "Notes:",
  [anon_sym_Warning_COLON] = "Warning:",
  [anon_sym_WARNING_COLON] = "WARNING:",
  [anon_sym_Deprecated] = "Deprecated",
  [anon_sym_DEPRECATED_COLON] = "DEPRECATED:",
  [aux_sym_keycode_token1] = "keycode_token1",
  [aux_sym_keycode_token2] = "keycode_token2",
  [aux_sym_keycode_token3] = "keycode_token3",
  [aux_sym_keycode_token4] = "keycode_token4",
  [aux_sym_keycode_token5] = "keycode_token5",
  [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = "CTRL-{char}",
  [aux_sym_keycode_token6] = "keycode_token6",
  [aux_sym_keycode_token7] = "keycode_token7",
  [aux_sym_uppercase_name_token1] = "uppercase_name_token1",
  [aux_sym_uppercase_name_token2] = "uppercase_name_token2",
  [anon_sym_LT] = "<",
  [aux_sym_codeblock_token1] = "language",
  [aux_sym_codeblock_token2] = "codeblock_token2",
  [aux_sym__blank_token1] = "_blank_token1",
  [aux_sym_line_li_token1] = "prefix",
  [aux_sym_line_code_token1] = "line_code_token1",
  [sym_modeline] = "modeline",
  [aux_sym_h1_token1] = "delimiter",
  [aux_sym_h2_token1] = "delimiter",
  [aux_sym_tag_token1] = "word",
  [anon_sym_STAR2] = "*",
  [sym_url_word] = "word",
  [aux_sym_optionlink_token1] = "word",
  [aux_sym_taglink_token1] = "word",
  [anon_sym_PIPE2] = "|",
  [anon_sym_BQUOTE] = "`",
  [aux_sym_codespan_token1] = "word",
  [anon_sym_BQUOTE2] = "`",
  [aux_sym_argument_token1] = "word",
  [anon_sym_RBRACE] = "}",
  [anon_sym_QMARK] = "\?",
  [sym_help_file] = "help_file",
  [sym__atom] = "_atom",
  [sym_word] = "word",
  [sym__atom_noli] = "_atom_noli",
  [sym_word_noli] = "word",
  [sym__atom_common] = "_atom_common",
  [sym__word_common] = "_word_common",
  [sym_note] = "note",
  [sym_keycode] = "keycode",
  [sym_uppercase_name] = "heading",
  [sym__uppercase_words] = "_uppercase_words",
  [sym_block] = "block",
  [sym_codeblock] = "codeblock",
  [sym__blank] = "_blank",
  [sym_line] = "line",
  [sym_line_li] = "line_li",
  [sym_line_code] = "line",
  [sym__line_noli] = "_line_noli",
  [sym_column_heading] = "column_heading",
  [sym__column_heading] = "heading",
  [sym_h1] = "h1",
  [sym_h2] = "h2",
  [sym_h3] = "h3",
  [sym_tag] = "tag",
  [sym_url] = "url",
  [sym_optionlink] = "optionlink",
  [sym_taglink] = "taglink",
  [sym_codespan] = "codespan",
  [sym_argument] = "argument",
  [aux_sym_help_file_repeat1] = "help_file_repeat1",
  [aux_sym_help_file_repeat2] = "help_file_repeat2",
  [aux_sym_help_file_repeat3] = "help_file_repeat3",
  [aux_sym_uppercase_name_repeat1] = "uppercase_name_repeat1",
  [aux_sym_block_repeat1] = "block_repeat1",
  [aux_sym_block_repeat2] = "block_repeat2",
  [aux_sym_codeblock_repeat1] = "codeblock_repeat1",
  [aux_sym_line_li_repeat1] = "line_li_repeat1",
  [aux_sym_line_li_repeat2] = "line_li_repeat2",
  [alias_sym_code] = "code",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [aux_sym_word_token1] = aux_sym_word_token1,
  [aux_sym_word_noli_token1] = aux_sym_word_noli_token1,
  [aux_sym_word_noli_token2] = aux_sym_word_noli_token2,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [aux_sym__word_common_token1] = aux_sym__word_common_token1,
  [aux_sym__word_common_token2] = aux_sym__word_common_token2,
  [anon_sym_SQUOTE2] = anon_sym_SQUOTE,
  [aux_sym__word_common_token3] = aux_sym__word_common_token3,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_SQUOTE_PIPE_SQUOTE] = anon_sym_SQUOTE_PIPE_SQUOTE,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_LBRACE_RBRACE] = anon_sym_LBRACE_RBRACE,
  [aux_sym__word_common_token4] = aux_sym__word_common_token4,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_Note_COLON] = anon_sym_Note_COLON,
  [anon_sym_NOTE_COLON] = anon_sym_NOTE_COLON,
  [anon_sym_Notes_COLON] = anon_sym_Notes_COLON,
  [anon_sym_Warning_COLON] = anon_sym_Warning_COLON,
  [anon_sym_WARNING_COLON] = anon_sym_WARNING_COLON,
  [anon_sym_Deprecated] = anon_sym_Deprecated,
  [anon_sym_DEPRECATED_COLON] = anon_sym_DEPRECATED_COLON,
  [aux_sym_keycode_token1] = aux_sym_keycode_token1,
  [aux_sym_keycode_token2] = aux_sym_keycode_token2,
  [aux_sym_keycode_token3] = aux_sym_keycode_token3,
  [aux_sym_keycode_token4] = aux_sym_keycode_token4,
  [aux_sym_keycode_token5] = aux_sym_keycode_token5,
  [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
  [aux_sym_keycode_token6] = aux_sym_keycode_token6,
  [aux_sym_keycode_token7] = aux_sym_keycode_token7,
  [aux_sym_uppercase_name_token1] = aux_sym_uppercase_name_token1,
  [aux_sym_uppercase_name_token2] = aux_sym_uppercase_name_token2,
  [anon_sym_LT] = anon_sym_LT,
  [aux_sym_codeblock_token1] = aux_sym_codeblock_token1,
  [aux_sym_codeblock_token2] = aux_sym_codeblock_token2,
  [aux_sym__blank_token1] = aux_sym__blank_token1,
  [aux_sym_line_li_token1] = aux_sym_line_li_token1,
  [aux_sym_line_code_token1] = aux_sym_line_code_token1,
  [sym_modeline] = sym_modeline,
  [aux_sym_h1_token1] = aux_sym_h1_token1,
  [aux_sym_h2_token1] = aux_sym_h1_token1,
  [aux_sym_tag_token1] = sym_word,
  [anon_sym_STAR2] = anon_sym_STAR,
  [sym_url_word] = sym_word,
  [aux_sym_optionlink_token1] = sym_word,
  [aux_sym_taglink_token1] = sym_word,
  [anon_sym_PIPE2] = anon_sym_PIPE,
  [anon_sym_BQUOTE] = anon_sym_BQUOTE,
  [aux_sym_codespan_token1] = sym_word,
  [anon_sym_BQUOTE2] = anon_sym_BQUOTE,
  [aux_sym_argument_token1] = sym_word,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [sym_help_file] = sym_help_file,
  [sym__atom] = sym__atom,
  [sym_word] = sym_word,
  [sym__atom_noli] = sym__atom_noli,
  [sym_word_noli] = sym_word,
  [sym__atom_common] = sym__atom_common,
  [sym__word_common] = sym__word_common,
  [sym_note] = sym_note,
  [sym_keycode] = sym_keycode,
  [sym_uppercase_name] = sym_uppercase_name,
  [sym__uppercase_words] = sym__uppercase_words,
  [sym_block] = sym_block,
  [sym_codeblock] = sym_codeblock,
  [sym__blank] = sym__blank,
  [sym_line] = sym_line,
  [sym_line_li] = sym_line_li,
  [sym_line_code] = sym_line,
  [sym__line_noli] = sym__line_noli,
  [sym_column_heading] = sym_column_heading,
  [sym__column_heading] = sym_uppercase_name,
  [sym_h1] = sym_h1,
  [sym_h2] = sym_h2,
  [sym_h3] = sym_h3,
  [sym_tag] = sym_tag,
  [sym_url] = sym_url,
  [sym_optionlink] = sym_optionlink,
  [sym_taglink] = sym_taglink,
  [sym_codespan] = sym_codespan,
  [sym_argument] = sym_argument,
  [aux_sym_help_file_repeat1] = aux_sym_help_file_repeat1,
  [aux_sym_help_file_repeat2] = aux_sym_help_file_repeat2,
  [aux_sym_help_file_repeat3] = aux_sym_help_file_repeat3,
  [aux_sym_uppercase_name_repeat1] = aux_sym_uppercase_name_repeat1,
  [aux_sym_block_repeat1] = aux_sym_block_repeat1,
  [aux_sym_block_repeat2] = aux_sym_block_repeat2,
  [aux_sym_codeblock_repeat1] = aux_sym_codeblock_repeat1,
  [aux_sym_line_li_repeat1] = aux_sym_line_li_repeat1,
  [aux_sym_line_li_repeat2] = aux_sym_line_li_repeat2,
  [alias_sym_code] = alias_sym_code,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_word_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_word_noli_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_word_noli_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__word_common_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__word_common_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_SQUOTE2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__word_common_token3] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE_PIPE_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__word_common_token4] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Note_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_NOTE_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Notes_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Warning_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_WARNING_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Deprecated] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DEPRECATED_COLON] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_keycode_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_keycode_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_keycode_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_keycode_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_keycode_token5] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_keycode_token6] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_keycode_token7] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_uppercase_name_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_uppercase_name_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_codeblock_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_codeblock_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__blank_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_line_li_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_line_code_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_modeline] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_h1_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_h2_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_tag_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_STAR2] = {
    .visible = true,
    .named = false,
  },
  [sym_url_word] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_optionlink_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_taglink_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_PIPE2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_codespan_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_BQUOTE2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_argument_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [sym_help_file] = {
    .visible = true,
    .named = true,
  },
  [sym__atom] = {
    .visible = false,
    .named = true,
  },
  [sym_word] = {
    .visible = true,
    .named = true,
  },
  [sym__atom_noli] = {
    .visible = false,
    .named = true,
  },
  [sym_word_noli] = {
    .visible = true,
    .named = true,
  },
  [sym__atom_common] = {
    .visible = false,
    .named = true,
  },
  [sym__word_common] = {
    .visible = false,
    .named = true,
  },
  [sym_note] = {
    .visible = true,
    .named = true,
  },
  [sym_keycode] = {
    .visible = true,
    .named = true,
  },
  [sym_uppercase_name] = {
    .visible = true,
    .named = true,
  },
  [sym__uppercase_words] = {
    .visible = false,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_codeblock] = {
    .visible = true,
    .named = true,
  },
  [sym__blank] = {
    .visible = false,
    .named = true,
  },
  [sym_line] = {
    .visible = true,
    .named = true,
  },
  [sym_line_li] = {
    .visible = true,
    .named = true,
  },
  [sym_line_code] = {
    .visible = true,
    .named = true,
  },
  [sym__line_noli] = {
    .visible = false,
    .named = true,
  },
  [sym_column_heading] = {
    .visible = true,
    .named = true,
  },
  [sym__column_heading] = {
    .visible = true,
    .named = true,
  },
  [sym_h1] = {
    .visible = true,
    .named = true,
  },
  [sym_h2] = {
    .visible = true,
    .named = true,
  },
  [sym_h3] = {
    .visible = true,
    .named = true,
  },
  [sym_tag] = {
    .visible = true,
    .named = true,
  },
  [sym_url] = {
    .visible = true,
    .named = true,
  },
  [sym_optionlink] = {
    .visible = true,
    .named = true,
  },
  [sym_taglink] = {
    .visible = true,
    .named = true,
  },
  [sym_codespan] = {
    .visible = true,
    .named = true,
  },
  [sym_argument] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_help_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_help_file_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_help_file_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_uppercase_name_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_codeblock_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_line_li_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_line_li_repeat2] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_code] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_blank = 1,
  field_text = 2,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_blank] = "blank",
  [field_text] = "text",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 1},
  [3] = {.index = 1, .length = 1},
  [5] = {.index = 2, .length = 1},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_blank, 0},
  [1] =
    {field_text, 0},
  [2] =
    {field_text, 1},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = sym_word,
  },
  [4] = {
    [0] = sym_word,
    [1] = sym_word,
  },
  [6] = {
    [2] = alias_sym_code,
  },
  [7] = {
    [1] = sym_line,
    [2] = sym_line,
  },
  [8] = {
    [1] = sym_line,
  },
  [9] = {
    [1] = sym_uppercase_name,
  },
  [10] = {
    [1] = aux_sym_h1_token1,
  },
  [11] = {
    [2] = sym_line,
    [3] = sym_line,
  },
  [12] = {
    [2] = sym_line,
  },
  [13] = {
    [0] = sym_line,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym__line_noli, 2,
    sym__line_noli,
    sym_line,
  aux_sym_uppercase_name_repeat1, 2,
    aux_sym_uppercase_name_repeat1,
    sym_word,
  aux_sym_codeblock_repeat1, 2,
    aux_sym_codeblock_repeat1,
    alias_sym_code,
  aux_sym_line_li_repeat1, 3,
    aux_sym_line_li_repeat1,
    sym_line,
    sym_uppercase_name,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 43,
  [49] = 44,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 46,
  [64] = 47,
  [65] = 65,
  [66] = 55,
  [67] = 56,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 69,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 97,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(38);
      ADVANCE_MAP(
        '\n', 634,
        '\'', 736,
        '(', 743,
        ')', 742,
        '*', 744,
        ',', 743,
        '.', 743,
        '<', 739,
        '>', 742,
        '?', 742,
        'A', 675,
        'C', 684,
        'D', 665,
        'M', 669,
        'N', 679,
        'W', 659,
        '[', 743,
        ']', 742,
        '`', 742,
        'h', 729,
        '{', 734,
        '|', 742,
        '}', 742,
        '~', 742,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(35);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(741);
      if (lookahead != 0) ADVANCE(742);
      END_STATE();
    case 1:
      if (lookahead == '\t') ADVANCE(25);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == ' ') ADVANCE(636);
      if (lookahead == '.') ADVANCE(374);
      if (lookahead != 0) ADVANCE(237);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '\n', 634,
        '\'', 381,
        '(', 437,
        ')', 443,
        '*', 376,
        ',', 465,
        '.', 469,
        '<', 139,
        '>', 461,
        'A', 84,
        'C', 94,
        'D', 72,
        'M', 78,
        'N', 89,
        'W', 64,
        '[', 449,
        ']', 453,
        '`', 849,
        'h', 43,
        '{', 428,
        '|', 421,
        '~', 457,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(5);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(44);
      if (lookahead != 0) ADVANCE(143);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '\n', 635,
        '\'', 736,
        '(', 743,
        ')', 742,
        '*', 376,
        ',', 743,
        '.', 743,
        '<', 739,
        '>', 742,
        'A', 675,
        'C', 684,
        'D', 665,
        'M', 669,
        'N', 679,
        'W', 659,
        '[', 743,
        ']', 742,
        '`', 742,
        'h', 731,
        '{', 734,
        '|', 737,
        '~', 742,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(5);
      if (lookahead != 0) ADVANCE(742);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '\n', 635,
        '\'', 381,
        '(', 437,
        ')', 443,
        '*', 376,
        ',', 465,
        '.', 469,
        '<', 139,
        '>', 461,
        '?', 960,
        'A', 84,
        'C', 94,
        'D', 72,
        'M', 78,
        'N', 89,
        'W', 64,
        '[', 449,
        ']', 453,
        '`', 849,
        'h', 134,
        '{', 428,
        '|', 421,
        '~', 457,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(5);
      if (lookahead != 0) ADVANCE(143);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '\n', 635,
        '\'', 381,
        '(', 437,
        ')', 443,
        '*', 376,
        ',', 465,
        '.', 469,
        '<', 139,
        '>', 461,
        'A', 84,
        'C', 94,
        'D', 72,
        'M', 78,
        'N', 89,
        'W', 64,
        '[', 449,
        ']', 453,
        '`', 849,
        'h', 134,
        '{', 428,
        '|', 421,
        '~', 457,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(5);
      if (lookahead != 0) ADVANCE(143);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '\n', 635,
        '\'', 381,
        '(', 440,
        ')', 448,
        '*', 379,
        ',', 467,
        '.', 472,
        '<', 392,
        '>', 464,
        'A', 387,
        'C', 389,
        'D', 385,
        'M', 386,
        'N', 388,
        'W', 384,
        '[', 451,
        ']', 456,
        '`', 852,
        'h', 390,
        '{', 429,
        '|', 422,
        '~', 460,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(5);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(391);
      if (lookahead != 0) ADVANCE(393);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '\n', 635,
        '\'', 381,
        '(', 441,
        ')', 446,
        '*', 376,
        ',', 465,
        '.', 473,
        '<', 139,
        '>', 461,
        'A', 83,
        'C', 97,
        'D', 76,
        'M', 77,
        'N', 88,
        'W', 65,
        '[', 449,
        ']', 453,
        '`', 849,
        'h', 134,
        '{', 428,
        '|', 421,
        '~', 457,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(7);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z')) ADVANCE(138);
      if (lookahead != 0) ADVANCE(143);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '\n', 635,
        '\'', 380,
        '(', 438,
        ')', 444,
        '*', 377,
        ',', 466,
        '.', 470,
        '<', 238,
        '>', 462,
        'A', 186,
        'C', 195,
        'D', 177,
        'M', 181,
        'N', 190,
        'W', 170,
        '[', 450,
        ']', 454,
        '`', 850,
        'h', 233,
        '{', 427,
        '|', 420,
        '~', 458,
        '\t', 8,
        ' ', 8,
        '-', 1,
        0x2022, 1,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(154);
      if (lookahead != 0) ADVANCE(239);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '\n', 635,
        '\'', 846,
        '(', 847,
        ')', 846,
        '*', 846,
        ',', 847,
        '.', 847,
        '<', 844,
        '>', 846,
        'A', 785,
        'C', 794,
        'D', 775,
        'M', 779,
        'N', 789,
        'W', 769,
        '[', 847,
        ']', 846,
        '`', 846,
        'h', 838,
        '{', 841,
        '|', 421,
        '~', 846,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(5);
      if (lookahead != 0) ADVANCE(846);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '\n', 635,
        '\'', 383,
        '(', 442,
        ')', 447,
        '*', 378,
        ',', 468,
        '.', 474,
        '<', 955,
        '>', 463,
        'A', 892,
        'C', 901,
        'D', 882,
        'M', 886,
        'N', 896,
        'W', 875,
        '[', 452,
        ']', 455,
        '`', 851,
        'h', 946,
        '{', 430,
        '|', 423,
        '}', 143,
        '~', 459,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(5);
      if (lookahead != 0) ADVANCE(957);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '\n', 635,
        '\'', 416,
        '(', 437,
        ')', 443,
        '*', 376,
        ',', 465,
        '.', 469,
        '<', 139,
        '>', 461,
        'A', 84,
        'C', 94,
        'D', 72,
        'M', 78,
        'N', 89,
        'W', 64,
        '[', 449,
        ']', 453,
        '`', 849,
        'h', 134,
        '{', 428,
        '|', 421,
        '~', 457,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(5);
      if (lookahead != 0) ADVANCE(143);
      END_STATE();
    case 12:
      if (lookahead == '\n') ADVANCE(635);
      if (lookahead == '\'') ADVANCE(415);
      if (lookahead == '*') ADVANCE(744);
      if (lookahead == '<') ADVANCE(631);
      if (lookahead == '`') ADVANCE(854);
      if (lookahead == '|') ADVANCE(848);
      if (lookahead == '}') ADVANCE(959);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(18);
      if (lookahead == '-' ||
          lookahead == 0x2022) ADVANCE(26);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(31);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '\n', 635,
        '\'', 382,
        '(', 437,
        ')', 443,
        '*', 376,
        ',', 465,
        '.', 469,
        '<', 366,
        '>', 461,
        'A', 313,
        'C', 322,
        'D', 304,
        'M', 307,
        'N', 317,
        'W', 297,
        '[', 449,
        ']', 453,
        '`', 849,
        'h', 362,
        '{', 428,
        '|', 421,
        '~', 457,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(13);
      if (lookahead == '-' ||
          lookahead == 0x2022) ADVANCE(28);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(270);
      if (lookahead != 0) ADVANCE(367);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        '\n', 635,
        '\'', 382,
        '(', 439,
        ')', 445,
        '*', 376,
        ',', 465,
        '-', 27,
        '.', 471,
        '<', 632,
        '=', 283,
        '>', 461,
        'A', 248,
        'C', 250,
        'D', 246,
        'M', 247,
        'N', 249,
        'W', 245,
        '[', 449,
        ']', 453,
        '`', 849,
        'h', 362,
        '{', 428,
        '|', 421,
        '~', 457,
        0x2022, 28,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(13);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(252);
      if (('B' <= lookahead && lookahead <= 'Z')) ADVANCE(251);
      if (lookahead != 0) ADVANCE(367);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        '\n', 635,
        '\'', 382,
        '(', 439,
        ')', 445,
        '*', 376,
        ',', 465,
        '-', 27,
        '.', 471,
        '<', 632,
        '=', 283,
        '>', 461,
        'A', 248,
        'C', 250,
        'D', 246,
        'M', 247,
        'N', 249,
        'W', 245,
        '[', 449,
        ']', 453,
        '`', 849,
        'h', 362,
        '{', 428,
        '|', 421,
        '~', 457,
        0x2022, 28,
        '\t', 8,
        ' ', 8,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(252);
      if (('B' <= lookahead && lookahead <= 'Z')) ADVANCE(251);
      if (lookahead != 0) ADVANCE(367);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '\n', 635,
        '\'', 382,
        '(', 439,
        ')', 445,
        '*', 376,
        ',', 465,
        '.', 471,
        '<', 632,
        '>', 461,
        'A', 248,
        'C', 250,
        'D', 246,
        'M', 247,
        'N', 249,
        'W', 245,
        '[', 449,
        ']', 453,
        '`', 849,
        'h', 362,
        '{', 428,
        '|', 421,
        '~', 457,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(13);
      if (lookahead == '-' ||
          lookahead == 0x2022) ADVANCE(28);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(252);
      if (('B' <= lookahead && lookahead <= 'Z')) ADVANCE(251);
      if (lookahead != 0) ADVANCE(367);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '\n', 635,
        '\'', 382,
        '(', 439,
        ')', 445,
        '*', 376,
        ',', 465,
        '.', 471,
        '<', 632,
        '>', 461,
        'A', 248,
        'C', 250,
        'D', 246,
        'M', 247,
        'N', 249,
        'W', 245,
        '[', 449,
        ']', 453,
        '`', 849,
        'h', 362,
        '{', 428,
        '|', 421,
        '~', 457,
        '\t', 8,
        ' ', 8,
        '-', 28,
        0x2022, 28,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(252);
      if (('B' <= lookahead && lookahead <= 'Z')) ADVANCE(251);
      if (lookahead != 0) ADVANCE(367);
      END_STATE();
    case 18:
      if (lookahead == '\n') ADVANCE(635);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(18);
      if (lookahead == '-' ||
          lookahead == 0x2022) ADVANCE(26);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(31);
      END_STATE();
    case 19:
      if (lookahead == '\n') ADVANCE(639);
      if (lookahead != 0) ADVANCE(19);
      END_STATE();
    case 20:
      if (lookahead == '\n') ADVANCE(641);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(20);
      END_STATE();
    case 21:
      if (lookahead == '\n') ADVANCE(640);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(21);
      END_STATE();
    case 22:
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == ' ') ADVANCE(636);
      if (lookahead != 0) ADVANCE(25);
      END_STATE();
    case 23:
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '>') ADVANCE(503);
      if (lookahead != 0) ADVANCE(25);
      END_STATE();
    case 24:
      ADVANCE_MAP(
        '\n', 638,
        '\t', 25,
        ' ', 25,
        ']', 25,
        ')', 24,
        ',', 24,
        '.', 24,
        ':', 24,
      );
      if (lookahead != 0) ADVANCE(746);
      END_STATE();
    case 25:
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead != 0) ADVANCE(25);
      END_STATE();
    case 26:
      if (lookahead == ' ') ADVANCE(637);
      END_STATE();
    case 27:
      if (lookahead == ' ') ADVANCE(637);
      if (lookahead == '-') ADVANCE(267);
      if (lookahead == '.') ADVANCE(375);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(368);
      END_STATE();
    case 28:
      if (lookahead == ' ') ADVANCE(637);
      if (lookahead == '.') ADVANCE(375);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(368);
      END_STATE();
    case 29:
      if (lookahead == '.') ADVANCE(26);
      END_STATE();
    case 30:
      if (lookahead == '.') ADVANCE(26);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(29);
      END_STATE();
    case 31:
      if (lookahead == '.') ADVANCE(26);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(30);
      END_STATE();
    case 32:
      if (lookahead == '>') ADVANCE(501);
      END_STATE();
    case 33:
      if (lookahead == ')' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == ':') ADVANCE(33);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ']') ADVANCE(749);
      END_STATE();
    case 34:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '`') ADVANCE(853);
      END_STATE();
    case 35:
      if (eof) ADVANCE(38);
      ADVANCE_MAP(
        '\n', 635,
        '\'', 381,
        '(', 437,
        ')', 443,
        '*', 376,
        ',', 465,
        '.', 469,
        '<', 139,
        '>', 461,
        'A', 84,
        'C', 94,
        'D', 72,
        'M', 78,
        'N', 89,
        'W', 64,
        '[', 449,
        ']', 453,
        '`', 849,
        'h', 134,
        '{', 428,
        '|', 419,
        '~', 457,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(35);
      if (lookahead != 0) ADVANCE(143);
      END_STATE();
    case 36:
      if (eof) ADVANCE(38);
      ADVANCE_MAP(
        '\n', 635,
        '\'', 382,
        '(', 437,
        ')', 443,
        '*', 376,
        ',', 465,
        '.', 469,
        '<', 366,
        '>', 461,
        'A', 313,
        'C', 322,
        'D', 304,
        'M', 307,
        'N', 317,
        'W', 297,
        '[', 449,
        ']', 453,
        '`', 849,
        'h', 362,
        'v', 342,
        '{', 428,
        '|', 421,
        '~', 457,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(36);
      if (lookahead == '-' ||
          lookahead == 0x2022) ADVANCE(28);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(270);
      if (lookahead != 0) ADVANCE(367);
      END_STATE();
    case 37:
      if (eof) ADVANCE(38);
      ADVANCE_MAP(
        '\n', 635,
        '\'', 382,
        '(', 439,
        ')', 445,
        '*', 376,
        ',', 465,
        '-', 27,
        '.', 471,
        '<', 632,
        '=', 283,
        '>', 461,
        'A', 248,
        'C', 250,
        'D', 246,
        'M', 247,
        'N', 249,
        'W', 245,
        '[', 449,
        ']', 453,
        '`', 849,
        'h', 362,
        'v', 342,
        '{', 428,
        '|', 421,
        '~', 457,
        0x2022, 28,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(36);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(252);
      if (('B' <= lookahead && lookahead <= 'Z')) ADVANCE(251);
      if (lookahead != 0) ADVANCE(367);
      END_STATE();
    case 38:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '\n') ADVANCE(633);
      if (lookahead == ':') ADVANCE(52);
      if (lookahead == 's') ADVANCE(40);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(44);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '\n') ADVANCE(633);
      if (lookahead == ':') ADVANCE(52);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(44);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 41:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '\n') ADVANCE(633);
      if (lookahead == 'p') ADVANCE(39);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(44);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '\n') ADVANCE(633);
      if (lookahead == 't') ADVANCE(41);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(44);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '\n') ADVANCE(633);
      if (lookahead == 't') ADVANCE(42);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(44);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '\n') ADVANCE(633);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(44);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '\'') ADVANCE(424);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '\'' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '-') ADVANCE(62);
      if (lookahead == '>') ADVANCE(497);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(61);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          (lookahead < ',' || '.' < lookahead) &&
          (lookahead < 'A' || '[' < lookahead)) ADVANCE(143);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '-') ADVANCE(140);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          (lookahead < ',' || '.' < lookahead) &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '-') ADVANCE(68);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          (lookahead < ',' || '.' < lookahead) &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '-') ADVANCE(141);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          (lookahead < ',' || '.' < lookahead) &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '-') ADVANCE(142);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          (lookahead < ',' || '.' < lookahead) &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '/') ADVANCE(101);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '/' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '/') ADVANCE(51);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '/' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == ':') ADVANCE(478);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == ':') ADVANCE(475);
      if (lookahead == 's') ADVANCE(57);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == ':') ADVANCE(52);
      if (lookahead == 's') ADVANCE(56);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == ':') ADVANCE(52);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == ':') ADVANCE(481);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == ':') ADVANCE(487);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == ':') ADVANCE(484);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == ':') ADVANCE(494);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '>') ADVANCE(497);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(61);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          (lookahead < ',' || '.' < lookahead) &&
          (lookahead < 'A' || '[' < lookahead)) ADVANCE(143);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '>') ADVANCE(500);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(32);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(61);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(63);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '>') ADVANCE(501);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'A') ADVANCE(91);
      if (lookahead == 'a') ADVANCE(126);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'A') ADVANCE(619);
      if (lookahead == 'a') ADVANCE(126);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          (lookahead < ',' || '.' < lookahead) &&
          (lookahead < 'A' || '[' < lookahead)) ADVANCE(143);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'A') ADVANCE(99);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'A') ADVANCE(49);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(aux_sym_word_token1);
      ADVANCE_MAP(
        'B', 527,
        'D', 521,
        'I', 524,
        'P', 516,
        'S', 513,
        '{', 519,
        '\t', 504,
        ' ', 504,
        '(', 504,
        ',', 504,
        '.', 504,
        '[', 504,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(504);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'C') ADVANCE(66);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'D') ADVANCE(122);
      if (lookahead == 'U') ADVANCE(123);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'D') ADVANCE(60);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'E') ADVANCE(90);
      if (lookahead == 'e') ADVANCE(124);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'E') ADVANCE(53);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'E') ADVANCE(69);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'E') ADVANCE(71);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'E') ADVANCE(617);
      if (lookahead == 'e') ADVANCE(124);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          (lookahead < ',' || '.' < lookahead) &&
          (lookahead < 'A' || '[' < lookahead)) ADVANCE(143);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'E') ADVANCE(622);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          (lookahead < ',' || '.' < lookahead) &&
          (lookahead < 'A' || '[' < lookahead)) ADVANCE(143);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'E') ADVANCE(96);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'F') ADVANCE(100);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'G') ADVANCE(58);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'I') ADVANCE(79);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'I') ADVANCE(87);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'L') ADVANCE(621);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          (lookahead < ',' || '.' < lookahead) &&
          (lookahead < 'A' || '[' < lookahead)) ADVANCE(143);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'L') ADVANCE(95);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'L') ADVANCE(48);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'N') ADVANCE(82);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'N') ADVANCE(80);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'O') ADVANCE(623);
      if (lookahead == 'o') ADVANCE(131);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          (lookahead < ',' || '.' < lookahead) &&
          (lookahead < 'A' || '[' < lookahead)) ADVANCE(143);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'O') ADVANCE(98);
      if (lookahead == 'o') ADVANCE(131);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'P') ADVANCE(93);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'R') ADVANCE(86);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'R') ADVANCE(85);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'R') ADVANCE(74);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'T') ADVANCE(92);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'T') ADVANCE(47);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'T') ADVANCE(67);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'T') ADVANCE(618);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          (lookahead < ',' || '.' < lookahead) &&
          (lookahead < 'A' || '[' < lookahead)) ADVANCE(143);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'T') ADVANCE(73);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'T') ADVANCE(75);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'T') ADVANCE(50);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == ']') ADVANCE(143);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(749);
      if (lookahead == ')' ||
          lookahead == ':') ADVANCE(101);
      if (lookahead == ',' ||
          lookahead == '.') ADVANCE(33);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(748);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'a') ADVANCE(117);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'a') ADVANCE(135);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'a') ADVANCE(127);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'c') ADVANCE(103);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'd') ADVANCE(490);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'e') ADVANCE(54);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'e') ADVANCE(105);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'e') ADVANCE(70);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'e') ADVANCE(106);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'e') ADVANCE(102);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'e') ADVANCE(129);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'g') ADVANCE(109);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'g') ADVANCE(59);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'h') ADVANCE(104);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'i') ADVANCE(120);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'k') ADVANCE(537);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'l') ADVANCE(537);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'n') ADVANCE(116);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'n') ADVANCE(114);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'n') ADVANCE(537);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'o') ADVANCE(136);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'p') ADVANCE(537);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'p') ADVANCE(128);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'p') ADVANCE(55);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'r') ADVANCE(119);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'r') ADVANCE(137);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'r') ADVANCE(108);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'r') ADVANCE(132);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 's') ADVANCE(112);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 't') ADVANCE(107);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 't') ADVANCE(537);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 't') ADVANCE(125);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 't') ADVANCE(133);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 't') ADVANCE(110);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'w') ADVANCE(121);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '}') ADVANCE(539);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          (lookahead < ',' || '.' < lookahead) &&
          (lookahead < 'A' || '[' < lookahead)) ADVANCE(143);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == 'A' ||
          lookahead == 'C' ||
          lookahead == 'D' ||
          lookahead == 'M' ||
          lookahead == 'S') ADVANCE(46);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(61);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          (lookahead < ',' || '.' < lookahead) &&
          (lookahead < 'A' || '[' < lookahead)) ADVANCE(143);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(546);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(546);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(541);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(541);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(532);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(532);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(aux_sym_word_token1);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != ',' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(143);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(639);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(19);
      if (lookahead != 0) ADVANCE(144);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(641);
      if (lookahead == '-') ADVANCE(145);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(20);
      if (lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(375);
      if (lookahead != 0) ADVANCE(368);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(640);
      if (lookahead == '=') ADVANCE(146);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(21);
      if (lookahead != 0 &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\'') ADVANCE(425);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '-') ADVANCE(173);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      ADVANCE_MAP(
        '\n', 638,
        '-', 168,
        '>', 499,
        '\t', 25,
        ' ', 25,
        '(', 25,
        '.', 25,
        '[', 25,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(167);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '-') ADVANCE(240);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '-') ADVANCE(241);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '-') ADVANCE(242);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '.') ADVANCE(22);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '[') ADVANCE(25);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(155);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '.') ADVANCE(22);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '[') ADVANCE(25);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(153);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '.') ADVANCE(22);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      ADVANCE_MAP(
        '\n', 638,
        '.', 24,
        ']', 243,
        '\t', 25,
        ' ', 25,
        '(', 746,
        '[', 746,
        ')', 156,
        ',', 156,
        ':', 156,
      );
      if (lookahead != 0) ADVANCE(745);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '/') ADVANCE(156);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == ':') ADVANCE(479);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      ADVANCE_MAP(
        '\n', 638,
        ':', 476,
        's', 163,
        '\t', 25,
        ' ', 25,
        '(', 25,
        '.', 25,
        '[', 25,
      );
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      ADVANCE_MAP(
        '\n', 638,
        ':', 158,
        's', 162,
        '\t', 25,
        ' ', 25,
        '(', 25,
        '.', 25,
        '[', 25,
      );
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == ':') ADVANCE(158);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == ':') ADVANCE(482);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == ':') ADVANCE(488);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == ':') ADVANCE(485);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == ':') ADVANCE(495);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '>') ADVANCE(499);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(167);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '>') ADVANCE(498);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(23);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(167);
      if (lookahead != 0) ADVANCE(169);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '>') ADVANCE(502);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      ADVANCE_MAP(
        '\n', 638,
        'A', 193,
        'a', 225,
        '(', 243,
        '[', 243,
        '\t', 25,
        ' ', 25,
        '.', 25,
      );
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'A') ADVANCE(199);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'A') ADVANCE(151);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      ADVANCE_MAP(
        '\n', 638,
        'B', 510,
        'D', 508,
        'I', 509,
        'P', 506,
        'S', 505,
        '{', 507,
        '\t', 512,
        ' ', 512,
        '(', 512,
        '.', 512,
        '[', 512,
      );
      if (lookahead != 0) ADVANCE(511);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'C') ADVANCE(171);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      ADVANCE_MAP(
        '\n', 638,
        'D', 221,
        'U', 222,
        '\t', 25,
        ' ', 25,
        '(', 25,
        '.', 25,
        '[', 25,
      );
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'D') ADVANCE(166);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      ADVANCE_MAP(
        '\n', 638,
        'E', 191,
        'e', 223,
        '(', 243,
        '[', 243,
        '\t', 25,
        ' ', 25,
        '.', 25,
      );
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'E') ADVANCE(159);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'E') ADVANCE(174);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'E') ADVANCE(176);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'E') ADVANCE(197);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'F') ADVANCE(200);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'G') ADVANCE(164);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'I') ADVANCE(182);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'I') ADVANCE(189);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'L') ADVANCE(196);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'L') ADVANCE(148);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'N') ADVANCE(185);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'N') ADVANCE(183);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      ADVANCE_MAP(
        '\n', 638,
        'O', 198,
        'o', 230,
        '(', 243,
        '[', 243,
        '\t', 25,
        ' ', 25,
        '.', 25,
      );
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'P') ADVANCE(194);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'R') ADVANCE(187);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'R') ADVANCE(188);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'R') ADVANCE(179);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'T') ADVANCE(192);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'T') ADVANCE(150);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'T') ADVANCE(172);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'T') ADVANCE(178);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'T') ADVANCE(180);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'T') ADVANCE(152);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'a') ADVANCE(216);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'a') ADVANCE(226);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'a') ADVANCE(234);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'c') ADVANCE(203);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'd') ADVANCE(491);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'e') ADVANCE(160);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'e') ADVANCE(204);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'e') ADVANCE(175);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'e') ADVANCE(205);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'e') ADVANCE(201);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'e') ADVANCE(228);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'g') ADVANCE(208);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'g') ADVANCE(165);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'h') ADVANCE(202);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'i') ADVANCE(219);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'k') ADVANCE(538);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 217:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'l') ADVANCE(538);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'n') ADVANCE(215);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'n') ADVANCE(213);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'n') ADVANCE(538);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'o') ADVANCE(235);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'p') ADVANCE(538);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'p') ADVANCE(227);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'p') ADVANCE(161);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'r') ADVANCE(218);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 226:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'r') ADVANCE(236);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 227:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'r') ADVANCE(207);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'r') ADVANCE(231);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 's') ADVANCE(211);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 't') ADVANCE(206);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 't') ADVANCE(538);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 232:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 't') ADVANCE(224);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 't') ADVANCE(232);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 't') ADVANCE(209);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 235:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'w') ADVANCE(220);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 236:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '}') ADVANCE(540);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 237:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(25);
      if (lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(374);
      if (lookahead != 0) ADVANCE(237);
      END_STATE();
    case 238:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      ADVANCE_MAP(
        '\n', 638,
        '(', 243,
        '[', 243,
        '\t', 25,
        ' ', 25,
        '.', 25,
        'A', 149,
        'C', 149,
        'D', 149,
        'M', 149,
        'S', 149,
      );
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(167);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 240:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(548);
      if (lookahead != 0) ADVANCE(547);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(543);
      if (lookahead != 0) ADVANCE(542);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(534);
      if (lookahead != 0) ADVANCE(533);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\'') ADVANCE(424);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '\'' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '(') ADVANCE(593);
      if (lookahead == '.') ADVANCE(594);
      if (lookahead == 'A') ADVANCE(579);
      if (lookahead == '[') ADVANCE(373);
      if (lookahead == 'a') ADVANCE(354);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(373);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '(') ADVANCE(593);
      if (lookahead == '.') ADVANCE(594);
      if (lookahead == 'E') ADVANCE(577);
      if (lookahead == '[') ADVANCE(373);
      if (lookahead == 'e') ADVANCE(352);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(373);
      END_STATE();
    case 247:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '(') ADVANCE(593);
      if (lookahead == '.') ADVANCE(594);
      if (lookahead == 'E') ADVANCE(582);
      if (lookahead == '[') ADVANCE(373);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(373);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '(') ADVANCE(593);
      if (lookahead == '.') ADVANCE(594);
      if (lookahead == 'L') ADVANCE(581);
      if (lookahead == '[') ADVANCE(373);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(373);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '(') ADVANCE(593);
      if (lookahead == '.') ADVANCE(594);
      if (lookahead == 'O') ADVANCE(583);
      if (lookahead == '[') ADVANCE(373);
      if (lookahead == 'o') ADVANCE(360);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(373);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '(') ADVANCE(593);
      if (lookahead == '.') ADVANCE(594);
      if (lookahead == 'T') ADVANCE(578);
      if (lookahead == '[') ADVANCE(373);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(373);
      END_STATE();
    case 251:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '(') ADVANCE(593);
      if (lookahead == '.') ADVANCE(594);
      if (lookahead == '[') ADVANCE(373);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(373);
      END_STATE();
    case 252:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '(') ADVANCE(594);
      if (lookahead == '.') ADVANCE(551);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(552);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          (lookahead < 'A' || '[' < lookahead)) ADVANCE(373);
      END_STATE();
    case 253:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '-') ADVANCE(295);
      if (lookahead == '>') ADVANCE(497);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '-' &&
          lookahead != '.' &&
          (lookahead < 'A' || '[' < lookahead)) ADVANCE(373);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '-') ADVANCE(300);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '-' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 255:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '-') ADVANCE(145);
      if (lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(375);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(368);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '-') ADVANCE(255);
      if (lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(375);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(368);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '-') ADVANCE(369);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '-' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '-') ADVANCE(370);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '-' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '-') ADVANCE(371);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '-' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 260:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '-') ADVANCE(256);
      if (lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(375);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(368);
      END_STATE();
    case 261:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '-') ADVANCE(260);
      if (lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(375);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(368);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '-') ADVANCE(261);
      if (lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(375);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(368);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '-') ADVANCE(262);
      if (lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(375);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(368);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '-') ADVANCE(263);
      if (lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(375);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(368);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '-') ADVANCE(264);
      if (lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(375);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(368);
      END_STATE();
    case 266:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '-') ADVANCE(265);
      if (lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(375);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(368);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '-') ADVANCE(266);
      if (lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(375);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(368);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '.') ADVANCE(33);
      if (lookahead == ']') ADVANCE(373);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(749);
      if (lookahead == ')' ||
          lookahead == ',' ||
          lookahead == ':') ADVANCE(268);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(747);
      END_STATE();
    case 269:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '.') ADVANCE(26);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(271);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 270:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '.') ADVANCE(26);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(269);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 271:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '.') ADVANCE(26);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '/') ADVANCE(268);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '/' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '/') ADVANCE(272);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '/' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == ':') ADVANCE(478);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 275:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == ':') ADVANCE(475);
      if (lookahead == 's') ADVANCE(276);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 276:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == ':') ADVANCE(481);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 277:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == ':') ADVANCE(487);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 278:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == ':') ADVANCE(484);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 279:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == ':') ADVANCE(494);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 280:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == ':') ADVANCE(372);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 281:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == ':') ADVANCE(273);
      if (lookahead == 's') ADVANCE(282);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 282:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == ':') ADVANCE(273);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 283:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '=') ADVANCE(293);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(373);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '.') ADVANCE(373);
      END_STATE();
    case 284:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '=') ADVANCE(146);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 285:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '=') ADVANCE(284);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 286:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '=') ADVANCE(285);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 287:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '=') ADVANCE(286);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 288:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '=') ADVANCE(287);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 289:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '=') ADVANCE(288);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 290:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '=') ADVANCE(289);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 291:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '=') ADVANCE(290);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 292:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '=') ADVANCE(291);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 293:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '=') ADVANCE(292);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 294:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '>') ADVANCE(497);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '-' &&
          lookahead != '.' &&
          (lookahead < 'A' || '[' < lookahead)) ADVANCE(373);
      END_STATE();
    case 295:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '>') ADVANCE(500);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(32);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(296);
      END_STATE();
    case 296:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '>') ADVANCE(501);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 297:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'A') ADVANCE(320);
      if (lookahead == 'a') ADVANCE(354);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(373);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '.') ADVANCE(373);
      END_STATE();
    case 298:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'A') ADVANCE(326);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 299:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'A') ADVANCE(258);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 300:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      ADVANCE_MAP(
        'B', 529,
        'D', 523,
        'I', 526,
        'P', 518,
        'S', 514,
        '{', 520,
        '\t', 504,
        ' ', 504,
        '(', 504,
        '.', 504,
        '[', 504,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(504);
      END_STATE();
    case 301:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'C') ADVANCE(298);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 302:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'D') ADVANCE(350);
      if (lookahead == 'U') ADVANCE(351);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 303:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'D') ADVANCE(279);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 304:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'E') ADVANCE(318);
      if (lookahead == 'e') ADVANCE(352);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(373);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '.') ADVANCE(373);
      END_STATE();
    case 305:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'E') ADVANCE(301);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 306:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'E') ADVANCE(303);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 307:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'E') ADVANCE(324);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(373);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '.') ADVANCE(373);
      END_STATE();
    case 308:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'E') ADVANCE(274);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 309:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'F') ADVANCE(327);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 310:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'G') ADVANCE(277);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 311:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'I') ADVANCE(309);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 312:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'I') ADVANCE(316);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 313:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'L') ADVANCE(323);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(373);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '.') ADVANCE(373);
      END_STATE();
    case 314:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'L') ADVANCE(254);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 315:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'N') ADVANCE(312);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 316:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'N') ADVANCE(310);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 317:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'O') ADVANCE(325);
      if (lookahead == 'o') ADVANCE(360);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(373);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '.') ADVANCE(373);
      END_STATE();
    case 318:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'P') ADVANCE(321);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 319:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'R') ADVANCE(314);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 320:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'R') ADVANCE(315);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 321:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'R') ADVANCE(305);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 322:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'T') ADVANCE(319);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(373);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '.') ADVANCE(373);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'T') ADVANCE(257);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 324:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'T') ADVANCE(299);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 325:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'T') ADVANCE(308);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 326:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'T') ADVANCE(306);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 327:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'T') ADVANCE(259);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 328:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'a') ADVANCE(344);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 329:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'a') ADVANCE(355);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 330:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'a') ADVANCE(363);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 331:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'c') ADVANCE(330);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'd') ADVANCE(490);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'e') ADVANCE(275);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 334:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'e') ADVANCE(331);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 335:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'e') ADVANCE(302);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 336:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'e') ADVANCE(332);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 337:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'e') ADVANCE(328);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'e') ADVANCE(357);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 339:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'g') ADVANCE(335);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 340:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'g') ADVANCE(278);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'h') ADVANCE(329);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 342:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'i') ADVANCE(346);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(373);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '.') ADVANCE(373);
      END_STATE();
    case 343:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'i') ADVANCE(349);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 344:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'k') ADVANCE(537);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'l') ADVANCE(537);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 346:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'm') ADVANCE(280);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 347:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'n') ADVANCE(537);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 348:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'n') ADVANCE(343);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 349:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'n') ADVANCE(340);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 350:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'o') ADVANCE(364);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 351:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'p') ADVANCE(537);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 352:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'p') ADVANCE(356);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 353:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'p') ADVANCE(281);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 354:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'r') ADVANCE(348);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 355:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'r') ADVANCE(365);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 356:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'r') ADVANCE(334);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 357:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'r') ADVANCE(359);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 358:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 's') ADVANCE(338);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 359:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 't') ADVANCE(537);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 360:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 't') ADVANCE(333);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 361:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 't') ADVANCE(353);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 362:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 't') ADVANCE(361);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(373);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '.') ADVANCE(373);
      END_STATE();
    case 363:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 't') ADVANCE(336);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 364:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == 'w') ADVANCE(347);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 365:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '}') ADVANCE(539);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 366:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(373);
      if (lookahead == 'A' ||
          lookahead == 'C' ||
          lookahead == 'D' ||
          lookahead == 'M' ||
          lookahead == 'S') ADVANCE(253);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '-' &&
          lookahead != '.') ADVANCE(373);
      END_STATE();
    case 367:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(373);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '.') ADVANCE(373);
      END_STATE();
    case 368:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(375);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(368);
      END_STATE();
    case 369:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(546);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(546);
      END_STATE();
    case 370:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(541);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(541);
      END_STATE();
    case 371:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(532);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(532);
      END_STATE();
    case 372:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(19);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(144);
      END_STATE();
    case 373:
      ACCEPT_TOKEN(aux_sym_word_noli_token1);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '(' &&
          lookahead != '.' &&
          lookahead != '[') ADVANCE(373);
      END_STATE();
    case 374:
      ACCEPT_TOKEN(aux_sym_word_noli_token2);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(25);
      if (lookahead != 0) ADVANCE(374);
      END_STATE();
    case 375:
      ACCEPT_TOKEN(aux_sym_word_noli_token2);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(375);
      END_STATE();
    case 376:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 377:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 378:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 379:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 380:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '|') ADVANCE(147);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      if (lookahead == '|') ADVANCE(45);
      END_STATE();
    case 382:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      if (lookahead == '|') ADVANCE(244);
      END_STATE();
    case 383:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      if (lookahead == '|') ADVANCE(855);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(aux_sym__word_common_token1);
      if (lookahead == 'A') ADVANCE(91);
      if (lookahead == 'a') ADVANCE(410);
      if (('b' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 385:
      ACCEPT_TOKEN(aux_sym__word_common_token1);
      if (lookahead == 'E') ADVANCE(90);
      if (lookahead == 'e') ADVANCE(409);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 386:
      ACCEPT_TOKEN(aux_sym__word_common_token1);
      if (lookahead == 'E') ADVANCE(96);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 387:
      ACCEPT_TOKEN(aux_sym__word_common_token1);
      if (lookahead == 'L') ADVANCE(95);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 388:
      ACCEPT_TOKEN(aux_sym__word_common_token1);
      if (lookahead == 'O') ADVANCE(98);
      if (lookahead == 'o') ADVANCE(412);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 389:
      ACCEPT_TOKEN(aux_sym__word_common_token1);
      if (lookahead == 'T') ADVANCE(92);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(aux_sym__word_common_token1);
      if (lookahead == 't') ADVANCE(753);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(414);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(754);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '\'' &&
          lookahead != '(') ADVANCE(414);
      END_STATE();
    case 391:
      ACCEPT_TOKEN(aux_sym__word_common_token1);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(414);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(754);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '\'' &&
          lookahead != '(') ADVANCE(414);
      END_STATE();
    case 392:
      ACCEPT_TOKEN(aux_sym__word_common_token1);
      if (lookahead == 'A' ||
          lookahead == 'C' ||
          lookahead == 'D' ||
          lookahead == 'M' ||
          lookahead == 'S') ADVANCE(46);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(398);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(61);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(aux_sym__word_common_token1);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == '/') ADVANCE(51);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 395:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == ':') ADVANCE(475);
      if (lookahead == 's') ADVANCE(396);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == ':') ADVANCE(481);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 397:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == ':') ADVANCE(484);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 398:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == '>') ADVANCE(497);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(398);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(61);
      END_STATE();
    case 399:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == 'a') ADVANCE(413);
      if (('b' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 400:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == 'c') ADVANCE(399);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 401:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == 'd') ADVANCE(493);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 402:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == 'e') ADVANCE(395);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 403:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == 'e') ADVANCE(400);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == 'e') ADVANCE(401);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 405:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == 'g') ADVANCE(397);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 406:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == 'i') ADVANCE(408);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 407:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == 'n') ADVANCE(406);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 408:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == 'n') ADVANCE(405);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == 'p') ADVANCE(411);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 410:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == 'r') ADVANCE(407);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 411:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == 'r') ADVANCE(403);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 412:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == 't') ADVANCE(402);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 413:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (lookahead == 't') ADVANCE(404);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 414:
      ACCEPT_TOKEN(aux_sym__word_common_token2);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(anon_sym_SQUOTE2);
      END_STATE();
    case 416:
      ACCEPT_TOKEN(anon_sym_SQUOTE2);
      if (lookahead == '|') ADVANCE(45);
      END_STATE();
    case 417:
      ACCEPT_TOKEN(aux_sym__word_common_token3);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '|') ADVANCE(417);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 418:
      ACCEPT_TOKEN(aux_sym__word_common_token3);
      if (lookahead == '|') ADVANCE(418);
      END_STATE();
    case 419:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 420:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '|') ADVANCE(417);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 421:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(418);
      END_STATE();
    case 422:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(418);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 423:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(950);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 424:
      ACCEPT_TOKEN(anon_sym_SQUOTE_PIPE_SQUOTE);
      END_STATE();
    case 425:
      ACCEPT_TOKEN(anon_sym_SQUOTE_PIPE_SQUOTE);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 426:
      ACCEPT_TOKEN(anon_sym_SQUOTE_PIPE_SQUOTE);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 427:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      ADVANCE_MAP(
        '\n', 638,
        '{', 433,
        '}', 432,
        '(', 243,
        '[', 243,
        '\t', 25,
        ' ', 25,
        '.', 25,
      );
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 428:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '{') ADVANCE(435);
      if (lookahead == '}') ADVANCE(431);
      END_STATE();
    case 429:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '{') ADVANCE(435);
      if (lookahead == '}') ADVANCE(431);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 430:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '{') ADVANCE(949);
      if (lookahead == '}') ADVANCE(431);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(957);
      END_STATE();
    case 431:
      ACCEPT_TOKEN(anon_sym_LBRACE_RBRACE);
      END_STATE();
    case 432:
      ACCEPT_TOKEN(anon_sym_LBRACE_RBRACE);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 433:
      ACCEPT_TOKEN(aux_sym__word_common_token4);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '{') ADVANCE(433);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(434);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 434:
      ACCEPT_TOKEN(aux_sym__word_common_token4);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(434);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 435:
      ACCEPT_TOKEN(aux_sym__word_common_token4);
      if (lookahead == '{') ADVANCE(435);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(436);
      END_STATE();
    case 436:
      ACCEPT_TOKEN(aux_sym__word_common_token4);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(436);
      END_STATE();
    case 437:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 438:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 439:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      if (lookahead == '(') ADVANCE(593);
      if (lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 440:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 441:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      if (lookahead == '(' ||
          lookahead == ')' ||
          lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(630);
      END_STATE();
    case 442:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(958);
      END_STATE();
    case 443:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 444:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 445:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      if (lookahead == '(') ADVANCE(593);
      if (lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 446:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 447:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 448:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 449:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 450:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 451:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 452:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(958);
      END_STATE();
    case 453:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 454:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 455:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 457:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 458:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 459:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 460:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 461:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 462:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 463:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 464:
      ACCEPT_TOKEN(anon_sym_GT);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 465:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 466:
      ACCEPT_TOKEN(anon_sym_COMMA);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 467:
      ACCEPT_TOKEN(anon_sym_COMMA);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 468:
      ACCEPT_TOKEN(anon_sym_COMMA);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(958);
      END_STATE();
    case 469:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 470:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 471:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '(') ADVANCE(593);
      if (lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 472:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 473:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '(' ||
          lookahead == ')' ||
          lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(630);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(958);
      END_STATE();
    case 475:
      ACCEPT_TOKEN(anon_sym_Note_COLON);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(anon_sym_Note_COLON);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(anon_sym_Note_COLON);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 478:
      ACCEPT_TOKEN(anon_sym_NOTE_COLON);
      END_STATE();
    case 479:
      ACCEPT_TOKEN(anon_sym_NOTE_COLON);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 480:
      ACCEPT_TOKEN(anon_sym_NOTE_COLON);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(anon_sym_Notes_COLON);
      END_STATE();
    case 482:
      ACCEPT_TOKEN(anon_sym_Notes_COLON);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 483:
      ACCEPT_TOKEN(anon_sym_Notes_COLON);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 484:
      ACCEPT_TOKEN(anon_sym_Warning_COLON);
      END_STATE();
    case 485:
      ACCEPT_TOKEN(anon_sym_Warning_COLON);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 486:
      ACCEPT_TOKEN(anon_sym_Warning_COLON);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(anon_sym_WARNING_COLON);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(anon_sym_WARNING_COLON);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(anon_sym_WARNING_COLON);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 490:
      ACCEPT_TOKEN(anon_sym_Deprecated);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(anon_sym_Deprecated);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 492:
      ACCEPT_TOKEN(anon_sym_Deprecated);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 493:
      ACCEPT_TOKEN(anon_sym_Deprecated);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(anon_sym_DEPRECATED_COLON);
      END_STATE();
    case 495:
      ACCEPT_TOKEN(anon_sym_DEPRECATED_COLON);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 496:
      ACCEPT_TOKEN(anon_sym_DEPRECATED_COLON);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(aux_sym_keycode_token1);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(aux_sym_keycode_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '>') ADVANCE(502);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 499:
      ACCEPT_TOKEN(aux_sym_keycode_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 500:
      ACCEPT_TOKEN(aux_sym_keycode_token1);
      if (lookahead == '>') ADVANCE(501);
      END_STATE();
    case 501:
      ACCEPT_TOKEN(aux_sym_keycode_token2);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(aux_sym_keycode_token2);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(aux_sym_keycode_token2);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead != 0) ADVANCE(25);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'H') ADVANCE(184);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 506:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'a') ADVANCE(212);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'c') ADVANCE(214);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'e') ADVANCE(217);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'n') ADVANCE(229);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == 'r') ADVANCE(210);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead != 0) ADVANCE(25);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'H') ADVANCE(81);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'H') ADVANCE(311);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'H') ADVANCE(612);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'a') ADVANCE(113);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'a') ADVANCE(113);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'a') ADVANCE(339);
      END_STATE();
    case 519:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'c') ADVANCE(115);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'c') ADVANCE(341);
      END_STATE();
    case 521:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'e') ADVANCE(118);
      END_STATE();
    case 522:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'e') ADVANCE(118);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'e') ADVANCE(345);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'n') ADVANCE(130);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'n') ADVANCE(130);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'n') ADVANCE(358);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'r') ADVANCE(111);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'r') ADVANCE(111);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == 'r') ADVANCE(337);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(aux_sym_keycode_token3);
      if (lookahead == '(' ||
          lookahead == ')' ||
          lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(630);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(aux_sym_keycode_token4);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(aux_sym_keycode_token4);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(aux_sym_keycode_token4);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead != 0) ADVANCE(25);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(aux_sym_keycode_token4);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(aux_sym_keycode_token4);
      if (lookahead == '(' ||
          lookahead == ')' ||
          lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(630);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(aux_sym_keycode_token5);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(aux_sym_keycode_token5);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(anon_sym_CTRL_DASH_LBRACEchar_RBRACE);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(anon_sym_CTRL_DASH_LBRACEchar_RBRACE);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(aux_sym_keycode_token6);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(aux_sym_keycode_token6);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(aux_sym_keycode_token6);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead != 0) ADVANCE(25);
      END_STATE();
    case 544:
      ACCEPT_TOKEN(aux_sym_keycode_token6);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(aux_sym_keycode_token6);
      if (lookahead == '(' ||
          lookahead == ')' ||
          lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(630);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(aux_sym_keycode_token7);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(aux_sym_keycode_token7);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '(' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(aux_sym_keycode_token7);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead != 0) ADVANCE(25);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(aux_sym_keycode_token7);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(aux_sym_keycode_token7);
      if (lookahead == '(' ||
          lookahead == ')' ||
          lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(630);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == ' ') ADVANCE(637);
      if (lookahead == '(' ||
          lookahead == ')' ||
          lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(594);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == '(') ADVANCE(594);
      if (lookahead == '.') ADVANCE(551);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(553);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == '(') ADVANCE(594);
      if (lookahead == '.') ADVANCE(551);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == '-') ADVANCE(590);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == '-') ADVANCE(563);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == '-') ADVANCE(591);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == '-') ADVANCE(592);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == ':') ADVANCE(478);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == ':') ADVANCE(487);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == ':') ADVANCE(494);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'A') ADVANCE(584);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'A') ADVANCE(556);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      ADVANCE_MAP(
        'B', 589,
        'D', 587,
        'I', 588,
        'P', 586,
        'S', 571,
        '{', 520,
        '(', 594,
        '.', 594,
        '\t', 504,
        ' ', 504,
        '[', 504,
      );
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(504);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'C') ADVANCE(561);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'D') ADVANCE(560);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'E') ADVANCE(558);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'E') ADVANCE(564);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'E') ADVANCE(565);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'F') ADVANCE(585);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'G') ADVANCE(559);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'H') ADVANCE(572);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'I') ADVANCE(569);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'I') ADVANCE(576);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'L') ADVANCE(555);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'N') ADVANCE(573);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'N') ADVANCE(570);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'P') ADVANCE(580);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'R') ADVANCE(574);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'R') ADVANCE(575);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'R') ADVANCE(567);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'T') ADVANCE(554);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'T') ADVANCE(562);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'T') ADVANCE(566);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'T') ADVANCE(568);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'T') ADVANCE(557);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'a') ADVANCE(339);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'e') ADVANCE(345);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'n') ADVANCE(358);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == 'r') ADVANCE(337);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '[') ADVANCE(546);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(546);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '[') ADVANCE(541);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(541);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '[') ADVANCE(532);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(532);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(594);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(593);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token1);
      if (lookahead == '(' ||
          lookahead == ')' ||
          lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(594);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == '-') ADVANCE(627);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == '-') ADVANCE(604);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == '-') ADVANCE(628);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == '-') ADVANCE(629);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == ':') ADVANCE(478);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == ':') ADVANCE(487);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == ':') ADVANCE(494);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'A') ADVANCE(624);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'A') ADVANCE(597);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      ADVANCE_MAP(
        'B', 528,
        'D', 522,
        'I', 525,
        'P', 517,
        'S', 515,
        '{', 519,
        '(', 531,
        '.', 531,
        '\t', 504,
        ' ', 504,
        ',', 504,
        '[', 504,
      );
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(530);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(504);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'C') ADVANCE(602);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'D') ADVANCE(601);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'E') ADVANCE(599);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'E') ADVANCE(605);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'E') ADVANCE(606);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'F') ADVANCE(625);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 611:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'G') ADVANCE(600);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'I') ADVANCE(610);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'I') ADVANCE(616);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'L') ADVANCE(596);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'N') ADVANCE(613);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'N') ADVANCE(611);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'P') ADVANCE(620);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'R') ADVANCE(614);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 619:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'R') ADVANCE(615);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 620:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'R') ADVANCE(608);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 621:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'T') ADVANCE(595);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 622:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'T') ADVANCE(603);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 623:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'T') ADVANCE(607);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'T') ADVANCE(609);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == 'T') ADVANCE(598);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 626:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(630);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(626);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(550);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == ',' ||
          lookahead == '[') ADVANCE(546);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(549);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(546);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(545);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == ',' ||
          lookahead == '[') ADVANCE(541);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(544);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(541);
      END_STATE();
    case 629:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == '(' ||
          lookahead == '.') ADVANCE(536);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == ',' ||
          lookahead == '[') ADVANCE(532);
      if (lookahead == ')' ||
          lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(535);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(532);
      END_STATE();
    case 630:
      ACCEPT_TOKEN(aux_sym_uppercase_name_token2);
      if (lookahead == '(' ||
          lookahead == ')' ||
          lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_') ADVANCE(630);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == 'A' ||
          lookahead == 'C' ||
          lookahead == 'D' ||
          lookahead == 'M' ||
          lookahead == 'S') ADVANCE(253);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      END_STATE();
    case 633:
      ACCEPT_TOKEN(aux_sym_codeblock_token1);
      END_STATE();
    case 634:
      ACCEPT_TOKEN(aux_sym_codeblock_token2);
      END_STATE();
    case 635:
      ACCEPT_TOKEN(aux_sym__blank_token1);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(aux_sym_line_li_token1);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == ' ') ADVANCE(636);
      if (lookahead != 0) ADVANCE(25);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(aux_sym_line_li_token1);
      if (lookahead == ' ') ADVANCE(637);
      END_STATE();
    case 638:
      ACCEPT_TOKEN(aux_sym_line_code_token1);
      END_STATE();
    case 639:
      ACCEPT_TOKEN(sym_modeline);
      END_STATE();
    case 640:
      ACCEPT_TOKEN(aux_sym_h1_token1);
      END_STATE();
    case 641:
      ACCEPT_TOKEN(aux_sym_h2_token1);
      END_STATE();
    case 642:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '\'') ADVANCE(742);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 643:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '-') ADVANCE(742);
      if (lookahead == '(' ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '-') ADVANCE(661);
      if (lookahead == '(' ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '-') ADVANCE(657);
      if (lookahead == '>') ADVANCE(742);
      if (lookahead == '(' ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '[') ADVANCE(743);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(655);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 646:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '/') ADVANCE(690);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '/') ADVANCE(646);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 648:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == ':') ADVANCE(742);
      if (lookahead == 's') ADVANCE(649);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 649:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == ':') ADVANCE(742);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 650:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == ':') ADVANCE(647);
      if (lookahead == 's') ADVANCE(652);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(741);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 651:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == ':') ADVANCE(647);
      if (lookahead == 's') ADVANCE(653);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 652:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == ':') ADVANCE(647);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(741);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == ':') ADVANCE(647);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 654:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '>') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(743);
      END_STATE();
    case 655:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '>') ADVANCE(742);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(655);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 656:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '>') ADVANCE(742);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 657:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '>') ADVANCE(656);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(654);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(655);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(656);
      END_STATE();
    case 658:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'A') ADVANCE(643);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 659:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'A') ADVANCE(681);
      if (lookahead == 'a') ADVANCE(720);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 660:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'A') ADVANCE(688);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 661:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      ADVANCE_MAP(
        'B', 724,
        'D', 700,
        'I', 714,
        'P', 692,
        'S', 672,
        '{', 695,
        '(', 743,
        ',', 743,
        '.', 743,
        '[', 743,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 662:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'C') ADVANCE(660);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 663:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'D') ADVANCE(649);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 664:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'D') ADVANCE(715);
      if (lookahead == 'U') ADVANCE(716);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 665:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'E') ADVANCE(680);
      if (lookahead == 'e') ADVANCE(718);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 666:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'E') ADVANCE(649);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 667:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'E') ADVANCE(662);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 668:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'E') ADVANCE(663);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 669:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'E') ADVANCE(686);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 670:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'F') ADVANCE(685);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 671:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'G') ADVANCE(649);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 672:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'H') ADVANCE(673);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 673:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'I') ADVANCE(670);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 674:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'I') ADVANCE(678);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 675:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'L') ADVANCE(685);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 676:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'L') ADVANCE(644);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 677:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'N') ADVANCE(674);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 678:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'N') ADVANCE(671);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 679:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'O') ADVANCE(687);
      if (lookahead == 'o') ADVANCE(727);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 680:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'P') ADVANCE(683);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 681:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'R') ADVANCE(677);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 682:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'R') ADVANCE(676);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 683:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'R') ADVANCE(667);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 684:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'T') ADVANCE(682);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 685:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'T') ADVANCE(643);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 686:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'T') ADVANCE(658);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 687:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'T') ADVANCE(666);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 688:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'T') ADVANCE(668);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 689:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == ']') ADVANCE(743);
      if (lookahead == ')' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == ':') ADVANCE(689);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ')' &&
          lookahead != '*') ADVANCE(689);
      END_STATE();
    case 690:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == ']') ADVANCE(742);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(689);
      if (lookahead == ')' ||
          lookahead == ':') ADVANCE(690);
      if (lookahead == ',' ||
          lookahead == '.') ADVANCE(689);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          (lookahead < '(' || '*' < lookahead)) ADVANCE(690);
      END_STATE();
    case 691:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'a') ADVANCE(709);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 692:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'a') ADVANCE(706);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 693:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'a') ADVANCE(721);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 694:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'a') ADVANCE(732);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 695:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'c') ADVANCE(707);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 696:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'c') ADVANCE(694);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 697:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'd') ADVANCE(742);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 698:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'e') ADVANCE(648);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 699:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'e') ADVANCE(696);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 700:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'e') ADVANCE(710);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 701:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'e') ADVANCE(664);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 702:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'e') ADVANCE(697);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 703:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'e') ADVANCE(722);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 704:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'e') ADVANCE(691);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 705:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'g') ADVANCE(649);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 706:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'g') ADVANCE(701);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 707:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'h') ADVANCE(693);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 708:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'i') ADVANCE(713);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 709:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'k') ADVANCE(742);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 710:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'l') ADVANCE(742);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 711:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'n') ADVANCE(742);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 712:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'n') ADVANCE(708);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 713:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'n') ADVANCE(705);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 714:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'n') ADVANCE(725);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 715:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'o') ADVANCE(733);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 716:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'p') ADVANCE(742);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 717:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'p') ADVANCE(650);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(741);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 718:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'p') ADVANCE(723);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 719:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'p') ADVANCE(651);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 720:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'r') ADVANCE(712);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 721:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'r') ADVANCE(738);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 722:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'r') ADVANCE(726);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 723:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'r') ADVANCE(699);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 724:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'r') ADVANCE(704);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 725:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 's') ADVANCE(703);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 726:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 't') ADVANCE(742);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 727:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 't') ADVANCE(698);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 728:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 't') ADVANCE(717);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(741);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 729:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 't') ADVANCE(728);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(741);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 730:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 't') ADVANCE(719);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 731:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 't') ADVANCE(730);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 732:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 't') ADVANCE(702);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 733:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == 'w') ADVANCE(711);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 734:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '{') ADVANCE(735);
      if (lookahead == '}') ADVANCE(742);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 735:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '{') ADVANCE(735);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(740);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 736:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '|') ADVANCE(642);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 737:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '|') ADVANCE(737);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 738:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '}') ADVANCE(742);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 739:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      ADVANCE_MAP(
        '(', 743,
        ',', 743,
        '.', 743,
        '[', 743,
        'A', 645,
        'C', 645,
        'D', 645,
        'M', 645,
        'S', 645,
      );
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(655);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 740:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(740);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 741:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(741);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 742:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(742);
      END_STATE();
    case 743:
      ACCEPT_TOKEN(aux_sym_tag_token1);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '*') ADVANCE(743);
      END_STATE();
    case 744:
      ACCEPT_TOKEN(anon_sym_STAR2);
      END_STATE();
    case 745:
      ACCEPT_TOKEN(sym_url_word);
      ADVANCE_MAP(
        '\n', 638,
        '.', 24,
        ']', 243,
        '\t', 25,
        ' ', 25,
        '(', 746,
        '[', 746,
        ')', 156,
        ',', 156,
        ':', 156,
      );
      if (lookahead != 0) ADVANCE(745);
      END_STATE();
    case 746:
      ACCEPT_TOKEN(sym_url_word);
      ADVANCE_MAP(
        '\n', 638,
        '\t', 25,
        ' ', 25,
        ']', 25,
        ')', 24,
        ',', 24,
        '.', 24,
        ':', 24,
      );
      if (lookahead != 0) ADVANCE(746);
      END_STATE();
    case 747:
      ACCEPT_TOKEN(sym_url_word);
      if (lookahead == '.') ADVANCE(33);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(749);
      if (lookahead == ')' ||
          lookahead == ',' ||
          lookahead == ':') ADVANCE(268);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ']') ADVANCE(747);
      END_STATE();
    case 748:
      ACCEPT_TOKEN(sym_url_word);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(749);
      if (lookahead == ')' ||
          lookahead == ':') ADVANCE(101);
      if (lookahead == ',' ||
          lookahead == '.') ADVANCE(33);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ']') ADVANCE(748);
      END_STATE();
    case 749:
      ACCEPT_TOKEN(sym_url_word);
      if (lookahead == ')' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == ':') ADVANCE(33);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ']') ADVANCE(749);
      END_STATE();
    case 750:
      ACCEPT_TOKEN(aux_sym_optionlink_token1);
      if (lookahead == ':') ADVANCE(394);
      if (lookahead == 's') ADVANCE(751);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(414);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(754);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '\'' &&
          lookahead != '(') ADVANCE(414);
      END_STATE();
    case 751:
      ACCEPT_TOKEN(aux_sym_optionlink_token1);
      if (lookahead == ':') ADVANCE(394);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(414);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(754);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '\'' &&
          lookahead != '(') ADVANCE(414);
      END_STATE();
    case 752:
      ACCEPT_TOKEN(aux_sym_optionlink_token1);
      if (lookahead == 'p') ADVANCE(750);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(414);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(754);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '\'' &&
          lookahead != '(') ADVANCE(414);
      END_STATE();
    case 753:
      ACCEPT_TOKEN(aux_sym_optionlink_token1);
      if (lookahead == 't') ADVANCE(752);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(414);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(754);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '\'' &&
          lookahead != '(') ADVANCE(414);
      END_STATE();
    case 754:
      ACCEPT_TOKEN(aux_sym_optionlink_token1);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(414);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(754);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '\'' &&
          lookahead != '(') ADVANCE(414);
      END_STATE();
    case 755:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == '-') ADVANCE(846);
      if (lookahead == '(' ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 756:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == '-') ADVANCE(771);
      if (lookahead == '(' ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 757:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == '-') ADVANCE(767);
      if (lookahead == '>') ADVANCE(846);
      if (lookahead == '(' ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '[') ADVANCE(847);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(764);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 758:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == '/') ADVANCE(799);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 759:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == '/') ADVANCE(758);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 760:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == ':') ADVANCE(846);
      if (lookahead == 's') ADVANCE(761);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 761:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == ':') ADVANCE(846);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 762:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == ':') ADVANCE(759);
      if (lookahead == 's') ADVANCE(763);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 763:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == ':') ADVANCE(759);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 764:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == '>') ADVANCE(846);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(764);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 765:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == '>') ADVANCE(846);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 766:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == '>') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(847);
      END_STATE();
    case 767:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == '>') ADVANCE(765);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(766);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(764);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(765);
      END_STATE();
    case 768:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'A') ADVANCE(755);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 769:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'A') ADVANCE(791);
      if (lookahead == 'a') ADVANCE(829);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 770:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'A') ADVANCE(798);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 771:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      ADVANCE_MAP(
        'B', 832,
        'D', 810,
        'I', 824,
        'P', 802,
        'S', 782,
        '{', 805,
        '(', 847,
        ',', 847,
        '.', 847,
        '[', 847,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '{' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 772:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'C') ADVANCE(770);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 773:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'D') ADVANCE(761);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 774:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'D') ADVANCE(825);
      if (lookahead == 'U') ADVANCE(826);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 775:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'E') ADVANCE(790);
      if (lookahead == 'e') ADVANCE(827);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 776:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'E') ADVANCE(761);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 777:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'E') ADVANCE(772);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 778:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'E') ADVANCE(773);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 779:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'E') ADVANCE(796);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 780:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'F') ADVANCE(795);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 781:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'G') ADVANCE(761);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 782:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'H') ADVANCE(783);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 783:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'I') ADVANCE(780);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 784:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'I') ADVANCE(788);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 785:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'L') ADVANCE(795);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 786:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'L') ADVANCE(756);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 787:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'N') ADVANCE(784);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 788:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'N') ADVANCE(781);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 789:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'O') ADVANCE(797);
      if (lookahead == 'o') ADVANCE(836);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 790:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'P') ADVANCE(793);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 791:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'R') ADVANCE(787);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 792:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'R') ADVANCE(786);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 793:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'R') ADVANCE(777);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 794:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'T') ADVANCE(792);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 795:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'T') ADVANCE(755);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 796:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'T') ADVANCE(768);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 797:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'T') ADVANCE(776);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 798:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'T') ADVANCE(778);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 799:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == ']') ADVANCE(846);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(800);
      if (lookahead == ')' ||
          lookahead == ':') ADVANCE(799);
      if (lookahead == ',' ||
          lookahead == '.') ADVANCE(800);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(799);
      END_STATE();
    case 800:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == ']') ADVANCE(847);
      if (lookahead == ')' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == ':') ADVANCE(800);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(800);
      END_STATE();
    case 801:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'a') ADVANCE(819);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 802:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'a') ADVANCE(816);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 803:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'a') ADVANCE(839);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 804:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'a') ADVANCE(830);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 805:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'c') ADVANCE(817);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 806:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'c') ADVANCE(803);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 807:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'd') ADVANCE(846);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 808:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'e') ADVANCE(760);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 809:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'e') ADVANCE(806);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 810:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'e') ADVANCE(820);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 811:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'e') ADVANCE(774);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 812:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'e') ADVANCE(807);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 813:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'e') ADVANCE(833);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 814:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'e') ADVANCE(801);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 815:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'g') ADVANCE(761);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 816:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'g') ADVANCE(811);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 817:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'h') ADVANCE(804);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 818:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'i') ADVANCE(823);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 819:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'k') ADVANCE(846);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 820:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'l') ADVANCE(846);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 821:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'n') ADVANCE(846);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 822:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'n') ADVANCE(818);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 823:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'n') ADVANCE(815);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 824:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'n') ADVANCE(834);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 825:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'o') ADVANCE(840);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 826:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'p') ADVANCE(846);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 827:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'p') ADVANCE(831);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 828:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'p') ADVANCE(762);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 829:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'r') ADVANCE(822);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 830:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'r') ADVANCE(843);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 831:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'r') ADVANCE(809);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 832:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'r') ADVANCE(814);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 833:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'r') ADVANCE(835);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 834:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 's') ADVANCE(813);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 835:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 't') ADVANCE(846);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 836:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 't') ADVANCE(808);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 837:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 't') ADVANCE(828);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 838:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 't') ADVANCE(837);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 839:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 't') ADVANCE(812);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 840:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == 'w') ADVANCE(821);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 841:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == '{') ADVANCE(842);
      if (lookahead == '}') ADVANCE(846);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(846);
      END_STATE();
    case 842:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == '{') ADVANCE(842);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(845);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '{' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 843:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == '}') ADVANCE(846);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|' &&
          lookahead != '}') ADVANCE(846);
      END_STATE();
    case 844:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      ADVANCE_MAP(
        '(', 847,
        ',', 847,
        '.', 847,
        '[', 847,
        'A', 757,
        'C', 757,
        'D', 757,
        'M', 757,
        'S', 757,
      );
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(764);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 845:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(845);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 846:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(847);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(846);
      END_STATE();
    case 847:
      ACCEPT_TOKEN(aux_sym_taglink_token1);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|') ADVANCE(847);
      END_STATE();
    case 848:
      ACCEPT_TOKEN(anon_sym_PIPE2);
      END_STATE();
    case 849:
      ACCEPT_TOKEN(anon_sym_BQUOTE);
      END_STATE();
    case 850:
      ACCEPT_TOKEN(anon_sym_BQUOTE);
      if (lookahead == '\n') ADVANCE(638);
      if (lookahead == '(' ||
          lookahead == '[') ADVANCE(243);
      if (lookahead == '\t' ||
          lookahead == ' ' ||
          lookahead == '.') ADVANCE(25);
      if (lookahead != 0) ADVANCE(243);
      END_STATE();
    case 851:
      ACCEPT_TOKEN(anon_sym_BQUOTE);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 852:
      ACCEPT_TOKEN(anon_sym_BQUOTE);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(414);
      END_STATE();
    case 853:
      ACCEPT_TOKEN(aux_sym_codespan_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '`') ADVANCE(853);
      END_STATE();
    case 854:
      ACCEPT_TOKEN(anon_sym_BQUOTE2);
      END_STATE();
    case 855:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '\'') ADVANCE(426);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 856:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '-') ADVANCE(874);
      if (lookahead == '>') ADVANCE(957);
      if (lookahead == '(' ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '[') ADVANCE(958);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(871);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 857:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '-') ADVANCE(951);
      if (lookahead == '(' ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 858:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '-') ADVANCE(878);
      if (lookahead == '(' ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 859:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '-') ADVANCE(952);
      if (lookahead == '(' ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 860:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '-') ADVANCE(954);
      if (lookahead == '(' ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 861:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '/') ADVANCE(907);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 862:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '/') ADVANCE(861);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 863:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == ':') ADVANCE(480);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 864:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == ':') ADVANCE(477);
      if (lookahead == 's') ADVANCE(867);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 865:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == ':') ADVANCE(862);
      if (lookahead == 's') ADVANCE(866);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 866:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == ':') ADVANCE(862);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 867:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == ':') ADVANCE(483);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 868:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == ':') ADVANCE(489);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 869:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == ':') ADVANCE(486);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 870:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == ':') ADVANCE(496);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 871:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '>') ADVANCE(957);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(871);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 872:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '>') ADVANCE(957);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 873:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '>') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(958);
      END_STATE();
    case 874:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      ADVANCE_MAP(
        '>', 872,
        '}', 63,
        '\t', 32,
        ' ', 32,
        '(', 873,
        ',', 873,
        '.', 873,
        '[', 873,
      );
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(871);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(872);
      END_STATE();
    case 875:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'A') ADVANCE(898);
      if (lookahead == 'a') ADVANCE(937);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 876:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'A') ADVANCE(905);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 877:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'A') ADVANCE(859);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 878:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      ADVANCE_MAP(
        'B', 940,
        'D', 918,
        'I', 932,
        'P', 910,
        'S', 889,
        '{', 913,
        '}', 504,
        '\t', 504,
        ' ', 504,
        '(', 958,
        ',', 958,
        '.', 958,
        '[', 958,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(957);
      END_STATE();
    case 879:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'C') ADVANCE(876);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 880:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'D') ADVANCE(933);
      if (lookahead == 'U') ADVANCE(934);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 881:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'D') ADVANCE(870);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 882:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'E') ADVANCE(897);
      if (lookahead == 'e') ADVANCE(935);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 883:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'E') ADVANCE(863);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 884:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'E') ADVANCE(879);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 885:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'E') ADVANCE(881);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 886:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'E') ADVANCE(903);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 887:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'F') ADVANCE(906);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 888:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'G') ADVANCE(868);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 889:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'H') ADVANCE(890);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 890:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'I') ADVANCE(887);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 891:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'I') ADVANCE(895);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 892:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'L') ADVANCE(902);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 893:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'L') ADVANCE(858);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 894:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'N') ADVANCE(891);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 895:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'N') ADVANCE(888);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 896:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'O') ADVANCE(904);
      if (lookahead == 'o') ADVANCE(944);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 897:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'P') ADVANCE(900);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 898:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'R') ADVANCE(894);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 899:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'R') ADVANCE(893);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 900:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'R') ADVANCE(884);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 901:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'T') ADVANCE(899);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 902:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'T') ADVANCE(857);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 903:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'T') ADVANCE(877);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 904:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'T') ADVANCE(883);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 905:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'T') ADVANCE(885);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 906:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'T') ADVANCE(860);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 907:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      ADVANCE_MAP(
        ']', 957,
        '}', 748,
        '(', 908,
        '[', 908,
        ')', 907,
        ':', 907,
        ',', 908,
        '.', 908,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(907);
      END_STATE();
    case 908:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == ']') ADVANCE(958);
      if (lookahead == '}') ADVANCE(749);
      if (lookahead == ')' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == ':') ADVANCE(908);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(908);
      END_STATE();
    case 909:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'a') ADVANCE(927);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 910:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'a') ADVANCE(924);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 911:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'a') ADVANCE(947);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 912:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'a') ADVANCE(938);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 913:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'c') ADVANCE(925);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 914:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'c') ADVANCE(911);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 915:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'd') ADVANCE(492);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 916:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'e') ADVANCE(864);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 917:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'e') ADVANCE(914);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 918:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'e') ADVANCE(928);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 919:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'e') ADVANCE(880);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 920:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'e') ADVANCE(915);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 921:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'e') ADVANCE(941);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 922:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'e') ADVANCE(909);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 923:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'g') ADVANCE(869);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 924:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'g') ADVANCE(919);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 925:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'h') ADVANCE(912);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 926:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'i') ADVANCE(931);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 927:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'k') ADVANCE(957);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 928:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'l') ADVANCE(957);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 929:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'n') ADVANCE(957);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 930:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'n') ADVANCE(926);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 931:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'n') ADVANCE(923);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 932:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'n') ADVANCE(942);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 933:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'o') ADVANCE(948);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 934:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'p') ADVANCE(957);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 935:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'p') ADVANCE(939);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 936:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'p') ADVANCE(865);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 937:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'r') ADVANCE(930);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 938:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'r') ADVANCE(953);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 939:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'r') ADVANCE(917);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 940:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'r') ADVANCE(922);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 941:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'r') ADVANCE(943);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 942:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 's') ADVANCE(921);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 943:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 't') ADVANCE(957);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 944:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 't') ADVANCE(916);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 945:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 't') ADVANCE(936);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 946:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 't') ADVANCE(945);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 947:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 't') ADVANCE(920);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 948:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'w') ADVANCE(929);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 949:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '{') ADVANCE(949);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(956);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 950:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '|') ADVANCE(950);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '|' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 951:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '}') ADVANCE(546);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(546);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(957);
      END_STATE();
    case 952:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '}') ADVANCE(541);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(541);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(957);
      END_STATE();
    case 953:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '}') ADVANCE(539);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(957);
      END_STATE();
    case 954:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '}') ADVANCE(532);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(532);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(957);
      END_STATE();
    case 955:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      ADVANCE_MAP(
        '(', 958,
        ',', 958,
        '.', 958,
        '[', 958,
        'A', 856,
        'C', 856,
        'D', 856,
        'M', 856,
        'S', 856,
      );
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(871);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 956:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(956);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 957:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '(' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '[') ADVANCE(958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(957);
      END_STATE();
    case 958:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != '}') ADVANCE(958);
      END_STATE();
    case 959:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 960:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 37},
  [2] = {.lex_state = 37},
  [3] = {.lex_state = 37},
  [4] = {.lex_state = 37},
  [5] = {.lex_state = 37},
  [6] = {.lex_state = 14},
  [7] = {.lex_state = 14},
  [8] = {.lex_state = 16},
  [9] = {.lex_state = 16},
  [10] = {.lex_state = 16},
  [11] = {.lex_state = 16},
  [12] = {.lex_state = 16},
  [13] = {.lex_state = 16},
  [14] = {.lex_state = 16},
  [15] = {.lex_state = 16},
  [16] = {.lex_state = 16},
  [17] = {.lex_state = 5},
  [18] = {.lex_state = 5},
  [19] = {.lex_state = 5},
  [20] = {.lex_state = 5},
  [21] = {.lex_state = 5},
  [22] = {.lex_state = 5},
  [23] = {.lex_state = 5},
  [24] = {.lex_state = 5},
  [25] = {.lex_state = 5},
  [26] = {.lex_state = 5},
  [27] = {.lex_state = 5},
  [28] = {.lex_state = 5},
  [29] = {.lex_state = 5},
  [30] = {.lex_state = 5},
  [31] = {.lex_state = 5},
  [32] = {.lex_state = 5},
  [33] = {.lex_state = 5},
  [34] = {.lex_state = 5},
  [35] = {.lex_state = 5},
  [36] = {.lex_state = 37},
  [37] = {.lex_state = 37},
  [38] = {.lex_state = 37},
  [39] = {.lex_state = 37},
  [40] = {.lex_state = 37},
  [41] = {.lex_state = 37},
  [42] = {.lex_state = 37},
  [43] = {.lex_state = 15},
  [44] = {.lex_state = 15},
  [45] = {.lex_state = 37},
  [46] = {.lex_state = 15},
  [47] = {.lex_state = 15},
  [48] = {.lex_state = 17},
  [49] = {.lex_state = 17},
  [50] = {.lex_state = 14},
  [51] = {.lex_state = 14},
  [52] = {.lex_state = 14},
  [53] = {.lex_state = 14},
  [54] = {.lex_state = 14},
  [55] = {.lex_state = 14},
  [56] = {.lex_state = 14},
  [57] = {.lex_state = 14},
  [58] = {.lex_state = 14},
  [59] = {.lex_state = 14},
  [60] = {.lex_state = 14},
  [61] = {.lex_state = 14},
  [62] = {.lex_state = 14},
  [63] = {.lex_state = 17},
  [64] = {.lex_state = 17},
  [65] = {.lex_state = 16},
  [66] = {.lex_state = 16},
  [67] = {.lex_state = 16},
  [68] = {.lex_state = 6},
  [69] = {.lex_state = 2},
  [70] = {.lex_state = 7},
  [71] = {.lex_state = 7},
  [72] = {.lex_state = 2},
  [73] = {.lex_state = 7},
  [74] = {.lex_state = 7},
  [75] = {.lex_state = 7},
  [76] = {.lex_state = 7},
  [77] = {.lex_state = 9},
  [78] = {.lex_state = 3},
  [79] = {.lex_state = 4},
  [80] = {.lex_state = 10},
  [81] = {.lex_state = 11},
  [82] = {.lex_state = 5},
  [83] = {.lex_state = 5},
  [84] = {.lex_state = 5},
  [85] = {.lex_state = 5},
  [86] = {.lex_state = 5},
  [87] = {.lex_state = 5},
  [88] = {.lex_state = 5},
  [89] = {.lex_state = 5},
  [90] = {.lex_state = 5},
  [91] = {.lex_state = 5},
  [92] = {.lex_state = 5},
  [93] = {.lex_state = 5},
  [94] = {.lex_state = 12},
  [95] = {.lex_state = 12},
  [96] = {.lex_state = 12},
  [97] = {.lex_state = 15},
  [98] = {.lex_state = 15},
  [99] = {.lex_state = 37},
  [100] = {.lex_state = 37},
  [101] = {.lex_state = 37},
  [102] = {.lex_state = 37},
  [103] = {.lex_state = 37},
  [104] = {.lex_state = 12},
  [105] = {.lex_state = 3},
  [106] = {.lex_state = 34},
  [107] = {.lex_state = 0},
  [108] = {.lex_state = 0},
  [109] = {.lex_state = 37},
  [110] = {.lex_state = 12},
  [111] = {.lex_state = 37},
  [112] = {.lex_state = 12},
  [113] = {.lex_state = 12},
  [114] = {.lex_state = 12},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [aux_sym_word_token1] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [aux_sym__word_common_token1] = ACTIONS(1),
    [anon_sym_SQUOTE2] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(1),
    [aux_sym__word_common_token4] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_Note_COLON] = ACTIONS(1),
    [anon_sym_NOTE_COLON] = ACTIONS(1),
    [anon_sym_Notes_COLON] = ACTIONS(1),
    [anon_sym_Warning_COLON] = ACTIONS(1),
    [anon_sym_WARNING_COLON] = ACTIONS(1),
    [anon_sym_Deprecated] = ACTIONS(1),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(1),
    [aux_sym_keycode_token1] = ACTIONS(1),
    [aux_sym_keycode_token2] = ACTIONS(1),
    [aux_sym_keycode_token3] = ACTIONS(1),
    [aux_sym_keycode_token4] = ACTIONS(1),
    [aux_sym_keycode_token5] = ACTIONS(1),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(1),
    [aux_sym_keycode_token6] = ACTIONS(1),
    [aux_sym_keycode_token7] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [aux_sym_codeblock_token2] = ACTIONS(1),
    [aux_sym__blank_token1] = ACTIONS(1),
    [aux_sym_tag_token1] = ACTIONS(1),
    [anon_sym_STAR2] = ACTIONS(1),
    [sym_url_word] = ACTIONS(1),
    [aux_sym_optionlink_token1] = ACTIONS(1),
    [anon_sym_PIPE2] = ACTIONS(1),
    [anon_sym_BQUOTE] = ACTIONS(1),
    [anon_sym_BQUOTE2] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_help_file] = STATE(108),
    [sym__atom_noli] = STATE(20),
    [sym_word_noli] = STATE(20),
    [sym__atom_common] = STATE(20),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(20),
    [sym_keycode] = STATE(20),
    [sym_uppercase_name] = STATE(100),
    [sym__uppercase_words] = STATE(20),
    [sym_block] = STATE(3),
    [sym_codeblock] = STATE(58),
    [sym__blank] = STATE(2),
    [sym_line] = STATE(6),
    [sym_line_li] = STATE(95),
    [sym__line_noli] = STATE(58),
    [sym_column_heading] = STATE(58),
    [sym__column_heading] = STATE(109),
    [sym_h1] = STATE(58),
    [sym_h2] = STATE(58),
    [sym_h3] = STATE(58),
    [sym_tag] = STATE(20),
    [sym_url] = STATE(20),
    [sym_optionlink] = STATE(20),
    [sym_taglink] = STATE(20),
    [sym_codespan] = STATE(20),
    [sym_argument] = STATE(20),
    [aux_sym_help_file_repeat1] = STATE(2),
    [aux_sym_help_file_repeat2] = STATE(3),
    [aux_sym_help_file_repeat3] = STATE(102),
    [aux_sym_block_repeat1] = STATE(6),
    [aux_sym_block_repeat2] = STATE(95),
    [ts_builtin_sym_end] = ACTIONS(3),
    [aux_sym_word_noli_token1] = ACTIONS(5),
    [aux_sym_word_noli_token2] = ACTIONS(5),
    [anon_sym_STAR] = ACTIONS(7),
    [anon_sym_SQUOTE] = ACTIONS(9),
    [aux_sym__word_common_token3] = ACTIONS(11),
    [anon_sym_PIPE] = ACTIONS(13),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(11),
    [aux_sym__word_common_token4] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(5),
    [anon_sym_RPAREN] = ACTIONS(5),
    [anon_sym_LBRACK] = ACTIONS(11),
    [anon_sym_RBRACK] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_GT] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(11),
    [anon_sym_DOT] = ACTIONS(5),
    [anon_sym_Note_COLON] = ACTIONS(19),
    [anon_sym_NOTE_COLON] = ACTIONS(19),
    [anon_sym_Notes_COLON] = ACTIONS(19),
    [anon_sym_Warning_COLON] = ACTIONS(19),
    [anon_sym_WARNING_COLON] = ACTIONS(19),
    [anon_sym_Deprecated] = ACTIONS(19),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(19),
    [aux_sym_keycode_token1] = ACTIONS(21),
    [aux_sym_keycode_token2] = ACTIONS(21),
    [aux_sym_keycode_token3] = ACTIONS(21),
    [aux_sym_keycode_token4] = ACTIONS(21),
    [aux_sym_keycode_token5] = ACTIONS(23),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(23),
    [aux_sym_keycode_token6] = ACTIONS(21),
    [aux_sym_keycode_token7] = ACTIONS(21),
    [aux_sym_uppercase_name_token1] = ACTIONS(25),
    [anon_sym_LT] = ACTIONS(27),
    [aux_sym__blank_token1] = ACTIONS(29),
    [aux_sym_line_li_token1] = ACTIONS(31),
    [sym_modeline] = ACTIONS(33),
    [aux_sym_h1_token1] = ACTIONS(35),
    [aux_sym_h2_token1] = ACTIONS(37),
    [sym_url_word] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(41),
  },
  [STATE(2)] = {
    [sym__atom_noli] = STATE(20),
    [sym_word_noli] = STATE(20),
    [sym__atom_common] = STATE(20),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(20),
    [sym_keycode] = STATE(20),
    [sym_uppercase_name] = STATE(100),
    [sym__uppercase_words] = STATE(20),
    [sym_block] = STATE(4),
    [sym_codeblock] = STATE(58),
    [sym__blank] = STATE(40),
    [sym_line] = STATE(6),
    [sym_line_li] = STATE(95),
    [sym__line_noli] = STATE(58),
    [sym_column_heading] = STATE(58),
    [sym__column_heading] = STATE(109),
    [sym_h1] = STATE(58),
    [sym_h2] = STATE(58),
    [sym_h3] = STATE(58),
    [sym_tag] = STATE(20),
    [sym_url] = STATE(20),
    [sym_optionlink] = STATE(20),
    [sym_taglink] = STATE(20),
    [sym_codespan] = STATE(20),
    [sym_argument] = STATE(20),
    [aux_sym_help_file_repeat1] = STATE(40),
    [aux_sym_help_file_repeat2] = STATE(4),
    [aux_sym_help_file_repeat3] = STATE(99),
    [aux_sym_block_repeat1] = STATE(6),
    [aux_sym_block_repeat2] = STATE(95),
    [ts_builtin_sym_end] = ACTIONS(43),
    [aux_sym_word_noli_token1] = ACTIONS(5),
    [aux_sym_word_noli_token2] = ACTIONS(5),
    [anon_sym_STAR] = ACTIONS(7),
    [anon_sym_SQUOTE] = ACTIONS(9),
    [aux_sym__word_common_token3] = ACTIONS(11),
    [anon_sym_PIPE] = ACTIONS(13),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(11),
    [aux_sym__word_common_token4] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(5),
    [anon_sym_RPAREN] = ACTIONS(5),
    [anon_sym_LBRACK] = ACTIONS(11),
    [anon_sym_RBRACK] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_GT] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(11),
    [anon_sym_DOT] = ACTIONS(5),
    [anon_sym_Note_COLON] = ACTIONS(19),
    [anon_sym_NOTE_COLON] = ACTIONS(19),
    [anon_sym_Notes_COLON] = ACTIONS(19),
    [anon_sym_Warning_COLON] = ACTIONS(19),
    [anon_sym_WARNING_COLON] = ACTIONS(19),
    [anon_sym_Deprecated] = ACTIONS(19),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(19),
    [aux_sym_keycode_token1] = ACTIONS(21),
    [aux_sym_keycode_token2] = ACTIONS(21),
    [aux_sym_keycode_token3] = ACTIONS(21),
    [aux_sym_keycode_token4] = ACTIONS(21),
    [aux_sym_keycode_token5] = ACTIONS(23),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(23),
    [aux_sym_keycode_token6] = ACTIONS(21),
    [aux_sym_keycode_token7] = ACTIONS(21),
    [aux_sym_uppercase_name_token1] = ACTIONS(25),
    [anon_sym_LT] = ACTIONS(27),
    [aux_sym__blank_token1] = ACTIONS(29),
    [aux_sym_line_li_token1] = ACTIONS(31),
    [sym_modeline] = ACTIONS(45),
    [aux_sym_h1_token1] = ACTIONS(35),
    [aux_sym_h2_token1] = ACTIONS(37),
    [sym_url_word] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(41),
  },
  [STATE(3)] = {
    [sym__atom_noli] = STATE(20),
    [sym_word_noli] = STATE(20),
    [sym__atom_common] = STATE(20),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(20),
    [sym_keycode] = STATE(20),
    [sym_uppercase_name] = STATE(100),
    [sym__uppercase_words] = STATE(20),
    [sym_block] = STATE(5),
    [sym_codeblock] = STATE(58),
    [sym_line] = STATE(6),
    [sym_line_li] = STATE(95),
    [sym__line_noli] = STATE(58),
    [sym_column_heading] = STATE(58),
    [sym__column_heading] = STATE(109),
    [sym_h1] = STATE(58),
    [sym_h2] = STATE(58),
    [sym_h3] = STATE(58),
    [sym_tag] = STATE(20),
    [sym_url] = STATE(20),
    [sym_optionlink] = STATE(20),
    [sym_taglink] = STATE(20),
    [sym_codespan] = STATE(20),
    [sym_argument] = STATE(20),
    [aux_sym_help_file_repeat2] = STATE(5),
    [aux_sym_help_file_repeat3] = STATE(99),
    [aux_sym_block_repeat1] = STATE(6),
    [aux_sym_block_repeat2] = STATE(95),
    [ts_builtin_sym_end] = ACTIONS(43),
    [aux_sym_word_noli_token1] = ACTIONS(5),
    [aux_sym_word_noli_token2] = ACTIONS(5),
    [anon_sym_STAR] = ACTIONS(7),
    [anon_sym_SQUOTE] = ACTIONS(9),
    [aux_sym__word_common_token3] = ACTIONS(11),
    [anon_sym_PIPE] = ACTIONS(13),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(11),
    [aux_sym__word_common_token4] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(5),
    [anon_sym_RPAREN] = ACTIONS(5),
    [anon_sym_LBRACK] = ACTIONS(11),
    [anon_sym_RBRACK] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_GT] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(11),
    [anon_sym_DOT] = ACTIONS(5),
    [anon_sym_Note_COLON] = ACTIONS(19),
    [anon_sym_NOTE_COLON] = ACTIONS(19),
    [anon_sym_Notes_COLON] = ACTIONS(19),
    [anon_sym_Warning_COLON] = ACTIONS(19),
    [anon_sym_WARNING_COLON] = ACTIONS(19),
    [anon_sym_Deprecated] = ACTIONS(19),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(19),
    [aux_sym_keycode_token1] = ACTIONS(21),
    [aux_sym_keycode_token2] = ACTIONS(21),
    [aux_sym_keycode_token3] = ACTIONS(21),
    [aux_sym_keycode_token4] = ACTIONS(21),
    [aux_sym_keycode_token5] = ACTIONS(23),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(23),
    [aux_sym_keycode_token6] = ACTIONS(21),
    [aux_sym_keycode_token7] = ACTIONS(21),
    [aux_sym_uppercase_name_token1] = ACTIONS(25),
    [anon_sym_LT] = ACTIONS(27),
    [aux_sym_line_li_token1] = ACTIONS(31),
    [sym_modeline] = ACTIONS(45),
    [aux_sym_h1_token1] = ACTIONS(35),
    [aux_sym_h2_token1] = ACTIONS(37),
    [sym_url_word] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(41),
  },
  [STATE(4)] = {
    [sym__atom_noli] = STATE(20),
    [sym_word_noli] = STATE(20),
    [sym__atom_common] = STATE(20),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(20),
    [sym_keycode] = STATE(20),
    [sym_uppercase_name] = STATE(100),
    [sym__uppercase_words] = STATE(20),
    [sym_block] = STATE(5),
    [sym_codeblock] = STATE(58),
    [sym_line] = STATE(6),
    [sym_line_li] = STATE(95),
    [sym__line_noli] = STATE(58),
    [sym_column_heading] = STATE(58),
    [sym__column_heading] = STATE(109),
    [sym_h1] = STATE(58),
    [sym_h2] = STATE(58),
    [sym_h3] = STATE(58),
    [sym_tag] = STATE(20),
    [sym_url] = STATE(20),
    [sym_optionlink] = STATE(20),
    [sym_taglink] = STATE(20),
    [sym_codespan] = STATE(20),
    [sym_argument] = STATE(20),
    [aux_sym_help_file_repeat2] = STATE(5),
    [aux_sym_help_file_repeat3] = STATE(103),
    [aux_sym_block_repeat1] = STATE(6),
    [aux_sym_block_repeat2] = STATE(95),
    [ts_builtin_sym_end] = ACTIONS(47),
    [aux_sym_word_noli_token1] = ACTIONS(5),
    [aux_sym_word_noli_token2] = ACTIONS(5),
    [anon_sym_STAR] = ACTIONS(7),
    [anon_sym_SQUOTE] = ACTIONS(9),
    [aux_sym__word_common_token3] = ACTIONS(11),
    [anon_sym_PIPE] = ACTIONS(13),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(11),
    [aux_sym__word_common_token4] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(5),
    [anon_sym_RPAREN] = ACTIONS(5),
    [anon_sym_LBRACK] = ACTIONS(11),
    [anon_sym_RBRACK] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_GT] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(11),
    [anon_sym_DOT] = ACTIONS(5),
    [anon_sym_Note_COLON] = ACTIONS(19),
    [anon_sym_NOTE_COLON] = ACTIONS(19),
    [anon_sym_Notes_COLON] = ACTIONS(19),
    [anon_sym_Warning_COLON] = ACTIONS(19),
    [anon_sym_WARNING_COLON] = ACTIONS(19),
    [anon_sym_Deprecated] = ACTIONS(19),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(19),
    [aux_sym_keycode_token1] = ACTIONS(21),
    [aux_sym_keycode_token2] = ACTIONS(21),
    [aux_sym_keycode_token3] = ACTIONS(21),
    [aux_sym_keycode_token4] = ACTIONS(21),
    [aux_sym_keycode_token5] = ACTIONS(23),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(23),
    [aux_sym_keycode_token6] = ACTIONS(21),
    [aux_sym_keycode_token7] = ACTIONS(21),
    [aux_sym_uppercase_name_token1] = ACTIONS(25),
    [anon_sym_LT] = ACTIONS(27),
    [aux_sym_line_li_token1] = ACTIONS(31),
    [sym_modeline] = ACTIONS(49),
    [aux_sym_h1_token1] = ACTIONS(35),
    [aux_sym_h2_token1] = ACTIONS(37),
    [sym_url_word] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(41),
  },
  [STATE(5)] = {
    [sym__atom_noli] = STATE(20),
    [sym_word_noli] = STATE(20),
    [sym__atom_common] = STATE(20),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(20),
    [sym_keycode] = STATE(20),
    [sym_uppercase_name] = STATE(100),
    [sym__uppercase_words] = STATE(20),
    [sym_block] = STATE(5),
    [sym_codeblock] = STATE(58),
    [sym_line] = STATE(6),
    [sym_line_li] = STATE(95),
    [sym__line_noli] = STATE(58),
    [sym_column_heading] = STATE(58),
    [sym__column_heading] = STATE(109),
    [sym_h1] = STATE(58),
    [sym_h2] = STATE(58),
    [sym_h3] = STATE(58),
    [sym_tag] = STATE(20),
    [sym_url] = STATE(20),
    [sym_optionlink] = STATE(20),
    [sym_taglink] = STATE(20),
    [sym_codespan] = STATE(20),
    [sym_argument] = STATE(20),
    [aux_sym_help_file_repeat2] = STATE(5),
    [aux_sym_block_repeat1] = STATE(6),
    [aux_sym_block_repeat2] = STATE(95),
    [ts_builtin_sym_end] = ACTIONS(51),
    [aux_sym_word_noli_token1] = ACTIONS(53),
    [aux_sym_word_noli_token2] = ACTIONS(53),
    [anon_sym_STAR] = ACTIONS(56),
    [anon_sym_SQUOTE] = ACTIONS(59),
    [aux_sym__word_common_token3] = ACTIONS(62),
    [anon_sym_PIPE] = ACTIONS(65),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(62),
    [anon_sym_LBRACE] = ACTIONS(68),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(62),
    [aux_sym__word_common_token4] = ACTIONS(62),
    [anon_sym_LPAREN] = ACTIONS(53),
    [anon_sym_RPAREN] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(62),
    [anon_sym_RBRACK] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(62),
    [anon_sym_GT] = ACTIONS(71),
    [anon_sym_COMMA] = ACTIONS(62),
    [anon_sym_DOT] = ACTIONS(53),
    [anon_sym_Note_COLON] = ACTIONS(74),
    [anon_sym_NOTE_COLON] = ACTIONS(74),
    [anon_sym_Notes_COLON] = ACTIONS(74),
    [anon_sym_Warning_COLON] = ACTIONS(74),
    [anon_sym_WARNING_COLON] = ACTIONS(74),
    [anon_sym_Deprecated] = ACTIONS(74),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(74),
    [aux_sym_keycode_token1] = ACTIONS(77),
    [aux_sym_keycode_token2] = ACTIONS(77),
    [aux_sym_keycode_token3] = ACTIONS(77),
    [aux_sym_keycode_token4] = ACTIONS(77),
    [aux_sym_keycode_token5] = ACTIONS(80),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(80),
    [aux_sym_keycode_token6] = ACTIONS(77),
    [aux_sym_keycode_token7] = ACTIONS(77),
    [aux_sym_uppercase_name_token1] = ACTIONS(83),
    [anon_sym_LT] = ACTIONS(86),
    [aux_sym_line_li_token1] = ACTIONS(89),
    [sym_modeline] = ACTIONS(51),
    [aux_sym_h1_token1] = ACTIONS(92),
    [aux_sym_h2_token1] = ACTIONS(95),
    [sym_url_word] = ACTIONS(98),
    [anon_sym_BQUOTE] = ACTIONS(101),
  },
  [STATE(6)] = {
    [sym__atom_noli] = STATE(20),
    [sym_word_noli] = STATE(20),
    [sym__atom_common] = STATE(20),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(20),
    [sym_keycode] = STATE(20),
    [sym_uppercase_name] = STATE(100),
    [sym__uppercase_words] = STATE(20),
    [sym_codeblock] = STATE(58),
    [sym__blank] = STATE(36),
    [sym_line] = STATE(7),
    [sym_line_li] = STATE(94),
    [sym__line_noli] = STATE(58),
    [sym_column_heading] = STATE(58),
    [sym__column_heading] = STATE(109),
    [sym_h1] = STATE(58),
    [sym_h2] = STATE(58),
    [sym_h3] = STATE(58),
    [sym_tag] = STATE(20),
    [sym_url] = STATE(20),
    [sym_optionlink] = STATE(20),
    [sym_taglink] = STATE(20),
    [sym_codespan] = STATE(20),
    [sym_argument] = STATE(20),
    [aux_sym_block_repeat1] = STATE(7),
    [aux_sym_block_repeat2] = STATE(94),
    [aux_sym_word_noli_token1] = ACTIONS(5),
    [aux_sym_word_noli_token2] = ACTIONS(5),
    [anon_sym_STAR] = ACTIONS(7),
    [anon_sym_SQUOTE] = ACTIONS(9),
    [aux_sym__word_common_token3] = ACTIONS(11),
    [anon_sym_PIPE] = ACTIONS(13),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(11),
    [aux_sym__word_common_token4] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(5),
    [anon_sym_RPAREN] = ACTIONS(5),
    [anon_sym_LBRACK] = ACTIONS(11),
    [anon_sym_RBRACK] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_GT] = ACTIONS(17),
    [anon_sym_COMMA] = ACTIONS(11),
    [anon_sym_DOT] = ACTIONS(5),
    [anon_sym_Note_COLON] = ACTIONS(19),
    [anon_sym_NOTE_COLON] = ACTIONS(19),
    [anon_sym_Notes_COLON] = ACTIONS(19),
    [anon_sym_Warning_COLON] = ACTIONS(19),
    [anon_sym_WARNING_COLON] = ACTIONS(19),
    [anon_sym_Deprecated] = ACTIONS(19),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(19),
    [aux_sym_keycode_token1] = ACTIONS(21),
    [aux_sym_keycode_token2] = ACTIONS(21),
    [aux_sym_keycode_token3] = ACTIONS(21),
    [aux_sym_keycode_token4] = ACTIONS(21),
    [aux_sym_keycode_token5] = ACTIONS(23),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(23),
    [aux_sym_keycode_token6] = ACTIONS(21),
    [aux_sym_keycode_token7] = ACTIONS(21),
    [aux_sym_uppercase_name_token1] = ACTIONS(25),
    [anon_sym_LT] = ACTIONS(104),
    [aux_sym__blank_token1] = ACTIONS(29),
    [aux_sym_line_li_token1] = ACTIONS(31),
    [aux_sym_h1_token1] = ACTIONS(35),
    [aux_sym_h2_token1] = ACTIONS(37),
    [sym_url_word] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(41),
  },
  [STATE(7)] = {
    [sym__atom_noli] = STATE(20),
    [sym_word_noli] = STATE(20),
    [sym__atom_common] = STATE(20),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(20),
    [sym_keycode] = STATE(20),
    [sym_uppercase_name] = STATE(100),
    [sym__uppercase_words] = STATE(20),
    [sym_codeblock] = STATE(58),
    [sym_line] = STATE(7),
    [sym__line_noli] = STATE(58),
    [sym_column_heading] = STATE(58),
    [sym__column_heading] = STATE(109),
    [sym_h1] = STATE(58),
    [sym_h2] = STATE(58),
    [sym_h3] = STATE(58),
    [sym_tag] = STATE(20),
    [sym_url] = STATE(20),
    [sym_optionlink] = STATE(20),
    [sym_taglink] = STATE(20),
    [sym_codespan] = STATE(20),
    [sym_argument] = STATE(20),
    [aux_sym_block_repeat1] = STATE(7),
    [aux_sym_word_noli_token1] = ACTIONS(106),
    [aux_sym_word_noli_token2] = ACTIONS(106),
    [anon_sym_STAR] = ACTIONS(109),
    [anon_sym_SQUOTE] = ACTIONS(112),
    [aux_sym__word_common_token3] = ACTIONS(115),
    [anon_sym_PIPE] = ACTIONS(118),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(115),
    [anon_sym_LBRACE] = ACTIONS(121),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(115),
    [aux_sym__word_common_token4] = ACTIONS(115),
    [anon_sym_LPAREN] = ACTIONS(106),
    [anon_sym_RPAREN] = ACTIONS(106),
    [anon_sym_LBRACK] = ACTIONS(115),
    [anon_sym_RBRACK] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_GT] = ACTIONS(124),
    [anon_sym_COMMA] = ACTIONS(115),
    [anon_sym_DOT] = ACTIONS(106),
    [anon_sym_Note_COLON] = ACTIONS(127),
    [anon_sym_NOTE_COLON] = ACTIONS(127),
    [anon_sym_Notes_COLON] = ACTIONS(127),
    [anon_sym_Warning_COLON] = ACTIONS(127),
    [anon_sym_WARNING_COLON] = ACTIONS(127),
    [anon_sym_Deprecated] = ACTIONS(127),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(127),
    [aux_sym_keycode_token1] = ACTIONS(130),
    [aux_sym_keycode_token2] = ACTIONS(130),
    [aux_sym_keycode_token3] = ACTIONS(130),
    [aux_sym_keycode_token4] = ACTIONS(130),
    [aux_sym_keycode_token5] = ACTIONS(133),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(133),
    [aux_sym_keycode_token6] = ACTIONS(130),
    [aux_sym_keycode_token7] = ACTIONS(130),
    [aux_sym_uppercase_name_token1] = ACTIONS(136),
    [anon_sym_LT] = ACTIONS(139),
    [aux_sym__blank_token1] = ACTIONS(141),
    [aux_sym_line_li_token1] = ACTIONS(141),
    [aux_sym_h1_token1] = ACTIONS(143),
    [aux_sym_h2_token1] = ACTIONS(146),
    [sym_url_word] = ACTIONS(149),
    [anon_sym_BQUOTE] = ACTIONS(152),
  },
  [STATE(8)] = {
    [sym__atom_noli] = STATE(21),
    [sym_word_noli] = STATE(21),
    [sym__atom_common] = STATE(21),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(21),
    [sym_keycode] = STATE(21),
    [sym__uppercase_words] = STATE(21),
    [sym__line_noli] = STATE(65),
    [sym_tag] = STATE(21),
    [sym_url] = STATE(21),
    [sym_optionlink] = STATE(21),
    [sym_taglink] = STATE(21),
    [sym_codespan] = STATE(21),
    [sym_argument] = STATE(21),
    [aux_sym_line_li_repeat2] = STATE(12),
    [aux_sym_word_noli_token1] = ACTIONS(5),
    [aux_sym_word_noli_token2] = ACTIONS(5),
    [anon_sym_STAR] = ACTIONS(7),
    [anon_sym_SQUOTE] = ACTIONS(9),
    [aux_sym__word_common_token3] = ACTIONS(11),
    [anon_sym_PIPE] = ACTIONS(13),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(11),
    [aux_sym__word_common_token4] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(5),
    [anon_sym_RPAREN] = ACTIONS(5),
    [anon_sym_LBRACK] = ACTIONS(11),
    [anon_sym_RBRACK] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_GT] = ACTIONS(11),
    [anon_sym_COMMA] = ACTIONS(11),
    [anon_sym_DOT] = ACTIONS(5),
    [anon_sym_Note_COLON] = ACTIONS(19),
    [anon_sym_NOTE_COLON] = ACTIONS(19),
    [anon_sym_Notes_COLON] = ACTIONS(19),
    [anon_sym_Warning_COLON] = ACTIONS(19),
    [anon_sym_WARNING_COLON] = ACTIONS(19),
    [anon_sym_Deprecated] = ACTIONS(19),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(19),
    [aux_sym_keycode_token1] = ACTIONS(21),
    [aux_sym_keycode_token2] = ACTIONS(21),
    [aux_sym_keycode_token3] = ACTIONS(21),
    [aux_sym_keycode_token4] = ACTIONS(21),
    [aux_sym_keycode_token5] = ACTIONS(23),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(23),
    [aux_sym_keycode_token6] = ACTIONS(21),
    [aux_sym_keycode_token7] = ACTIONS(21),
    [aux_sym_uppercase_name_token1] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(157),
    [aux_sym__blank_token1] = ACTIONS(159),
    [aux_sym_line_li_token1] = ACTIONS(159),
    [sym_url_word] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(41),
  },
  [STATE(9)] = {
    [sym__atom_noli] = STATE(21),
    [sym_word_noli] = STATE(21),
    [sym__atom_common] = STATE(21),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(21),
    [sym_keycode] = STATE(21),
    [sym__uppercase_words] = STATE(21),
    [sym__line_noli] = STATE(65),
    [sym_tag] = STATE(21),
    [sym_url] = STATE(21),
    [sym_optionlink] = STATE(21),
    [sym_taglink] = STATE(21),
    [sym_codespan] = STATE(21),
    [sym_argument] = STATE(21),
    [aux_sym_line_li_repeat2] = STATE(13),
    [aux_sym_word_noli_token1] = ACTIONS(5),
    [aux_sym_word_noli_token2] = ACTIONS(5),
    [anon_sym_STAR] = ACTIONS(7),
    [anon_sym_SQUOTE] = ACTIONS(9),
    [aux_sym__word_common_token3] = ACTIONS(11),
    [anon_sym_PIPE] = ACTIONS(13),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(11),
    [aux_sym__word_common_token4] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(5),
    [anon_sym_RPAREN] = ACTIONS(5),
    [anon_sym_LBRACK] = ACTIONS(11),
    [anon_sym_RBRACK] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_GT] = ACTIONS(11),
    [anon_sym_COMMA] = ACTIONS(11),
    [anon_sym_DOT] = ACTIONS(5),
    [anon_sym_Note_COLON] = ACTIONS(19),
    [anon_sym_NOTE_COLON] = ACTIONS(19),
    [anon_sym_Notes_COLON] = ACTIONS(19),
    [anon_sym_Warning_COLON] = ACTIONS(19),
    [anon_sym_WARNING_COLON] = ACTIONS(19),
    [anon_sym_Deprecated] = ACTIONS(19),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(19),
    [aux_sym_keycode_token1] = ACTIONS(21),
    [aux_sym_keycode_token2] = ACTIONS(21),
    [aux_sym_keycode_token3] = ACTIONS(21),
    [aux_sym_keycode_token4] = ACTIONS(21),
    [aux_sym_keycode_token5] = ACTIONS(23),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(23),
    [aux_sym_keycode_token6] = ACTIONS(21),
    [aux_sym_keycode_token7] = ACTIONS(21),
    [aux_sym_uppercase_name_token1] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(161),
    [aux_sym__blank_token1] = ACTIONS(163),
    [aux_sym_line_li_token1] = ACTIONS(163),
    [sym_url_word] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(41),
  },
  [STATE(10)] = {
    [sym__atom_noli] = STATE(21),
    [sym_word_noli] = STATE(21),
    [sym__atom_common] = STATE(21),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(21),
    [sym_keycode] = STATE(21),
    [sym__uppercase_words] = STATE(21),
    [sym__line_noli] = STATE(65),
    [sym_tag] = STATE(21),
    [sym_url] = STATE(21),
    [sym_optionlink] = STATE(21),
    [sym_taglink] = STATE(21),
    [sym_codespan] = STATE(21),
    [sym_argument] = STATE(21),
    [aux_sym_line_li_repeat2] = STATE(14),
    [aux_sym_word_noli_token1] = ACTIONS(5),
    [aux_sym_word_noli_token2] = ACTIONS(5),
    [anon_sym_STAR] = ACTIONS(7),
    [anon_sym_SQUOTE] = ACTIONS(9),
    [aux_sym__word_common_token3] = ACTIONS(11),
    [anon_sym_PIPE] = ACTIONS(13),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(11),
    [aux_sym__word_common_token4] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(5),
    [anon_sym_RPAREN] = ACTIONS(5),
    [anon_sym_LBRACK] = ACTIONS(11),
    [anon_sym_RBRACK] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_GT] = ACTIONS(11),
    [anon_sym_COMMA] = ACTIONS(11),
    [anon_sym_DOT] = ACTIONS(5),
    [anon_sym_Note_COLON] = ACTIONS(19),
    [anon_sym_NOTE_COLON] = ACTIONS(19),
    [anon_sym_Notes_COLON] = ACTIONS(19),
    [anon_sym_Warning_COLON] = ACTIONS(19),
    [anon_sym_WARNING_COLON] = ACTIONS(19),
    [anon_sym_Deprecated] = ACTIONS(19),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(19),
    [aux_sym_keycode_token1] = ACTIONS(21),
    [aux_sym_keycode_token2] = ACTIONS(21),
    [aux_sym_keycode_token3] = ACTIONS(21),
    [aux_sym_keycode_token4] = ACTIONS(21),
    [aux_sym_keycode_token5] = ACTIONS(23),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(23),
    [aux_sym_keycode_token6] = ACTIONS(21),
    [aux_sym_keycode_token7] = ACTIONS(21),
    [aux_sym_uppercase_name_token1] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(165),
    [aux_sym__blank_token1] = ACTIONS(167),
    [aux_sym_line_li_token1] = ACTIONS(167),
    [sym_url_word] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(41),
  },
  [STATE(11)] = {
    [sym__atom_noli] = STATE(21),
    [sym_word_noli] = STATE(21),
    [sym__atom_common] = STATE(21),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(21),
    [sym_keycode] = STATE(21),
    [sym__uppercase_words] = STATE(21),
    [sym__line_noli] = STATE(65),
    [sym_tag] = STATE(21),
    [sym_url] = STATE(21),
    [sym_optionlink] = STATE(21),
    [sym_taglink] = STATE(21),
    [sym_codespan] = STATE(21),
    [sym_argument] = STATE(21),
    [aux_sym_line_li_repeat2] = STATE(15),
    [aux_sym_word_noli_token1] = ACTIONS(5),
    [aux_sym_word_noli_token2] = ACTIONS(5),
    [anon_sym_STAR] = ACTIONS(7),
    [anon_sym_SQUOTE] = ACTIONS(9),
    [aux_sym__word_common_token3] = ACTIONS(11),
    [anon_sym_PIPE] = ACTIONS(13),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(11),
    [aux_sym__word_common_token4] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(5),
    [anon_sym_RPAREN] = ACTIONS(5),
    [anon_sym_LBRACK] = ACTIONS(11),
    [anon_sym_RBRACK] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_GT] = ACTIONS(11),
    [anon_sym_COMMA] = ACTIONS(11),
    [anon_sym_DOT] = ACTIONS(5),
    [anon_sym_Note_COLON] = ACTIONS(19),
    [anon_sym_NOTE_COLON] = ACTIONS(19),
    [anon_sym_Notes_COLON] = ACTIONS(19),
    [anon_sym_Warning_COLON] = ACTIONS(19),
    [anon_sym_WARNING_COLON] = ACTIONS(19),
    [anon_sym_Deprecated] = ACTIONS(19),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(19),
    [aux_sym_keycode_token1] = ACTIONS(21),
    [aux_sym_keycode_token2] = ACTIONS(21),
    [aux_sym_keycode_token3] = ACTIONS(21),
    [aux_sym_keycode_token4] = ACTIONS(21),
    [aux_sym_keycode_token5] = ACTIONS(23),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(23),
    [aux_sym_keycode_token6] = ACTIONS(21),
    [aux_sym_keycode_token7] = ACTIONS(21),
    [aux_sym_uppercase_name_token1] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(169),
    [aux_sym__blank_token1] = ACTIONS(171),
    [aux_sym_line_li_token1] = ACTIONS(171),
    [sym_url_word] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(41),
  },
  [STATE(12)] = {
    [sym__atom_noli] = STATE(21),
    [sym_word_noli] = STATE(21),
    [sym__atom_common] = STATE(21),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(21),
    [sym_keycode] = STATE(21),
    [sym__uppercase_words] = STATE(21),
    [sym__line_noli] = STATE(65),
    [sym_tag] = STATE(21),
    [sym_url] = STATE(21),
    [sym_optionlink] = STATE(21),
    [sym_taglink] = STATE(21),
    [sym_codespan] = STATE(21),
    [sym_argument] = STATE(21),
    [aux_sym_line_li_repeat2] = STATE(16),
    [aux_sym_word_noli_token1] = ACTIONS(5),
    [aux_sym_word_noli_token2] = ACTIONS(5),
    [anon_sym_STAR] = ACTIONS(7),
    [anon_sym_SQUOTE] = ACTIONS(9),
    [aux_sym__word_common_token3] = ACTIONS(11),
    [anon_sym_PIPE] = ACTIONS(13),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(11),
    [aux_sym__word_common_token4] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(5),
    [anon_sym_RPAREN] = ACTIONS(5),
    [anon_sym_LBRACK] = ACTIONS(11),
    [anon_sym_RBRACK] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_GT] = ACTIONS(11),
    [anon_sym_COMMA] = ACTIONS(11),
    [anon_sym_DOT] = ACTIONS(5),
    [anon_sym_Note_COLON] = ACTIONS(19),
    [anon_sym_NOTE_COLON] = ACTIONS(19),
    [anon_sym_Notes_COLON] = ACTIONS(19),
    [anon_sym_Warning_COLON] = ACTIONS(19),
    [anon_sym_WARNING_COLON] = ACTIONS(19),
    [anon_sym_Deprecated] = ACTIONS(19),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(19),
    [aux_sym_keycode_token1] = ACTIONS(21),
    [aux_sym_keycode_token2] = ACTIONS(21),
    [aux_sym_keycode_token3] = ACTIONS(21),
    [aux_sym_keycode_token4] = ACTIONS(21),
    [aux_sym_keycode_token5] = ACTIONS(23),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(23),
    [aux_sym_keycode_token6] = ACTIONS(21),
    [aux_sym_keycode_token7] = ACTIONS(21),
    [aux_sym_uppercase_name_token1] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(173),
    [aux_sym__blank_token1] = ACTIONS(175),
    [aux_sym_line_li_token1] = ACTIONS(175),
    [sym_url_word] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(41),
  },
  [STATE(13)] = {
    [sym__atom_noli] = STATE(21),
    [sym_word_noli] = STATE(21),
    [sym__atom_common] = STATE(21),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(21),
    [sym_keycode] = STATE(21),
    [sym__uppercase_words] = STATE(21),
    [sym__line_noli] = STATE(65),
    [sym_tag] = STATE(21),
    [sym_url] = STATE(21),
    [sym_optionlink] = STATE(21),
    [sym_taglink] = STATE(21),
    [sym_codespan] = STATE(21),
    [sym_argument] = STATE(21),
    [aux_sym_line_li_repeat2] = STATE(16),
    [aux_sym_word_noli_token1] = ACTIONS(5),
    [aux_sym_word_noli_token2] = ACTIONS(5),
    [anon_sym_STAR] = ACTIONS(7),
    [anon_sym_SQUOTE] = ACTIONS(9),
    [aux_sym__word_common_token3] = ACTIONS(11),
    [anon_sym_PIPE] = ACTIONS(13),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(11),
    [aux_sym__word_common_token4] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(5),
    [anon_sym_RPAREN] = ACTIONS(5),
    [anon_sym_LBRACK] = ACTIONS(11),
    [anon_sym_RBRACK] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_GT] = ACTIONS(11),
    [anon_sym_COMMA] = ACTIONS(11),
    [anon_sym_DOT] = ACTIONS(5),
    [anon_sym_Note_COLON] = ACTIONS(19),
    [anon_sym_NOTE_COLON] = ACTIONS(19),
    [anon_sym_Notes_COLON] = ACTIONS(19),
    [anon_sym_Warning_COLON] = ACTIONS(19),
    [anon_sym_WARNING_COLON] = ACTIONS(19),
    [anon_sym_Deprecated] = ACTIONS(19),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(19),
    [aux_sym_keycode_token1] = ACTIONS(21),
    [aux_sym_keycode_token2] = ACTIONS(21),
    [aux_sym_keycode_token3] = ACTIONS(21),
    [aux_sym_keycode_token4] = ACTIONS(21),
    [aux_sym_keycode_token5] = ACTIONS(23),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(23),
    [aux_sym_keycode_token6] = ACTIONS(21),
    [aux_sym_keycode_token7] = ACTIONS(21),
    [aux_sym_uppercase_name_token1] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(177),
    [aux_sym__blank_token1] = ACTIONS(179),
    [aux_sym_line_li_token1] = ACTIONS(179),
    [sym_url_word] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(41),
  },
  [STATE(14)] = {
    [sym__atom_noli] = STATE(21),
    [sym_word_noli] = STATE(21),
    [sym__atom_common] = STATE(21),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(21),
    [sym_keycode] = STATE(21),
    [sym__uppercase_words] = STATE(21),
    [sym__line_noli] = STATE(65),
    [sym_tag] = STATE(21),
    [sym_url] = STATE(21),
    [sym_optionlink] = STATE(21),
    [sym_taglink] = STATE(21),
    [sym_codespan] = STATE(21),
    [sym_argument] = STATE(21),
    [aux_sym_line_li_repeat2] = STATE(16),
    [aux_sym_word_noli_token1] = ACTIONS(5),
    [aux_sym_word_noli_token2] = ACTIONS(5),
    [anon_sym_STAR] = ACTIONS(7),
    [anon_sym_SQUOTE] = ACTIONS(9),
    [aux_sym__word_common_token3] = ACTIONS(11),
    [anon_sym_PIPE] = ACTIONS(13),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(11),
    [aux_sym__word_common_token4] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(5),
    [anon_sym_RPAREN] = ACTIONS(5),
    [anon_sym_LBRACK] = ACTIONS(11),
    [anon_sym_RBRACK] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_GT] = ACTIONS(11),
    [anon_sym_COMMA] = ACTIONS(11),
    [anon_sym_DOT] = ACTIONS(5),
    [anon_sym_Note_COLON] = ACTIONS(19),
    [anon_sym_NOTE_COLON] = ACTIONS(19),
    [anon_sym_Notes_COLON] = ACTIONS(19),
    [anon_sym_Warning_COLON] = ACTIONS(19),
    [anon_sym_WARNING_COLON] = ACTIONS(19),
    [anon_sym_Deprecated] = ACTIONS(19),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(19),
    [aux_sym_keycode_token1] = ACTIONS(21),
    [aux_sym_keycode_token2] = ACTIONS(21),
    [aux_sym_keycode_token3] = ACTIONS(21),
    [aux_sym_keycode_token4] = ACTIONS(21),
    [aux_sym_keycode_token5] = ACTIONS(23),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(23),
    [aux_sym_keycode_token6] = ACTIONS(21),
    [aux_sym_keycode_token7] = ACTIONS(21),
    [aux_sym_uppercase_name_token1] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(181),
    [aux_sym__blank_token1] = ACTIONS(183),
    [aux_sym_line_li_token1] = ACTIONS(183),
    [sym_url_word] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(41),
  },
  [STATE(15)] = {
    [sym__atom_noli] = STATE(21),
    [sym_word_noli] = STATE(21),
    [sym__atom_common] = STATE(21),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(21),
    [sym_keycode] = STATE(21),
    [sym__uppercase_words] = STATE(21),
    [sym__line_noli] = STATE(65),
    [sym_tag] = STATE(21),
    [sym_url] = STATE(21),
    [sym_optionlink] = STATE(21),
    [sym_taglink] = STATE(21),
    [sym_codespan] = STATE(21),
    [sym_argument] = STATE(21),
    [aux_sym_line_li_repeat2] = STATE(16),
    [aux_sym_word_noli_token1] = ACTIONS(5),
    [aux_sym_word_noli_token2] = ACTIONS(5),
    [anon_sym_STAR] = ACTIONS(7),
    [anon_sym_SQUOTE] = ACTIONS(9),
    [aux_sym__word_common_token3] = ACTIONS(11),
    [anon_sym_PIPE] = ACTIONS(13),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(11),
    [aux_sym__word_common_token4] = ACTIONS(11),
    [anon_sym_LPAREN] = ACTIONS(5),
    [anon_sym_RPAREN] = ACTIONS(5),
    [anon_sym_LBRACK] = ACTIONS(11),
    [anon_sym_RBRACK] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_GT] = ACTIONS(11),
    [anon_sym_COMMA] = ACTIONS(11),
    [anon_sym_DOT] = ACTIONS(5),
    [anon_sym_Note_COLON] = ACTIONS(19),
    [anon_sym_NOTE_COLON] = ACTIONS(19),
    [anon_sym_Notes_COLON] = ACTIONS(19),
    [anon_sym_Warning_COLON] = ACTIONS(19),
    [anon_sym_WARNING_COLON] = ACTIONS(19),
    [anon_sym_Deprecated] = ACTIONS(19),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(19),
    [aux_sym_keycode_token1] = ACTIONS(21),
    [aux_sym_keycode_token2] = ACTIONS(21),
    [aux_sym_keycode_token3] = ACTIONS(21),
    [aux_sym_keycode_token4] = ACTIONS(21),
    [aux_sym_keycode_token5] = ACTIONS(23),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(23),
    [aux_sym_keycode_token6] = ACTIONS(21),
    [aux_sym_keycode_token7] = ACTIONS(21),
    [aux_sym_uppercase_name_token1] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(185),
    [aux_sym__blank_token1] = ACTIONS(187),
    [aux_sym_line_li_token1] = ACTIONS(187),
    [sym_url_word] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(41),
  },
  [STATE(16)] = {
    [sym__atom_noli] = STATE(21),
    [sym_word_noli] = STATE(21),
    [sym__atom_common] = STATE(21),
    [sym__word_common] = STATE(92),
    [sym_note] = STATE(21),
    [sym_keycode] = STATE(21),
    [sym__uppercase_words] = STATE(21),
    [sym__line_noli] = STATE(65),
    [sym_tag] = STATE(21),
    [sym_url] = STATE(21),
    [sym_optionlink] = STATE(21),
    [sym_taglink] = STATE(21),
    [sym_codespan] = STATE(21),
    [sym_argument] = STATE(21),
    [aux_sym_line_li_repeat2] = STATE(16),
    [aux_sym_word_noli_token1] = ACTIONS(189),
    [aux_sym_word_noli_token2] = ACTIONS(189),
    [anon_sym_STAR] = ACTIONS(192),
    [anon_sym_SQUOTE] = ACTIONS(195),
    [aux_sym__word_common_token3] = ACTIONS(198),
    [anon_sym_PIPE] = ACTIONS(201),
    [anon_sym_SQUOTE_PIPE_SQUOTE] = ACTIONS(198),
    [anon_sym_LBRACE] = ACTIONS(204),
    [anon_sym_LBRACE_RBRACE] = ACTIONS(198),
    [aux_sym__word_common_token4] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(189),
    [anon_sym_RPAREN] = ACTIONS(189),
    [anon_sym_LBRACK] = ACTIONS(198),
    [anon_sym_RBRACK] = ACTIONS(198),
    [anon_sym_TILDE] = ACTIONS(198),
    [anon_sym_GT] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(198),
    [anon_sym_DOT] = ACTIONS(189),
    [anon_sym_Note_COLON] = ACTIONS(207),
    [anon_sym_NOTE_COLON] = ACTIONS(207),
    [anon_sym_Notes_COLON] = ACTIONS(207),
    [anon_sym_Warning_COLON] = ACTIONS(207),
    [anon_sym_WARNING_COLON] = ACTIONS(207),
    [anon_sym_Deprecated] = ACTIONS(207),
    [anon_sym_DEPRECATED_COLON] = ACTIONS(207),
    [aux_sym_keycode_token1] = ACTIONS(210),
    [aux_sym_keycode_token2] = ACTIONS(210),
    [aux_sym_keycode_token3] = ACTIONS(210),
    [aux_sym_keycode_token4] = ACTIONS(210),
    [aux_sym_keycode_token5] = ACTIONS(213),
    [anon_sym_CTRL_DASH_LBRACEchar_RBRACE] = ACTIONS(213),
    [aux_sym_keycode_token6] = ACTIONS(210),
    [aux_sym_keycode_token7] = ACTIONS(210),
    [aux_sym_uppercase_name_token1] = ACTIONS(216),
    [anon_sym_LT] = ACTIONS(219),
    [aux_sym__blank_token1] = ACTIONS(221),
    [aux_sym_line_li_token1] = ACTIONS(221),
    [sym_url_word] = ACTIONS(223),
    [anon_sym_BQUOTE] = ACTIONS(226),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 17,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    ACTIONS(233), 1,
      anon_sym_GT,
    ACTIONS(235), 1,
      aux_sym__blank_token1,
    STATE(11), 1,
      sym_codeblock,
    STATE(24), 1,
      aux_sym_line_li_repeat1,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    ACTIONS(231), 11,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_COMMA,
      anon_sym_DOT,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
  [84] = 17,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    ACTIONS(233), 1,
      anon_sym_GT,
    ACTIONS(237), 1,
      aux_sym__blank_token1,
    STATE(9), 1,
      sym_codeblock,
    STATE(24), 1,
      aux_sym_line_li_repeat1,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    ACTIONS(231), 11,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_COMMA,
      anon_sym_DOT,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
  [168] = 18,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(17), 1,
      anon_sym_GT,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    ACTIONS(239), 1,
      anon_sym_TILDE,
    ACTIONS(242), 1,
      aux_sym__blank_token1,
    STATE(24), 1,
      aux_sym_line_li_repeat1,
    STATE(56), 1,
      sym_codeblock,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    ACTIONS(231), 10,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_DOT,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
  [254] = 18,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(17), 1,
      anon_sym_GT,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    ACTIONS(244), 1,
      anon_sym_TILDE,
    ACTIONS(247), 1,
      aux_sym__blank_token1,
    STATE(19), 1,
      aux_sym_line_li_repeat1,
    STATE(55), 1,
      sym_codeblock,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    ACTIONS(231), 10,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_DOT,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
  [340] = 17,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    ACTIONS(233), 1,
      anon_sym_GT,
    ACTIONS(249), 1,
      aux_sym__blank_token1,
    STATE(22), 1,
      aux_sym_line_li_repeat1,
    STATE(66), 1,
      sym_codeblock,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    ACTIONS(231), 11,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_COMMA,
      anon_sym_DOT,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
  [424] = 17,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    ACTIONS(233), 1,
      anon_sym_GT,
    ACTIONS(251), 1,
      aux_sym__blank_token1,
    STATE(24), 1,
      aux_sym_line_li_repeat1,
    STATE(67), 1,
      sym_codeblock,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    ACTIONS(231), 11,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_COMMA,
      anon_sym_DOT,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
  [508] = 15,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    ACTIONS(253), 1,
      aux_sym__blank_token1,
    STATE(24), 1,
      aux_sym_line_li_repeat1,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
    ACTIONS(231), 12,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
  [587] = 15,
    ACTIONS(255), 1,
      aux_sym_word_token1,
    ACTIONS(258), 1,
      anon_sym_STAR,
    ACTIONS(261), 1,
      anon_sym_SQUOTE,
    ACTIONS(267), 1,
      anon_sym_PIPE,
    ACTIONS(270), 1,
      anon_sym_LBRACE,
    ACTIONS(282), 1,
      aux_sym__blank_token1,
    ACTIONS(284), 1,
      sym_url_word,
    ACTIONS(287), 1,
      anon_sym_BQUOTE,
    STATE(24), 1,
      aux_sym_line_li_repeat1,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(276), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(279), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(273), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
    ACTIONS(264), 12,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
  [666] = 15,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    ACTIONS(290), 1,
      aux_sym__blank_token1,
    STATE(28), 1,
      aux_sym_line_li_repeat1,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
    ACTIONS(231), 12,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
  [745] = 15,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    ACTIONS(292), 1,
      aux_sym__blank_token1,
    STATE(30), 1,
      aux_sym_line_li_repeat1,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
    ACTIONS(231), 12,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
  [824] = 16,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    ACTIONS(294), 1,
      aux_sym__blank_token1,
    STATE(24), 1,
      aux_sym_line_li_repeat1,
    STATE(26), 1,
      sym_tag,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    STATE(89), 10,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
    ACTIONS(231), 12,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
  [905] = 15,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    ACTIONS(296), 1,
      aux_sym__blank_token1,
    STATE(24), 1,
      aux_sym_line_li_repeat1,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
    ACTIONS(231), 12,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
  [984] = 15,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    ACTIONS(298), 1,
      aux_sym__blank_token1,
    STATE(23), 1,
      aux_sym_line_li_repeat1,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
    ACTIONS(231), 12,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
  [1063] = 15,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    ACTIONS(300), 1,
      aux_sym__blank_token1,
    STATE(24), 1,
      aux_sym_line_li_repeat1,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
    ACTIONS(231), 12,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
  [1142] = 16,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    ACTIONS(302), 1,
      aux_sym__blank_token1,
    STATE(24), 1,
      aux_sym_line_li_repeat1,
    STATE(25), 1,
      sym_tag,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    STATE(89), 10,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
    ACTIONS(231), 12,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
  [1223] = 14,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    STATE(17), 1,
      aux_sym_line_li_repeat1,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
    ACTIONS(231), 12,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
  [1299] = 14,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    STATE(27), 1,
      aux_sym_line_li_repeat1,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
    ACTIONS(231), 12,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
  [1375] = 14,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    STATE(31), 1,
      aux_sym_line_li_repeat1,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
    ACTIONS(231), 12,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
  [1451] = 14,
    ACTIONS(7), 1,
      anon_sym_STAR,
    ACTIONS(9), 1,
      anon_sym_SQUOTE,
    ACTIONS(13), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(39), 1,
      sym_url_word,
    ACTIONS(41), 1,
      anon_sym_BQUOTE,
    ACTIONS(229), 1,
      aux_sym_word_token1,
    STATE(18), 1,
      aux_sym_line_li_repeat1,
    STATE(84), 1,
      sym__word_common,
    ACTIONS(21), 3,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(23), 5,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(19), 7,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
    STATE(89), 11,
      sym__atom,
      sym_word,
      sym__atom_common,
      sym_note,
      sym_keycode,
      sym_tag,
      sym_url,
      sym_optionlink,
      sym_taglink,
      sym_codespan,
      sym_argument,
    ACTIONS(231), 12,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
  [1527] = 4,
    ACTIONS(29), 1,
      aux_sym__blank_token1,
    STATE(37), 2,
      sym__blank,
      aux_sym_help_file_repeat1,
    ACTIONS(306), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(304), 26,
      ts_builtin_sym_end,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_line_li_token1,
      sym_modeline,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [1581] = 4,
    ACTIONS(29), 1,
      aux_sym__blank_token1,
    STATE(40), 2,
      sym__blank,
      aux_sym_help_file_repeat1,
    ACTIONS(310), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(308), 26,
      ts_builtin_sym_end,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_line_li_token1,
      sym_modeline,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [1635] = 5,
    ACTIONS(29), 1,
      aux_sym__blank_token1,
    ACTIONS(312), 1,
      aux_sym_line_li_token1,
    STATE(41), 2,
      sym__blank,
      aux_sym_help_file_repeat1,
    ACTIONS(310), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(308), 25,
      ts_builtin_sym_end,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      sym_modeline,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [1691] = 4,
    ACTIONS(29), 1,
      aux_sym__blank_token1,
    STATE(41), 2,
      sym__blank,
      aux_sym_help_file_repeat1,
    ACTIONS(310), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(308), 26,
      ts_builtin_sym_end,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_line_li_token1,
      sym_modeline,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [1745] = 4,
    ACTIONS(318), 1,
      aux_sym__blank_token1,
    STATE(40), 2,
      sym__blank,
      aux_sym_help_file_repeat1,
    ACTIONS(316), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(314), 26,
      ts_builtin_sym_end,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_line_li_token1,
      sym_modeline,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [1799] = 4,
    ACTIONS(29), 1,
      aux_sym__blank_token1,
    STATE(40), 2,
      sym__blank,
      aux_sym_help_file_repeat1,
    ACTIONS(323), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(321), 26,
      ts_builtin_sym_end,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_line_li_token1,
      sym_modeline,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [1853] = 5,
    ACTIONS(29), 1,
      aux_sym__blank_token1,
    ACTIONS(312), 1,
      aux_sym_line_li_token1,
    STATE(37), 2,
      sym__blank,
      aux_sym_help_file_repeat1,
    ACTIONS(306), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(304), 25,
      ts_builtin_sym_end,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      sym_modeline,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [1909] = 6,
    ACTIONS(327), 1,
      aux_sym__blank_token1,
    ACTIONS(329), 1,
      aux_sym_line_code_token1,
    STATE(44), 1,
      aux_sym_codeblock_repeat1,
    STATE(47), 1,
      sym_line_code,
    ACTIONS(331), 2,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
    ACTIONS(325), 38,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_STAR,
      anon_sym_SQUOTE,
      aux_sym__word_common_token3,
      anon_sym_PIPE,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
      aux_sym_line_li_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [1966] = 6,
    ACTIONS(335), 1,
      aux_sym__blank_token1,
    ACTIONS(338), 1,
      aux_sym_line_code_token1,
    STATE(44), 1,
      aux_sym_codeblock_repeat1,
    STATE(47), 1,
      sym_line_code,
    ACTIONS(341), 2,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
    ACTIONS(333), 38,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_STAR,
      anon_sym_SQUOTE,
      aux_sym__word_common_token3,
      anon_sym_PIPE,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
      aux_sym_line_li_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2023] = 2,
    ACTIONS(345), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(343), 27,
      ts_builtin_sym_end,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      sym_modeline,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2071] = 2,
    ACTIONS(349), 3,
      aux_sym__blank_token1,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
    ACTIONS(347), 39,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_STAR,
      anon_sym_SQUOTE,
      aux_sym__word_common_token3,
      anon_sym_PIPE,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
      aux_sym_line_li_token1,
      aux_sym_line_code_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2118] = 2,
    ACTIONS(353), 3,
      aux_sym__blank_token1,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
    ACTIONS(351), 39,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_STAR,
      anon_sym_SQUOTE,
      aux_sym__word_common_token3,
      anon_sym_PIPE,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
      aux_sym_line_li_token1,
      aux_sym_line_code_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2165] = 5,
    ACTIONS(355), 1,
      aux_sym__blank_token1,
    ACTIONS(357), 1,
      aux_sym_line_code_token1,
    STATE(49), 1,
      aux_sym_codeblock_repeat1,
    STATE(64), 1,
      sym_line_code,
    ACTIONS(325), 38,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_STAR,
      anon_sym_SQUOTE,
      aux_sym__word_common_token3,
      anon_sym_PIPE,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
      aux_sym_line_li_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2218] = 5,
    ACTIONS(359), 1,
      aux_sym__blank_token1,
    ACTIONS(362), 1,
      aux_sym_line_code_token1,
    STATE(49), 1,
      aux_sym_codeblock_repeat1,
    STATE(64), 1,
      sym_line_code,
    ACTIONS(333), 38,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_STAR,
      anon_sym_SQUOTE,
      aux_sym__word_common_token3,
      anon_sym_PIPE,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
      aux_sym_line_li_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2271] = 2,
    ACTIONS(365), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(367), 25,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2317] = 2,
    ACTIONS(369), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(371), 25,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2363] = 2,
    ACTIONS(373), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(375), 25,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2409] = 2,
    ACTIONS(377), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(379), 25,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2455] = 2,
    ACTIONS(381), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(383), 25,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2501] = 2,
    ACTIONS(385), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(387), 25,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2547] = 2,
    ACTIONS(389), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(391), 25,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2593] = 2,
    ACTIONS(393), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(395), 25,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2639] = 2,
    ACTIONS(397), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(399), 25,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2685] = 2,
    ACTIONS(401), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(403), 25,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2731] = 2,
    ACTIONS(405), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(407), 25,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2777] = 2,
    ACTIONS(409), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(411), 25,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2823] = 2,
    ACTIONS(413), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(415), 25,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      aux_sym_h1_token1,
      aux_sym_h2_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2869] = 2,
    ACTIONS(349), 1,
      aux_sym__blank_token1,
    ACTIONS(347), 39,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_STAR,
      anon_sym_SQUOTE,
      aux_sym__word_common_token3,
      anon_sym_PIPE,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
      aux_sym_line_li_token1,
      aux_sym_line_code_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2914] = 2,
    ACTIONS(353), 1,
      aux_sym__blank_token1,
    ACTIONS(351), 39,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_STAR,
      anon_sym_SQUOTE,
      aux_sym__word_common_token3,
      anon_sym_PIPE,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
      aux_sym_line_li_token1,
      aux_sym_line_code_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [2959] = 2,
    ACTIONS(417), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(419), 23,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3003] = 2,
    ACTIONS(385), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(387), 23,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3047] = 2,
    ACTIONS(389), 16,
      aux_sym_word_noli_token1,
      aux_sym_word_noli_token2,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token1,
      anon_sym_LT,
    ACTIONS(391), 23,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      aux_sym_line_li_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3091] = 4,
    ACTIONS(427), 1,
      aux_sym_optionlink_token1,
    ACTIONS(423), 2,
      aux_sym__word_common_token1,
      aux_sym__word_common_token2,
    ACTIONS(425), 17,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym__blank_token1,
      sym_url_word,
    ACTIONS(421), 18,
      aux_sym_word_token1,
      anon_sym_STAR,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Deprecated,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      anon_sym_BQUOTE,
  [3138] = 3,
    ACTIONS(429), 2,
      aux_sym_codeblock_token1,
      aux_sym_codeblock_token2,
    ACTIONS(421), 8,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym__blank_token1,
    ACTIONS(425), 27,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      sym_url_word,
      anon_sym_BQUOTE,
  [3182] = 4,
    ACTIONS(435), 1,
      aux_sym_uppercase_name_token2,
    STATE(73), 1,
      aux_sym_uppercase_name_repeat1,
    ACTIONS(431), 13,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(433), 22,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3228] = 5,
    ACTIONS(435), 1,
      aux_sym_uppercase_name_token2,
    STATE(74), 1,
      aux_sym_uppercase_name_repeat1,
    ACTIONS(439), 2,
      anon_sym_STAR,
      aux_sym__blank_token1,
    ACTIONS(437), 13,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(441), 20,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      sym_url_word,
      anon_sym_BQUOTE,
  [3276] = 3,
    ACTIONS(443), 2,
      aux_sym_codeblock_token1,
      aux_sym_codeblock_token2,
    ACTIONS(421), 8,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym__blank_token1,
    ACTIONS(425), 27,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      sym_url_word,
      anon_sym_BQUOTE,
  [3320] = 4,
    ACTIONS(435), 1,
      aux_sym_uppercase_name_token2,
    STATE(74), 1,
      aux_sym_uppercase_name_repeat1,
    ACTIONS(437), 13,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(441), 22,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3366] = 4,
    ACTIONS(449), 1,
      aux_sym_uppercase_name_token2,
    STATE(74), 1,
      aux_sym_uppercase_name_repeat1,
    ACTIONS(445), 13,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(447), 22,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3412] = 5,
    ACTIONS(435), 1,
      aux_sym_uppercase_name_token2,
    STATE(71), 1,
      aux_sym_uppercase_name_repeat1,
    ACTIONS(452), 2,
      anon_sym_STAR,
      aux_sym__blank_token1,
    ACTIONS(431), 13,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
    ACTIONS(433), 20,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      sym_url_word,
      anon_sym_BQUOTE,
  [3460] = 2,
    ACTIONS(454), 14,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym_uppercase_name_token2,
    ACTIONS(456), 22,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3501] = 3,
    ACTIONS(458), 1,
      aux_sym_taglink_token1,
    ACTIONS(425), 2,
      aux_sym__word_common_token3,
      aux_sym__blank_token1,
    ACTIONS(421), 33,
      aux_sym_word_token1,
      anon_sym_STAR,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      sym_url_word,
      anon_sym_BQUOTE,
  [3544] = 3,
    ACTIONS(460), 1,
      aux_sym_tag_token1,
    ACTIONS(425), 2,
      anon_sym_STAR,
      aux_sym__blank_token1,
    ACTIONS(421), 33,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      aux_sym__word_common_token3,
      anon_sym_PIPE,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      sym_url_word,
      anon_sym_BQUOTE,
  [3587] = 3,
    ACTIONS(466), 1,
      anon_sym_QMARK,
    ACTIONS(462), 7,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(464), 28,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3630] = 3,
    ACTIONS(468), 1,
      aux_sym_argument_token1,
    ACTIONS(425), 3,
      anon_sym_LBRACE_RBRACE,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym__blank_token1,
    ACTIONS(421), 32,
      aux_sym_word_token1,
      anon_sym_STAR,
      anon_sym_SQUOTE,
      aux_sym__word_common_token3,
      anon_sym_PIPE,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      sym_url_word,
      anon_sym_BQUOTE,
  [3673] = 3,
    ACTIONS(474), 1,
      anon_sym_SQUOTE2,
    ACTIONS(470), 7,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(472), 28,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3716] = 2,
    ACTIONS(476), 7,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(478), 28,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3756] = 2,
    ACTIONS(480), 7,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(482), 28,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3796] = 2,
    ACTIONS(484), 7,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(486), 28,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3836] = 2,
    ACTIONS(488), 7,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(490), 28,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3876] = 2,
    ACTIONS(492), 7,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(494), 28,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3916] = 2,
    ACTIONS(496), 7,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(498), 28,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3956] = 2,
    ACTIONS(500), 7,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(502), 28,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [3996] = 2,
    ACTIONS(504), 7,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(506), 28,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [4036] = 2,
    ACTIONS(508), 7,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(510), 28,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [4076] = 2,
    ACTIONS(512), 7,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(514), 28,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [4116] = 2,
    ACTIONS(516), 7,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(518), 28,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [4156] = 2,
    ACTIONS(520), 7,
      aux_sym_word_token1,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_LBRACE,
      aux_sym_keycode_token1,
      aux_sym_keycode_token2,
      aux_sym_keycode_token3,
    ACTIONS(522), 28,
      anon_sym_STAR,
      aux_sym__word_common_token3,
      anon_sym_SQUOTE_PIPE_SQUOTE,
      anon_sym_LBRACE_RBRACE,
      aux_sym__word_common_token4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_TILDE,
      anon_sym_GT,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_Note_COLON,
      anon_sym_NOTE_COLON,
      anon_sym_Notes_COLON,
      anon_sym_Warning_COLON,
      anon_sym_WARNING_COLON,
      anon_sym_Deprecated,
      anon_sym_DEPRECATED_COLON,
      aux_sym_keycode_token4,
      aux_sym_keycode_token5,
      anon_sym_CTRL_DASH_LBRACEchar_RBRACE,
      aux_sym_keycode_token6,
      aux_sym_keycode_token7,
      aux_sym__blank_token1,
      sym_url_word,
      anon_sym_BQUOTE,
  [4196] = 5,
    ACTIONS(29), 1,
      aux_sym__blank_token1,
    ACTIONS(31), 1,
      aux_sym_line_li_token1,
    ACTIONS(524), 1,
      anon_sym_LT,
    STATE(39), 1,
      sym__blank,
    STATE(96), 2,
      sym_line_li,
      aux_sym_block_repeat2,
  [4213] = 5,
    ACTIONS(29), 1,
      aux_sym__blank_token1,
    ACTIONS(31), 1,
      aux_sym_line_li_token1,
    ACTIONS(526), 1,
      anon_sym_LT,
    STATE(36), 1,
      sym__blank,
    STATE(96), 2,
      sym_line_li,
      aux_sym_block_repeat2,
  [4230] = 4,
    ACTIONS(528), 1,
      anon_sym_LT,
    ACTIONS(531), 1,
      aux_sym__blank_token1,
    ACTIONS(533), 1,
      aux_sym_line_li_token1,
    STATE(96), 2,
      sym_line_li,
      aux_sym_block_repeat2,
  [4244] = 4,
    ACTIONS(327), 1,
      aux_sym__blank_token1,
    ACTIONS(329), 1,
      aux_sym_line_code_token1,
    STATE(43), 1,
      aux_sym_codeblock_repeat1,
    STATE(47), 1,
      sym_line_code,
  [4257] = 4,
    ACTIONS(355), 1,
      aux_sym__blank_token1,
    ACTIONS(357), 1,
      aux_sym_line_code_token1,
    STATE(48), 1,
      aux_sym_codeblock_repeat1,
    STATE(64), 1,
      sym_line_code,
  [4270] = 3,
    ACTIONS(47), 1,
      ts_builtin_sym_end,
    ACTIONS(536), 1,
      sym_modeline,
    STATE(101), 1,
      aux_sym_help_file_repeat3,
  [4280] = 3,
    ACTIONS(538), 1,
      anon_sym_STAR,
    ACTIONS(540), 1,
      aux_sym__blank_token1,
    STATE(29), 1,
      sym_tag,
  [4290] = 3,
    ACTIONS(542), 1,
      ts_builtin_sym_end,
    ACTIONS(544), 1,
      sym_modeline,
    STATE(101), 1,
      aux_sym_help_file_repeat3,
  [4300] = 3,
    ACTIONS(43), 1,
      ts_builtin_sym_end,
    ACTIONS(536), 1,
      sym_modeline,
    STATE(101), 1,
      aux_sym_help_file_repeat3,
  [4310] = 3,
    ACTIONS(536), 1,
      sym_modeline,
    ACTIONS(547), 1,
      ts_builtin_sym_end,
    STATE(101), 1,
      aux_sym_help_file_repeat3,
  [4320] = 1,
    ACTIONS(549), 1,
      anon_sym_PIPE2,
  [4324] = 1,
    ACTIONS(460), 1,
      aux_sym_tag_token1,
  [4328] = 1,
    ACTIONS(551), 1,
      aux_sym_codespan_token1,
  [4332] = 1,
    ACTIONS(553), 1,
      aux_sym_codeblock_token2,
  [4336] = 1,
    ACTIONS(555), 1,
      ts_builtin_sym_end,
  [4340] = 1,
    ACTIONS(557), 1,
      anon_sym_TILDE,
  [4344] = 1,
    ACTIONS(559), 1,
      anon_sym_SQUOTE2,
  [4348] = 1,
    ACTIONS(312), 1,
      aux_sym_line_li_token1,
  [4352] = 1,
    ACTIONS(561), 1,
      anon_sym_STAR2,
  [4356] = 1,
    ACTIONS(563), 1,
      anon_sym_RBRACE,
  [4360] = 1,
    ACTIONS(565), 1,
      anon_sym_BQUOTE2,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(17)] = 0,
  [SMALL_STATE(18)] = 84,
  [SMALL_STATE(19)] = 168,
  [SMALL_STATE(20)] = 254,
  [SMALL_STATE(21)] = 340,
  [SMALL_STATE(22)] = 424,
  [SMALL_STATE(23)] = 508,
  [SMALL_STATE(24)] = 587,
  [SMALL_STATE(25)] = 666,
  [SMALL_STATE(26)] = 745,
  [SMALL_STATE(27)] = 824,
  [SMALL_STATE(28)] = 905,
  [SMALL_STATE(29)] = 984,
  [SMALL_STATE(30)] = 1063,
  [SMALL_STATE(31)] = 1142,
  [SMALL_STATE(32)] = 1223,
  [SMALL_STATE(33)] = 1299,
  [SMALL_STATE(34)] = 1375,
  [SMALL_STATE(35)] = 1451,
  [SMALL_STATE(36)] = 1527,
  [SMALL_STATE(37)] = 1581,
  [SMALL_STATE(38)] = 1635,
  [SMALL_STATE(39)] = 1691,
  [SMALL_STATE(40)] = 1745,
  [SMALL_STATE(41)] = 1799,
  [SMALL_STATE(42)] = 1853,
  [SMALL_STATE(43)] = 1909,
  [SMALL_STATE(44)] = 1966,
  [SMALL_STATE(45)] = 2023,
  [SMALL_STATE(46)] = 2071,
  [SMALL_STATE(47)] = 2118,
  [SMALL_STATE(48)] = 2165,
  [SMALL_STATE(49)] = 2218,
  [SMALL_STATE(50)] = 2271,
  [SMALL_STATE(51)] = 2317,
  [SMALL_STATE(52)] = 2363,
  [SMALL_STATE(53)] = 2409,
  [SMALL_STATE(54)] = 2455,
  [SMALL_STATE(55)] = 2501,
  [SMALL_STATE(56)] = 2547,
  [SMALL_STATE(57)] = 2593,
  [SMALL_STATE(58)] = 2639,
  [SMALL_STATE(59)] = 2685,
  [SMALL_STATE(60)] = 2731,
  [SMALL_STATE(61)] = 2777,
  [SMALL_STATE(62)] = 2823,
  [SMALL_STATE(63)] = 2869,
  [SMALL_STATE(64)] = 2914,
  [SMALL_STATE(65)] = 2959,
  [SMALL_STATE(66)] = 3003,
  [SMALL_STATE(67)] = 3047,
  [SMALL_STATE(68)] = 3091,
  [SMALL_STATE(69)] = 3138,
  [SMALL_STATE(70)] = 3182,
  [SMALL_STATE(71)] = 3228,
  [SMALL_STATE(72)] = 3276,
  [SMALL_STATE(73)] = 3320,
  [SMALL_STATE(74)] = 3366,
  [SMALL_STATE(75)] = 3412,
  [SMALL_STATE(76)] = 3460,
  [SMALL_STATE(77)] = 3501,
  [SMALL_STATE(78)] = 3544,
  [SMALL_STATE(79)] = 3587,
  [SMALL_STATE(80)] = 3630,
  [SMALL_STATE(81)] = 3673,
  [SMALL_STATE(82)] = 3716,
  [SMALL_STATE(83)] = 3756,
  [SMALL_STATE(84)] = 3796,
  [SMALL_STATE(85)] = 3836,
  [SMALL_STATE(86)] = 3876,
  [SMALL_STATE(87)] = 3916,
  [SMALL_STATE(88)] = 3956,
  [SMALL_STATE(89)] = 3996,
  [SMALL_STATE(90)] = 4036,
  [SMALL_STATE(91)] = 4076,
  [SMALL_STATE(92)] = 4116,
  [SMALL_STATE(93)] = 4156,
  [SMALL_STATE(94)] = 4196,
  [SMALL_STATE(95)] = 4213,
  [SMALL_STATE(96)] = 4230,
  [SMALL_STATE(97)] = 4244,
  [SMALL_STATE(98)] = 4257,
  [SMALL_STATE(99)] = 4270,
  [SMALL_STATE(100)] = 4280,
  [SMALL_STATE(101)] = 4290,
  [SMALL_STATE(102)] = 4300,
  [SMALL_STATE(103)] = 4310,
  [SMALL_STATE(104)] = 4320,
  [SMALL_STATE(105)] = 4324,
  [SMALL_STATE(106)] = 4328,
  [SMALL_STATE(107)] = 4332,
  [SMALL_STATE(108)] = 4336,
  [SMALL_STATE(109)] = 4340,
  [SMALL_STATE(110)] = 4344,
  [SMALL_STATE(111)] = 4348,
  [SMALL_STATE(112)] = 4352,
  [SMALL_STATE(113)] = 4356,
  [SMALL_STATE(114)] = 4360,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_help_file, 0, 0, 0),
  [5] = {.entry = {.count = 1, .reusable = false}}, SHIFT(92),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(68),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(77),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(80),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(88),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(75),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(111),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [43] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_help_file, 1, 0, 0),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [47] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_help_file, 2, 0, 0),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [51] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0),
  [53] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(92),
  [56] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(78),
  [59] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(68),
  [62] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(92),
  [65] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(77),
  [68] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(80),
  [71] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(72),
  [74] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(87),
  [77] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(88),
  [80] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(88),
  [83] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(75),
  [86] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(111),
  [89] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(35),
  [92] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(34),
  [95] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(33),
  [98] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(83),
  [101] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_help_file_repeat2, 2, 0, 0), SHIFT_REPEAT(106),
  [104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(42),
  [106] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(92),
  [109] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(78),
  [112] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(68),
  [115] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(92),
  [118] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(77),
  [121] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(80),
  [124] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(72),
  [127] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(87),
  [130] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [133] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [136] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(75),
  [139] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0),
  [141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0),
  [143] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(34),
  [146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(33),
  [149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(83),
  [152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(106),
  [155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(70),
  [157] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_line_li, 3, 0, 7),
  [159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_line_li, 3, 0, 7),
  [161] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_line_li, 3, 0, 8),
  [163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_line_li, 3, 0, 8),
  [165] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_line_li, 4, 0, 11),
  [167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_line_li, 4, 0, 11),
  [169] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_line_li, 4, 0, 12),
  [171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_line_li, 4, 0, 12),
  [173] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_line_li, 4, 0, 7),
  [175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_line_li, 4, 0, 7),
  [177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_line_li, 4, 0, 8),
  [179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_line_li, 4, 0, 8),
  [181] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_line_li, 5, 0, 11),
  [183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_line_li, 5, 0, 11),
  [185] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_line_li, 5, 0, 12),
  [187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_line_li, 5, 0, 12),
  [189] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_line_li_repeat2, 2, 0, 0), SHIFT_REPEAT(92),
  [192] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_line_li_repeat2, 2, 0, 0), SHIFT_REPEAT(78),
  [195] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_line_li_repeat2, 2, 0, 0), SHIFT_REPEAT(68),
  [198] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_line_li_repeat2, 2, 0, 0), SHIFT_REPEAT(92),
  [201] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_line_li_repeat2, 2, 0, 0), SHIFT_REPEAT(77),
  [204] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_line_li_repeat2, 2, 0, 0), SHIFT_REPEAT(80),
  [207] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_line_li_repeat2, 2, 0, 0), SHIFT_REPEAT(87),
  [210] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_line_li_repeat2, 2, 0, 0), SHIFT_REPEAT(88),
  [213] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_line_li_repeat2, 2, 0, 0), SHIFT_REPEAT(88),
  [216] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_line_li_repeat2, 2, 0, 0), SHIFT_REPEAT(70),
  [219] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_line_li_repeat2, 2, 0, 0),
  [221] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_line_li_repeat2, 2, 0, 0),
  [223] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_line_li_repeat2, 2, 0, 0), SHIFT_REPEAT(83),
  [226] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_line_li_repeat2, 2, 0, 0), SHIFT_REPEAT(106),
  [229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(84),
  [231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [239] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__column_heading, 2, 1, 0), SHIFT(84),
  [242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [244] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__column_heading, 1, 1, 0), SHIFT(84),
  [247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [255] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_line_li_repeat1, 2, 0, 0), SHIFT_REPEAT(84),
  [258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_line_li_repeat1, 2, 0, 0), SHIFT_REPEAT(78),
  [261] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_line_li_repeat1, 2, 0, 0), SHIFT_REPEAT(68),
  [264] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_line_li_repeat1, 2, 0, 0), SHIFT_REPEAT(84),
  [267] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_line_li_repeat1, 2, 0, 0), SHIFT_REPEAT(77),
  [270] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_line_li_repeat1, 2, 0, 0), SHIFT_REPEAT(80),
  [273] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_line_li_repeat1, 2, 0, 0), SHIFT_REPEAT(87),
  [276] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_line_li_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [279] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_line_li_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_line_li_repeat1, 2, 0, 0),
  [284] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_line_li_repeat1, 2, 0, 0), SHIFT_REPEAT(83),
  [287] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_line_li_repeat1, 2, 0, 0), SHIFT_REPEAT(106),
  [290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [304] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2, 0, 0),
  [306] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2, 0, 0),
  [308] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 0),
  [310] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 0),
  [312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_help_file_repeat1, 2, 0, 0),
  [316] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_help_file_repeat1, 2, 0, 0),
  [318] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_help_file_repeat1, 2, 0, 0), SHIFT_REPEAT(45),
  [321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 4, 0, 0),
  [323] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 4, 0, 0),
  [325] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_codeblock, 3, 0, 6),
  [327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(46),
  [331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_codeblock, 3, 0, 6),
  [333] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_codeblock_repeat1, 2, 0, 0),
  [335] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_codeblock_repeat1, 2, 0, 0), SHIFT_REPEAT(46),
  [338] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_codeblock_repeat1, 2, 0, 0), SHIFT_REPEAT(46),
  [341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_codeblock_repeat1, 2, 0, 0),
  [343] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__blank, 1, 0, 2),
  [345] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__blank, 1, 0, 2),
  [347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_line_code, 1, 0, 0),
  [349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_line_code, 1, 0, 0),
  [351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_codeblock_repeat1, 1, 0, 0),
  [353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_codeblock_repeat1, 1, 0, 0),
  [355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(63),
  [359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_codeblock_repeat1, 2, 0, 0), SHIFT_REPEAT(63),
  [362] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_codeblock_repeat1, 2, 0, 0), SHIFT_REPEAT(63),
  [365] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_h1, 5, 0, 9),
  [367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_h1, 5, 0, 9),
  [369] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_h3, 2, 0, 0),
  [371] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_h3, 2, 0, 0),
  [373] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_h2, 4, 0, 9),
  [375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_h2, 4, 0, 9),
  [377] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_h2, 3, 0, 9),
  [379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_h2, 3, 0, 9),
  [381] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_h3, 4, 0, 0),
  [383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_h3, 4, 0, 0),
  [385] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__line_noli, 2, 0, 0),
  [387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__line_noli, 2, 0, 0),
  [389] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__line_noli, 3, 0, 0),
  [391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__line_noli, 3, 0, 0),
  [393] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_h3, 3, 0, 0),
  [395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_h3, 3, 0, 0),
  [397] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_line, 1, 0, 0),
  [399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_line, 1, 0, 0),
  [401] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_h2, 5, 0, 9),
  [403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_h2, 5, 0, 9),
  [405] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_column_heading, 3, 0, 10),
  [407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_column_heading, 3, 0, 10),
  [409] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_h1, 3, 0, 9),
  [411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_h1, 3, 0, 9),
  [413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_h1, 4, 0, 9),
  [415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_h1, 4, 0, 9),
  [417] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_line_li_repeat2, 1, 0, 13),
  [419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_line_li_repeat2, 1, 0, 13),
  [421] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__word_common, 1, 0, 0),
  [423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(81),
  [425] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__word_common, 1, 0, 0),
  [427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(110),
  [429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [431] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__uppercase_words, 1, 0, 1),
  [433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__uppercase_words, 1, 0, 1),
  [435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(76),
  [437] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__uppercase_words, 2, 0, 4),
  [439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_uppercase_name, 2, 0, 0),
  [441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__uppercase_words, 2, 0, 4),
  [443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [445] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_uppercase_name_repeat1, 2, 0, 0),
  [447] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_uppercase_name_repeat1, 2, 0, 0),
  [449] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_uppercase_name_repeat1, 2, 0, 0), SHIFT_REPEAT(76),
  [452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_uppercase_name, 1, 0, 0),
  [454] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_uppercase_name_repeat1, 1, 0, 0),
  [456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_uppercase_name_repeat1, 1, 0, 0),
  [458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [462] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument, 3, 0, 5),
  [464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument, 3, 0, 5),
  [466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(113),
  [470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__word_common, 2, 0, 0),
  [472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__word_common, 2, 0, 0),
  [474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(82),
  [476] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__word_common, 3, 0, 0),
  [478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__word_common, 3, 0, 0),
  [480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_url, 1, 0, 3),
  [482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_url, 1, 0, 3),
  [484] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_word, 1, 0, 0),
  [486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_word, 1, 0, 0),
  [488] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument, 4, 0, 5),
  [490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument, 4, 0, 5),
  [492] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_codespan, 3, 0, 5),
  [494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_codespan, 3, 0, 5),
  [496] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_note, 1, 0, 0),
  [498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_note, 1, 0, 0),
  [500] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_keycode, 1, 0, 0),
  [502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_keycode, 1, 0, 0),
  [504] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_line_li_repeat1, 1, 0, 0),
  [506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_line_li_repeat1, 1, 0, 0),
  [508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tag, 3, 0, 5),
  [510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tag, 3, 0, 5),
  [512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_optionlink, 3, 0, 5),
  [514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optionlink, 3, 0, 5),
  [516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_word_noli, 1, 0, 0),
  [518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_word_noli, 1, 0, 0),
  [520] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_taglink, 3, 0, 5),
  [522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_taglink, 3, 0, 5),
  [524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [528] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(111),
  [531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0),
  [533] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(35),
  [536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [542] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_help_file_repeat3, 2, 0, 0),
  [544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_help_file_repeat3, 2, 0, 0), SHIFT_REPEAT(101),
  [547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_help_file, 3, 0, 0),
  [549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [555] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_vimdoc(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
    .name = "vimdoc",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 4,
      .minor_version = 1,
      .patch_version = 0,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
