/* Automatically @generated by tree-sitter */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 3350
#define LARGE_STATE_COUNT 124
#define SYMBOL_COUNT 919
#define ALIAS_COUNT 7
#define TOKEN_COUNT 623
#define EXTERNAL_TOKEN_COUNT 112
#define FIELD_COUNT 34
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 129
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  sym_keyword = 1,
  anon_sym_COLON = 2,
  anon_sym_a_COLON = 3,
  aux_sym_normal_statement_token1 = 4,
  sym_filetype = 5,
  aux_sym__filetype_immediate_token1 = 6,
  anon_sym_DOT = 7,
  anon_sym_FALLBACK = 8,
  anon_sym_dos = 9,
  anon_sym_unix = 10,
  anon_sym_mac = 11,
  anon_sym_latin1 = 12,
  anon_sym_iso = 13,
  anon_sym_koi8 = 14,
  anon_sym_macroman = 15,
  anon_sym_cp437 = 16,
  anon_sym_cp737 = 17,
  anon_sym_cp775 = 18,
  anon_sym_cp850 = 19,
  anon_sym_cp852 = 20,
  anon_sym_cp855 = 21,
  anon_sym_cp857 = 22,
  anon_sym_cp860 = 23,
  anon_sym_cp861 = 24,
  anon_sym_cp862 = 25,
  anon_sym_cp863 = 26,
  anon_sym_cp865 = 27,
  anon_sym_cp866 = 28,
  anon_sym_cp869 = 29,
  anon_sym_cp874 = 30,
  anon_sym_cp1250 = 31,
  anon_sym_cp1251 = 32,
  anon_sym_cp1253 = 33,
  anon_sym_cp1254 = 34,
  anon_sym_cp1255 = 35,
  anon_sym_cp1256 = 36,
  anon_sym_cp1257 = 37,
  anon_sym_cp1258 = 38,
  anon_sym_cp932 = 39,
  anon_sym_euc_DASHjp = 40,
  anon_sym_sjis = 41,
  anon_sym_cp949 = 42,
  anon_sym_euc_DASHkr = 43,
  anon_sym_cp936 = 44,
  anon_sym_euc_DASHcn = 45,
  anon_sym_cp950 = 46,
  anon_sym_big5 = 47,
  anon_sym_euc_DASHtw = 48,
  anon_sym_utf_DASH8 = 49,
  anon_sym_ucs_DASH2 = 50,
  anon_sym_ucs_DASH21e = 51,
  anon_sym_utf_DASH16 = 52,
  anon_sym_utf_DASH16le = 53,
  anon_sym_ucs_DASH4 = 54,
  anon_sym_ucs_DASH4le = 55,
  anon_sym_ansi = 56,
  anon_sym_japan = 57,
  anon_sym_korea = 58,
  anon_sym_prc = 59,
  anon_sym_chinese = 60,
  anon_sym_taiwan = 61,
  anon_sym_utf8 = 62,
  anon_sym_unicode = 63,
  anon_sym_ucs2be = 64,
  anon_sym_ucs_DASH2be = 65,
  anon_sym_ucs_DASH4be = 66,
  anon_sym_utf_DASH32 = 67,
  anon_sym_utf_DASH32le = 68,
  anon_sym_default = 69,
  anon_sym_latin12 = 70,
  anon_sym_iso2 = 71,
  anon_sym_koi82 = 72,
  anon_sym_macroman2 = 73,
  anon_sym_cp4372 = 74,
  anon_sym_cp7372 = 75,
  anon_sym_cp7752 = 76,
  anon_sym_cp8502 = 77,
  anon_sym_cp8522 = 78,
  anon_sym_cp8552 = 79,
  anon_sym_cp8572 = 80,
  anon_sym_cp8602 = 81,
  anon_sym_cp8612 = 82,
  anon_sym_cp8622 = 83,
  anon_sym_cp8632 = 84,
  anon_sym_cp8652 = 85,
  anon_sym_cp8662 = 86,
  anon_sym_cp8692 = 87,
  anon_sym_cp8742 = 88,
  anon_sym_cp12502 = 89,
  anon_sym_cp12512 = 90,
  anon_sym_cp12532 = 91,
  anon_sym_cp12542 = 92,
  anon_sym_cp12552 = 93,
  anon_sym_cp12562 = 94,
  anon_sym_cp12572 = 95,
  anon_sym_cp12582 = 96,
  anon_sym_cp9322 = 97,
  anon_sym_euc_DASHjp2 = 98,
  anon_sym_sjis2 = 99,
  anon_sym_cp9492 = 100,
  anon_sym_euc_DASHkr2 = 101,
  anon_sym_cp9362 = 102,
  anon_sym_euc_DASHcn2 = 103,
  anon_sym_cp9502 = 104,
  anon_sym_big52 = 105,
  anon_sym_euc_DASHtw2 = 106,
  anon_sym_utf_DASH82 = 107,
  anon_sym_ucs_DASH22 = 108,
  anon_sym_ucs_DASH21e2 = 109,
  anon_sym_utf_DASH162 = 110,
  anon_sym_utf_DASH16le2 = 111,
  anon_sym_ucs_DASH42 = 112,
  anon_sym_ucs_DASH4le2 = 113,
  anon_sym_ansi2 = 114,
  anon_sym_japan2 = 115,
  anon_sym_korea2 = 116,
  anon_sym_prc2 = 117,
  anon_sym_chinese2 = 118,
  anon_sym_taiwan2 = 119,
  anon_sym_utf82 = 120,
  anon_sym_unicode2 = 121,
  anon_sym_ucs2be2 = 122,
  anon_sym_ucs_DASH2be2 = 123,
  anon_sym_ucs_DASH4be2 = 124,
  anon_sym_utf_DASH322 = 125,
  anon_sym_utf_DASH32le2 = 126,
  anon_sym_default2 = 127,
  anon_sym_START = 128,
  anon_sym_OPT = 129,
  anon_sym_PACK = 130,
  anon_sym_ALL = 131,
  aux_sym_wincmd_statement_token1 = 132,
  anon_sym_on = 133,
  anon_sym_off = 134,
  anon_sym_detect = 135,
  anon_sym_plugin = 136,
  anon_sym_indent = 137,
  anon_sym_EQ = 138,
  sym_chunk = 139,
  sym__heredoc_line = 140,
  anon_sym_LT_LT = 141,
  anon_sym_trim = 142,
  anon_sym_LF = 143,
  anon_sym_in = 144,
  aux_sym__au_pattern_token1 = 145,
  aux_sym__au_pattern_token2 = 146,
  aux_sym__bang_filter_command_argument_token1 = 147,
  anon_sym_BSLASH = 148,
  aux_sym__bang_filter_command_argument_token2 = 149,
  aux_sym__bang_filter_command_argument_token3 = 150,
  aux_sym__bang_filter_command_argument_token4 = 151,
  aux_sym_argument_token1 = 152,
  aux_sym_argument_token2 = 153,
  anon_sym_LBRACE = 154,
  anon_sym_RBRACE = 155,
  anon_sym_LBRACE2 = 156,
  aux_sym_identifier_token1 = 157,
  aux_sym_identifier_token2 = 158,
  aux_sym__immediate_identifier_token1 = 159,
  anon_sym_PLUS_EQ = 160,
  anon_sym_DASH_EQ = 161,
  anon_sym_STAR_EQ = 162,
  anon_sym_SLASH_EQ = 163,
  anon_sym_PERCENT_EQ = 164,
  anon_sym_DOT_EQ = 165,
  anon_sym_DOT_DOT_EQ = 166,
  anon_sym_EQ_LT_LT = 167,
  anon_sym_eval = 168,
  aux_sym_option_name_token1 = 169,
  anon_sym_t_ = 170,
  aux_sym_option_name_token2 = 171,
  anon_sym_BANG = 172,
  anon_sym_AMP = 173,
  anon_sym_vi = 174,
  anon_sym_vim = 175,
  anon_sym_all = 176,
  anon_sym_all_AMP = 177,
  anon_sym_QMARK = 178,
  anon_sym_EQ2 = 179,
  anon_sym_COLON2 = 180,
  anon_sym_PLUS_EQ2 = 181,
  anon_sym_CARET_EQ = 182,
  anon_sym_DASH_EQ2 = 183,
  sym_set_value = 184,
  anon_sym_SPACE = 185,
  anon_sym_POUND_BANG = 186,
  aux_sym_shebang_token1 = 187,
  aux_sym_command_argument_token1 = 188,
  anon_sym_dict = 189,
  anon_sym_range = 190,
  anon_sym_abort = 191,
  anon_sym_closure = 192,
  anon_sym_LPAREN = 193,
  anon_sym_COMMA = 194,
  anon_sym_RPAREN = 195,
  sym_spread = 196,
  sym__printable = 197,
  sym_mark = 198,
  anon_sym_PERCENT = 199,
  anon_sym_SEMI = 200,
  anon_sym_SLASH = 201,
  anon_sym_SLASH2 = 202,
  anon_sym_QMARK2 = 203,
  anon_sym_DOT2 = 204,
  anon_sym_PLUS = 205,
  anon_sym_DOLLAR = 206,
  anon_sym_BSLASH_SLASH = 207,
  anon_sym_BSLASH_QMARK = 208,
  anon_sym_BSLASH_AMP = 209,
  anon_sym_LTbuffer_GT = 210,
  anon_sym_LTnowait_GT = 211,
  anon_sym_LTsilent_GT = 212,
  anon_sym_LTunique_GT = 213,
  anon_sym_LTscript_GT = 214,
  anon_sym_LTexpr_GT = 215,
  sym__keycode_modifier = 216,
  aux_sym__keycode_in_token1 = 217,
  aux_sym__keycode_in_token2 = 218,
  aux_sym__keycode_in_token3 = 219,
  aux_sym__keycode_in_token4 = 220,
  aux_sym__keycode_in_token5 = 221,
  aux_sym__keycode_in_token6 = 222,
  aux_sym__keycode_in_token7 = 223,
  aux_sym__keycode_in_token8 = 224,
  aux_sym__keycode_in_token9 = 225,
  aux_sym__keycode_in_token10 = 226,
  aux_sym__keycode_in_token11 = 227,
  aux_sym__keycode_in_token12 = 228,
  aux_sym__keycode_in_token13 = 229,
  aux_sym__keycode_in_token14 = 230,
  aux_sym__keycode_in_token15 = 231,
  aux_sym__keycode_in_token16 = 232,
  aux_sym__keycode_in_token17 = 233,
  aux_sym__keycode_in_token18 = 234,
  aux_sym__keycode_in_token19 = 235,
  aux_sym__keycode_in_token20 = 236,
  aux_sym__keycode_in_token21 = 237,
  aux_sym__keycode_in_token22 = 238,
  aux_sym__keycode_in_token23 = 239,
  aux_sym__keycode_in_token24 = 240,
  aux_sym__keycode_in_token25 = 241,
  aux_sym__keycode_in_token26 = 242,
  aux_sym__keycode_in_token27 = 243,
  aux_sym__keycode_in_token28 = 244,
  aux_sym__keycode_in_token29 = 245,
  aux_sym__keycode_in_token30 = 246,
  aux_sym__keycode_in_token31 = 247,
  aux_sym__keycode_in_token32 = 248,
  aux_sym__keycode_in_token33 = 249,
  aux_sym__keycode_in_token34 = 250,
  aux_sym__keycode_in_token35 = 251,
  aux_sym__keycode_in_token36 = 252,
  aux_sym__keycode_in_token37 = 253,
  aux_sym__keycode_in_token38 = 254,
  aux_sym__keycode_in_token39 = 255,
  aux_sym__keycode_in_token40 = 256,
  aux_sym__keycode_in_token41 = 257,
  aux_sym__keycode_in_token42 = 258,
  aux_sym__keycode_in_token43 = 259,
  anon_sym_LT = 260,
  anon_sym_GT = 261,
  anon_sym_LT2 = 262,
  anon_sym_BSLASH2 = 263,
  aux_sym__map_lhs_token1 = 264,
  aux_sym__map_rhs_statement_token1 = 265,
  anon_sym_BSLASH_PIPE = 266,
  aux_sym__map_rhs_statement_token2 = 267,
  aux_sym__map_rhs_statement_token3 = 268,
  aux_sym__map_rhs_token1 = 269,
  aux_sym__map_rhs_token2 = 270,
  anon_sym_icon = 271,
  anon_sym_linehl = 272,
  anon_sym_numhl = 273,
  anon_sym_text = 274,
  anon_sym_texthl = 275,
  anon_sym_culhl = 276,
  anon_sym_define = 277,
  anon_sym_undefine = 278,
  anon_sym_list = 279,
  anon_sym_line = 280,
  anon_sym_name = 281,
  anon_sym_buffer = 282,
  anon_sym_group = 283,
  anon_sym_priority = 284,
  anon_sym_file = 285,
  anon_sym_STAR = 286,
  anon_sym_place = 287,
  anon_sym_STAR2 = 288,
  anon_sym_unplace = 289,
  anon_sym_jump = 290,
  anon_sym_POUND = 291,
  anon_sym_PIPE_PIPE = 292,
  anon_sym_AMP_AMP = 293,
  anon_sym_DASH = 294,
  anon_sym_DOT_DOT = 295,
  anon_sym_EQ_EQ = 296,
  anon_sym_BANG_EQ = 297,
  anon_sym_GT2 = 298,
  anon_sym_GT_EQ = 299,
  anon_sym_LT_EQ = 300,
  anon_sym_EQ_TILDE = 301,
  anon_sym_BANG_TILDE = 302,
  anon_sym_is = 303,
  anon_sym_isnot = 304,
  anon_sym_BANG2 = 305,
  sym_float_literal = 306,
  sym_integer_literal = 307,
  anon_sym_LBRACK = 308,
  anon_sym_RBRACK = 309,
  anon_sym_LPAREN2 = 310,
  anon_sym_DASH_GT = 311,
  aux_sym_filename_token1 = 312,
  aux_sym_filename_token2 = 313,
  aux_sym_filename_token3 = 314,
  aux_sym_filename_token4 = 315,
  aux_sym_filename_token5 = 316,
  aux_sym_filename_token6 = 317,
  aux_sym_filename_token7 = 318,
  aux_sym_filename_token8 = 319,
  aux_sym_pattern_multi_token1 = 320,
  aux_sym_pattern_multi_token2 = 321,
  aux_sym_pattern_multi_token3 = 322,
  aux_sym__pattern_ordinary_atom_token1 = 323,
  aux_sym__pattern_ordinary_atom_token2 = 324,
  anon_sym_BSLASH_LPAREN = 325,
  anon_sym_BSLASH_RPAREN = 326,
  anon_sym_BSLASH_PERCENT_LPAREN = 327,
  anon_sym_BSLASHz_LPAREN = 328,
  sym_register = 329,
  sym_literal_key = 330,
  anon_sym_POUND_LBRACE = 331,
  anon_sym_keep = 332,
  anon_sym_drop = 333,
  anon_sym_PLUS_PLUS = 334,
  anon_sym_ff = 335,
  anon_sym_fileformat = 336,
  anon_sym_enc = 337,
  anon_sym_encoding = 338,
  anon_sym_bin = 339,
  anon_sym_binary = 340,
  anon_sym_nobin = 341,
  anon_sym_nobinary = 342,
  anon_sym_bad = 343,
  anon_sym_edit = 344,
  aux_sym__plus_cmd_arg_token1 = 345,
  sym_au_event = 346,
  aux_sym__autocmd_pattern_token1 = 347,
  sym_au_once = 348,
  sym_au_nested = 349,
  sym_command_name = 350,
  anon_sym_arglist = 351,
  anon_sym_augroup = 352,
  anon_sym_buffer2 = 353,
  anon_sym_behave = 354,
  anon_sym_color = 355,
  anon_sym_command = 356,
  anon_sym_compiler = 357,
  anon_sym_dir = 358,
  anon_sym_environment = 359,
  anon_sym_even = 360,
  anon_sym_expression = 361,
  anon_sym_file2 = 362,
  anon_sym_file_in_path = 363,
  anon_sym_filetype = 364,
  anon_sym_function = 365,
  anon_sym_help = 366,
  anon_sym_highlight = 367,
  anon_sym_history = 368,
  anon_sym_local = 369,
  anon_sym_lua = 370,
  anon_sym_mapclear = 371,
  anon_sym_mapping = 372,
  anon_sym_menu = 373,
  anon_sym_messages = 374,
  anon_sym_option = 375,
  anon_sym_packadd = 376,
  anon_sym_shellcmd = 377,
  anon_sym_sign = 378,
  anon_sym_syntax = 379,
  anon_sym_syntime = 380,
  anon_sym_tag = 381,
  anon_sym_tag_listfiles = 382,
  anon_sym_user = 383,
  anon_sym_var = 384,
  anon_sym_custom = 385,
  anon_sym_COMMA2 = 386,
  anon_sym_customlist = 387,
  anon_sym_lines = 388,
  anon_sym_arguments = 389,
  anon_sym_buffers = 390,
  anon_sym_loaded_buffers = 391,
  anon_sym_windows = 392,
  anon_sym_tabs = 393,
  anon_sym_quickfix = 394,
  anon_sym_other = 395,
  aux_sym__command_attribute_nargs_value_token1 = 396,
  aux_sym__command_attribute_nargs_value_token2 = 397,
  anon_sym_PERCENT2 = 398,
  anon_sym_DASHnargs = 399,
  anon_sym_DASHcomplete = 400,
  anon_sym_DASHrange = 401,
  anon_sym_DASHcount = 402,
  anon_sym_DASHaddr = 403,
  anon_sym_DASHbang = 404,
  anon_sym_DASHbar = 405,
  anon_sym_DASHregister = 406,
  anon_sym_DASHbuffer = 407,
  anon_sym_DASHkeepscript = 408,
  aux_sym_command_statement_token1 = 409,
  sym_hl_group = 410,
  anon_sym_link = 411,
  anon_sym_clear = 412,
  anon_sym_NONE = 413,
  anon_sym_NONE2 = 414,
  anon_sym_bold = 415,
  anon_sym_underline = 416,
  anon_sym_undercurl = 417,
  anon_sym_underdouble = 418,
  anon_sym_underdotted = 419,
  anon_sym_underdashed = 420,
  anon_sym_strikethrough = 421,
  anon_sym_reverse = 422,
  anon_sym_inverse = 423,
  anon_sym_italic = 424,
  anon_sym_standout = 425,
  anon_sym_nocombine = 426,
  anon_sym_term = 427,
  anon_sym_cterm = 428,
  aux_sym__hl_term_list_token1 = 429,
  anon_sym_start = 430,
  anon_sym_stop = 431,
  sym__hl_color_nr = 432,
  anon_sym_ctermfg = 433,
  anon_sym_ctermbg = 434,
  anon_sym_gui = 435,
  anon_sym_SQUOTE = 436,
  aux_sym__hl_quoted_name_token1 = 437,
  anon_sym_SQUOTE2 = 438,
  anon_sym_bg = 439,
  anon_sym_background = 440,
  anon_sym_fg = 441,
  anon_sym_foreground = 442,
  aux_sym_color_token1 = 443,
  aux_sym_color_token2 = 444,
  anon_sym_guifg = 445,
  anon_sym_guibg = 446,
  anon_sym_guisp = 447,
  aux_sym_font_token1 = 448,
  anon_sym_font = 449,
  anon_sym_blend = 450,
  anon_sym_enable = 451,
  anon_sym_reset = 452,
  anon_sym_case = 453,
  anon_sym_match = 454,
  anon_sym_ignore = 455,
  anon_sym_spell = 456,
  anon_sym_toplevel = 457,
  anon_sym_notoplevel = 458,
  anon_sym_foldlevel = 459,
  anon_sym_minimum = 460,
  anon_sym_iskeyword = 461,
  aux_sym__syn_iskeyword_token1 = 462,
  anon_sym_conceal = 463,
  anon_sym_cchar = 464,
  anon_sym_contained = 465,
  anon_sym_containedin = 466,
  anon_sym_nextgroup = 467,
  anon_sym_transparent = 468,
  anon_sym_skipwhite = 469,
  anon_sym_skipnl = 470,
  anon_sym_skipempty = 471,
  anon_sym_contains = 472,
  anon_sym_fold = 473,
  anon_sym_display = 474,
  anon_sym_extend = 475,
  anon_sym_keepend = 476,
  anon_sym_excludenl = 477,
  anon_sym_matchgroup = 478,
  anon_sym_oneline = 479,
  anon_sym_concealends = 480,
  anon_sym_add = 481,
  anon_sym_remove = 482,
  anon_sym_ms = 483,
  anon_sym_me = 484,
  anon_sym_hs = 485,
  anon_sym_he = 486,
  anon_sym_rs = 487,
  anon_sym_re = 488,
  anon_sym_lc = 489,
  aux_sym__syn_pattern_offset_token1 = 490,
  aux_sym__syn_pattern_offset_token2 = 491,
  anon_sym_keyword = 492,
  aux_sym__syn_keyword_token1 = 493,
  anon_sym_skip = 494,
  anon_sym_end = 495,
  anon_sym_region = 496,
  anon_sym_cluster = 497,
  anon_sym_include = 498,
  anon_sym_AT = 499,
  anon_sym_minlines = 500,
  anon_sym_maxlines = 501,
  aux_sym__syn_sync_lines_token1 = 502,
  anon_sym_sync = 503,
  anon_sym_linebreaks = 504,
  anon_sym_fromstart = 505,
  anon_sym_ccomment = 506,
  anon_sym_lines2 = 507,
  anon_sym_grouphere = 508,
  anon_sym_groupthere = 509,
  anon_sym_linecont = 510,
  sym__no = 511,
  sym__inv = 512,
  sym__newline_or_pipe = 513,
  sym__line_continuation = 514,
  sym__script_heredoc_marker = 515,
  sym__let_heredoc_marker = 516,
  sym__heredoc_end = 517,
  sym__separator_first = 518,
  sym__separator = 519,
  sym__scope_dict = 520,
  sym_scope = 521,
  sym_string_literal = 522,
  sym_comment = 523,
  sym_line_continuation_comment = 524,
  sym__bang_filter = 525,
  sym__function = 526,
  sym__endfunction = 527,
  sym__for = 528,
  sym__endfor = 529,
  sym__while = 530,
  sym__endwhile = 531,
  sym__if = 532,
  sym__elseif = 533,
  sym__else = 534,
  sym__endif = 535,
  sym__try = 536,
  sym__catch = 537,
  sym__cnext = 538,
  sym__cprevious = 539,
  sym__cNext = 540,
  sym__finally = 541,
  sym__endtry = 542,
  sym__const = 543,
  sym__normal = 544,
  sym__return = 545,
  sym__perl = 546,
  sym__lua = 547,
  sym__ruby = 548,
  sym__python = 549,
  sym__throw = 550,
  sym__execute = 551,
  sym__autocmd = 552,
  sym__silent = 553,
  sym__echo = 554,
  sym__echon = 555,
  sym__echohl = 556,
  sym__echomsg = 557,
  sym__echoerr = 558,
  sym__map = 559,
  sym__nmap = 560,
  sym__vmap = 561,
  sym__xmap = 562,
  sym__smap = 563,
  sym__omap = 564,
  sym__imap = 565,
  sym__lmap = 566,
  sym__cmap = 567,
  sym__tmap = 568,
  sym__noremap = 569,
  sym__nnoremap = 570,
  sym__vnoremap = 571,
  sym__xnoremap = 572,
  sym__snoremap = 573,
  sym__onoremap = 574,
  sym__inoremap = 575,
  sym__lnoremap = 576,
  sym__cnoremap = 577,
  sym__tnoremap = 578,
  sym__augroup = 579,
  sym__highlight = 580,
  sym__default = 581,
  sym__syntax = 582,
  sym__set = 583,
  sym__setlocal = 584,
  sym__setfiletype = 585,
  sym__browse = 586,
  sym__options = 587,
  sym__startinsert = 588,
  sym__stopinsert = 589,
  sym__scriptencoding = 590,
  sym__source = 591,
  sym__global = 592,
  sym__colorscheme = 593,
  sym__command = 594,
  sym__comclear = 595,
  sym__delcommand = 596,
  sym__runtime = 597,
  sym__wincmd = 598,
  sym__sign = 599,
  sym__filetype = 600,
  sym__let = 601,
  sym__unlet = 602,
  sym__call = 603,
  sym__break = 604,
  sym__continue = 605,
  sym__tab = 606,
  sym__vertical = 607,
  sym__leftabove = 608,
  sym__aboveleft = 609,
  sym__rightbelow = 610,
  sym__belowright = 611,
  sym__topleft = 612,
  sym__botright = 613,
  sym__edit = 614,
  sym__enew = 615,
  sym__find = 616,
  sym__ex = 617,
  sym__visual = 618,
  sym__view = 619,
  sym__eval = 620,
  sym__substitute = 621,
  sym_unknown_command_name = 622,
  sym_script_file = 623,
  sym__cmd_separator = 624,
  aux_sym__separated_statements = 625,
  sym__statement = 626,
  sym_unknown_builtin_statement = 627,
  sym_return_statement = 628,
  sym_break_statement = 629,
  sym_continue_statement = 630,
  sym_scope_dict = 631,
  sym_normal_statement = 632,
  sym__filetype_immediate = 633,
  sym_filetypes = 634,
  sym_setfiletype_statement = 635,
  sym_options_statement = 636,
  sym_startinsert_statement = 637,
  sym_stopinsert_statement = 638,
  sym__immediate_file_format = 639,
  sym_encoding = 640,
  sym__immediate_encoding = 641,
  sym_scriptencoding_statement = 642,
  sym_cnext_statement = 643,
  sym_cprevious_statement = 644,
  sym__runtime_where = 645,
  sym_runtime_statement = 646,
  sym_wincmd_statement = 647,
  sym_source_statement = 648,
  sym_global_statement = 649,
  sym__filetype_state = 650,
  sym__filetype_enable = 651,
  sym__filetype_detect = 652,
  sym__filetype_plugin = 653,
  sym__filetype_indent = 654,
  sym_filetype_statement = 655,
  sym_colorscheme_statement = 656,
  sym_lua_statement = 657,
  sym_ruby_statement = 658,
  sym_python_statement = 659,
  sym_perl_statement = 660,
  sym_script = 661,
  sym_for_loop = 662,
  sym_while_loop = 663,
  sym_if_statement = 664,
  sym_elseif_statement = 665,
  sym_else_statement = 666,
  sym_try_statement = 667,
  sym__au_pattern = 668,
  sym_catch_statement = 669,
  sym_finally_statement = 670,
  sym_throw_statement = 671,
  sym__bang_filter_bangs = 672,
  sym__bang_filter_command_argument = 673,
  sym__bang_filter_command = 674,
  sym_bang_filter_statement = 675,
  sym_scoped_identifier = 676,
  sym_argument = 677,
  sym__curly_braces_name_expression = 678,
  sym__immediate_curly_braces_name_expression = 679,
  sym_identifier = 680,
  sym__immediate_identifier = 681,
  sym__ident = 682,
  sym__let_operator = 683,
  sym__assignment_variable = 684,
  sym__let_assignment = 685,
  sym_let_statement = 686,
  sym__const_assignment = 687,
  sym_const_statement = 688,
  sym__let_heredoc = 689,
  sym__let_heredoc_parameter = 690,
  sym_option_name = 691,
  sym_no_option = 692,
  sym_inv_option = 693,
  sym_default_option = 694,
  sym__set_option = 695,
  sym__set_operator = 696,
  sym__set_rhs = 697,
  sym_set_item = 698,
  sym_set_statement = 699,
  sym_setlocal_statement = 700,
  sym_unlet_statement = 701,
  sym_call_statement = 702,
  sym_echo_statement = 703,
  sym_echon_statement = 704,
  sym_echohl_statement = 705,
  sym_echomsg_statement = 706,
  sym_echoerr_statement = 707,
  sym_execute_statement = 708,
  sym_silent_statement = 709,
  sym_tab_statement = 710,
  sym_vertical_statement = 711,
  sym_topleft_statement = 712,
  sym_botright_statement = 713,
  sym_aboveleft_statement = 714,
  sym_belowright_statement = 715,
  sym_user_command = 716,
  sym_shebang = 717,
  sym_command_argument = 718,
  sym_function_definition = 719,
  sym_function_declaration = 720,
  sym_parameters = 721,
  sym_default_parameter = 722,
  sym_bang = 723,
  sym_range_statement = 724,
  sym__range = 725,
  sym__range_explicit = 726,
  sym__range_marker = 727,
  sym__complete_range = 728,
  sym__complete_range_explicit = 729,
  sym__complete_range_marker = 730,
  sym_current_line = 731,
  sym_next_line = 732,
  sym_last_line = 733,
  sym_previous_pattern = 734,
  sym_register_statement = 735,
  sym_map_statement = 736,
  sym__map_definition = 737,
  sym__keycode_in = 738,
  sym__immediate_keycode = 739,
  sym_keycode = 740,
  sym__map_lhs = 741,
  sym__map_rhs_statement = 742,
  sym__map_rhs = 743,
  sym__sign_name = 744,
  sym__sign_define_arg_text = 745,
  sym__sign_define_argument = 746,
  sym__sign_define = 747,
  sym__sign_undefine = 748,
  sym__sign_list = 749,
  sym__sign_place_place_argument = 750,
  sym__sign_place_place = 751,
  sym__sign_place_list_argument = 752,
  aux_sym__sign_place_list = 753,
  sym__sign_place = 754,
  sym__sign_unplace_cursor_argument = 755,
  sym__sign_unplace_cursor = 756,
  sym__sign_unplace_id_argument = 757,
  sym__sign_unplace_id = 758,
  sym__sign_unplace = 759,
  sym__sign_jump_argument = 760,
  sym__sign_jump = 761,
  sym_sign_statement = 762,
  sym__variable = 763,
  sym__expression = 764,
  sym_ternary_expression = 765,
  sym_match_case = 766,
  sym_binary_operation = 767,
  sym_unary_operation = 768,
  sym_list = 769,
  sym_list_assignment = 770,
  sym_index_expression = 771,
  sym_slice_expression = 772,
  sym_field_expression = 773,
  sym_call_expression = 774,
  sym_eval_statement = 775,
  sym_substitute_statement = 776,
  sym__method_call_expression = 777,
  sym_method_expression = 778,
  sym_filename = 779,
  sym_pattern_multi = 780,
  aux_sym__pattern_ordinary_atom = 781,
  sym__pattern_atom = 782,
  sym__pattern_piece = 783,
  aux_sym__pattern_concat = 784,
  sym__pattern_branch = 785,
  sym_pattern = 786,
  sym_env_variable = 787,
  sym_option = 788,
  sym_dictionnary_entry = 789,
  sym_dictionnary = 790,
  sym__literal_dictionary_entry = 791,
  sym_literal_dictionary = 792,
  sym_lambda_expression = 793,
  sym__immediate_lambda_expression = 794,
  sym__plus_plus_opt_bad = 795,
  sym_plus_plus_opt = 796,
  aux_sym__plus_cmd_arg = 797,
  sym__plus_cmd_number = 798,
  sym__plus_cmd_command = 799,
  sym__plus_cmd_pattern = 800,
  sym_plus_cmd = 801,
  sym_au_event_list = 802,
  sym__augroup_name = 803,
  sym__autocmd_pattern = 804,
  sym__autocmd_command = 805,
  sym__autocmd_define = 806,
  sym__autocmd_remove = 807,
  sym__autocmd_list = 808,
  sym_autocmd_statement = 809,
  sym_augroup_statement = 810,
  sym__command_attribute_completion_behavior = 811,
  sym__command_attribute_address_behavior = 812,
  sym__command_attribute_nargs_value = 813,
  sym__command_attribute_range_value = 814,
  sym_command_attribute = 815,
  sym_command_statement = 816,
  sym_comclear_statement = 817,
  sym_delcommand_statement = 818,
  sym__hl_body_link = 819,
  sym__hl_body_clear = 820,
  sym__hl_body_none = 821,
  sym__hl_none = 822,
  sym__hl_attr_list = 823,
  sym__hl_key_cterm = 824,
  aux_sym__hl_term_list = 825,
  sym__hl_key_start_stop = 826,
  sym__hl_key_ctermfg_ctermbg = 827,
  sym__hl_key_gui = 828,
  sym__hl_quoted_name = 829,
  sym_color = 830,
  sym__hl_key_gui_color = 831,
  sym_font = 832,
  sym__hl_key_font = 833,
  sym__hl_key_blend = 834,
  sym_hl_attribute = 835,
  sym__hl_body_keys = 836,
  sym__hl_body = 837,
  sym_highlight_statement = 838,
  sym__syn_enable = 839,
  sym__syn_case = 840,
  sym__syn_spell = 841,
  sym__syn_foldlevel = 842,
  sym__syn_iskeyword = 843,
  sym__syn_conceal = 844,
  sym__syn_hl_pattern = 845,
  sym_hl_groups = 846,
  sym__syn_arguments_keyword = 847,
  sym__syn_arguments_match = 848,
  sym__syn_arguments_region = 849,
  sym__syn_arguments_cluster = 850,
  sym__syn_pattern_offset = 851,
  sym__syn_keyword = 852,
  sym__syn_match = 853,
  sym__syn_region_start = 854,
  sym__syn_region_skip = 855,
  sym__syn_region_end = 856,
  sym__syn_region = 857,
  sym__syn_cluster = 858,
  sym__syn_include = 859,
  sym__syn_sync_lines = 860,
  sym__syn_sync = 861,
  sym__syn_list = 862,
  sym__syn_clear = 863,
  sym_syntax_statement = 864,
  sym_edit_statement = 865,
  sym_enew_statement = 866,
  sym_find_statement = 867,
  sym_ex_statement = 868,
  sym_visual_statement = 869,
  sym_view_statement = 870,
  aux_sym__statement_repeat1 = 871,
  aux_sym_unknown_builtin_statement_repeat1 = 872,
  aux_sym_filetypes_repeat1 = 873,
  aux_sym_runtime_statement_repeat1 = 874,
  aux_sym_script_repeat1 = 875,
  aux_sym_if_statement_repeat1 = 876,
  aux_sym_try_statement_repeat1 = 877,
  aux_sym__bang_filter_command_argument_repeat1 = 878,
  aux_sym__bang_filter_command_repeat1 = 879,
  aux_sym_identifier_repeat1 = 880,
  aux_sym_let_statement_repeat1 = 881,
  aux_sym__let_heredoc_repeat1 = 882,
  aux_sym_set_statement_repeat1 = 883,
  aux_sym_unlet_statement_repeat1 = 884,
  aux_sym_function_definition_repeat1 = 885,
  aux_sym_parameters_repeat1 = 886,
  aux_sym_parameters_repeat2 = 887,
  aux_sym_map_statement_repeat1 = 888,
  aux_sym__map_lhs_repeat1 = 889,
  aux_sym__map_rhs_statement_repeat1 = 890,
  aux_sym__map_rhs_repeat1 = 891,
  aux_sym__sign_define_repeat1 = 892,
  aux_sym__sign_place_place_repeat1 = 893,
  aux_sym__sign_unplace_id_repeat1 = 894,
  aux_sym__sign_jump_repeat1 = 895,
  aux_sym_list_repeat1 = 896,
  aux_sym_filename_repeat1 = 897,
  aux_sym__pattern_ordinary_atom_repeat1 = 898,
  aux_sym__pattern_branch_repeat1 = 899,
  aux_sym_pattern_repeat1 = 900,
  aux_sym_dictionnary_repeat1 = 901,
  aux_sym_literal_dictionary_repeat1 = 902,
  aux_sym_au_event_list_repeat1 = 903,
  aux_sym__autocmd_pattern_repeat1 = 904,
  aux_sym_command_statement_repeat1 = 905,
  aux_sym__hl_attr_list_repeat1 = 906,
  aux_sym__hl_body_keys_repeat1 = 907,
  aux_sym_hl_groups_repeat1 = 908,
  aux_sym__syn_keyword_repeat1 = 909,
  aux_sym__syn_keyword_repeat2 = 910,
  aux_sym__syn_match_repeat1 = 911,
  aux_sym__syn_match_repeat2 = 912,
  aux_sym__syn_region_repeat1 = 913,
  aux_sym__syn_region_repeat2 = 914,
  aux_sym__syn_cluster_repeat1 = 915,
  aux_sym__syn_sync_repeat1 = 916,
  aux_sym_edit_statement_repeat1 = 917,
  aux_sym_edit_statement_repeat2 = 918,
  alias_sym_arguments = 919,
  alias_sym_augroup_name = 920,
  alias_sym_body = 921,
  alias_sym_file = 922,
  alias_sym_filenames = 923,
  alias_sym_filter_command = 924,
  alias_sym_name = 925,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_keyword] = "keyword",
  [anon_sym_COLON] = ":",
  [anon_sym_a_COLON] = "a:",
  [aux_sym_normal_statement_token1] = "commands",
  [sym_filetype] = "filetype",
  [aux_sym__filetype_immediate_token1] = "filetype",
  [anon_sym_DOT] = ".",
  [anon_sym_FALLBACK] = "fallback",
  [anon_sym_dos] = "file_format",
  [anon_sym_unix] = "file_format",
  [anon_sym_mac] = "file_format",
  [anon_sym_latin1] = "latin1",
  [anon_sym_iso] = "iso",
  [anon_sym_koi8] = "koi8",
  [anon_sym_macroman] = "macroman",
  [anon_sym_cp437] = "cp437",
  [anon_sym_cp737] = "cp737",
  [anon_sym_cp775] = "cp775",
  [anon_sym_cp850] = "cp850",
  [anon_sym_cp852] = "cp852",
  [anon_sym_cp855] = "cp855",
  [anon_sym_cp857] = "cp857",
  [anon_sym_cp860] = "cp860",
  [anon_sym_cp861] = "cp861",
  [anon_sym_cp862] = "cp862",
  [anon_sym_cp863] = "cp863",
  [anon_sym_cp865] = "cp865",
  [anon_sym_cp866] = "cp866",
  [anon_sym_cp869] = "cp869",
  [anon_sym_cp874] = "cp874",
  [anon_sym_cp1250] = "cp1250",
  [anon_sym_cp1251] = "cp1251",
  [anon_sym_cp1253] = "cp1253",
  [anon_sym_cp1254] = "cp1254",
  [anon_sym_cp1255] = "cp1255",
  [anon_sym_cp1256] = "cp1256",
  [anon_sym_cp1257] = "cp1257",
  [anon_sym_cp1258] = "cp1258",
  [anon_sym_cp932] = "cp932",
  [anon_sym_euc_DASHjp] = "euc-jp",
  [anon_sym_sjis] = "sjis",
  [anon_sym_cp949] = "cp949",
  [anon_sym_euc_DASHkr] = "euc-kr",
  [anon_sym_cp936] = "cp936",
  [anon_sym_euc_DASHcn] = "euc-cn",
  [anon_sym_cp950] = "cp950",
  [anon_sym_big5] = "big5",
  [anon_sym_euc_DASHtw] = "euc-tw",
  [anon_sym_utf_DASH8] = "utf-8",
  [anon_sym_ucs_DASH2] = "ucs-2",
  [anon_sym_ucs_DASH21e] = "ucs-21e",
  [anon_sym_utf_DASH16] = "utf-16",
  [anon_sym_utf_DASH16le] = "utf-16le",
  [anon_sym_ucs_DASH4] = "ucs-4",
  [anon_sym_ucs_DASH4le] = "ucs-4le",
  [anon_sym_ansi] = "ansi",
  [anon_sym_japan] = "japan",
  [anon_sym_korea] = "korea",
  [anon_sym_prc] = "prc",
  [anon_sym_chinese] = "chinese",
  [anon_sym_taiwan] = "taiwan",
  [anon_sym_utf8] = "utf8",
  [anon_sym_unicode] = "unicode",
  [anon_sym_ucs2be] = "ucs2be",
  [anon_sym_ucs_DASH2be] = "ucs-2be",
  [anon_sym_ucs_DASH4be] = "ucs-4be",
  [anon_sym_utf_DASH32] = "utf-32",
  [anon_sym_utf_DASH32le] = "utf-32le",
  [anon_sym_default] = "default",
  [anon_sym_latin12] = "encoding",
  [anon_sym_iso2] = "encoding",
  [anon_sym_koi82] = "encoding",
  [anon_sym_macroman2] = "encoding",
  [anon_sym_cp4372] = "encoding",
  [anon_sym_cp7372] = "encoding",
  [anon_sym_cp7752] = "encoding",
  [anon_sym_cp8502] = "encoding",
  [anon_sym_cp8522] = "encoding",
  [anon_sym_cp8552] = "encoding",
  [anon_sym_cp8572] = "encoding",
  [anon_sym_cp8602] = "encoding",
  [anon_sym_cp8612] = "encoding",
  [anon_sym_cp8622] = "encoding",
  [anon_sym_cp8632] = "encoding",
  [anon_sym_cp8652] = "encoding",
  [anon_sym_cp8662] = "encoding",
  [anon_sym_cp8692] = "encoding",
  [anon_sym_cp8742] = "encoding",
  [anon_sym_cp12502] = "encoding",
  [anon_sym_cp12512] = "encoding",
  [anon_sym_cp12532] = "encoding",
  [anon_sym_cp12542] = "encoding",
  [anon_sym_cp12552] = "encoding",
  [anon_sym_cp12562] = "encoding",
  [anon_sym_cp12572] = "encoding",
  [anon_sym_cp12582] = "encoding",
  [anon_sym_cp9322] = "encoding",
  [anon_sym_euc_DASHjp2] = "encoding",
  [anon_sym_sjis2] = "encoding",
  [anon_sym_cp9492] = "encoding",
  [anon_sym_euc_DASHkr2] = "encoding",
  [anon_sym_cp9362] = "encoding",
  [anon_sym_euc_DASHcn2] = "encoding",
  [anon_sym_cp9502] = "encoding",
  [anon_sym_big52] = "encoding",
  [anon_sym_euc_DASHtw2] = "encoding",
  [anon_sym_utf_DASH82] = "encoding",
  [anon_sym_ucs_DASH22] = "encoding",
  [anon_sym_ucs_DASH21e2] = "encoding",
  [anon_sym_utf_DASH162] = "encoding",
  [anon_sym_utf_DASH16le2] = "encoding",
  [anon_sym_ucs_DASH42] = "encoding",
  [anon_sym_ucs_DASH4le2] = "encoding",
  [anon_sym_ansi2] = "encoding",
  [anon_sym_japan2] = "encoding",
  [anon_sym_korea2] = "encoding",
  [anon_sym_prc2] = "encoding",
  [anon_sym_chinese2] = "encoding",
  [anon_sym_taiwan2] = "encoding",
  [anon_sym_utf82] = "encoding",
  [anon_sym_unicode2] = "encoding",
  [anon_sym_ucs2be2] = "encoding",
  [anon_sym_ucs_DASH2be2] = "encoding",
  [anon_sym_ucs_DASH4be2] = "encoding",
  [anon_sym_utf_DASH322] = "encoding",
  [anon_sym_utf_DASH32le2] = "encoding",
  [anon_sym_default2] = "encoding",
  [anon_sym_START] = "START",
  [anon_sym_OPT] = "OPT",
  [anon_sym_PACK] = "PACK",
  [anon_sym_ALL] = "ALL",
  [aux_sym_wincmd_statement_token1] = "wincmd_statement_token1",
  [anon_sym_on] = "on",
  [anon_sym_off] = "off",
  [anon_sym_detect] = "detect",
  [anon_sym_plugin] = "plugin",
  [anon_sym_indent] = "indent",
  [anon_sym_EQ] = "=",
  [sym_chunk] = "chunk",
  [sym__heredoc_line] = "_heredoc_line",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_trim] = "trim",
  [anon_sym_LF] = "\n",
  [anon_sym_in] = "in",
  [aux_sym__au_pattern_token1] = "_au_pattern_token1",
  [aux_sym__au_pattern_token2] = "_au_pattern_token2",
  [aux_sym__bang_filter_command_argument_token1] = "_bang_filter_command_argument_token1",
  [anon_sym_BSLASH] = "\\",
  [aux_sym__bang_filter_command_argument_token2] = "_bang_filter_command_argument_token2",
  [aux_sym__bang_filter_command_argument_token3] = "_bang_filter_command_argument_token3",
  [aux_sym__bang_filter_command_argument_token4] = "_bang_filter_command_argument_token4",
  [aux_sym_argument_token1] = "identifier",
  [aux_sym_argument_token2] = "argument_token2",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_LBRACE2] = "{",
  [aux_sym_identifier_token1] = "identifier_token1",
  [aux_sym_identifier_token2] = "identifier_token2",
  [aux_sym__immediate_identifier_token1] = "_immediate_identifier_token1",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_DOT_EQ] = ".=",
  [anon_sym_DOT_DOT_EQ] = "..=",
  [anon_sym_EQ_LT_LT] = "=<<",
  [anon_sym_eval] = "eval",
  [aux_sym_option_name_token1] = "option_name_token1",
  [anon_sym_t_] = "t_",
  [aux_sym_option_name_token2] = "option_name_token2",
  [anon_sym_BANG] = "!",
  [anon_sym_AMP] = "&",
  [anon_sym_vi] = "vi",
  [anon_sym_vim] = "vim",
  [anon_sym_all] = "all",
  [anon_sym_all_AMP] = "all&",
  [anon_sym_QMARK] = "\?",
  [anon_sym_EQ2] = "=",
  [anon_sym_COLON2] = ":",
  [anon_sym_PLUS_EQ2] = "+=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_DASH_EQ2] = "-=",
  [sym_set_value] = "set_value",
  [anon_sym_SPACE] = " ",
  [anon_sym_POUND_BANG] = "#!",
  [aux_sym_shebang_token1] = "shebang_token1",
  [aux_sym_command_argument_token1] = "command_argument_token1",
  [anon_sym_dict] = "dict",
  [anon_sym_range] = "range",
  [anon_sym_abort] = "abort",
  [anon_sym_closure] = "closure",
  [anon_sym_LPAREN] = "(",
  [anon_sym_COMMA] = ",",
  [anon_sym_RPAREN] = ")",
  [sym_spread] = "spread",
  [sym__printable] = "_printable",
  [sym_mark] = "mark",
  [anon_sym_PERCENT] = "%",
  [anon_sym_SEMI] = ";",
  [anon_sym_SLASH] = "/",
  [anon_sym_SLASH2] = "/",
  [anon_sym_QMARK2] = "\?",
  [anon_sym_DOT2] = ".",
  [anon_sym_PLUS] = "+",
  [anon_sym_DOLLAR] = "$",
  [anon_sym_BSLASH_SLASH] = "\\/",
  [anon_sym_BSLASH_QMARK] = "\\\?",
  [anon_sym_BSLASH_AMP] = "\\&",
  [anon_sym_LTbuffer_GT] = "<buffer>",
  [anon_sym_LTnowait_GT] = "<nowait>",
  [anon_sym_LTsilent_GT] = "<silent>",
  [anon_sym_LTunique_GT] = "<unique>",
  [anon_sym_LTscript_GT] = "<script>",
  [anon_sym_LTexpr_GT] = "<expr>",
  [sym__keycode_modifier] = "_keycode_modifier",
  [aux_sym__keycode_in_token1] = "_keycode_in_token1",
  [aux_sym__keycode_in_token2] = "_keycode_in_token2",
  [aux_sym__keycode_in_token3] = "_keycode_in_token3",
  [aux_sym__keycode_in_token4] = "_keycode_in_token4",
  [aux_sym__keycode_in_token5] = "_keycode_in_token5",
  [aux_sym__keycode_in_token6] = "_keycode_in_token6",
  [aux_sym__keycode_in_token7] = "_keycode_in_token7",
  [aux_sym__keycode_in_token8] = "_keycode_in_token8",
  [aux_sym__keycode_in_token9] = "_keycode_in_token9",
  [aux_sym__keycode_in_token10] = "_keycode_in_token10",
  [aux_sym__keycode_in_token11] = "_keycode_in_token11",
  [aux_sym__keycode_in_token12] = "_keycode_in_token12",
  [aux_sym__keycode_in_token13] = "_keycode_in_token13",
  [aux_sym__keycode_in_token14] = "_keycode_in_token14",
  [aux_sym__keycode_in_token15] = "_keycode_in_token15",
  [aux_sym__keycode_in_token16] = "_keycode_in_token16",
  [aux_sym__keycode_in_token17] = "_keycode_in_token17",
  [aux_sym__keycode_in_token18] = "_keycode_in_token18",
  [aux_sym__keycode_in_token19] = "_keycode_in_token19",
  [aux_sym__keycode_in_token20] = "_keycode_in_token20",
  [aux_sym__keycode_in_token21] = "_keycode_in_token21",
  [aux_sym__keycode_in_token22] = "_keycode_in_token22",
  [aux_sym__keycode_in_token23] = "_keycode_in_token23",
  [aux_sym__keycode_in_token24] = "_keycode_in_token24",
  [aux_sym__keycode_in_token25] = "_keycode_in_token25",
  [aux_sym__keycode_in_token26] = "_keycode_in_token26",
  [aux_sym__keycode_in_token27] = "_keycode_in_token27",
  [aux_sym__keycode_in_token28] = "_keycode_in_token28",
  [aux_sym__keycode_in_token29] = "_keycode_in_token29",
  [aux_sym__keycode_in_token30] = "_keycode_in_token30",
  [aux_sym__keycode_in_token31] = "_keycode_in_token31",
  [aux_sym__keycode_in_token32] = "_keycode_in_token32",
  [aux_sym__keycode_in_token33] = "_keycode_in_token33",
  [aux_sym__keycode_in_token34] = "_keycode_in_token34",
  [aux_sym__keycode_in_token35] = "_keycode_in_token35",
  [aux_sym__keycode_in_token36] = "_keycode_in_token36",
  [aux_sym__keycode_in_token37] = "_keycode_in_token37",
  [aux_sym__keycode_in_token38] = "_keycode_in_token38",
  [aux_sym__keycode_in_token39] = "_keycode_in_token39",
  [aux_sym__keycode_in_token40] = "_keycode_in_token40",
  [aux_sym__keycode_in_token41] = "_keycode_in_token41",
  [aux_sym__keycode_in_token42] = "_keycode_in_token42",
  [aux_sym__keycode_in_token43] = "_keycode_in_token43",
  [anon_sym_LT] = "<",
  [anon_sym_GT] = ">",
  [anon_sym_LT2] = "<",
  [anon_sym_BSLASH2] = "\\",
  [aux_sym__map_lhs_token1] = "_map_lhs_token1",
  [aux_sym__map_rhs_statement_token1] = "keycode",
  [anon_sym_BSLASH_PIPE] = "\\|",
  [aux_sym__map_rhs_statement_token2] = "keycode",
  [aux_sym__map_rhs_statement_token3] = "keycode",
  [aux_sym__map_rhs_token1] = "_map_rhs_token1",
  [aux_sym__map_rhs_token2] = "_map_rhs_token2",
  [anon_sym_icon] = "icon",
  [anon_sym_linehl] = "linehl",
  [anon_sym_numhl] = "numhl",
  [anon_sym_text] = "text",
  [anon_sym_texthl] = "texthl",
  [anon_sym_culhl] = "culhl",
  [anon_sym_define] = "define",
  [anon_sym_undefine] = "undefine",
  [anon_sym_list] = "list",
  [anon_sym_line] = "line",
  [anon_sym_name] = "name",
  [anon_sym_buffer] = "buffer",
  [anon_sym_group] = "group",
  [anon_sym_priority] = "priority",
  [anon_sym_file] = "file",
  [anon_sym_STAR] = "wildcard",
  [anon_sym_place] = "place",
  [anon_sym_STAR2] = "*",
  [anon_sym_unplace] = "unplace",
  [anon_sym_jump] = "jump",
  [anon_sym_POUND] = "#",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_DASH] = "-",
  [anon_sym_DOT_DOT] = "..",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_GT2] = ">",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_EQ_TILDE] = "=~",
  [anon_sym_BANG_TILDE] = "!~",
  [anon_sym_is] = "is",
  [anon_sym_isnot] = "isnot",
  [anon_sym_BANG2] = "!",
  [sym_float_literal] = "float_literal",
  [sym_integer_literal] = "integer_literal",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_LPAREN2] = "(",
  [anon_sym_DASH_GT] = "->",
  [aux_sym_filename_token1] = "filename_token1",
  [aux_sym_filename_token2] = "filename_token2",
  [aux_sym_filename_token3] = "filename_token3",
  [aux_sym_filename_token4] = "filename_token4",
  [aux_sym_filename_token5] = "filename_token5",
  [aux_sym_filename_token6] = "filename_token6",
  [aux_sym_filename_token7] = "filename_token7",
  [aux_sym_filename_token8] = "filename_token8",
  [aux_sym_pattern_multi_token1] = "pattern_multi_token1",
  [aux_sym_pattern_multi_token2] = "pattern_multi_token2",
  [aux_sym_pattern_multi_token3] = "pattern_multi_token3",
  [aux_sym__pattern_ordinary_atom_token1] = "_pattern_ordinary_atom_token1",
  [aux_sym__pattern_ordinary_atom_token2] = "_pattern_ordinary_atom_token2",
  [anon_sym_BSLASH_LPAREN] = "\\(",
  [anon_sym_BSLASH_RPAREN] = "\\)",
  [anon_sym_BSLASH_PERCENT_LPAREN] = "\\%(",
  [anon_sym_BSLASHz_LPAREN] = "\\z(",
  [sym_register] = "register",
  [sym_literal_key] = "literal_key",
  [anon_sym_POUND_LBRACE] = "#{",
  [anon_sym_keep] = "keep",
  [anon_sym_drop] = "drop",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_ff] = "ff",
  [anon_sym_fileformat] = "fileformat",
  [anon_sym_enc] = "enc",
  [anon_sym_encoding] = "encoding",
  [anon_sym_bin] = "bin",
  [anon_sym_binary] = "binary",
  [anon_sym_nobin] = "nobin",
  [anon_sym_nobinary] = "nobinary",
  [anon_sym_bad] = "bad",
  [anon_sym_edit] = "edit",
  [aux_sym__plus_cmd_arg_token1] = "_plus_cmd_arg_token1",
  [sym_au_event] = "au_event",
  [aux_sym__autocmd_pattern_token1] = "pattern",
  [sym_au_once] = "au_once",
  [sym_au_nested] = "au_nested",
  [sym_command_name] = "command_name",
  [anon_sym_arglist] = "arglist",
  [anon_sym_augroup] = "augroup",
  [anon_sym_buffer2] = "buffer",
  [anon_sym_behave] = "behave",
  [anon_sym_color] = "color",
  [anon_sym_command] = "command",
  [anon_sym_compiler] = "compiler",
  [anon_sym_dir] = "dir",
  [anon_sym_environment] = "environment",
  [anon_sym_even] = "even",
  [anon_sym_expression] = "expression",
  [anon_sym_file2] = "file",
  [anon_sym_file_in_path] = "file_in_path",
  [anon_sym_filetype] = "filetype",
  [anon_sym_function] = "function",
  [anon_sym_help] = "help",
  [anon_sym_highlight] = "highlight",
  [anon_sym_history] = "history",
  [anon_sym_local] = "local",
  [anon_sym_lua] = "lua",
  [anon_sym_mapclear] = "mapclear",
  [anon_sym_mapping] = "mapping",
  [anon_sym_menu] = "menu",
  [anon_sym_messages] = "messages",
  [anon_sym_option] = "option",
  [anon_sym_packadd] = "packadd",
  [anon_sym_shellcmd] = "shellcmd",
  [anon_sym_sign] = "sign",
  [anon_sym_syntax] = "syntax",
  [anon_sym_syntime] = "syntime",
  [anon_sym_tag] = "tag",
  [anon_sym_tag_listfiles] = "tag_listfiles",
  [anon_sym_user] = "user",
  [anon_sym_var] = "var",
  [anon_sym_custom] = "custom",
  [anon_sym_COMMA2] = ",",
  [anon_sym_customlist] = "customlist",
  [anon_sym_lines] = "lines",
  [anon_sym_arguments] = "arguments",
  [anon_sym_buffers] = "buffers",
  [anon_sym_loaded_buffers] = "loaded_buffers",
  [anon_sym_windows] = "windows",
  [anon_sym_tabs] = "tabs",
  [anon_sym_quickfix] = "quickfix",
  [anon_sym_other] = "other",
  [aux_sym__command_attribute_nargs_value_token1] = "integer_literal",
  [aux_sym__command_attribute_nargs_value_token2] = "pattern_multi",
  [anon_sym_PERCENT2] = "pattern_multi",
  [anon_sym_DASHnargs] = "-nargs",
  [anon_sym_DASHcomplete] = "-complete",
  [anon_sym_DASHrange] = "-range",
  [anon_sym_DASHcount] = "-count",
  [anon_sym_DASHaddr] = "-addr",
  [anon_sym_DASHbang] = "-bang",
  [anon_sym_DASHbar] = "-bar",
  [anon_sym_DASHregister] = "-register",
  [anon_sym_DASHbuffer] = "-buffer",
  [anon_sym_DASHkeepscript] = "-keepscript",
  [aux_sym_command_statement_token1] = "command",
  [sym_hl_group] = "hl_group",
  [anon_sym_link] = "link",
  [anon_sym_clear] = "clear",
  [anon_sym_NONE] = "hl_group",
  [anon_sym_NONE2] = "NONE",
  [anon_sym_bold] = "bold",
  [anon_sym_underline] = "underline",
  [anon_sym_undercurl] = "undercurl",
  [anon_sym_underdouble] = "underdouble",
  [anon_sym_underdotted] = "underdotted",
  [anon_sym_underdashed] = "underdashed",
  [anon_sym_strikethrough] = "strikethrough",
  [anon_sym_reverse] = "reverse",
  [anon_sym_inverse] = "inverse",
  [anon_sym_italic] = "italic",
  [anon_sym_standout] = "standout",
  [anon_sym_nocombine] = "nocombine",
  [anon_sym_term] = "term",
  [anon_sym_cterm] = "cterm",
  [aux_sym__hl_term_list_token1] = "_hl_term_list_token1",
  [anon_sym_start] = "start",
  [anon_sym_stop] = "stop",
  [sym__hl_color_nr] = "_hl_color_nr",
  [anon_sym_ctermfg] = "ctermfg",
  [anon_sym_ctermbg] = "ctermbg",
  [anon_sym_gui] = "gui",
  [anon_sym_SQUOTE] = "'",
  [aux_sym__hl_quoted_name_token1] = "_hl_quoted_name_token1",
  [anon_sym_SQUOTE2] = "'",
  [anon_sym_bg] = "bg",
  [anon_sym_background] = "background",
  [anon_sym_fg] = "fg",
  [anon_sym_foreground] = "foreground",
  [aux_sym_color_token1] = "color_token1",
  [aux_sym_color_token2] = "color_token2",
  [anon_sym_guifg] = "guifg",
  [anon_sym_guibg] = "guibg",
  [anon_sym_guisp] = "guisp",
  [aux_sym_font_token1] = "font_token1",
  [anon_sym_font] = "font",
  [anon_sym_blend] = "blend",
  [anon_sym_enable] = "enable",
  [anon_sym_reset] = "reset",
  [anon_sym_case] = "case",
  [anon_sym_match] = "match",
  [anon_sym_ignore] = "ignore",
  [anon_sym_spell] = "spell",
  [anon_sym_toplevel] = "toplevel",
  [anon_sym_notoplevel] = "notoplevel",
  [anon_sym_foldlevel] = "foldlevel",
  [anon_sym_minimum] = "minimum",
  [anon_sym_iskeyword] = "iskeyword",
  [aux_sym__syn_iskeyword_token1] = "value",
  [anon_sym_conceal] = "conceal",
  [anon_sym_cchar] = "cchar",
  [anon_sym_contained] = "contained",
  [anon_sym_containedin] = "containedin",
  [anon_sym_nextgroup] = "nextgroup",
  [anon_sym_transparent] = "transparent",
  [anon_sym_skipwhite] = "skipwhite",
  [anon_sym_skipnl] = "skipnl",
  [anon_sym_skipempty] = "skipempty",
  [anon_sym_contains] = "contains",
  [anon_sym_fold] = "fold",
  [anon_sym_display] = "display",
  [anon_sym_extend] = "extend",
  [anon_sym_keepend] = "keepend",
  [anon_sym_excludenl] = "excludenl",
  [anon_sym_matchgroup] = "matchgroup",
  [anon_sym_oneline] = "oneline",
  [anon_sym_concealends] = "concealends",
  [anon_sym_add] = "add",
  [anon_sym_remove] = "remove",
  [anon_sym_ms] = "ms",
  [anon_sym_me] = "me",
  [anon_sym_hs] = "hs",
  [anon_sym_he] = "he",
  [anon_sym_rs] = "rs",
  [anon_sym_re] = "re",
  [anon_sym_lc] = "lc",
  [aux_sym__syn_pattern_offset_token1] = "_syn_pattern_offset_token1",
  [aux_sym__syn_pattern_offset_token2] = "_syn_pattern_offset_token2",
  [anon_sym_keyword] = "keyword",
  [aux_sym__syn_keyword_token1] = "keyword",
  [anon_sym_skip] = "skip",
  [anon_sym_end] = "end",
  [anon_sym_region] = "region",
  [anon_sym_cluster] = "cluster",
  [anon_sym_include] = "include",
  [anon_sym_AT] = "@",
  [anon_sym_minlines] = "minlines",
  [anon_sym_maxlines] = "maxlines",
  [aux_sym__syn_sync_lines_token1] = "_syn_sync_lines_token1",
  [anon_sym_sync] = "sync",
  [anon_sym_linebreaks] = "linebreaks",
  [anon_sym_fromstart] = "fromstart",
  [anon_sym_ccomment] = "ccomment",
  [anon_sym_lines2] = "lines",
  [anon_sym_grouphere] = "grouphere",
  [anon_sym_groupthere] = "groupthere",
  [anon_sym_linecont] = "linecont",
  [sym__no] = "_no",
  [sym__inv] = "_inv",
  [sym__newline_or_pipe] = "_newline_or_pipe",
  [sym__line_continuation] = "_line_continuation",
  [sym__script_heredoc_marker] = "marker_definition",
  [sym__let_heredoc_marker] = "marker_definition",
  [sym__heredoc_end] = "endmarker",
  [sym__separator_first] = "_separator_first",
  [sym__separator] = "_separator",
  [sym__scope_dict] = "_scope_dict",
  [sym_scope] = "scope",
  [sym_string_literal] = "string_literal",
  [sym_comment] = "comment",
  [sym_line_continuation_comment] = "line_continuation_comment",
  [sym__bang_filter] = "_bang_filter",
  [sym__function] = "function",
  [sym__endfunction] = "endfunction",
  [sym__for] = "for",
  [sym__endfor] = "endfor",
  [sym__while] = "while",
  [sym__endwhile] = "endwhile",
  [sym__if] = "if",
  [sym__elseif] = "elseif",
  [sym__else] = "else",
  [sym__endif] = "endif",
  [sym__try] = "try",
  [sym__catch] = "catch",
  [sym__cnext] = "cnext",
  [sym__cprevious] = "cprevious",
  [sym__cNext] = "cNext",
  [sym__finally] = "finally",
  [sym__endtry] = "endtry",
  [sym__const] = "const",
  [sym__normal] = "normal",
  [sym__return] = "return",
  [sym__perl] = "perl",
  [sym__lua] = "lua",
  [sym__ruby] = "ruby",
  [sym__python] = "python",
  [sym__throw] = "throw",
  [sym__execute] = "execute",
  [sym__autocmd] = "autocmd",
  [sym__silent] = "silent",
  [sym__echo] = "echo",
  [sym__echon] = "echon",
  [sym__echohl] = "echohl",
  [sym__echomsg] = "echomsg",
  [sym__echoerr] = "echoerr",
  [sym__map] = "map",
  [sym__nmap] = "nmap",
  [sym__vmap] = "vmap",
  [sym__xmap] = "xmap",
  [sym__smap] = "smap",
  [sym__omap] = "omap",
  [sym__imap] = "imap",
  [sym__lmap] = "lmap",
  [sym__cmap] = "cmap",
  [sym__tmap] = "tmap",
  [sym__noremap] = "noremap",
  [sym__nnoremap] = "nnoremap",
  [sym__vnoremap] = "vnoremap",
  [sym__xnoremap] = "xnoremap",
  [sym__snoremap] = "snoremap",
  [sym__onoremap] = "onoremap",
  [sym__inoremap] = "inoremap",
  [sym__lnoremap] = "lnoremap",
  [sym__cnoremap] = "cnoremap",
  [sym__tnoremap] = "tnoremap",
  [sym__augroup] = "augroup",
  [sym__highlight] = "highlight",
  [sym__default] = "default",
  [sym__syntax] = "syntax",
  [sym__set] = "set",
  [sym__setlocal] = "setlocal",
  [sym__setfiletype] = "setfiletype",
  [sym__browse] = "browse",
  [sym__options] = "options",
  [sym__startinsert] = "startinsert",
  [sym__stopinsert] = "stopinsert",
  [sym__scriptencoding] = "scriptencoding",
  [sym__source] = "source",
  [sym__global] = "global",
  [sym__colorscheme] = "colorscheme",
  [sym__command] = "command",
  [sym__comclear] = "comclear",
  [sym__delcommand] = "delcommand",
  [sym__runtime] = "runtime",
  [sym__wincmd] = "wincmd",
  [sym__sign] = "sign",
  [sym__filetype] = "filetype",
  [sym__let] = "let",
  [sym__unlet] = "unlet",
  [sym__call] = "call",
  [sym__break] = "break",
  [sym__continue] = "continue",
  [sym__tab] = "tab",
  [sym__vertical] = "vertical",
  [sym__leftabove] = "leftabove",
  [sym__aboveleft] = "aboveleft",
  [sym__rightbelow] = "rightbelow",
  [sym__belowright] = "belowright",
  [sym__topleft] = "topleft",
  [sym__botright] = "botright",
  [sym__edit] = "edit",
  [sym__enew] = "enew",
  [sym__find] = "find",
  [sym__ex] = "ex",
  [sym__visual] = "visual",
  [sym__view] = "view",
  [sym__eval] = "eval",
  [sym__substitute] = "substitute",
  [sym_unknown_command_name] = "unknown_command_name",
  [sym_script_file] = "script_file",
  [sym__cmd_separator] = "_cmd_separator",
  [aux_sym__separated_statements] = "_separated_statements",
  [sym__statement] = "_statement",
  [sym_unknown_builtin_statement] = "unknown_builtin_statement",
  [sym_return_statement] = "return_statement",
  [sym_break_statement] = "break_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_scope_dict] = "scope_dict",
  [sym_normal_statement] = "normal_statement",
  [sym__filetype_immediate] = "_filetype_immediate",
  [sym_filetypes] = "filetypes",
  [sym_setfiletype_statement] = "setfiletype_statement",
  [sym_options_statement] = "options_statement",
  [sym_startinsert_statement] = "startinsert_statement",
  [sym_stopinsert_statement] = "stopinsert_statement",
  [sym__immediate_file_format] = "_immediate_file_format",
  [sym_encoding] = "encoding",
  [sym__immediate_encoding] = "_immediate_encoding",
  [sym_scriptencoding_statement] = "scriptencoding_statement",
  [sym_cnext_statement] = "cnext_statement",
  [sym_cprevious_statement] = "cprevious_statement",
  [sym__runtime_where] = "where",
  [sym_runtime_statement] = "runtime_statement",
  [sym_wincmd_statement] = "wincmd_statement",
  [sym_source_statement] = "source_statement",
  [sym_global_statement] = "global_statement",
  [sym__filetype_state] = "_filetype_state",
  [sym__filetype_enable] = "_filetype_enable",
  [sym__filetype_detect] = "_filetype_detect",
  [sym__filetype_plugin] = "_filetype_plugin",
  [sym__filetype_indent] = "_filetype_indent",
  [sym_filetype_statement] = "filetype_statement",
  [sym_colorscheme_statement] = "colorscheme_statement",
  [sym_lua_statement] = "lua_statement",
  [sym_ruby_statement] = "ruby_statement",
  [sym_python_statement] = "python_statement",
  [sym_perl_statement] = "perl_statement",
  [sym_script] = "script",
  [sym_for_loop] = "for_loop",
  [sym_while_loop] = "while_loop",
  [sym_if_statement] = "if_statement",
  [sym_elseif_statement] = "elseif_statement",
  [sym_else_statement] = "else_statement",
  [sym_try_statement] = "try_statement",
  [sym__au_pattern] = "pattern",
  [sym_catch_statement] = "catch_statement",
  [sym_finally_statement] = "finally_statement",
  [sym_throw_statement] = "throw_statement",
  [sym__bang_filter_bangs] = "bangs",
  [sym__bang_filter_command_argument] = "command_argument",
  [sym__bang_filter_command] = "command",
  [sym_bang_filter_statement] = "bang_filter_statement",
  [sym_scoped_identifier] = "scoped_identifier",
  [sym_argument] = "argument",
  [sym__curly_braces_name_expression] = "curly_braces_name",
  [sym__immediate_curly_braces_name_expression] = "curly_braces_name",
  [sym_identifier] = "identifier",
  [sym__immediate_identifier] = "identifier",
  [sym__ident] = "_ident",
  [sym__let_operator] = "_let_operator",
  [sym__assignment_variable] = "_assignment_variable",
  [sym__let_assignment] = "_let_assignment",
  [sym_let_statement] = "let_statement",
  [sym__const_assignment] = "_const_assignment",
  [sym_const_statement] = "const_statement",
  [sym__let_heredoc] = "heredoc",
  [sym__let_heredoc_parameter] = "parameter",
  [sym_option_name] = "option_name",
  [sym_no_option] = "no_option",
  [sym_inv_option] = "inv_option",
  [sym_default_option] = "default_option",
  [sym__set_option] = "_set_option",
  [sym__set_operator] = "_set_operator",
  [sym__set_rhs] = "_set_rhs",
  [sym_set_item] = "set_item",
  [sym_set_statement] = "set_statement",
  [sym_setlocal_statement] = "setlocal_statement",
  [sym_unlet_statement] = "unlet_statement",
  [sym_call_statement] = "call_statement",
  [sym_echo_statement] = "echo_statement",
  [sym_echon_statement] = "echon_statement",
  [sym_echohl_statement] = "echohl_statement",
  [sym_echomsg_statement] = "echomsg_statement",
  [sym_echoerr_statement] = "echoerr_statement",
  [sym_execute_statement] = "execute_statement",
  [sym_silent_statement] = "silent_statement",
  [sym_tab_statement] = "tab_statement",
  [sym_vertical_statement] = "vertical_statement",
  [sym_topleft_statement] = "topleft_statement",
  [sym_botright_statement] = "botright_statement",
  [sym_aboveleft_statement] = "aboveleft_statement",
  [sym_belowright_statement] = "belowright_statement",
  [sym_user_command] = "user_command",
  [sym_shebang] = "shebang",
  [sym_command_argument] = "command_argument",
  [sym_function_definition] = "function_definition",
  [sym_function_declaration] = "function_declaration",
  [sym_parameters] = "parameters",
  [sym_default_parameter] = "default_parameter",
  [sym_bang] = "bang",
  [sym_range_statement] = "range_statement",
  [sym__range] = "_range",
  [sym__range_explicit] = "_range_explicit",
  [sym__range_marker] = "_range_marker",
  [sym__complete_range] = "range",
  [sym__complete_range_explicit] = "_complete_range_explicit",
  [sym__complete_range_marker] = "_complete_range_marker",
  [sym_current_line] = "current_line",
  [sym_next_line] = "next_line",
  [sym_last_line] = "last_line",
  [sym_previous_pattern] = "previous_pattern",
  [sym_register_statement] = "register_statement",
  [sym_map_statement] = "map_statement",
  [sym__map_definition] = "_map_definition",
  [sym__keycode_in] = "_keycode_in",
  [sym__immediate_keycode] = "_immediate_keycode",
  [sym_keycode] = "keycode",
  [sym__map_lhs] = "map_side",
  [sym__map_rhs_statement] = "_map_rhs_statement",
  [sym__map_rhs] = "map_side",
  [sym__sign_name] = "_sign_name",
  [sym__sign_define_arg_text] = "text",
  [sym__sign_define_argument] = "sign_argument",
  [sym__sign_define] = "_sign_define",
  [sym__sign_undefine] = "_sign_undefine",
  [sym__sign_list] = "_sign_list",
  [sym__sign_place_place_argument] = "sign_argument",
  [sym__sign_place_place] = "_sign_place_place",
  [sym__sign_place_list_argument] = "sign_argument",
  [aux_sym__sign_place_list] = "_sign_place_list",
  [sym__sign_place] = "_sign_place",
  [sym__sign_unplace_cursor_argument] = "sign_argument",
  [sym__sign_unplace_cursor] = "_sign_unplace_cursor",
  [sym__sign_unplace_id_argument] = "sign_argument",
  [sym__sign_unplace_id] = "_sign_unplace_id",
  [sym__sign_unplace] = "_sign_unplace",
  [sym__sign_jump_argument] = "sign_argument",
  [sym__sign_jump] = "_sign_jump",
  [sym_sign_statement] = "sign_statement",
  [sym__variable] = "_variable",
  [sym__expression] = "_expression",
  [sym_ternary_expression] = "ternary_expression",
  [sym_match_case] = "match_case",
  [sym_binary_operation] = "binary_operation",
  [sym_unary_operation] = "unary_operation",
  [sym_list] = "list",
  [sym_list_assignment] = "list_assignment",
  [sym_index_expression] = "index_expression",
  [sym_slice_expression] = "slice_expression",
  [sym_field_expression] = "field_expression",
  [sym_call_expression] = "call_expression",
  [sym_eval_statement] = "eval_statement",
  [sym_substitute_statement] = "substitute_statement",
  [sym__method_call_expression] = "call_expression",
  [sym_method_expression] = "method_expression",
  [sym_filename] = "filename",
  [sym_pattern_multi] = "pattern_multi",
  [aux_sym__pattern_ordinary_atom] = "_pattern_ordinary_atom",
  [sym__pattern_atom] = "_pattern_atom",
  [sym__pattern_piece] = "_pattern_piece",
  [aux_sym__pattern_concat] = "_pattern_concat",
  [sym__pattern_branch] = "_pattern_branch",
  [sym_pattern] = "pattern",
  [sym_env_variable] = "env_variable",
  [sym_option] = "option",
  [sym_dictionnary_entry] = "dictionnary_entry",
  [sym_dictionnary] = "dictionnary",
  [sym__literal_dictionary_entry] = "_literal_dictionary_entry",
  [sym_literal_dictionary] = "literal_dictionary",
  [sym_lambda_expression] = "lambda_expression",
  [sym__immediate_lambda_expression] = "lambda_expression",
  [sym__plus_plus_opt_bad] = "_plus_plus_opt_bad",
  [sym_plus_plus_opt] = "plus_plus_opt",
  [aux_sym__plus_cmd_arg] = "_plus_cmd_arg",
  [sym__plus_cmd_number] = "_plus_cmd_number",
  [sym__plus_cmd_command] = "_plus_cmd_command",
  [sym__plus_cmd_pattern] = "_plus_cmd_pattern",
  [sym_plus_cmd] = "plus_cmd",
  [sym_au_event_list] = "au_event_list",
  [sym__augroup_name] = "_augroup_name",
  [sym__autocmd_pattern] = "_autocmd_pattern",
  [sym__autocmd_command] = "_autocmd_command",
  [sym__autocmd_define] = "_autocmd_define",
  [sym__autocmd_remove] = "_autocmd_remove",
  [sym__autocmd_list] = "_autocmd_list",
  [sym_autocmd_statement] = "autocmd_statement",
  [sym_augroup_statement] = "augroup_statement",
  [sym__command_attribute_completion_behavior] = "behavior",
  [sym__command_attribute_address_behavior] = "behavior",
  [sym__command_attribute_nargs_value] = "_command_attribute_nargs_value",
  [sym__command_attribute_range_value] = "_command_attribute_range_value",
  [sym_command_attribute] = "command_attribute",
  [sym_command_statement] = "command_statement",
  [sym_comclear_statement] = "comclear_statement",
  [sym_delcommand_statement] = "delcommand_statement",
  [sym__hl_body_link] = "_hl_body_link",
  [sym__hl_body_clear] = "_hl_body_clear",
  [sym__hl_body_none] = "_hl_body_none",
  [sym__hl_none] = "_hl_none",
  [sym__hl_attr_list] = "_hl_attr_list",
  [sym__hl_key_cterm] = "_hl_key_cterm",
  [aux_sym__hl_term_list] = "_hl_term_list",
  [sym__hl_key_start_stop] = "_hl_key_start_stop",
  [sym__hl_key_ctermfg_ctermbg] = "_hl_key_ctermfg_ctermbg",
  [sym__hl_key_gui] = "_hl_key_gui",
  [sym__hl_quoted_name] = "_hl_quoted_name",
  [sym_color] = "color",
  [sym__hl_key_gui_color] = "_hl_key_gui_color",
  [sym_font] = "font",
  [sym__hl_key_font] = "_hl_key_font",
  [sym__hl_key_blend] = "_hl_key_blend",
  [sym_hl_attribute] = "hl_attribute",
  [sym__hl_body_keys] = "_hl_body_keys",
  [sym__hl_body] = "_hl_body",
  [sym_highlight_statement] = "highlight_statement",
  [sym__syn_enable] = "_syn_enable",
  [sym__syn_case] = "_syn_case",
  [sym__syn_spell] = "_syn_spell",
  [sym__syn_foldlevel] = "_syn_foldlevel",
  [sym__syn_iskeyword] = "_syn_iskeyword",
  [sym__syn_conceal] = "_syn_conceal",
  [sym__syn_hl_pattern] = "_syn_hl_pattern",
  [sym_hl_groups] = "hl_groups",
  [sym__syn_arguments_keyword] = "_syn_arguments_keyword",
  [sym__syn_arguments_match] = "_syn_arguments_match",
  [sym__syn_arguments_region] = "syntax_argument",
  [sym__syn_arguments_cluster] = "syntax_argument",
  [sym__syn_pattern_offset] = "pattern_offset",
  [sym__syn_keyword] = "_syn_keyword",
  [sym__syn_match] = "_syn_match",
  [sym__syn_region_start] = "syntax_argument",
  [sym__syn_region_skip] = "syntax_argument",
  [sym__syn_region_end] = "syntax_argument",
  [sym__syn_region] = "_syn_region",
  [sym__syn_cluster] = "_syn_cluster",
  [sym__syn_include] = "_syn_include",
  [sym__syn_sync_lines] = "_syn_sync_lines",
  [sym__syn_sync] = "_syn_sync",
  [sym__syn_list] = "_syn_list",
  [sym__syn_clear] = "_syn_clear",
  [sym_syntax_statement] = "syntax_statement",
  [sym_edit_statement] = "edit_statement",
  [sym_enew_statement] = "enew_statement",
  [sym_find_statement] = "find_statement",
  [sym_ex_statement] = "ex_statement",
  [sym_visual_statement] = "visual_statement",
  [sym_view_statement] = "view_statement",
  [aux_sym__statement_repeat1] = "_statement_repeat1",
  [aux_sym_unknown_builtin_statement_repeat1] = "unknown_builtin_statement_repeat1",
  [aux_sym_filetypes_repeat1] = "filetypes_repeat1",
  [aux_sym_runtime_statement_repeat1] = "runtime_statement_repeat1",
  [aux_sym_script_repeat1] = "script_repeat1",
  [aux_sym_if_statement_repeat1] = "if_statement_repeat1",
  [aux_sym_try_statement_repeat1] = "try_statement_repeat1",
  [aux_sym__bang_filter_command_argument_repeat1] = "_bang_filter_command_argument_repeat1",
  [aux_sym__bang_filter_command_repeat1] = "_bang_filter_command_repeat1",
  [aux_sym_identifier_repeat1] = "identifier_repeat1",
  [aux_sym_let_statement_repeat1] = "let_statement_repeat1",
  [aux_sym__let_heredoc_repeat1] = "_let_heredoc_repeat1",
  [aux_sym_set_statement_repeat1] = "set_statement_repeat1",
  [aux_sym_unlet_statement_repeat1] = "unlet_statement_repeat1",
  [aux_sym_function_definition_repeat1] = "function_definition_repeat1",
  [aux_sym_parameters_repeat1] = "parameters_repeat1",
  [aux_sym_parameters_repeat2] = "parameters_repeat2",
  [aux_sym_map_statement_repeat1] = "map_statement_repeat1",
  [aux_sym__map_lhs_repeat1] = "_map_lhs_repeat1",
  [aux_sym__map_rhs_statement_repeat1] = "_map_rhs_statement_repeat1",
  [aux_sym__map_rhs_repeat1] = "_map_rhs_repeat1",
  [aux_sym__sign_define_repeat1] = "_sign_define_repeat1",
  [aux_sym__sign_place_place_repeat1] = "_sign_place_place_repeat1",
  [aux_sym__sign_unplace_id_repeat1] = "_sign_unplace_id_repeat1",
  [aux_sym__sign_jump_repeat1] = "_sign_jump_repeat1",
  [aux_sym_list_repeat1] = "list_repeat1",
  [aux_sym_filename_repeat1] = "filename_repeat1",
  [aux_sym__pattern_ordinary_atom_repeat1] = "_pattern_ordinary_atom_repeat1",
  [aux_sym__pattern_branch_repeat1] = "_pattern_branch_repeat1",
  [aux_sym_pattern_repeat1] = "pattern_repeat1",
  [aux_sym_dictionnary_repeat1] = "dictionnary_repeat1",
  [aux_sym_literal_dictionary_repeat1] = "literal_dictionary_repeat1",
  [aux_sym_au_event_list_repeat1] = "au_event_list_repeat1",
  [aux_sym__autocmd_pattern_repeat1] = "_autocmd_pattern_repeat1",
  [aux_sym_command_statement_repeat1] = "command_statement_repeat1",
  [aux_sym__hl_attr_list_repeat1] = "_hl_attr_list_repeat1",
  [aux_sym__hl_body_keys_repeat1] = "_hl_body_keys_repeat1",
  [aux_sym_hl_groups_repeat1] = "hl_groups_repeat1",
  [aux_sym__syn_keyword_repeat1] = "_syn_keyword_repeat1",
  [aux_sym__syn_keyword_repeat2] = "_syn_keyword_repeat2",
  [aux_sym__syn_match_repeat1] = "_syn_match_repeat1",
  [aux_sym__syn_match_repeat2] = "_syn_match_repeat2",
  [aux_sym__syn_region_repeat1] = "_syn_region_repeat1",
  [aux_sym__syn_region_repeat2] = "_syn_region_repeat2",
  [aux_sym__syn_cluster_repeat1] = "_syn_cluster_repeat1",
  [aux_sym__syn_sync_repeat1] = "_syn_sync_repeat1",
  [aux_sym_edit_statement_repeat1] = "edit_statement_repeat1",
  [aux_sym_edit_statement_repeat2] = "edit_statement_repeat2",
  [alias_sym_arguments] = "arguments",
  [alias_sym_augroup_name] = "augroup_name",
  [alias_sym_body] = "body",
  [alias_sym_file] = "file",
  [alias_sym_filenames] = "filenames",
  [alias_sym_filter_command] = "filter_command",
  [alias_sym_name] = "name",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_keyword] = sym_keyword,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_a_COLON] = anon_sym_a_COLON,
  [aux_sym_normal_statement_token1] = aux_sym_normal_statement_token1,
  [sym_filetype] = sym_filetype,
  [aux_sym__filetype_immediate_token1] = sym_filetype,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_FALLBACK] = anon_sym_FALLBACK,
  [anon_sym_dos] = anon_sym_dos,
  [anon_sym_unix] = anon_sym_dos,
  [anon_sym_mac] = anon_sym_dos,
  [anon_sym_latin1] = anon_sym_latin1,
  [anon_sym_iso] = anon_sym_iso,
  [anon_sym_koi8] = anon_sym_koi8,
  [anon_sym_macroman] = anon_sym_macroman,
  [anon_sym_cp437] = anon_sym_cp437,
  [anon_sym_cp737] = anon_sym_cp737,
  [anon_sym_cp775] = anon_sym_cp775,
  [anon_sym_cp850] = anon_sym_cp850,
  [anon_sym_cp852] = anon_sym_cp852,
  [anon_sym_cp855] = anon_sym_cp855,
  [anon_sym_cp857] = anon_sym_cp857,
  [anon_sym_cp860] = anon_sym_cp860,
  [anon_sym_cp861] = anon_sym_cp861,
  [anon_sym_cp862] = anon_sym_cp862,
  [anon_sym_cp863] = anon_sym_cp863,
  [anon_sym_cp865] = anon_sym_cp865,
  [anon_sym_cp866] = anon_sym_cp866,
  [anon_sym_cp869] = anon_sym_cp869,
  [anon_sym_cp874] = anon_sym_cp874,
  [anon_sym_cp1250] = anon_sym_cp1250,
  [anon_sym_cp1251] = anon_sym_cp1251,
  [anon_sym_cp1253] = anon_sym_cp1253,
  [anon_sym_cp1254] = anon_sym_cp1254,
  [anon_sym_cp1255] = anon_sym_cp1255,
  [anon_sym_cp1256] = anon_sym_cp1256,
  [anon_sym_cp1257] = anon_sym_cp1257,
  [anon_sym_cp1258] = anon_sym_cp1258,
  [anon_sym_cp932] = anon_sym_cp932,
  [anon_sym_euc_DASHjp] = anon_sym_euc_DASHjp,
  [anon_sym_sjis] = anon_sym_sjis,
  [anon_sym_cp949] = anon_sym_cp949,
  [anon_sym_euc_DASHkr] = anon_sym_euc_DASHkr,
  [anon_sym_cp936] = anon_sym_cp936,
  [anon_sym_euc_DASHcn] = anon_sym_euc_DASHcn,
  [anon_sym_cp950] = anon_sym_cp950,
  [anon_sym_big5] = anon_sym_big5,
  [anon_sym_euc_DASHtw] = anon_sym_euc_DASHtw,
  [anon_sym_utf_DASH8] = anon_sym_utf_DASH8,
  [anon_sym_ucs_DASH2] = anon_sym_ucs_DASH2,
  [anon_sym_ucs_DASH21e] = anon_sym_ucs_DASH21e,
  [anon_sym_utf_DASH16] = anon_sym_utf_DASH16,
  [anon_sym_utf_DASH16le] = anon_sym_utf_DASH16le,
  [anon_sym_ucs_DASH4] = anon_sym_ucs_DASH4,
  [anon_sym_ucs_DASH4le] = anon_sym_ucs_DASH4le,
  [anon_sym_ansi] = anon_sym_ansi,
  [anon_sym_japan] = anon_sym_japan,
  [anon_sym_korea] = anon_sym_korea,
  [anon_sym_prc] = anon_sym_prc,
  [anon_sym_chinese] = anon_sym_chinese,
  [anon_sym_taiwan] = anon_sym_taiwan,
  [anon_sym_utf8] = anon_sym_utf8,
  [anon_sym_unicode] = anon_sym_unicode,
  [anon_sym_ucs2be] = anon_sym_ucs2be,
  [anon_sym_ucs_DASH2be] = anon_sym_ucs_DASH2be,
  [anon_sym_ucs_DASH4be] = anon_sym_ucs_DASH4be,
  [anon_sym_utf_DASH32] = anon_sym_utf_DASH32,
  [anon_sym_utf_DASH32le] = anon_sym_utf_DASH32le,
  [anon_sym_default] = anon_sym_default,
  [anon_sym_latin12] = sym_encoding,
  [anon_sym_iso2] = sym_encoding,
  [anon_sym_koi82] = sym_encoding,
  [anon_sym_macroman2] = sym_encoding,
  [anon_sym_cp4372] = sym_encoding,
  [anon_sym_cp7372] = sym_encoding,
  [anon_sym_cp7752] = sym_encoding,
  [anon_sym_cp8502] = sym_encoding,
  [anon_sym_cp8522] = sym_encoding,
  [anon_sym_cp8552] = sym_encoding,
  [anon_sym_cp8572] = sym_encoding,
  [anon_sym_cp8602] = sym_encoding,
  [anon_sym_cp8612] = sym_encoding,
  [anon_sym_cp8622] = sym_encoding,
  [anon_sym_cp8632] = sym_encoding,
  [anon_sym_cp8652] = sym_encoding,
  [anon_sym_cp8662] = sym_encoding,
  [anon_sym_cp8692] = sym_encoding,
  [anon_sym_cp8742] = sym_encoding,
  [anon_sym_cp12502] = sym_encoding,
  [anon_sym_cp12512] = sym_encoding,
  [anon_sym_cp12532] = sym_encoding,
  [anon_sym_cp12542] = sym_encoding,
  [anon_sym_cp12552] = sym_encoding,
  [anon_sym_cp12562] = sym_encoding,
  [anon_sym_cp12572] = sym_encoding,
  [anon_sym_cp12582] = sym_encoding,
  [anon_sym_cp9322] = sym_encoding,
  [anon_sym_euc_DASHjp2] = sym_encoding,
  [anon_sym_sjis2] = sym_encoding,
  [anon_sym_cp9492] = sym_encoding,
  [anon_sym_euc_DASHkr2] = sym_encoding,
  [anon_sym_cp9362] = sym_encoding,
  [anon_sym_euc_DASHcn2] = sym_encoding,
  [anon_sym_cp9502] = sym_encoding,
  [anon_sym_big52] = sym_encoding,
  [anon_sym_euc_DASHtw2] = sym_encoding,
  [anon_sym_utf_DASH82] = sym_encoding,
  [anon_sym_ucs_DASH22] = sym_encoding,
  [anon_sym_ucs_DASH21e2] = sym_encoding,
  [anon_sym_utf_DASH162] = sym_encoding,
  [anon_sym_utf_DASH16le2] = sym_encoding,
  [anon_sym_ucs_DASH42] = sym_encoding,
  [anon_sym_ucs_DASH4le2] = sym_encoding,
  [anon_sym_ansi2] = sym_encoding,
  [anon_sym_japan2] = sym_encoding,
  [anon_sym_korea2] = sym_encoding,
  [anon_sym_prc2] = sym_encoding,
  [anon_sym_chinese2] = sym_encoding,
  [anon_sym_taiwan2] = sym_encoding,
  [anon_sym_utf82] = sym_encoding,
  [anon_sym_unicode2] = sym_encoding,
  [anon_sym_ucs2be2] = sym_encoding,
  [anon_sym_ucs_DASH2be2] = sym_encoding,
  [anon_sym_ucs_DASH4be2] = sym_encoding,
  [anon_sym_utf_DASH322] = sym_encoding,
  [anon_sym_utf_DASH32le2] = sym_encoding,
  [anon_sym_default2] = sym_encoding,
  [anon_sym_START] = anon_sym_START,
  [anon_sym_OPT] = anon_sym_OPT,
  [anon_sym_PACK] = anon_sym_PACK,
  [anon_sym_ALL] = anon_sym_ALL,
  [aux_sym_wincmd_statement_token1] = aux_sym_wincmd_statement_token1,
  [anon_sym_on] = anon_sym_on,
  [anon_sym_off] = anon_sym_off,
  [anon_sym_detect] = anon_sym_detect,
  [anon_sym_plugin] = anon_sym_plugin,
  [anon_sym_indent] = anon_sym_indent,
  [anon_sym_EQ] = anon_sym_EQ,
  [sym_chunk] = sym_chunk,
  [sym__heredoc_line] = sym__heredoc_line,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_trim] = anon_sym_trim,
  [anon_sym_LF] = anon_sym_LF,
  [anon_sym_in] = anon_sym_in,
  [aux_sym__au_pattern_token1] = aux_sym__au_pattern_token1,
  [aux_sym__au_pattern_token2] = aux_sym__au_pattern_token2,
  [aux_sym__bang_filter_command_argument_token1] = aux_sym__bang_filter_command_argument_token1,
  [anon_sym_BSLASH] = anon_sym_BSLASH,
  [aux_sym__bang_filter_command_argument_token2] = aux_sym__bang_filter_command_argument_token2,
  [aux_sym__bang_filter_command_argument_token3] = aux_sym__bang_filter_command_argument_token3,
  [aux_sym__bang_filter_command_argument_token4] = aux_sym__bang_filter_command_argument_token4,
  [aux_sym_argument_token1] = sym_identifier,
  [aux_sym_argument_token2] = aux_sym_argument_token2,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_LBRACE2] = anon_sym_LBRACE,
  [aux_sym_identifier_token1] = aux_sym_identifier_token1,
  [aux_sym_identifier_token2] = aux_sym_identifier_token2,
  [aux_sym__immediate_identifier_token1] = aux_sym__immediate_identifier_token1,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_DOT_EQ] = anon_sym_DOT_EQ,
  [anon_sym_DOT_DOT_EQ] = anon_sym_DOT_DOT_EQ,
  [anon_sym_EQ_LT_LT] = anon_sym_EQ_LT_LT,
  [anon_sym_eval] = anon_sym_eval,
  [aux_sym_option_name_token1] = aux_sym_option_name_token1,
  [anon_sym_t_] = anon_sym_t_,
  [aux_sym_option_name_token2] = aux_sym_option_name_token2,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_vi] = anon_sym_vi,
  [anon_sym_vim] = anon_sym_vim,
  [anon_sym_all] = anon_sym_all,
  [anon_sym_all_AMP] = anon_sym_all_AMP,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_EQ2] = anon_sym_EQ,
  [anon_sym_COLON2] = anon_sym_COLON,
  [anon_sym_PLUS_EQ2] = anon_sym_PLUS_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_DASH_EQ2] = anon_sym_DASH_EQ,
  [sym_set_value] = sym_set_value,
  [anon_sym_SPACE] = anon_sym_SPACE,
  [anon_sym_POUND_BANG] = anon_sym_POUND_BANG,
  [aux_sym_shebang_token1] = aux_sym_shebang_token1,
  [aux_sym_command_argument_token1] = aux_sym_command_argument_token1,
  [anon_sym_dict] = anon_sym_dict,
  [anon_sym_range] = anon_sym_range,
  [anon_sym_abort] = anon_sym_abort,
  [anon_sym_closure] = anon_sym_closure,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [sym_spread] = sym_spread,
  [sym__printable] = sym__printable,
  [sym_mark] = sym_mark,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_SLASH2] = anon_sym_SLASH,
  [anon_sym_QMARK2] = anon_sym_QMARK,
  [anon_sym_DOT2] = anon_sym_DOT,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [anon_sym_BSLASH_SLASH] = anon_sym_BSLASH_SLASH,
  [anon_sym_BSLASH_QMARK] = anon_sym_BSLASH_QMARK,
  [anon_sym_BSLASH_AMP] = anon_sym_BSLASH_AMP,
  [anon_sym_LTbuffer_GT] = anon_sym_LTbuffer_GT,
  [anon_sym_LTnowait_GT] = anon_sym_LTnowait_GT,
  [anon_sym_LTsilent_GT] = anon_sym_LTsilent_GT,
  [anon_sym_LTunique_GT] = anon_sym_LTunique_GT,
  [anon_sym_LTscript_GT] = anon_sym_LTscript_GT,
  [anon_sym_LTexpr_GT] = anon_sym_LTexpr_GT,
  [sym__keycode_modifier] = sym__keycode_modifier,
  [aux_sym__keycode_in_token1] = aux_sym__keycode_in_token1,
  [aux_sym__keycode_in_token2] = aux_sym__keycode_in_token2,
  [aux_sym__keycode_in_token3] = aux_sym__keycode_in_token3,
  [aux_sym__keycode_in_token4] = aux_sym__keycode_in_token4,
  [aux_sym__keycode_in_token5] = aux_sym__keycode_in_token5,
  [aux_sym__keycode_in_token6] = aux_sym__keycode_in_token6,
  [aux_sym__keycode_in_token7] = aux_sym__keycode_in_token7,
  [aux_sym__keycode_in_token8] = aux_sym__keycode_in_token8,
  [aux_sym__keycode_in_token9] = aux_sym__keycode_in_token9,
  [aux_sym__keycode_in_token10] = aux_sym__keycode_in_token10,
  [aux_sym__keycode_in_token11] = aux_sym__keycode_in_token11,
  [aux_sym__keycode_in_token12] = aux_sym__keycode_in_token12,
  [aux_sym__keycode_in_token13] = aux_sym__keycode_in_token13,
  [aux_sym__keycode_in_token14] = aux_sym__keycode_in_token14,
  [aux_sym__keycode_in_token15] = aux_sym__keycode_in_token15,
  [aux_sym__keycode_in_token16] = aux_sym__keycode_in_token16,
  [aux_sym__keycode_in_token17] = aux_sym__keycode_in_token17,
  [aux_sym__keycode_in_token18] = aux_sym__keycode_in_token18,
  [aux_sym__keycode_in_token19] = aux_sym__keycode_in_token19,
  [aux_sym__keycode_in_token20] = aux_sym__keycode_in_token20,
  [aux_sym__keycode_in_token21] = aux_sym__keycode_in_token21,
  [aux_sym__keycode_in_token22] = aux_sym__keycode_in_token22,
  [aux_sym__keycode_in_token23] = aux_sym__keycode_in_token23,
  [aux_sym__keycode_in_token24] = aux_sym__keycode_in_token24,
  [aux_sym__keycode_in_token25] = aux_sym__keycode_in_token25,
  [aux_sym__keycode_in_token26] = aux_sym__keycode_in_token26,
  [aux_sym__keycode_in_token27] = aux_sym__keycode_in_token27,
  [aux_sym__keycode_in_token28] = aux_sym__keycode_in_token28,
  [aux_sym__keycode_in_token29] = aux_sym__keycode_in_token29,
  [aux_sym__keycode_in_token30] = aux_sym__keycode_in_token30,
  [aux_sym__keycode_in_token31] = aux_sym__keycode_in_token31,
  [aux_sym__keycode_in_token32] = aux_sym__keycode_in_token32,
  [aux_sym__keycode_in_token33] = aux_sym__keycode_in_token33,
  [aux_sym__keycode_in_token34] = aux_sym__keycode_in_token34,
  [aux_sym__keycode_in_token35] = aux_sym__keycode_in_token35,
  [aux_sym__keycode_in_token36] = aux_sym__keycode_in_token36,
  [aux_sym__keycode_in_token37] = aux_sym__keycode_in_token37,
  [aux_sym__keycode_in_token38] = aux_sym__keycode_in_token38,
  [aux_sym__keycode_in_token39] = aux_sym__keycode_in_token39,
  [aux_sym__keycode_in_token40] = aux_sym__keycode_in_token40,
  [aux_sym__keycode_in_token41] = aux_sym__keycode_in_token41,
  [aux_sym__keycode_in_token42] = aux_sym__keycode_in_token42,
  [aux_sym__keycode_in_token43] = aux_sym__keycode_in_token43,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_LT2] = anon_sym_LT,
  [anon_sym_BSLASH2] = anon_sym_BSLASH,
  [aux_sym__map_lhs_token1] = aux_sym__map_lhs_token1,
  [aux_sym__map_rhs_statement_token1] = sym_keycode,
  [anon_sym_BSLASH_PIPE] = anon_sym_BSLASH_PIPE,
  [aux_sym__map_rhs_statement_token2] = sym_keycode,
  [aux_sym__map_rhs_statement_token3] = sym_keycode,
  [aux_sym__map_rhs_token1] = aux_sym__map_rhs_token1,
  [aux_sym__map_rhs_token2] = aux_sym__map_rhs_token2,
  [anon_sym_icon] = anon_sym_icon,
  [anon_sym_linehl] = anon_sym_linehl,
  [anon_sym_numhl] = anon_sym_numhl,
  [anon_sym_text] = anon_sym_text,
  [anon_sym_texthl] = anon_sym_texthl,
  [anon_sym_culhl] = anon_sym_culhl,
  [anon_sym_define] = anon_sym_define,
  [anon_sym_undefine] = anon_sym_undefine,
  [anon_sym_list] = anon_sym_list,
  [anon_sym_line] = anon_sym_line,
  [anon_sym_name] = anon_sym_name,
  [anon_sym_buffer] = anon_sym_buffer,
  [anon_sym_group] = anon_sym_group,
  [anon_sym_priority] = anon_sym_priority,
  [anon_sym_file] = anon_sym_file,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_place] = anon_sym_place,
  [anon_sym_STAR2] = anon_sym_STAR,
  [anon_sym_unplace] = anon_sym_unplace,
  [anon_sym_jump] = anon_sym_jump,
  [anon_sym_POUND] = anon_sym_POUND,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_GT2] = anon_sym_GT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_EQ_TILDE] = anon_sym_EQ_TILDE,
  [anon_sym_BANG_TILDE] = anon_sym_BANG_TILDE,
  [anon_sym_is] = anon_sym_is,
  [anon_sym_isnot] = anon_sym_isnot,
  [anon_sym_BANG2] = anon_sym_BANG,
  [sym_float_literal] = sym_float_literal,
  [sym_integer_literal] = sym_integer_literal,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_LPAREN2] = anon_sym_LPAREN,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [aux_sym_filename_token1] = aux_sym_filename_token1,
  [aux_sym_filename_token2] = aux_sym_filename_token2,
  [aux_sym_filename_token3] = aux_sym_filename_token3,
  [aux_sym_filename_token4] = aux_sym_filename_token4,
  [aux_sym_filename_token5] = aux_sym_filename_token5,
  [aux_sym_filename_token6] = aux_sym_filename_token6,
  [aux_sym_filename_token7] = aux_sym_filename_token7,
  [aux_sym_filename_token8] = aux_sym_filename_token8,
  [aux_sym_pattern_multi_token1] = aux_sym_pattern_multi_token1,
  [aux_sym_pattern_multi_token2] = aux_sym_pattern_multi_token2,
  [aux_sym_pattern_multi_token3] = aux_sym_pattern_multi_token3,
  [aux_sym__pattern_ordinary_atom_token1] = aux_sym__pattern_ordinary_atom_token1,
  [aux_sym__pattern_ordinary_atom_token2] = aux_sym__pattern_ordinary_atom_token2,
  [anon_sym_BSLASH_LPAREN] = anon_sym_BSLASH_LPAREN,
  [anon_sym_BSLASH_RPAREN] = anon_sym_BSLASH_RPAREN,
  [anon_sym_BSLASH_PERCENT_LPAREN] = anon_sym_BSLASH_PERCENT_LPAREN,
  [anon_sym_BSLASHz_LPAREN] = anon_sym_BSLASHz_LPAREN,
  [sym_register] = sym_register,
  [sym_literal_key] = sym_literal_key,
  [anon_sym_POUND_LBRACE] = anon_sym_POUND_LBRACE,
  [anon_sym_keep] = anon_sym_keep,
  [anon_sym_drop] = anon_sym_drop,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_ff] = anon_sym_ff,
  [anon_sym_fileformat] = anon_sym_fileformat,
  [anon_sym_enc] = anon_sym_enc,
  [anon_sym_encoding] = anon_sym_encoding,
  [anon_sym_bin] = anon_sym_bin,
  [anon_sym_binary] = anon_sym_binary,
  [anon_sym_nobin] = anon_sym_nobin,
  [anon_sym_nobinary] = anon_sym_nobinary,
  [anon_sym_bad] = anon_sym_bad,
  [anon_sym_edit] = anon_sym_edit,
  [aux_sym__plus_cmd_arg_token1] = aux_sym__plus_cmd_arg_token1,
  [sym_au_event] = sym_au_event,
  [aux_sym__autocmd_pattern_token1] = sym_pattern,
  [sym_au_once] = sym_au_once,
  [sym_au_nested] = sym_au_nested,
  [sym_command_name] = sym_command_name,
  [anon_sym_arglist] = anon_sym_arglist,
  [anon_sym_augroup] = anon_sym_augroup,
  [anon_sym_buffer2] = anon_sym_buffer,
  [anon_sym_behave] = anon_sym_behave,
  [anon_sym_color] = anon_sym_color,
  [anon_sym_command] = anon_sym_command,
  [anon_sym_compiler] = anon_sym_compiler,
  [anon_sym_dir] = anon_sym_dir,
  [anon_sym_environment] = anon_sym_environment,
  [anon_sym_even] = anon_sym_even,
  [anon_sym_expression] = anon_sym_expression,
  [anon_sym_file2] = anon_sym_file,
  [anon_sym_file_in_path] = anon_sym_file_in_path,
  [anon_sym_filetype] = anon_sym_filetype,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_help] = anon_sym_help,
  [anon_sym_highlight] = anon_sym_highlight,
  [anon_sym_history] = anon_sym_history,
  [anon_sym_local] = anon_sym_local,
  [anon_sym_lua] = anon_sym_lua,
  [anon_sym_mapclear] = anon_sym_mapclear,
  [anon_sym_mapping] = anon_sym_mapping,
  [anon_sym_menu] = anon_sym_menu,
  [anon_sym_messages] = anon_sym_messages,
  [anon_sym_option] = anon_sym_option,
  [anon_sym_packadd] = anon_sym_packadd,
  [anon_sym_shellcmd] = anon_sym_shellcmd,
  [anon_sym_sign] = anon_sym_sign,
  [anon_sym_syntax] = anon_sym_syntax,
  [anon_sym_syntime] = anon_sym_syntime,
  [anon_sym_tag] = anon_sym_tag,
  [anon_sym_tag_listfiles] = anon_sym_tag_listfiles,
  [anon_sym_user] = anon_sym_user,
  [anon_sym_var] = anon_sym_var,
  [anon_sym_custom] = anon_sym_custom,
  [anon_sym_COMMA2] = anon_sym_COMMA,
  [anon_sym_customlist] = anon_sym_customlist,
  [anon_sym_lines] = anon_sym_lines,
  [anon_sym_arguments] = anon_sym_arguments,
  [anon_sym_buffers] = anon_sym_buffers,
  [anon_sym_loaded_buffers] = anon_sym_loaded_buffers,
  [anon_sym_windows] = anon_sym_windows,
  [anon_sym_tabs] = anon_sym_tabs,
  [anon_sym_quickfix] = anon_sym_quickfix,
  [anon_sym_other] = anon_sym_other,
  [aux_sym__command_attribute_nargs_value_token1] = sym_integer_literal,
  [aux_sym__command_attribute_nargs_value_token2] = sym_pattern_multi,
  [anon_sym_PERCENT2] = sym_pattern_multi,
  [anon_sym_DASHnargs] = anon_sym_DASHnargs,
  [anon_sym_DASHcomplete] = anon_sym_DASHcomplete,
  [anon_sym_DASHrange] = anon_sym_DASHrange,
  [anon_sym_DASHcount] = anon_sym_DASHcount,
  [anon_sym_DASHaddr] = anon_sym_DASHaddr,
  [anon_sym_DASHbang] = anon_sym_DASHbang,
  [anon_sym_DASHbar] = anon_sym_DASHbar,
  [anon_sym_DASHregister] = anon_sym_DASHregister,
  [anon_sym_DASHbuffer] = anon_sym_DASHbuffer,
  [anon_sym_DASHkeepscript] = anon_sym_DASHkeepscript,
  [aux_sym_command_statement_token1] = aux_sym_command_statement_token1,
  [sym_hl_group] = sym_hl_group,
  [anon_sym_link] = anon_sym_link,
  [anon_sym_clear] = anon_sym_clear,
  [anon_sym_NONE] = sym_hl_group,
  [anon_sym_NONE2] = anon_sym_NONE,
  [anon_sym_bold] = anon_sym_bold,
  [anon_sym_underline] = anon_sym_underline,
  [anon_sym_undercurl] = anon_sym_undercurl,
  [anon_sym_underdouble] = anon_sym_underdouble,
  [anon_sym_underdotted] = anon_sym_underdotted,
  [anon_sym_underdashed] = anon_sym_underdashed,
  [anon_sym_strikethrough] = anon_sym_strikethrough,
  [anon_sym_reverse] = anon_sym_reverse,
  [anon_sym_inverse] = anon_sym_inverse,
  [anon_sym_italic] = anon_sym_italic,
  [anon_sym_standout] = anon_sym_standout,
  [anon_sym_nocombine] = anon_sym_nocombine,
  [anon_sym_term] = anon_sym_term,
  [anon_sym_cterm] = anon_sym_cterm,
  [aux_sym__hl_term_list_token1] = aux_sym__hl_term_list_token1,
  [anon_sym_start] = anon_sym_start,
  [anon_sym_stop] = anon_sym_stop,
  [sym__hl_color_nr] = sym__hl_color_nr,
  [anon_sym_ctermfg] = anon_sym_ctermfg,
  [anon_sym_ctermbg] = anon_sym_ctermbg,
  [anon_sym_gui] = anon_sym_gui,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [aux_sym__hl_quoted_name_token1] = aux_sym__hl_quoted_name_token1,
  [anon_sym_SQUOTE2] = anon_sym_SQUOTE,
  [anon_sym_bg] = anon_sym_bg,
  [anon_sym_background] = anon_sym_background,
  [anon_sym_fg] = anon_sym_fg,
  [anon_sym_foreground] = anon_sym_foreground,
  [aux_sym_color_token1] = aux_sym_color_token1,
  [aux_sym_color_token2] = aux_sym_color_token2,
  [anon_sym_guifg] = anon_sym_guifg,
  [anon_sym_guibg] = anon_sym_guibg,
  [anon_sym_guisp] = anon_sym_guisp,
  [aux_sym_font_token1] = aux_sym_font_token1,
  [anon_sym_font] = anon_sym_font,
  [anon_sym_blend] = anon_sym_blend,
  [anon_sym_enable] = anon_sym_enable,
  [anon_sym_reset] = anon_sym_reset,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_match] = anon_sym_match,
  [anon_sym_ignore] = anon_sym_ignore,
  [anon_sym_spell] = anon_sym_spell,
  [anon_sym_toplevel] = anon_sym_toplevel,
  [anon_sym_notoplevel] = anon_sym_notoplevel,
  [anon_sym_foldlevel] = anon_sym_foldlevel,
  [anon_sym_minimum] = anon_sym_minimum,
  [anon_sym_iskeyword] = anon_sym_iskeyword,
  [aux_sym__syn_iskeyword_token1] = aux_sym__syn_iskeyword_token1,
  [anon_sym_conceal] = anon_sym_conceal,
  [anon_sym_cchar] = anon_sym_cchar,
  [anon_sym_contained] = anon_sym_contained,
  [anon_sym_containedin] = anon_sym_containedin,
  [anon_sym_nextgroup] = anon_sym_nextgroup,
  [anon_sym_transparent] = anon_sym_transparent,
  [anon_sym_skipwhite] = anon_sym_skipwhite,
  [anon_sym_skipnl] = anon_sym_skipnl,
  [anon_sym_skipempty] = anon_sym_skipempty,
  [anon_sym_contains] = anon_sym_contains,
  [anon_sym_fold] = anon_sym_fold,
  [anon_sym_display] = anon_sym_display,
  [anon_sym_extend] = anon_sym_extend,
  [anon_sym_keepend] = anon_sym_keepend,
  [anon_sym_excludenl] = anon_sym_excludenl,
  [anon_sym_matchgroup] = anon_sym_matchgroup,
  [anon_sym_oneline] = anon_sym_oneline,
  [anon_sym_concealends] = anon_sym_concealends,
  [anon_sym_add] = anon_sym_add,
  [anon_sym_remove] = anon_sym_remove,
  [anon_sym_ms] = anon_sym_ms,
  [anon_sym_me] = anon_sym_me,
  [anon_sym_hs] = anon_sym_hs,
  [anon_sym_he] = anon_sym_he,
  [anon_sym_rs] = anon_sym_rs,
  [anon_sym_re] = anon_sym_re,
  [anon_sym_lc] = anon_sym_lc,
  [aux_sym__syn_pattern_offset_token1] = aux_sym__syn_pattern_offset_token1,
  [aux_sym__syn_pattern_offset_token2] = aux_sym__syn_pattern_offset_token2,
  [anon_sym_keyword] = anon_sym_keyword,
  [aux_sym__syn_keyword_token1] = sym_keyword,
  [anon_sym_skip] = anon_sym_skip,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_region] = anon_sym_region,
  [anon_sym_cluster] = anon_sym_cluster,
  [anon_sym_include] = anon_sym_include,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_minlines] = anon_sym_minlines,
  [anon_sym_maxlines] = anon_sym_maxlines,
  [aux_sym__syn_sync_lines_token1] = aux_sym__syn_sync_lines_token1,
  [anon_sym_sync] = anon_sym_sync,
  [anon_sym_linebreaks] = anon_sym_linebreaks,
  [anon_sym_fromstart] = anon_sym_fromstart,
  [anon_sym_ccomment] = anon_sym_ccomment,
  [anon_sym_lines2] = anon_sym_lines,
  [anon_sym_grouphere] = anon_sym_grouphere,
  [anon_sym_groupthere] = anon_sym_groupthere,
  [anon_sym_linecont] = anon_sym_linecont,
  [sym__no] = sym__no,
  [sym__inv] = sym__inv,
  [sym__newline_or_pipe] = sym__newline_or_pipe,
  [sym__line_continuation] = sym__line_continuation,
  [sym__script_heredoc_marker] = sym__script_heredoc_marker,
  [sym__let_heredoc_marker] = sym__script_heredoc_marker,
  [sym__heredoc_end] = sym__heredoc_end,
  [sym__separator_first] = sym__separator_first,
  [sym__separator] = sym__separator,
  [sym__scope_dict] = sym__scope_dict,
  [sym_scope] = sym_scope,
  [sym_string_literal] = sym_string_literal,
  [sym_comment] = sym_comment,
  [sym_line_continuation_comment] = sym_line_continuation_comment,
  [sym__bang_filter] = sym__bang_filter,
  [sym__function] = anon_sym_function,
  [sym__endfunction] = sym__endfunction,
  [sym__for] = sym__for,
  [sym__endfor] = sym__endfor,
  [sym__while] = sym__while,
  [sym__endwhile] = sym__endwhile,
  [sym__if] = sym__if,
  [sym__elseif] = sym__elseif,
  [sym__else] = sym__else,
  [sym__endif] = sym__endif,
  [sym__try] = sym__try,
  [sym__catch] = sym__catch,
  [sym__cnext] = sym__cnext,
  [sym__cprevious] = sym__cprevious,
  [sym__cNext] = sym__cNext,
  [sym__finally] = sym__finally,
  [sym__endtry] = sym__endtry,
  [sym__const] = sym__const,
  [sym__normal] = sym__normal,
  [sym__return] = sym__return,
  [sym__perl] = sym__perl,
  [sym__lua] = anon_sym_lua,
  [sym__ruby] = sym__ruby,
  [sym__python] = sym__python,
  [sym__throw] = sym__throw,
  [sym__execute] = sym__execute,
  [sym__autocmd] = sym__autocmd,
  [sym__silent] = sym__silent,
  [sym__echo] = sym__echo,
  [sym__echon] = sym__echon,
  [sym__echohl] = sym__echohl,
  [sym__echomsg] = sym__echomsg,
  [sym__echoerr] = sym__echoerr,
  [sym__map] = sym__map,
  [sym__nmap] = sym__nmap,
  [sym__vmap] = sym__vmap,
  [sym__xmap] = sym__xmap,
  [sym__smap] = sym__smap,
  [sym__omap] = sym__omap,
  [sym__imap] = sym__imap,
  [sym__lmap] = sym__lmap,
  [sym__cmap] = sym__cmap,
  [sym__tmap] = sym__tmap,
  [sym__noremap] = sym__noremap,
  [sym__nnoremap] = sym__nnoremap,
  [sym__vnoremap] = sym__vnoremap,
  [sym__xnoremap] = sym__xnoremap,
  [sym__snoremap] = sym__snoremap,
  [sym__onoremap] = sym__onoremap,
  [sym__inoremap] = sym__inoremap,
  [sym__lnoremap] = sym__lnoremap,
  [sym__cnoremap] = sym__cnoremap,
  [sym__tnoremap] = sym__tnoremap,
  [sym__augroup] = anon_sym_augroup,
  [sym__highlight] = anon_sym_highlight,
  [sym__default] = anon_sym_default,
  [sym__syntax] = anon_sym_syntax,
  [sym__set] = sym__set,
  [sym__setlocal] = sym__setlocal,
  [sym__setfiletype] = sym__setfiletype,
  [sym__browse] = sym__browse,
  [sym__options] = sym__options,
  [sym__startinsert] = sym__startinsert,
  [sym__stopinsert] = sym__stopinsert,
  [sym__scriptencoding] = sym__scriptencoding,
  [sym__source] = sym__source,
  [sym__global] = sym__global,
  [sym__colorscheme] = sym__colorscheme,
  [sym__command] = anon_sym_command,
  [sym__comclear] = sym__comclear,
  [sym__delcommand] = sym__delcommand,
  [sym__runtime] = sym__runtime,
  [sym__wincmd] = sym__wincmd,
  [sym__sign] = anon_sym_sign,
  [sym__filetype] = anon_sym_filetype,
  [sym__let] = sym__let,
  [sym__unlet] = sym__unlet,
  [sym__call] = sym__call,
  [sym__break] = sym__break,
  [sym__continue] = sym__continue,
  [sym__tab] = sym__tab,
  [sym__vertical] = sym__vertical,
  [sym__leftabove] = sym__leftabove,
  [sym__aboveleft] = sym__aboveleft,
  [sym__rightbelow] = sym__rightbelow,
  [sym__belowright] = sym__belowright,
  [sym__topleft] = sym__topleft,
  [sym__botright] = sym__botright,
  [sym__edit] = anon_sym_edit,
  [sym__enew] = sym__enew,
  [sym__find] = sym__find,
  [sym__ex] = sym__ex,
  [sym__visual] = sym__visual,
  [sym__view] = sym__view,
  [sym__eval] = anon_sym_eval,
  [sym__substitute] = sym__substitute,
  [sym_unknown_command_name] = sym_unknown_command_name,
  [sym_script_file] = sym_script_file,
  [sym__cmd_separator] = sym__cmd_separator,
  [aux_sym__separated_statements] = aux_sym__separated_statements,
  [sym__statement] = sym__statement,
  [sym_unknown_builtin_statement] = sym_unknown_builtin_statement,
  [sym_return_statement] = sym_return_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_scope_dict] = sym_scope_dict,
  [sym_normal_statement] = sym_normal_statement,
  [sym__filetype_immediate] = sym__filetype_immediate,
  [sym_filetypes] = sym_filetypes,
  [sym_setfiletype_statement] = sym_setfiletype_statement,
  [sym_options_statement] = sym_options_statement,
  [sym_startinsert_statement] = sym_startinsert_statement,
  [sym_stopinsert_statement] = sym_stopinsert_statement,
  [sym__immediate_file_format] = sym__immediate_file_format,
  [sym_encoding] = sym_encoding,
  [sym__immediate_encoding] = sym__immediate_encoding,
  [sym_scriptencoding_statement] = sym_scriptencoding_statement,
  [sym_cnext_statement] = sym_cnext_statement,
  [sym_cprevious_statement] = sym_cprevious_statement,
  [sym__runtime_where] = sym__runtime_where,
  [sym_runtime_statement] = sym_runtime_statement,
  [sym_wincmd_statement] = sym_wincmd_statement,
  [sym_source_statement] = sym_source_statement,
  [sym_global_statement] = sym_global_statement,
  [sym__filetype_state] = sym__filetype_state,
  [sym__filetype_enable] = sym__filetype_enable,
  [sym__filetype_detect] = sym__filetype_detect,
  [sym__filetype_plugin] = sym__filetype_plugin,
  [sym__filetype_indent] = sym__filetype_indent,
  [sym_filetype_statement] = sym_filetype_statement,
  [sym_colorscheme_statement] = sym_colorscheme_statement,
  [sym_lua_statement] = sym_lua_statement,
  [sym_ruby_statement] = sym_ruby_statement,
  [sym_python_statement] = sym_python_statement,
  [sym_perl_statement] = sym_perl_statement,
  [sym_script] = sym_script,
  [sym_for_loop] = sym_for_loop,
  [sym_while_loop] = sym_while_loop,
  [sym_if_statement] = sym_if_statement,
  [sym_elseif_statement] = sym_elseif_statement,
  [sym_else_statement] = sym_else_statement,
  [sym_try_statement] = sym_try_statement,
  [sym__au_pattern] = sym_pattern,
  [sym_catch_statement] = sym_catch_statement,
  [sym_finally_statement] = sym_finally_statement,
  [sym_throw_statement] = sym_throw_statement,
  [sym__bang_filter_bangs] = sym__bang_filter_bangs,
  [sym__bang_filter_command_argument] = sym_command_argument,
  [sym__bang_filter_command] = aux_sym_command_statement_token1,
  [sym_bang_filter_statement] = sym_bang_filter_statement,
  [sym_scoped_identifier] = sym_scoped_identifier,
  [sym_argument] = sym_argument,
  [sym__curly_braces_name_expression] = sym__curly_braces_name_expression,
  [sym__immediate_curly_braces_name_expression] = sym__curly_braces_name_expression,
  [sym_identifier] = sym_identifier,
  [sym__immediate_identifier] = sym_identifier,
  [sym__ident] = sym__ident,
  [sym__let_operator] = sym__let_operator,
  [sym__assignment_variable] = sym__assignment_variable,
  [sym__let_assignment] = sym__let_assignment,
  [sym_let_statement] = sym_let_statement,
  [sym__const_assignment] = sym__const_assignment,
  [sym_const_statement] = sym_const_statement,
  [sym__let_heredoc] = sym__let_heredoc,
  [sym__let_heredoc_parameter] = sym__let_heredoc_parameter,
  [sym_option_name] = sym_option_name,
  [sym_no_option] = sym_no_option,
  [sym_inv_option] = sym_inv_option,
  [sym_default_option] = sym_default_option,
  [sym__set_option] = sym__set_option,
  [sym__set_operator] = sym__set_operator,
  [sym__set_rhs] = sym__set_rhs,
  [sym_set_item] = sym_set_item,
  [sym_set_statement] = sym_set_statement,
  [sym_setlocal_statement] = sym_setlocal_statement,
  [sym_unlet_statement] = sym_unlet_statement,
  [sym_call_statement] = sym_call_statement,
  [sym_echo_statement] = sym_echo_statement,
  [sym_echon_statement] = sym_echon_statement,
  [sym_echohl_statement] = sym_echohl_statement,
  [sym_echomsg_statement] = sym_echomsg_statement,
  [sym_echoerr_statement] = sym_echoerr_statement,
  [sym_execute_statement] = sym_execute_statement,
  [sym_silent_statement] = sym_silent_statement,
  [sym_tab_statement] = sym_tab_statement,
  [sym_vertical_statement] = sym_vertical_statement,
  [sym_topleft_statement] = sym_topleft_statement,
  [sym_botright_statement] = sym_botright_statement,
  [sym_aboveleft_statement] = sym_aboveleft_statement,
  [sym_belowright_statement] = sym_belowright_statement,
  [sym_user_command] = sym_user_command,
  [sym_shebang] = sym_shebang,
  [sym_command_argument] = sym_command_argument,
  [sym_function_definition] = sym_function_definition,
  [sym_function_declaration] = sym_function_declaration,
  [sym_parameters] = sym_parameters,
  [sym_default_parameter] = sym_default_parameter,
  [sym_bang] = sym_bang,
  [sym_range_statement] = sym_range_statement,
  [sym__range] = sym__range,
  [sym__range_explicit] = sym__range_explicit,
  [sym__range_marker] = sym__range_marker,
  [sym__complete_range] = sym__complete_range,
  [sym__complete_range_explicit] = sym__complete_range_explicit,
  [sym__complete_range_marker] = sym__complete_range_marker,
  [sym_current_line] = sym_current_line,
  [sym_next_line] = sym_next_line,
  [sym_last_line] = sym_last_line,
  [sym_previous_pattern] = sym_previous_pattern,
  [sym_register_statement] = sym_register_statement,
  [sym_map_statement] = sym_map_statement,
  [sym__map_definition] = sym__map_definition,
  [sym__keycode_in] = sym__keycode_in,
  [sym__immediate_keycode] = sym__immediate_keycode,
  [sym_keycode] = sym_keycode,
  [sym__map_lhs] = sym__map_lhs,
  [sym__map_rhs_statement] = sym__map_rhs_statement,
  [sym__map_rhs] = sym__map_lhs,
  [sym__sign_name] = sym__sign_name,
  [sym__sign_define_arg_text] = sym__sign_define_arg_text,
  [sym__sign_define_argument] = sym__sign_define_argument,
  [sym__sign_define] = sym__sign_define,
  [sym__sign_undefine] = sym__sign_undefine,
  [sym__sign_list] = sym__sign_list,
  [sym__sign_place_place_argument] = sym__sign_define_argument,
  [sym__sign_place_place] = sym__sign_place_place,
  [sym__sign_place_list_argument] = sym__sign_define_argument,
  [aux_sym__sign_place_list] = aux_sym__sign_place_list,
  [sym__sign_place] = sym__sign_place,
  [sym__sign_unplace_cursor_argument] = sym__sign_define_argument,
  [sym__sign_unplace_cursor] = sym__sign_unplace_cursor,
  [sym__sign_unplace_id_argument] = sym__sign_define_argument,
  [sym__sign_unplace_id] = sym__sign_unplace_id,
  [sym__sign_unplace] = sym__sign_unplace,
  [sym__sign_jump_argument] = sym__sign_define_argument,
  [sym__sign_jump] = sym__sign_jump,
  [sym_sign_statement] = sym_sign_statement,
  [sym__variable] = sym__variable,
  [sym__expression] = sym__expression,
  [sym_ternary_expression] = sym_ternary_expression,
  [sym_match_case] = sym_match_case,
  [sym_binary_operation] = sym_binary_operation,
  [sym_unary_operation] = sym_unary_operation,
  [sym_list] = sym_list,
  [sym_list_assignment] = sym_list_assignment,
  [sym_index_expression] = sym_index_expression,
  [sym_slice_expression] = sym_slice_expression,
  [sym_field_expression] = sym_field_expression,
  [sym_call_expression] = sym_call_expression,
  [sym_eval_statement] = sym_eval_statement,
  [sym_substitute_statement] = sym_substitute_statement,
  [sym__method_call_expression] = sym_call_expression,
  [sym_method_expression] = sym_method_expression,
  [sym_filename] = sym_filename,
  [sym_pattern_multi] = sym_pattern_multi,
  [aux_sym__pattern_ordinary_atom] = aux_sym__pattern_ordinary_atom,
  [sym__pattern_atom] = sym__pattern_atom,
  [sym__pattern_piece] = sym__pattern_piece,
  [aux_sym__pattern_concat] = aux_sym__pattern_concat,
  [sym__pattern_branch] = sym__pattern_branch,
  [sym_pattern] = sym_pattern,
  [sym_env_variable] = sym_env_variable,
  [sym_option] = sym_option,
  [sym_dictionnary_entry] = sym_dictionnary_entry,
  [sym_dictionnary] = sym_dictionnary,
  [sym__literal_dictionary_entry] = sym__literal_dictionary_entry,
  [sym_literal_dictionary] = sym_literal_dictionary,
  [sym_lambda_expression] = sym_lambda_expression,
  [sym__immediate_lambda_expression] = sym_lambda_expression,
  [sym__plus_plus_opt_bad] = sym__plus_plus_opt_bad,
  [sym_plus_plus_opt] = sym_plus_plus_opt,
  [aux_sym__plus_cmd_arg] = aux_sym__plus_cmd_arg,
  [sym__plus_cmd_number] = sym__plus_cmd_number,
  [sym__plus_cmd_command] = sym__plus_cmd_command,
  [sym__plus_cmd_pattern] = sym__plus_cmd_pattern,
  [sym_plus_cmd] = sym_plus_cmd,
  [sym_au_event_list] = sym_au_event_list,
  [sym__augroup_name] = sym__augroup_name,
  [sym__autocmd_pattern] = sym__autocmd_pattern,
  [sym__autocmd_command] = sym__autocmd_command,
  [sym__autocmd_define] = sym__autocmd_define,
  [sym__autocmd_remove] = sym__autocmd_remove,
  [sym__autocmd_list] = sym__autocmd_list,
  [sym_autocmd_statement] = sym_autocmd_statement,
  [sym_augroup_statement] = sym_augroup_statement,
  [sym__command_attribute_completion_behavior] = sym__command_attribute_completion_behavior,
  [sym__command_attribute_address_behavior] = sym__command_attribute_completion_behavior,
  [sym__command_attribute_nargs_value] = sym__command_attribute_nargs_value,
  [sym__command_attribute_range_value] = sym__command_attribute_range_value,
  [sym_command_attribute] = sym_command_attribute,
  [sym_command_statement] = sym_command_statement,
  [sym_comclear_statement] = sym_comclear_statement,
  [sym_delcommand_statement] = sym_delcommand_statement,
  [sym__hl_body_link] = sym__hl_body_link,
  [sym__hl_body_clear] = sym__hl_body_clear,
  [sym__hl_body_none] = sym__hl_body_none,
  [sym__hl_none] = sym__hl_none,
  [sym__hl_attr_list] = sym__hl_attr_list,
  [sym__hl_key_cterm] = sym__hl_key_cterm,
  [aux_sym__hl_term_list] = aux_sym__hl_term_list,
  [sym__hl_key_start_stop] = sym__hl_key_start_stop,
  [sym__hl_key_ctermfg_ctermbg] = sym__hl_key_ctermfg_ctermbg,
  [sym__hl_key_gui] = sym__hl_key_gui,
  [sym__hl_quoted_name] = sym__hl_quoted_name,
  [sym_color] = sym_color,
  [sym__hl_key_gui_color] = sym__hl_key_gui_color,
  [sym_font] = sym_font,
  [sym__hl_key_font] = sym__hl_key_font,
  [sym__hl_key_blend] = sym__hl_key_blend,
  [sym_hl_attribute] = sym_hl_attribute,
  [sym__hl_body_keys] = sym__hl_body_keys,
  [sym__hl_body] = sym__hl_body,
  [sym_highlight_statement] = sym_highlight_statement,
  [sym__syn_enable] = sym__syn_enable,
  [sym__syn_case] = sym__syn_case,
  [sym__syn_spell] = sym__syn_spell,
  [sym__syn_foldlevel] = sym__syn_foldlevel,
  [sym__syn_iskeyword] = sym__syn_iskeyword,
  [sym__syn_conceal] = sym__syn_conceal,
  [sym__syn_hl_pattern] = sym__syn_hl_pattern,
  [sym_hl_groups] = sym_hl_groups,
  [sym__syn_arguments_keyword] = sym__syn_arguments_keyword,
  [sym__syn_arguments_match] = sym__syn_arguments_match,
  [sym__syn_arguments_region] = sym__syn_arguments_region,
  [sym__syn_arguments_cluster] = sym__syn_arguments_region,
  [sym__syn_pattern_offset] = sym__syn_pattern_offset,
  [sym__syn_keyword] = sym__syn_keyword,
  [sym__syn_match] = sym__syn_match,
  [sym__syn_region_start] = sym__syn_arguments_region,
  [sym__syn_region_skip] = sym__syn_arguments_region,
  [sym__syn_region_end] = sym__syn_arguments_region,
  [sym__syn_region] = sym__syn_region,
  [sym__syn_cluster] = sym__syn_cluster,
  [sym__syn_include] = sym__syn_include,
  [sym__syn_sync_lines] = sym__syn_sync_lines,
  [sym__syn_sync] = sym__syn_sync,
  [sym__syn_list] = sym__syn_list,
  [sym__syn_clear] = sym__syn_clear,
  [sym_syntax_statement] = sym_syntax_statement,
  [sym_edit_statement] = sym_edit_statement,
  [sym_enew_statement] = sym_enew_statement,
  [sym_find_statement] = sym_find_statement,
  [sym_ex_statement] = sym_ex_statement,
  [sym_visual_statement] = sym_visual_statement,
  [sym_view_statement] = sym_view_statement,
  [aux_sym__statement_repeat1] = aux_sym__statement_repeat1,
  [aux_sym_unknown_builtin_statement_repeat1] = aux_sym_unknown_builtin_statement_repeat1,
  [aux_sym_filetypes_repeat1] = aux_sym_filetypes_repeat1,
  [aux_sym_runtime_statement_repeat1] = aux_sym_runtime_statement_repeat1,
  [aux_sym_script_repeat1] = aux_sym_script_repeat1,
  [aux_sym_if_statement_repeat1] = aux_sym_if_statement_repeat1,
  [aux_sym_try_statement_repeat1] = aux_sym_try_statement_repeat1,
  [aux_sym__bang_filter_command_argument_repeat1] = aux_sym__bang_filter_command_argument_repeat1,
  [aux_sym__bang_filter_command_repeat1] = aux_sym__bang_filter_command_repeat1,
  [aux_sym_identifier_repeat1] = aux_sym_identifier_repeat1,
  [aux_sym_let_statement_repeat1] = aux_sym_let_statement_repeat1,
  [aux_sym__let_heredoc_repeat1] = aux_sym__let_heredoc_repeat1,
  [aux_sym_set_statement_repeat1] = aux_sym_set_statement_repeat1,
  [aux_sym_unlet_statement_repeat1] = aux_sym_unlet_statement_repeat1,
  [aux_sym_function_definition_repeat1] = aux_sym_function_definition_repeat1,
  [aux_sym_parameters_repeat1] = aux_sym_parameters_repeat1,
  [aux_sym_parameters_repeat2] = aux_sym_parameters_repeat2,
  [aux_sym_map_statement_repeat1] = aux_sym_map_statement_repeat1,
  [aux_sym__map_lhs_repeat1] = aux_sym__map_lhs_repeat1,
  [aux_sym__map_rhs_statement_repeat1] = aux_sym__map_rhs_statement_repeat1,
  [aux_sym__map_rhs_repeat1] = aux_sym__map_rhs_repeat1,
  [aux_sym__sign_define_repeat1] = aux_sym__sign_define_repeat1,
  [aux_sym__sign_place_place_repeat1] = aux_sym__sign_place_place_repeat1,
  [aux_sym__sign_unplace_id_repeat1] = aux_sym__sign_unplace_id_repeat1,
  [aux_sym__sign_jump_repeat1] = aux_sym__sign_jump_repeat1,
  [aux_sym_list_repeat1] = aux_sym_list_repeat1,
  [aux_sym_filename_repeat1] = aux_sym_filename_repeat1,
  [aux_sym__pattern_ordinary_atom_repeat1] = aux_sym__pattern_ordinary_atom_repeat1,
  [aux_sym__pattern_branch_repeat1] = aux_sym__pattern_branch_repeat1,
  [aux_sym_pattern_repeat1] = aux_sym_pattern_repeat1,
  [aux_sym_dictionnary_repeat1] = aux_sym_dictionnary_repeat1,
  [aux_sym_literal_dictionary_repeat1] = aux_sym_literal_dictionary_repeat1,
  [aux_sym_au_event_list_repeat1] = aux_sym_au_event_list_repeat1,
  [aux_sym__autocmd_pattern_repeat1] = aux_sym__autocmd_pattern_repeat1,
  [aux_sym_command_statement_repeat1] = aux_sym_command_statement_repeat1,
  [aux_sym__hl_attr_list_repeat1] = aux_sym__hl_attr_list_repeat1,
  [aux_sym__hl_body_keys_repeat1] = aux_sym__hl_body_keys_repeat1,
  [aux_sym_hl_groups_repeat1] = aux_sym_hl_groups_repeat1,
  [aux_sym__syn_keyword_repeat1] = aux_sym__syn_keyword_repeat1,
  [aux_sym__syn_keyword_repeat2] = aux_sym__syn_keyword_repeat2,
  [aux_sym__syn_match_repeat1] = aux_sym__syn_match_repeat1,
  [aux_sym__syn_match_repeat2] = aux_sym__syn_match_repeat2,
  [aux_sym__syn_region_repeat1] = aux_sym__syn_region_repeat1,
  [aux_sym__syn_region_repeat2] = aux_sym__syn_region_repeat2,
  [aux_sym__syn_cluster_repeat1] = aux_sym__syn_cluster_repeat1,
  [aux_sym__syn_sync_repeat1] = aux_sym__syn_sync_repeat1,
  [aux_sym_edit_statement_repeat1] = aux_sym_edit_statement_repeat1,
  [aux_sym_edit_statement_repeat2] = aux_sym_edit_statement_repeat2,
  [alias_sym_arguments] = alias_sym_arguments,
  [alias_sym_augroup_name] = alias_sym_augroup_name,
  [alias_sym_body] = alias_sym_body,
  [alias_sym_file] = alias_sym_file,
  [alias_sym_filenames] = alias_sym_filenames,
  [alias_sym_filter_command] = alias_sym_filter_command,
  [alias_sym_name] = alias_sym_name,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_keyword] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_a_COLON] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_normal_statement_token1] = {
    .visible = true,
    .named = true,
  },
  [sym_filetype] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__filetype_immediate_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_FALLBACK] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_dos] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_unix] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_mac] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_latin1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_iso] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_koi8] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_macroman] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp437] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp737] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp775] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp850] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp852] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp855] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp857] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp860] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp861] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp862] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp863] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp865] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp866] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp869] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp874] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp1250] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp1251] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp1253] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp1254] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp1255] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp1256] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp1257] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp1258] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp932] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_euc_DASHjp] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sjis] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp949] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_euc_DASHkr] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp936] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_euc_DASHcn] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cp950] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_big5] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_euc_DASHtw] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_utf_DASH8] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ucs_DASH2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ucs_DASH21e] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_utf_DASH16] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_utf_DASH16le] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ucs_DASH4] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ucs_DASH4le] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ansi] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_japan] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_korea] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_prc] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_chinese] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_taiwan] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_utf8] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unicode] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ucs2be] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ucs_DASH2be] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ucs_DASH4be] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_utf_DASH32] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_utf_DASH32le] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_default] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_latin12] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_iso2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_koi82] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_macroman2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp4372] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp7372] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp7752] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp8502] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp8522] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp8552] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp8572] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp8602] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp8612] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp8622] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp8632] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp8652] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp8662] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp8692] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp8742] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp12502] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp12512] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp12532] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp12542] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp12552] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp12562] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp12572] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp12582] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp9322] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_euc_DASHjp2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_sjis2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp9492] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_euc_DASHkr2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp9362] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_euc_DASHcn2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_cp9502] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_big52] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_euc_DASHtw2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_utf_DASH82] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_ucs_DASH22] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_ucs_DASH21e2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_utf_DASH162] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_utf_DASH16le2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_ucs_DASH42] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_ucs_DASH4le2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_ansi2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_japan2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_korea2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_prc2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_chinese2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_taiwan2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_utf82] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_unicode2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_ucs2be2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_ucs_DASH2be2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_ucs_DASH4be2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_utf_DASH322] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_utf_DASH32le2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_default2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_START] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_OPT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ALL] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_wincmd_statement_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_on] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_off] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_detect] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_plugin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_indent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [sym_chunk] = {
    .visible = true,
    .named = true,
  },
  [sym__heredoc_line] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_trim] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__au_pattern_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__au_pattern_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__bang_filter_command_argument_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__bang_filter_command_argument_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__bang_filter_command_argument_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__bang_filter_command_argument_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_argument_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_argument_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_identifier_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_identifier_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__immediate_identifier_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_eval] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_option_name_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_t_] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_option_name_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_vi] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_vim] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_all] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_all_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ2] = {
    .visible = true,
    .named = false,
  },
  [sym_set_value] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SPACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND_BANG] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_shebang_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_command_argument_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_dict] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_range] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_abort] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_closure] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [sym_spread] = {
    .visible = true,
    .named = true,
  },
  [sym__printable] = {
    .visible = false,
    .named = true,
  },
  [sym_mark] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LTbuffer_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LTnowait_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LTsilent_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LTunique_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LTscript_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LTexpr_GT] = {
    .visible = true,
    .named = false,
  },
  [sym__keycode_modifier] = {
    .visible = false,
    .named = true,
  },
  [aux_sym__keycode_in_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token5] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token6] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token7] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token8] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token9] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token10] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token11] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token12] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token13] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token14] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token15] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token16] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token17] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token18] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token19] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token20] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token21] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token22] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token23] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token24] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token25] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token26] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token27] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token28] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token29] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token30] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token31] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token32] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token33] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token34] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token35] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token36] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token37] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token38] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token39] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token40] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token41] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token42] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__keycode_in_token43] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__map_lhs_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__map_rhs_statement_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_BSLASH_PIPE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__map_rhs_statement_token2] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__map_rhs_statement_token3] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__map_rhs_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__map_rhs_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_icon] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_linehl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_numhl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_text] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_texthl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_culhl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_define] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_undefine] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_list] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_line] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_name] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_buffer] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_group] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_priority] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_file] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_place] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unplace] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_jump] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_is] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_isnot] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG2] = {
    .visible = true,
    .named = false,
  },
  [sym_float_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_integer_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_filename_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_filename_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_filename_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_filename_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_filename_token5] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_filename_token6] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_filename_token7] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_filename_token8] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_pattern_multi_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_pattern_multi_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_pattern_multi_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__pattern_ordinary_atom_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__pattern_ordinary_atom_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_BSLASH_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH_PERCENT_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASHz_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [sym_register] = {
    .visible = true,
    .named = true,
  },
  [sym_literal_key] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_POUND_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_keep] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_drop] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ff] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fileformat] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enc] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_encoding] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_binary] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nobin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nobinary] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bad] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_edit] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__plus_cmd_arg_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_au_event] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__autocmd_pattern_token1] = {
    .visible = true,
    .named = true,
  },
  [sym_au_once] = {
    .visible = true,
    .named = true,
  },
  [sym_au_nested] = {
    .visible = true,
    .named = true,
  },
  [sym_command_name] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_arglist] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_augroup] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_buffer2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_behave] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_color] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_command] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_compiler] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_dir] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_environment] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_even] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_expression] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_file2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_file_in_path] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_filetype] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_help] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_highlight] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_history] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_local] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lua] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mapclear] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mapping] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_menu] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_messages] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_option] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_packadd] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_shellcmd] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sign] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_syntax] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_syntime] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_tag] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_tag_listfiles] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_user] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_var] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_custom] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_customlist] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lines] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_arguments] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_buffers] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_loaded_buffers] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_windows] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_tabs] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_quickfix] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_other] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__command_attribute_nargs_value_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__command_attribute_nargs_value_token2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_PERCENT2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DASHnargs] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASHcomplete] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASHrange] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASHcount] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASHaddr] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASHbang] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASHbar] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASHregister] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASHbuffer] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASHkeepscript] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_command_statement_token1] = {
    .visible = true,
    .named = true,
  },
  [sym_hl_group] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_link] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_clear] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_NONE] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_NONE2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bold] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_underline] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_undercurl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_underdouble] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_underdotted] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_underdashed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_strikethrough] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_reverse] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_inverse] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_italic] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_standout] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nocombine] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_term] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cterm] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hl_term_list_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_start] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_stop] = {
    .visible = true,
    .named = false,
  },
  [sym__hl_color_nr] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_ctermfg] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ctermbg] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_gui] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hl_quoted_name_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_SQUOTE2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bg] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_background] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fg] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_foreground] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_color_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_color_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_guifg] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_guibg] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_guisp] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_font_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_font] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_blend] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enable] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_reset] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_match] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ignore] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_spell] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_toplevel] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_notoplevel] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_foldlevel] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_minimum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_iskeyword] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__syn_iskeyword_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_conceal] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cchar] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_contained] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_containedin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nextgroup] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_transparent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_skipwhite] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_skipnl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_skipempty] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_contains] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fold] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_display] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extend] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_keepend] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_excludenl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_matchgroup] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_oneline] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_concealends] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_add] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_remove] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ms] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_me] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_hs] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_he] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rs] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_re] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lc] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__syn_pattern_offset_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__syn_pattern_offset_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_keyword] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__syn_keyword_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_skip] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_region] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cluster] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_include] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_minlines] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_maxlines] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__syn_sync_lines_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_sync] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_linebreaks] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fromstart] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ccomment] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lines2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_grouphere] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_groupthere] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_linecont] = {
    .visible = true,
    .named = false,
  },
  [sym__no] = {
    .visible = false,
    .named = true,
  },
  [sym__inv] = {
    .visible = false,
    .named = true,
  },
  [sym__newline_or_pipe] = {
    .visible = false,
    .named = true,
  },
  [sym__line_continuation] = {
    .visible = false,
    .named = true,
  },
  [sym__script_heredoc_marker] = {
    .visible = true,
    .named = true,
  },
  [sym__let_heredoc_marker] = {
    .visible = true,
    .named = true,
  },
  [sym__heredoc_end] = {
    .visible = true,
    .named = true,
  },
  [sym__separator_first] = {
    .visible = false,
    .named = true,
  },
  [sym__separator] = {
    .visible = false,
    .named = true,
  },
  [sym__scope_dict] = {
    .visible = false,
    .named = true,
  },
  [sym_scope] = {
    .visible = true,
    .named = true,
  },
  [sym_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_line_continuation_comment] = {
    .visible = true,
    .named = true,
  },
  [sym__bang_filter] = {
    .visible = false,
    .named = true,
  },
  [sym__function] = {
    .visible = true,
    .named = false,
  },
  [sym__endfunction] = {
    .visible = true,
    .named = false,
  },
  [sym__for] = {
    .visible = true,
    .named = false,
  },
  [sym__endfor] = {
    .visible = true,
    .named = false,
  },
  [sym__while] = {
    .visible = true,
    .named = false,
  },
  [sym__endwhile] = {
    .visible = true,
    .named = false,
  },
  [sym__if] = {
    .visible = true,
    .named = false,
  },
  [sym__elseif] = {
    .visible = true,
    .named = false,
  },
  [sym__else] = {
    .visible = true,
    .named = false,
  },
  [sym__endif] = {
    .visible = true,
    .named = false,
  },
  [sym__try] = {
    .visible = true,
    .named = false,
  },
  [sym__catch] = {
    .visible = true,
    .named = false,
  },
  [sym__cnext] = {
    .visible = true,
    .named = false,
  },
  [sym__cprevious] = {
    .visible = true,
    .named = false,
  },
  [sym__cNext] = {
    .visible = true,
    .named = false,
  },
  [sym__finally] = {
    .visible = true,
    .named = false,
  },
  [sym__endtry] = {
    .visible = true,
    .named = false,
  },
  [sym__const] = {
    .visible = true,
    .named = false,
  },
  [sym__normal] = {
    .visible = true,
    .named = false,
  },
  [sym__return] = {
    .visible = true,
    .named = false,
  },
  [sym__perl] = {
    .visible = true,
    .named = false,
  },
  [sym__lua] = {
    .visible = true,
    .named = false,
  },
  [sym__ruby] = {
    .visible = true,
    .named = false,
  },
  [sym__python] = {
    .visible = true,
    .named = false,
  },
  [sym__throw] = {
    .visible = true,
    .named = false,
  },
  [sym__execute] = {
    .visible = true,
    .named = false,
  },
  [sym__autocmd] = {
    .visible = true,
    .named = false,
  },
  [sym__silent] = {
    .visible = true,
    .named = false,
  },
  [sym__echo] = {
    .visible = true,
    .named = false,
  },
  [sym__echon] = {
    .visible = true,
    .named = false,
  },
  [sym__echohl] = {
    .visible = true,
    .named = false,
  },
  [sym__echomsg] = {
    .visible = true,
    .named = false,
  },
  [sym__echoerr] = {
    .visible = true,
    .named = false,
  },
  [sym__map] = {
    .visible = true,
    .named = false,
  },
  [sym__nmap] = {
    .visible = true,
    .named = false,
  },
  [sym__vmap] = {
    .visible = true,
    .named = false,
  },
  [sym__xmap] = {
    .visible = true,
    .named = false,
  },
  [sym__smap] = {
    .visible = true,
    .named = false,
  },
  [sym__omap] = {
    .visible = true,
    .named = false,
  },
  [sym__imap] = {
    .visible = true,
    .named = false,
  },
  [sym__lmap] = {
    .visible = true,
    .named = false,
  },
  [sym__cmap] = {
    .visible = true,
    .named = false,
  },
  [sym__tmap] = {
    .visible = true,
    .named = false,
  },
  [sym__noremap] = {
    .visible = true,
    .named = false,
  },
  [sym__nnoremap] = {
    .visible = true,
    .named = false,
  },
  [sym__vnoremap] = {
    .visible = true,
    .named = false,
  },
  [sym__xnoremap] = {
    .visible = true,
    .named = false,
  },
  [sym__snoremap] = {
    .visible = true,
    .named = false,
  },
  [sym__onoremap] = {
    .visible = true,
    .named = false,
  },
  [sym__inoremap] = {
    .visible = true,
    .named = false,
  },
  [sym__lnoremap] = {
    .visible = true,
    .named = false,
  },
  [sym__cnoremap] = {
    .visible = true,
    .named = false,
  },
  [sym__tnoremap] = {
    .visible = true,
    .named = false,
  },
  [sym__augroup] = {
    .visible = true,
    .named = false,
  },
  [sym__highlight] = {
    .visible = true,
    .named = false,
  },
  [sym__default] = {
    .visible = true,
    .named = false,
  },
  [sym__syntax] = {
    .visible = true,
    .named = false,
  },
  [sym__set] = {
    .visible = true,
    .named = false,
  },
  [sym__setlocal] = {
    .visible = true,
    .named = false,
  },
  [sym__setfiletype] = {
    .visible = true,
    .named = false,
  },
  [sym__browse] = {
    .visible = true,
    .named = false,
  },
  [sym__options] = {
    .visible = true,
    .named = false,
  },
  [sym__startinsert] = {
    .visible = true,
    .named = false,
  },
  [sym__stopinsert] = {
    .visible = true,
    .named = false,
  },
  [sym__scriptencoding] = {
    .visible = true,
    .named = false,
  },
  [sym__source] = {
    .visible = true,
    .named = false,
  },
  [sym__global] = {
    .visible = true,
    .named = false,
  },
  [sym__colorscheme] = {
    .visible = true,
    .named = false,
  },
  [sym__command] = {
    .visible = true,
    .named = false,
  },
  [sym__comclear] = {
    .visible = true,
    .named = false,
  },
  [sym__delcommand] = {
    .visible = true,
    .named = false,
  },
  [sym__runtime] = {
    .visible = true,
    .named = false,
  },
  [sym__wincmd] = {
    .visible = true,
    .named = false,
  },
  [sym__sign] = {
    .visible = true,
    .named = false,
  },
  [sym__filetype] = {
    .visible = true,
    .named = false,
  },
  [sym__let] = {
    .visible = true,
    .named = false,
  },
  [sym__unlet] = {
    .visible = true,
    .named = false,
  },
  [sym__call] = {
    .visible = true,
    .named = false,
  },
  [sym__break] = {
    .visible = true,
    .named = false,
  },
  [sym__continue] = {
    .visible = true,
    .named = false,
  },
  [sym__tab] = {
    .visible = true,
    .named = false,
  },
  [sym__vertical] = {
    .visible = true,
    .named = false,
  },
  [sym__leftabove] = {
    .visible = true,
    .named = false,
  },
  [sym__aboveleft] = {
    .visible = true,
    .named = false,
  },
  [sym__rightbelow] = {
    .visible = true,
    .named = false,
  },
  [sym__belowright] = {
    .visible = true,
    .named = false,
  },
  [sym__topleft] = {
    .visible = true,
    .named = false,
  },
  [sym__botright] = {
    .visible = true,
    .named = false,
  },
  [sym__edit] = {
    .visible = true,
    .named = false,
  },
  [sym__enew] = {
    .visible = true,
    .named = false,
  },
  [sym__find] = {
    .visible = true,
    .named = false,
  },
  [sym__ex] = {
    .visible = true,
    .named = false,
  },
  [sym__visual] = {
    .visible = true,
    .named = false,
  },
  [sym__view] = {
    .visible = true,
    .named = false,
  },
  [sym__eval] = {
    .visible = true,
    .named = false,
  },
  [sym__substitute] = {
    .visible = true,
    .named = false,
  },
  [sym_unknown_command_name] = {
    .visible = true,
    .named = true,
  },
  [sym_script_file] = {
    .visible = true,
    .named = true,
  },
  [sym__cmd_separator] = {
    .visible = false,
    .named = true,
  },
  [aux_sym__separated_statements] = {
    .visible = false,
    .named = false,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym_unknown_builtin_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_scope_dict] = {
    .visible = true,
    .named = true,
  },
  [sym_normal_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__filetype_immediate] = {
    .visible = false,
    .named = true,
  },
  [sym_filetypes] = {
    .visible = true,
    .named = true,
  },
  [sym_setfiletype_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_options_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_startinsert_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_stopinsert_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__immediate_file_format] = {
    .visible = false,
    .named = true,
  },
  [sym_encoding] = {
    .visible = true,
    .named = true,
  },
  [sym__immediate_encoding] = {
    .visible = false,
    .named = true,
  },
  [sym_scriptencoding_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_cnext_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_cprevious_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__runtime_where] = {
    .visible = true,
    .named = true,
  },
  [sym_runtime_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_wincmd_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_source_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_global_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__filetype_state] = {
    .visible = false,
    .named = true,
  },
  [sym__filetype_enable] = {
    .visible = false,
    .named = true,
  },
  [sym__filetype_detect] = {
    .visible = false,
    .named = true,
  },
  [sym__filetype_plugin] = {
    .visible = false,
    .named = true,
  },
  [sym__filetype_indent] = {
    .visible = false,
    .named = true,
  },
  [sym_filetype_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_colorscheme_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_lua_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_ruby_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_python_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_perl_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_script] = {
    .visible = true,
    .named = true,
  },
  [sym_for_loop] = {
    .visible = true,
    .named = true,
  },
  [sym_while_loop] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_elseif_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_else_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__au_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_finally_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_throw_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__bang_filter_bangs] = {
    .visible = true,
    .named = true,
  },
  [sym__bang_filter_command_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__bang_filter_command] = {
    .visible = true,
    .named = true,
  },
  [sym_bang_filter_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_scoped_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__curly_braces_name_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__immediate_curly_braces_name_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__immediate_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__ident] = {
    .visible = false,
    .named = true,
  },
  [sym__let_operator] = {
    .visible = false,
    .named = true,
  },
  [sym__assignment_variable] = {
    .visible = false,
    .named = true,
  },
  [sym__let_assignment] = {
    .visible = false,
    .named = true,
  },
  [sym_let_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__const_assignment] = {
    .visible = false,
    .named = true,
  },
  [sym_const_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__let_heredoc] = {
    .visible = true,
    .named = true,
  },
  [sym__let_heredoc_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_option_name] = {
    .visible = true,
    .named = true,
  },
  [sym_no_option] = {
    .visible = true,
    .named = true,
  },
  [sym_inv_option] = {
    .visible = true,
    .named = true,
  },
  [sym_default_option] = {
    .visible = true,
    .named = true,
  },
  [sym__set_option] = {
    .visible = false,
    .named = true,
  },
  [sym__set_operator] = {
    .visible = false,
    .named = true,
  },
  [sym__set_rhs] = {
    .visible = false,
    .named = true,
  },
  [sym_set_item] = {
    .visible = true,
    .named = true,
  },
  [sym_set_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_setlocal_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_unlet_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_call_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_echo_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_echon_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_echohl_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_echomsg_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_echoerr_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_execute_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_silent_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_tab_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_vertical_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_topleft_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_botright_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_aboveleft_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_belowright_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_user_command] = {
    .visible = true,
    .named = true,
  },
  [sym_shebang] = {
    .visible = true,
    .named = true,
  },
  [sym_command_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_function_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_default_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_bang] = {
    .visible = true,
    .named = true,
  },
  [sym_range_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__range] = {
    .visible = false,
    .named = true,
  },
  [sym__range_explicit] = {
    .visible = false,
    .named = true,
  },
  [sym__range_marker] = {
    .visible = false,
    .named = true,
  },
  [sym__complete_range] = {
    .visible = true,
    .named = true,
  },
  [sym__complete_range_explicit] = {
    .visible = false,
    .named = true,
  },
  [sym__complete_range_marker] = {
    .visible = false,
    .named = true,
  },
  [sym_current_line] = {
    .visible = true,
    .named = true,
  },
  [sym_next_line] = {
    .visible = true,
    .named = true,
  },
  [sym_last_line] = {
    .visible = true,
    .named = true,
  },
  [sym_previous_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_register_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_map_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__map_definition] = {
    .visible = false,
    .named = true,
  },
  [sym__keycode_in] = {
    .visible = false,
    .named = true,
  },
  [sym__immediate_keycode] = {
    .visible = false,
    .named = true,
  },
  [sym_keycode] = {
    .visible = true,
    .named = true,
  },
  [sym__map_lhs] = {
    .visible = true,
    .named = true,
  },
  [sym__map_rhs_statement] = {
    .visible = false,
    .named = true,
  },
  [sym__map_rhs] = {
    .visible = true,
    .named = true,
  },
  [sym__sign_name] = {
    .visible = false,
    .named = true,
  },
  [sym__sign_define_arg_text] = {
    .visible = true,
    .named = true,
  },
  [sym__sign_define_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__sign_define] = {
    .visible = false,
    .named = true,
  },
  [sym__sign_undefine] = {
    .visible = false,
    .named = true,
  },
  [sym__sign_list] = {
    .visible = false,
    .named = true,
  },
  [sym__sign_place_place_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__sign_place_place] = {
    .visible = false,
    .named = true,
  },
  [sym__sign_place_list_argument] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__sign_place_list] = {
    .visible = false,
    .named = false,
  },
  [sym__sign_place] = {
    .visible = false,
    .named = true,
  },
  [sym__sign_unplace_cursor_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__sign_unplace_cursor] = {
    .visible = false,
    .named = true,
  },
  [sym__sign_unplace_id_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__sign_unplace_id] = {
    .visible = false,
    .named = true,
  },
  [sym__sign_unplace] = {
    .visible = false,
    .named = true,
  },
  [sym__sign_jump_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__sign_jump] = {
    .visible = false,
    .named = true,
  },
  [sym_sign_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__variable] = {
    .visible = false,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
  },
  [sym_ternary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_match_case] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_operation] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_operation] = {
    .visible = true,
    .named = true,
  },
  [sym_list] = {
    .visible = true,
    .named = true,
  },
  [sym_list_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_index_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_slice_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_eval_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_substitute_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__method_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_method_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_filename] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern_multi] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__pattern_ordinary_atom] = {
    .visible = false,
    .named = false,
  },
  [sym__pattern_atom] = {
    .visible = false,
    .named = true,
  },
  [sym__pattern_piece] = {
    .visible = false,
    .named = true,
  },
  [aux_sym__pattern_concat] = {
    .visible = false,
    .named = false,
  },
  [sym__pattern_branch] = {
    .visible = false,
    .named = true,
  },
  [sym_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_env_variable] = {
    .visible = true,
    .named = true,
  },
  [sym_option] = {
    .visible = true,
    .named = true,
  },
  [sym_dictionnary_entry] = {
    .visible = true,
    .named = true,
  },
  [sym_dictionnary] = {
    .visible = true,
    .named = true,
  },
  [sym__literal_dictionary_entry] = {
    .visible = false,
    .named = true,
  },
  [sym_literal_dictionary] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__immediate_lambda_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__plus_plus_opt_bad] = {
    .visible = false,
    .named = true,
  },
  [sym_plus_plus_opt] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__plus_cmd_arg] = {
    .visible = false,
    .named = false,
  },
  [sym__plus_cmd_number] = {
    .visible = false,
    .named = true,
  },
  [sym__plus_cmd_command] = {
    .visible = false,
    .named = true,
  },
  [sym__plus_cmd_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_plus_cmd] = {
    .visible = true,
    .named = true,
  },
  [sym_au_event_list] = {
    .visible = true,
    .named = true,
  },
  [sym__augroup_name] = {
    .visible = false,
    .named = true,
  },
  [sym__autocmd_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym__autocmd_command] = {
    .visible = false,
    .named = true,
  },
  [sym__autocmd_define] = {
    .visible = false,
    .named = true,
  },
  [sym__autocmd_remove] = {
    .visible = false,
    .named = true,
  },
  [sym__autocmd_list] = {
    .visible = false,
    .named = true,
  },
  [sym_autocmd_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_augroup_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__command_attribute_completion_behavior] = {
    .visible = true,
    .named = true,
  },
  [sym__command_attribute_address_behavior] = {
    .visible = true,
    .named = true,
  },
  [sym__command_attribute_nargs_value] = {
    .visible = false,
    .named = true,
  },
  [sym__command_attribute_range_value] = {
    .visible = false,
    .named = true,
  },
  [sym_command_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_command_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_comclear_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_delcommand_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__hl_body_link] = {
    .visible = false,
    .named = true,
  },
  [sym__hl_body_clear] = {
    .visible = false,
    .named = true,
  },
  [sym__hl_body_none] = {
    .visible = false,
    .named = true,
  },
  [sym__hl_none] = {
    .visible = false,
    .named = true,
  },
  [sym__hl_attr_list] = {
    .visible = false,
    .named = true,
  },
  [sym__hl_key_cterm] = {
    .visible = false,
    .named = true,
  },
  [aux_sym__hl_term_list] = {
    .visible = false,
    .named = false,
  },
  [sym__hl_key_start_stop] = {
    .visible = false,
    .named = true,
  },
  [sym__hl_key_ctermfg_ctermbg] = {
    .visible = false,
    .named = true,
  },
  [sym__hl_key_gui] = {
    .visible = false,
    .named = true,
  },
  [sym__hl_quoted_name] = {
    .visible = false,
    .named = true,
  },
  [sym_color] = {
    .visible = true,
    .named = true,
  },
  [sym__hl_key_gui_color] = {
    .visible = false,
    .named = true,
  },
  [sym_font] = {
    .visible = true,
    .named = true,
  },
  [sym__hl_key_font] = {
    .visible = false,
    .named = true,
  },
  [sym__hl_key_blend] = {
    .visible = false,
    .named = true,
  },
  [sym_hl_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym__hl_body_keys] = {
    .visible = false,
    .named = true,
  },
  [sym__hl_body] = {
    .visible = false,
    .named = true,
  },
  [sym_highlight_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__syn_enable] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_case] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_spell] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_foldlevel] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_iskeyword] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_conceal] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_hl_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_hl_groups] = {
    .visible = true,
    .named = true,
  },
  [sym__syn_arguments_keyword] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_arguments_match] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_arguments_region] = {
    .visible = true,
    .named = true,
  },
  [sym__syn_arguments_cluster] = {
    .visible = true,
    .named = true,
  },
  [sym__syn_pattern_offset] = {
    .visible = true,
    .named = true,
  },
  [sym__syn_keyword] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_match] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_region_start] = {
    .visible = true,
    .named = true,
  },
  [sym__syn_region_skip] = {
    .visible = true,
    .named = true,
  },
  [sym__syn_region_end] = {
    .visible = true,
    .named = true,
  },
  [sym__syn_region] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_cluster] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_include] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_sync_lines] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_sync] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_list] = {
    .visible = false,
    .named = true,
  },
  [sym__syn_clear] = {
    .visible = false,
    .named = true,
  },
  [sym_syntax_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_edit_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_enew_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_find_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_ex_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_visual_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_view_statement] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_unknown_builtin_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_filetypes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_runtime_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_script_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_try_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__bang_filter_command_argument_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__bang_filter_command_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_identifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_let_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__let_heredoc_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_set_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_unlet_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameters_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_map_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__map_lhs_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__map_rhs_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__map_rhs_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__sign_define_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__sign_place_place_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__sign_unplace_id_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__sign_jump_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_filename_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__pattern_ordinary_atom_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__pattern_branch_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dictionnary_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_literal_dictionary_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_au_event_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__autocmd_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_command_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hl_attr_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hl_body_keys_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hl_groups_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__syn_keyword_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__syn_keyword_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__syn_match_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__syn_match_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__syn_region_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__syn_region_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__syn_cluster_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__syn_sync_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_edit_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_edit_statement_repeat2] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_augroup_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_body] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_file] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_filenames] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_filter_command] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_name] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_action = 1,
  field_cmd = 2,
  field_command = 3,
  field_condition = 4,
  field_end = 5,
  field_field = 6,
  field_file = 7,
  field_filter = 8,
  field_from = 9,
  field_function = 10,
  field_grouplist = 11,
  field_id = 12,
  field_index = 13,
  field_iter = 14,
  field_key = 15,
  field_left = 16,
  field_lhs = 17,
  field_method = 18,
  field_name = 19,
  field_offset = 20,
  field_option = 21,
  field_parameters = 22,
  field_range = 23,
  field_repl = 24,
  field_rhs = 25,
  field_right = 26,
  field_start = 27,
  field_stop = 28,
  field_sub = 29,
  field_to = 30,
  field_val = 31,
  field_value = 32,
  field_variable = 33,
  field_what = 34,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_action] = "action",
  [field_cmd] = "cmd",
  [field_command] = "command",
  [field_condition] = "condition",
  [field_end] = "end",
  [field_field] = "field",
  [field_file] = "file",
  [field_filter] = "filter",
  [field_from] = "from",
  [field_function] = "function",
  [field_grouplist] = "grouplist",
  [field_id] = "id",
  [field_index] = "index",
  [field_iter] = "iter",
  [field_key] = "key",
  [field_left] = "left",
  [field_lhs] = "lhs",
  [field_method] = "method",
  [field_name] = "name",
  [field_offset] = "offset",
  [field_option] = "option",
  [field_parameters] = "parameters",
  [field_range] = "range",
  [field_repl] = "repl",
  [field_rhs] = "rhs",
  [field_right] = "right",
  [field_start] = "start",
  [field_stop] = "stop",
  [field_sub] = "sub",
  [field_to] = "to",
  [field_val] = "val",
  [field_value] = "value",
  [field_variable] = "variable",
  [field_what] = "what",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 2},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 1},
  [6] = {.index = 4, .length = 1},
  [7] = {.index = 5, .length = 3},
  [9] = {.index = 8, .length = 2},
  [10] = {.index = 10, .length = 2},
  [11] = {.index = 12, .length = 1},
  [12] = {.index = 13, .length = 1},
  [13] = {.index = 14, .length = 2},
  [14] = {.index = 16, .length = 3},
  [15] = {.index = 19, .length = 1},
  [16] = {.index = 20, .length = 1},
  [18] = {.index = 21, .length = 1},
  [19] = {.index = 22, .length = 1},
  [21] = {.index = 23, .length = 1},
  [22] = {.index = 24, .length = 2},
  [23] = {.index = 26, .length = 2},
  [25] = {.index = 28, .length = 3},
  [27] = {.index = 31, .length = 2},
  [28] = {.index = 33, .length = 1},
  [30] = {.index = 34, .length = 2},
  [31] = {.index = 36, .length = 3},
  [33] = {.index = 39, .length = 2},
  [34] = {.index = 41, .length = 2},
  [35] = {.index = 43, .length = 2},
  [36] = {.index = 45, .length = 2},
  [37] = {.index = 47, .length = 1},
  [38] = {.index = 48, .length = 2},
  [39] = {.index = 50, .length = 1},
  [41] = {.index = 51, .length = 2},
  [42] = {.index = 53, .length = 2},
  [43] = {.index = 55, .length = 2},
  [44] = {.index = 57, .length = 1},
  [45] = {.index = 57, .length = 1},
  [46] = {.index = 58, .length = 2},
  [47] = {.index = 58, .length = 2},
  [52] = {.index = 60, .length = 1},
  [53] = {.index = 61, .length = 4},
  [54] = {.index = 65, .length = 1},
  [55] = {.index = 66, .length = 2},
  [56] = {.index = 68, .length = 4},
  [57] = {.index = 28, .length = 3},
  [58] = {.index = 72, .length = 2},
  [59] = {.index = 74, .length = 1},
  [60] = {.index = 75, .length = 2},
  [61] = {.index = 77, .length = 2},
  [62] = {.index = 79, .length = 2},
  [63] = {.index = 81, .length = 1},
  [66] = {.index = 82, .length = 1},
  [67] = {.index = 83, .length = 1},
  [68] = {.index = 84, .length = 2},
  [69] = {.index = 86, .length = 2},
  [70] = {.index = 55, .length = 2},
  [71] = {.index = 88, .length = 1},
  [72] = {.index = 89, .length = 3},
  [73] = {.index = 92, .length = 1},
  [74] = {.index = 93, .length = 2},
  [75] = {.index = 95, .length = 4},
  [76] = {.index = 93, .length = 2},
  [77] = {.index = 99, .length = 3},
  [78] = {.index = 102, .length = 2},
  [82] = {.index = 104, .length = 4},
  [83] = {.index = 28, .length = 3},
  [84] = {.index = 108, .length = 2},
  [85] = {.index = 110, .length = 4},
  [86] = {.index = 114, .length = 4},
  [88] = {.index = 118, .length = 2},
  [89] = {.index = 120, .length = 1},
  [90] = {.index = 121, .length = 2},
  [91] = {.index = 81, .length = 1},
  [93] = {.index = 123, .length = 1},
  [94] = {.index = 124, .length = 2},
  [95] = {.index = 126, .length = 2},
  [96] = {.index = 128, .length = 2},
  [97] = {.index = 130, .length = 2},
  [98] = {.index = 132, .length = 3},
  [99] = {.index = 135, .length = 3},
  [100] = {.index = 138, .length = 3},
  [101] = {.index = 141, .length = 3},
  [102] = {.index = 144, .length = 2},
  [103] = {.index = 146, .length = 2},
  [104] = {.index = 148, .length = 2},
  [106] = {.index = 150, .length = 4},
  [107] = {.index = 154, .length = 2},
  [109] = {.index = 156, .length = 3},
  [110] = {.index = 159, .length = 2},
  [111] = {.index = 161, .length = 2},
  [112] = {.index = 163, .length = 2},
  [114] = {.index = 165, .length = 1},
  [115] = {.index = 166, .length = 2},
  [116] = {.index = 168, .length = 5},
  [117] = {.index = 173, .length = 3},
  [118] = {.index = 176, .length = 4},
  [121] = {.index = 180, .length = 3},
  [122] = {.index = 163, .length = 2},
  [123] = {.index = 183, .length = 2},
  [124] = {.index = 185, .length = 1},
  [125] = {.index = 186, .length = 3},
  [126] = {.index = 189, .length = 5},
  [127] = {.index = 194, .length = 5},
  [128] = {.index = 199, .length = 5},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_end, 0, .inherited = true},
    {field_start, 0, .inherited = true},
  [2] =
    {field_start, 0},
  [3] =
    {field_command, 0, .inherited = true},
  [4] =
    {field_command, 1, .inherited = true},
  [5] =
    {field_cmd, 0},
    {field_lhs, 1, .inherited = true},
    {field_rhs, 1, .inherited = true},
  [8] =
    {field_from, 0, .inherited = true},
    {field_to, 0, .inherited = true},
  [10] =
    {field_from, 1, .inherited = true},
    {field_to, 1, .inherited = true},
  [12] =
    {field_sub, 0},
  [13] =
    {field_sub, 1, .inherited = true},
  [14] =
    {field_grouplist, 1, .inherited = true},
    {field_sub, 1, .inherited = true},
  [16] =
    {field_method, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_sub, 1, .inherited = true},
  [19] =
    {field_option, 0},
  [20] =
    {field_file, 1},
  [21] =
    {field_name, 1},
  [22] =
    {field_name, 0},
  [23] =
    {field_action, 1},
  [24] =
    {field_name, 1, .inherited = true},
    {field_sub, 1, .inherited = true},
  [26] =
    {field_id, 1, .inherited = true},
    {field_sub, 1, .inherited = true},
  [28] =
    {field_end, 0, .inherited = true},
    {field_range, 0},
    {field_start, 0, .inherited = true},
  [31] =
    {field_name, 0},
    {field_parameters, 1},
  [33] =
    {field_command, 2, .inherited = true},
  [34] =
    {field_lhs, 0},
    {field_rhs, 1},
  [36] =
    {field_cmd, 0},
    {field_lhs, 2, .inherited = true},
    {field_rhs, 2, .inherited = true},
  [39] =
    {field_key, 0, .inherited = true},
    {field_val, 0, .inherited = true},
  [41] =
    {field_from, 2, .inherited = true},
    {field_to, 2, .inherited = true},
  [43] =
    {field_method, 1},
    {field_sub, 0},
  [45] =
    {field_option, 0},
    {field_value, 1, .inherited = true},
  [47] =
    {field_file, 2},
  [48] =
    {field_name, 1},
    {field_repl, 2},
  [50] =
    {field_name, 2},
  [51] =
    {field_name, 1},
    {field_sub, 0},
  [53] =
    {field_id, 1, .inherited = true},
    {field_sub, 0},
  [55] =
    {field_name, 0, .inherited = true},
    {field_val, 0, .inherited = true},
  [57] =
    {field_id, 0},
  [58] =
    {field_id, 1},
    {field_sub, 0},
  [60] =
    {field_action, 2},
  [61] =
    {field_end, 0, .inherited = true},
    {field_filter, 2, .inherited = true},
    {field_range, 0},
    {field_start, 0, .inherited = true},
  [65] =
    {field_filter, 0},
  [66] =
    {field_end, 2},
    {field_start, 0},
  [68] =
    {field_end, 0, .inherited = true},
    {field_file, 2},
    {field_range, 0},
    {field_start, 0, .inherited = true},
  [72] =
    {field_key, 1, .inherited = true},
    {field_value, 1, .inherited = true},
  [74] =
    {field_function, 0},
  [75] =
    {field_left, 0},
    {field_right, 2},
  [77] =
    {field_field, 2},
    {field_value, 0},
  [79] =
    {field_function, 2, .inherited = true},
    {field_value, 0},
  [81] =
    {field_condition, 1},
  [82] =
    {field_command, 3, .inherited = true},
  [83] =
    {field_command, 2},
  [84] =
    {field_lhs, 1},
    {field_rhs, 2},
  [86] =
    {field_from, 1},
    {field_to, 2},
  [88] =
    {field_name, 0, .inherited = true},
  [89] =
    {field_method, 1},
    {field_name, 2, .inherited = true},
    {field_sub, 0},
  [92] =
    {field_value, 1},
  [93] =
    {field_name, 0},
    {field_val, 2},
  [95] =
    {field_name, 0},
    {field_name, 2, .inherited = true},
    {field_val, 2},
    {field_val, 2, .inherited = true},
  [99] =
    {field_name, 0},
    {field_name, 2, .inherited = true},
    {field_val, 2},
  [102] =
    {field_name, 2},
    {field_repl, 3},
  [104] =
    {field_end, 0, .inherited = true},
    {field_file, 3},
    {field_range, 0},
    {field_start, 0, .inherited = true},
  [108] =
    {field_key, 0},
    {field_value, 2},
  [110] =
    {field_key, 1, .inherited = true},
    {field_key, 2, .inherited = true},
    {field_value, 1, .inherited = true},
    {field_value, 2, .inherited = true},
  [114] =
    {field_key, 0, .inherited = true},
    {field_key, 1, .inherited = true},
    {field_value, 0, .inherited = true},
    {field_value, 1, .inherited = true},
  [118] =
    {field_left, 0},
    {field_right, 3},
  [120] =
    {field_value, 0},
  [121] =
    {field_index, 2},
    {field_value, 0},
  [123] =
    {field_command, 3},
  [124] =
    {field_lhs, 2},
    {field_rhs, 3},
  [126] =
    {field_from, 2},
    {field_to, 3},
  [128] =
    {field_key, 0},
    {field_val, 2},
  [130] =
    {field_sub, 0},
    {field_what, 3, .inherited = true},
  [132] =
    {field_name, 2, .inherited = true},
    {field_sub, 0},
    {field_val, 2, .inherited = true},
  [135] =
    {field_grouplist, 1},
    {field_grouplist, 2},
    {field_sub, 0},
  [138] =
    {field_method, 1},
    {field_sub, 0},
    {field_val, 3},
  [141] =
    {field_method, 1},
    {field_name, 3, .inherited = true},
    {field_sub, 0},
  [144] =
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
  [146] =
    {field_name, 3},
    {field_repl, 4},
  [148] =
    {field_name, 1},
    {field_val, 3},
  [150] =
    {field_end, 0, .inherited = true},
    {field_file, 4},
    {field_range, 0},
    {field_start, 0, .inherited = true},
  [154] =
    {field_name, 0},
    {field_value, 2},
  [156] =
    {field_condition, 0},
    {field_left, 2},
    {field_right, 4},
  [159] =
    {field_stop, 3},
    {field_value, 0},
  [161] =
    {field_start, 2},
    {field_value, 0},
  [163] =
    {field_iter, 3},
    {field_variable, 1},
  [165] =
    {field_command, 4},
  [166] =
    {field_sub, 0},
    {field_what, 4, .inherited = true},
  [168] =
    {field_name, 2, .inherited = true},
    {field_name, 3, .inherited = true},
    {field_sub, 0},
    {field_val, 2, .inherited = true},
    {field_val, 3, .inherited = true},
  [173] =
    {field_name, 3, .inherited = true},
    {field_sub, 0},
    {field_val, 3, .inherited = true},
  [176] =
    {field_method, 1},
    {field_name, 2, .inherited = true},
    {field_name, 4, .inherited = true},
    {field_sub, 0},
  [180] =
    {field_start, 2},
    {field_stop, 4},
    {field_value, 0},
  [183] =
    {field_offset, 2},
    {field_what, 0},
  [185] =
    {field_what, 1, .inherited = true},
  [186] =
    {field_name, 0},
    {field_val, 2},
    {field_what, 3, .inherited = true},
  [189] =
    {field_name, 2, .inherited = true},
    {field_name, 4, .inherited = true},
    {field_sub, 0},
    {field_val, 2, .inherited = true},
    {field_val, 4, .inherited = true},
  [194] =
    {field_name, 3, .inherited = true},
    {field_name, 4, .inherited = true},
    {field_sub, 0},
    {field_val, 3, .inherited = true},
    {field_val, 4, .inherited = true},
  [199] =
    {field_name, 3, .inherited = true},
    {field_name, 5, .inherited = true},
    {field_sub, 0},
    {field_val, 3, .inherited = true},
    {field_val, 5, .inherited = true},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = alias_sym_file,
  },
  [5] = {
    [0] = alias_sym_augroup_name,
  },
  [8] = {
    [1] = alias_sym_augroup_name,
  },
  [17] = {
    [1] = alias_sym_name,
  },
  [20] = {
    [1] = alias_sym_filenames,
  },
  [24] = {
    [1] = alias_sym_arguments,
  },
  [26] = {
    [1] = sym_integer_literal,
  },
  [29] = {
    [0] = sym_keycode,
  },
  [32] = {
    [2] = alias_sym_augroup_name,
  },
  [40] = {
    [2] = alias_sym_filenames,
  },
  [44] = {
    [0] = anon_sym_STAR,
  },
  [46] = {
    [1] = anon_sym_STAR,
  },
  [48] = {
    [0] = sym_integer_literal,
  },
  [49] = {
    [0] = aux_sym_command_statement_token1,
  },
  [50] = {
    [2] = sym_integer_literal,
  },
  [51] = {
    [2] = alias_sym_arguments,
  },
  [53] = {
    [0] = sym__complete_range,
  },
  [54] = {
    [0] = alias_sym_filter_command,
  },
  [57] = {
    [2] = alias_sym_arguments,
  },
  [64] = {
    [1] = alias_sym_body,
  },
  [65] = {
    [2] = alias_sym_body,
  },
  [70] = {
    [0] = sym__syn_arguments_region,
  },
  [76] = {
    [2] = sym_integer_literal,
  },
  [79] = {
    [3] = alias_sym_filenames,
  },
  [80] = {
    [1] = sym_pattern,
  },
  [81] = {
    [3] = sym_integer_literal,
  },
  [83] = {
    [3] = alias_sym_arguments,
  },
  [87] = {
    [3] = alias_sym_body,
  },
  [91] = {
    [3] = alias_sym_body,
  },
  [92] = {
    [1] = sym__let_heredoc_parameter,
  },
  [105] = {
    [4] = sym_integer_literal,
  },
  [108] = {
    [4] = alias_sym_body,
  },
  [113] = {
    [1] = sym__let_heredoc_parameter,
    [3] = alias_sym_body,
  },
  [119] = {
    [5] = sym_integer_literal,
  },
  [120] = {
    [5] = alias_sym_body,
  },
  [122] = {
    [5] = alias_sym_body,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  aux_sym__separated_statements, 2,
    aux_sym__separated_statements,
    alias_sym_body,
  sym_identifier, 2,
    sym_identifier,
    alias_sym_augroup_name,
  sym__range, 2,
    sym__range,
    sym__complete_range,
  sym__immediate_keycode, 2,
    sym__immediate_keycode,
    sym_keycode,
  sym_filename, 3,
    sym_filename,
    alias_sym_filter_command,
    alias_sym_name,
  aux_sym__plus_cmd_arg, 3,
    aux_sym__plus_cmd_arg,
    aux_sym_command_statement_token1,
    sym_pattern,
  sym__syn_arguments_keyword, 2,
    sym__syn_arguments_keyword,
    sym__syn_arguments_region,
  sym__syn_arguments_match, 2,
    sym__syn_arguments_match,
    sym__syn_arguments_region,
  aux_sym_unknown_builtin_statement_repeat1, 2,
    aux_sym_unknown_builtin_statement_repeat1,
    alias_sym_arguments,
  aux_sym_runtime_statement_repeat1, 2,
    aux_sym_runtime_statement_repeat1,
    alias_sym_filenames,
  aux_sym_script_repeat1, 2,
    aux_sym_script_repeat1,
    alias_sym_body,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 3,
  [7] = 5,
  [8] = 2,
  [9] = 4,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 15,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 19,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 15,
  [36] = 15,
  [37] = 15,
  [38] = 15,
  [39] = 15,
  [40] = 15,
  [41] = 41,
  [42] = 24,
  [43] = 26,
  [44] = 44,
  [45] = 27,
  [46] = 28,
  [47] = 29,
  [48] = 20,
  [49] = 21,
  [50] = 22,
  [51] = 18,
  [52] = 52,
  [53] = 32,
  [54] = 52,
  [55] = 31,
  [56] = 30,
  [57] = 57,
  [58] = 57,
  [59] = 59,
  [60] = 59,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 61,
  [69] = 69,
  [70] = 63,
  [71] = 64,
  [72] = 72,
  [73] = 65,
  [74] = 74,
  [75] = 72,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 62,
  [82] = 66,
  [83] = 80,
  [84] = 74,
  [85] = 67,
  [86] = 69,
  [87] = 87,
  [88] = 88,
  [89] = 77,
  [90] = 78,
  [91] = 76,
  [92] = 79,
  [93] = 87,
  [94] = 94,
  [95] = 94,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 97,
  [100] = 96,
  [101] = 101,
  [102] = 98,
  [103] = 103,
  [104] = 101,
  [105] = 105,
  [106] = 105,
  [107] = 103,
  [108] = 103,
  [109] = 105,
  [110] = 103,
  [111] = 103,
  [112] = 103,
  [113] = 105,
  [114] = 105,
  [115] = 103,
  [116] = 105,
  [117] = 103,
  [118] = 105,
  [119] = 105,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 124,
  [126] = 126,
  [127] = 126,
  [128] = 126,
  [129] = 126,
  [130] = 126,
  [131] = 122,
  [132] = 132,
  [133] = 132,
  [134] = 123,
  [135] = 135,
  [136] = 135,
  [137] = 137,
  [138] = 138,
  [139] = 137,
  [140] = 140,
  [141] = 140,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 150,
  [151] = 150,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 150,
  [157] = 157,
  [158] = 150,
  [159] = 159,
  [160] = 150,
  [161] = 142,
  [162] = 150,
  [163] = 143,
  [164] = 150,
  [165] = 159,
  [166] = 166,
  [167] = 150,
  [168] = 145,
  [169] = 169,
  [170] = 170,
  [171] = 171,
  [172] = 159,
  [173] = 147,
  [174] = 153,
  [175] = 142,
  [176] = 143,
  [177] = 149,
  [178] = 178,
  [179] = 178,
  [180] = 155,
  [181] = 148,
  [182] = 144,
  [183] = 157,
  [184] = 166,
  [185] = 171,
  [186] = 186,
  [187] = 171,
  [188] = 146,
  [189] = 171,
  [190] = 152,
  [191] = 159,
  [192] = 154,
  [193] = 142,
  [194] = 171,
  [195] = 143,
  [196] = 169,
  [197] = 197,
  [198] = 198,
  [199] = 199,
  [200] = 200,
  [201] = 201,
  [202] = 201,
  [203] = 203,
  [204] = 203,
  [205] = 205,
  [206] = 198,
  [207] = 201,
  [208] = 200,
  [209] = 203,
  [210] = 198,
  [211] = 201,
  [212] = 203,
  [213] = 205,
  [214] = 198,
  [215] = 201,
  [216] = 203,
  [217] = 198,
  [218] = 170,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 220,
  [223] = 223,
  [224] = 220,
  [225] = 225,
  [226] = 223,
  [227] = 227,
  [228] = 200,
  [229] = 227,
  [230] = 230,
  [231] = 231,
  [232] = 232,
  [233] = 219,
  [234] = 223,
  [235] = 220,
  [236] = 199,
  [237] = 223,
  [238] = 227,
  [239] = 231,
  [240] = 230,
  [241] = 230,
  [242] = 231,
  [243] = 243,
  [244] = 205,
  [245] = 230,
  [246] = 220,
  [247] = 225,
  [248] = 223,
  [249] = 227,
  [250] = 250,
  [251] = 251,
  [252] = 230,
  [253] = 231,
  [254] = 232,
  [255] = 227,
  [256] = 231,
  [257] = 232,
  [258] = 219,
  [259] = 250,
  [260] = 205,
  [261] = 243,
  [262] = 219,
  [263] = 200,
  [264] = 231,
  [265] = 219,
  [266] = 232,
  [267] = 219,
  [268] = 227,
  [269] = 232,
  [270] = 270,
  [271] = 271,
  [272] = 272,
  [273] = 273,
  [274] = 274,
  [275] = 275,
  [276] = 276,
  [277] = 277,
  [278] = 278,
  [279] = 279,
  [280] = 280,
  [281] = 281,
  [282] = 282,
  [283] = 283,
  [284] = 284,
  [285] = 278,
  [286] = 279,
  [287] = 287,
  [288] = 280,
  [289] = 273,
  [290] = 273,
  [291] = 281,
  [292] = 282,
  [293] = 293,
  [294] = 294,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 278,
  [299] = 279,
  [300] = 280,
  [301] = 301,
  [302] = 281,
  [303] = 282,
  [304] = 304,
  [305] = 305,
  [306] = 273,
  [307] = 307,
  [308] = 308,
  [309] = 309,
  [310] = 310,
  [311] = 311,
  [312] = 312,
  [313] = 313,
  [314] = 314,
  [315] = 284,
  [316] = 316,
  [317] = 317,
  [318] = 318,
  [319] = 319,
  [320] = 320,
  [321] = 321,
  [322] = 322,
  [323] = 323,
  [324] = 287,
  [325] = 325,
  [326] = 326,
  [327] = 327,
  [328] = 328,
  [329] = 329,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 333,
  [334] = 334,
  [335] = 335,
  [336] = 336,
  [337] = 337,
  [338] = 271,
  [339] = 339,
  [340] = 340,
  [341] = 279,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 346,
  [347] = 347,
  [348] = 348,
  [349] = 270,
  [350] = 350,
  [351] = 351,
  [352] = 352,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 357,
  [358] = 358,
  [359] = 359,
  [360] = 278,
  [361] = 279,
  [362] = 280,
  [363] = 287,
  [364] = 281,
  [365] = 282,
  [366] = 366,
  [367] = 367,
  [368] = 368,
  [369] = 369,
  [370] = 370,
  [371] = 284,
  [372] = 372,
  [373] = 359,
  [374] = 294,
  [375] = 375,
  [376] = 376,
  [377] = 372,
  [378] = 378,
  [379] = 287,
  [380] = 357,
  [381] = 369,
  [382] = 376,
  [383] = 378,
  [384] = 384,
  [385] = 385,
  [386] = 386,
  [387] = 305,
  [388] = 388,
  [389] = 273,
  [390] = 390,
  [391] = 391,
  [392] = 392,
  [393] = 278,
  [394] = 279,
  [395] = 280,
  [396] = 281,
  [397] = 282,
  [398] = 284,
  [399] = 287,
  [400] = 277,
  [401] = 270,
  [402] = 388,
  [403] = 392,
  [404] = 272,
  [405] = 384,
  [406] = 350,
  [407] = 277,
  [408] = 270,
  [409] = 388,
  [410] = 392,
  [411] = 272,
  [412] = 384,
  [413] = 350,
  [414] = 277,
  [415] = 270,
  [416] = 388,
  [417] = 392,
  [418] = 272,
  [419] = 384,
  [420] = 350,
  [421] = 277,
  [422] = 270,
  [423] = 388,
  [424] = 392,
  [425] = 272,
  [426] = 384,
  [427] = 350,
  [428] = 392,
  [429] = 270,
  [430] = 392,
  [431] = 270,
  [432] = 392,
  [433] = 270,
  [434] = 392,
  [435] = 270,
  [436] = 392,
  [437] = 270,
  [438] = 392,
  [439] = 270,
  [440] = 392,
  [441] = 270,
  [442] = 392,
  [443] = 270,
  [444] = 392,
  [445] = 270,
  [446] = 392,
  [447] = 270,
  [448] = 392,
  [449] = 270,
  [450] = 392,
  [451] = 270,
  [452] = 392,
  [453] = 392,
  [454] = 392,
  [455] = 284,
  [456] = 370,
  [457] = 366,
  [458] = 375,
  [459] = 310,
  [460] = 309,
  [461] = 311,
  [462] = 312,
  [463] = 343,
  [464] = 313,
  [465] = 314,
  [466] = 316,
  [467] = 317,
  [468] = 318,
  [469] = 319,
  [470] = 320,
  [471] = 321,
  [472] = 322,
  [473] = 323,
  [474] = 325,
  [475] = 326,
  [476] = 344,
  [477] = 345,
  [478] = 327,
  [479] = 328,
  [480] = 329,
  [481] = 274,
  [482] = 330,
  [483] = 308,
  [484] = 337,
  [485] = 332,
  [486] = 346,
  [487] = 353,
  [488] = 347,
  [489] = 333,
  [490] = 358,
  [491] = 334,
  [492] = 348,
  [493] = 335,
  [494] = 336,
  [495] = 355,
  [496] = 351,
  [497] = 352,
  [498] = 293,
  [499] = 339,
  [500] = 295,
  [501] = 340,
  [502] = 296,
  [503] = 297,
  [504] = 307,
  [505] = 304,
  [506] = 354,
  [507] = 342,
  [508] = 331,
  [509] = 509,
  [510] = 159,
  [511] = 142,
  [512] = 143,
  [513] = 200,
  [514] = 514,
  [515] = 515,
  [516] = 514,
  [517] = 205,
  [518] = 518,
  [519] = 515,
  [520] = 143,
  [521] = 159,
  [522] = 518,
  [523] = 142,
  [524] = 351,
  [525] = 345,
  [526] = 352,
  [527] = 343,
  [528] = 358,
  [529] = 199,
  [530] = 339,
  [531] = 347,
  [532] = 532,
  [533] = 340,
  [534] = 346,
  [535] = 355,
  [536] = 536,
  [537] = 348,
  [538] = 538,
  [539] = 344,
  [540] = 353,
  [541] = 342,
  [542] = 205,
  [543] = 199,
  [544] = 199,
  [545] = 200,
  [546] = 351,
  [547] = 547,
  [548] = 353,
  [549] = 549,
  [550] = 550,
  [551] = 352,
  [552] = 354,
  [553] = 143,
  [554] = 142,
  [555] = 159,
  [556] = 304,
  [557] = 296,
  [558] = 297,
  [559] = 354,
  [560] = 355,
  [561] = 319,
  [562] = 320,
  [563] = 321,
  [564] = 549,
  [565] = 358,
  [566] = 322,
  [567] = 323,
  [568] = 293,
  [569] = 354,
  [570] = 325,
  [571] = 326,
  [572] = 344,
  [573] = 573,
  [574] = 345,
  [575] = 342,
  [576] = 576,
  [577] = 307,
  [578] = 308,
  [579] = 336,
  [580] = 159,
  [581] = 310,
  [582] = 142,
  [583] = 311,
  [584] = 312,
  [585] = 143,
  [586] = 343,
  [587] = 327,
  [588] = 328,
  [589] = 313,
  [590] = 329,
  [591] = 330,
  [592] = 314,
  [593] = 331,
  [594] = 332,
  [595] = 346,
  [596] = 347,
  [597] = 339,
  [598] = 333,
  [599] = 316,
  [600] = 317,
  [601] = 295,
  [602] = 334,
  [603] = 348,
  [604] = 318,
  [605] = 335,
  [606] = 547,
  [607] = 340,
  [608] = 309,
  [609] = 609,
  [610] = 576,
  [611] = 611,
  [612] = 550,
  [613] = 613,
  [614] = 199,
  [615] = 573,
  [616] = 200,
  [617] = 205,
  [618] = 618,
  [619] = 619,
  [620] = 620,
  [621] = 621,
  [622] = 622,
  [623] = 620,
  [624] = 620,
  [625] = 625,
  [626] = 626,
  [627] = 619,
  [628] = 625,
  [629] = 205,
  [630] = 630,
  [631] = 199,
  [632] = 622,
  [633] = 200,
  [634] = 626,
  [635] = 635,
  [636] = 636,
  [637] = 637,
  [638] = 620,
  [639] = 620,
  [640] = 640,
  [641] = 327,
  [642] = 328,
  [643] = 643,
  [644] = 329,
  [645] = 645,
  [646] = 646,
  [647] = 647,
  [648] = 330,
  [649] = 640,
  [650] = 354,
  [651] = 651,
  [652] = 331,
  [653] = 318,
  [654] = 355,
  [655] = 645,
  [656] = 656,
  [657] = 657,
  [658] = 645,
  [659] = 640,
  [660] = 660,
  [661] = 332,
  [662] = 662,
  [663] = 656,
  [664] = 333,
  [665] = 645,
  [666] = 309,
  [667] = 667,
  [668] = 640,
  [669] = 669,
  [670] = 334,
  [671] = 335,
  [672] = 656,
  [673] = 336,
  [674] = 645,
  [675] = 304,
  [676] = 358,
  [677] = 308,
  [678] = 640,
  [679] = 310,
  [680] = 656,
  [681] = 319,
  [682] = 320,
  [683] = 321,
  [684] = 352,
  [685] = 667,
  [686] = 669,
  [687] = 687,
  [688] = 339,
  [689] = 689,
  [690] = 340,
  [691] = 691,
  [692] = 692,
  [693] = 312,
  [694] = 342,
  [695] = 695,
  [696] = 696,
  [697] = 307,
  [698] = 322,
  [699] = 343,
  [700] = 656,
  [701] = 313,
  [702] = 344,
  [703] = 345,
  [704] = 314,
  [705] = 323,
  [706] = 325,
  [707] = 692,
  [708] = 346,
  [709] = 326,
  [710] = 347,
  [711] = 348,
  [712] = 316,
  [713] = 317,
  [714] = 714,
  [715] = 715,
  [716] = 293,
  [717] = 295,
  [718] = 718,
  [719] = 296,
  [720] = 297,
  [721] = 351,
  [722] = 722,
  [723] = 723,
  [724] = 353,
  [725] = 311,
  [726] = 331,
  [727] = 657,
  [728] = 715,
  [729] = 714,
  [730] = 730,
  [731] = 319,
  [732] = 320,
  [733] = 321,
  [734] = 322,
  [735] = 323,
  [736] = 696,
  [737] = 325,
  [738] = 326,
  [739] = 344,
  [740] = 345,
  [741] = 718,
  [742] = 722,
  [743] = 743,
  [744] = 723,
  [745] = 662,
  [746] = 327,
  [747] = 328,
  [748] = 329,
  [749] = 330,
  [750] = 332,
  [751] = 346,
  [752] = 347,
  [753] = 333,
  [754] = 351,
  [755] = 755,
  [756] = 352,
  [757] = 353,
  [758] = 293,
  [759] = 339,
  [760] = 334,
  [761] = 348,
  [762] = 762,
  [763] = 295,
  [764] = 340,
  [765] = 335,
  [766] = 296,
  [767] = 767,
  [768] = 768,
  [769] = 769,
  [770] = 297,
  [771] = 771,
  [772] = 772,
  [773] = 773,
  [774] = 774,
  [775] = 743,
  [776] = 776,
  [777] = 777,
  [778] = 755,
  [779] = 336,
  [780] = 743,
  [781] = 743,
  [782] = 355,
  [783] = 755,
  [784] = 643,
  [785] = 743,
  [786] = 646,
  [787] = 787,
  [788] = 755,
  [789] = 774,
  [790] = 358,
  [791] = 687,
  [792] = 743,
  [793] = 691,
  [794] = 755,
  [795] = 743,
  [796] = 743,
  [797] = 689,
  [798] = 354,
  [799] = 304,
  [800] = 342,
  [801] = 307,
  [802] = 308,
  [803] = 309,
  [804] = 804,
  [805] = 310,
  [806] = 311,
  [807] = 312,
  [808] = 343,
  [809] = 313,
  [810] = 314,
  [811] = 767,
  [812] = 651,
  [813] = 768,
  [814] = 769,
  [815] = 550,
  [816] = 755,
  [817] = 695,
  [818] = 316,
  [819] = 317,
  [820] = 318,
  [821] = 771,
  [822] = 772,
  [823] = 773,
  [824] = 762,
  [825] = 825,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 828,
  [830] = 830,
  [831] = 831,
  [832] = 832,
  [833] = 825,
  [834] = 834,
  [835] = 835,
  [836] = 830,
  [837] = 831,
  [838] = 838,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 842,
  [843] = 843,
  [844] = 844,
  [845] = 828,
  [846] = 846,
  [847] = 831,
  [848] = 832,
  [849] = 730,
  [850] = 825,
  [851] = 832,
  [852] = 834,
  [853] = 838,
  [854] = 830,
  [855] = 834,
  [856] = 838,
  [857] = 842,
  [858] = 843,
  [859] = 828,
  [860] = 860,
  [861] = 831,
  [862] = 832,
  [863] = 825,
  [864] = 834,
  [865] = 832,
  [866] = 830,
  [867] = 867,
  [868] = 838,
  [869] = 842,
  [870] = 843,
  [871] = 825,
  [872] = 872,
  [873] = 831,
  [874] = 825,
  [875] = 838,
  [876] = 843,
  [877] = 834,
  [878] = 831,
  [879] = 825,
  [880] = 831,
  [881] = 881,
  [882] = 831,
  [883] = 825,
  [884] = 831,
  [885] = 831,
  [886] = 825,
  [887] = 831,
  [888] = 825,
  [889] = 831,
  [890] = 825,
  [891] = 831,
  [892] = 825,
  [893] = 831,
  [894] = 825,
  [895] = 831,
  [896] = 825,
  [897] = 831,
  [898] = 825,
  [899] = 831,
  [900] = 825,
  [901] = 825,
  [902] = 825,
  [903] = 903,
  [904] = 842,
  [905] = 905,
  [906] = 906,
  [907] = 907,
  [908] = 860,
  [909] = 830,
  [910] = 910,
  [911] = 843,
  [912] = 912,
  [913] = 913,
  [914] = 914,
  [915] = 828,
  [916] = 550,
  [917] = 917,
  [918] = 838,
  [919] = 919,
  [920] = 143,
  [921] = 921,
  [922] = 922,
  [923] = 662,
  [924] = 842,
  [925] = 843,
  [926] = 926,
  [927] = 927,
  [928] = 928,
  [929] = 910,
  [930] = 930,
  [931] = 831,
  [932] = 932,
  [933] = 825,
  [934] = 934,
  [935] = 825,
  [936] = 611,
  [937] = 662,
  [938] = 776,
  [939] = 939,
  [940] = 917,
  [941] = 905,
  [942] = 939,
  [943] = 943,
  [944] = 944,
  [945] = 840,
  [946] = 846,
  [947] = 939,
  [948] = 159,
  [949] = 142,
  [950] = 927,
  [951] = 839,
  [952] = 907,
  [953] = 867,
  [954] = 609,
  [955] = 955,
  [956] = 613,
  [957] = 939,
  [958] = 958,
  [959] = 959,
  [960] = 200,
  [961] = 927,
  [962] = 955,
  [963] = 963,
  [964] = 827,
  [965] = 930,
  [966] = 917,
  [967] = 958,
  [968] = 968,
  [969] = 846,
  [970] = 970,
  [971] = 636,
  [972] = 943,
  [973] = 944,
  [974] = 974,
  [975] = 975,
  [976] = 976,
  [977] = 977,
  [978] = 906,
  [979] = 979,
  [980] = 980,
  [981] = 934,
  [982] = 205,
  [983] = 613,
  [984] = 984,
  [985] = 609,
  [986] = 979,
  [987] = 919,
  [988] = 611,
  [989] = 922,
  [990] = 990,
  [991] = 917,
  [992] = 826,
  [993] = 993,
  [994] = 994,
  [995] = 921,
  [996] = 881,
  [997] = 997,
  [998] = 872,
  [999] = 846,
  [1000] = 1000,
  [1001] = 912,
  [1002] = 1002,
  [1003] = 927,
  [1004] = 1004,
  [1005] = 1005,
  [1006] = 977,
  [1007] = 776,
  [1008] = 609,
  [1009] = 846,
  [1010] = 927,
  [1011] = 1011,
  [1012] = 1012,
  [1013] = 1002,
  [1014] = 1000,
  [1015] = 611,
  [1016] = 613,
  [1017] = 636,
  [1018] = 980,
  [1019] = 1019,
  [1020] = 1004,
  [1021] = 984,
  [1022] = 997,
  [1023] = 1012,
  [1024] = 993,
  [1025] = 1025,
  [1026] = 1026,
  [1027] = 1002,
  [1028] = 776,
  [1029] = 1029,
  [1030] = 1030,
  [1031] = 1026,
  [1032] = 1032,
  [1033] = 1033,
  [1034] = 1034,
  [1035] = 1030,
  [1036] = 1032,
  [1037] = 930,
  [1038] = 827,
  [1039] = 927,
  [1040] = 636,
  [1041] = 1030,
  [1042] = 1026,
  [1043] = 1032,
  [1044] = 1030,
  [1045] = 1026,
  [1046] = 1032,
  [1047] = 846,
  [1048] = 1048,
  [1049] = 1048,
  [1050] = 1050,
  [1051] = 1051,
  [1052] = 1052,
  [1053] = 1053,
  [1054] = 1034,
  [1055] = 611,
  [1056] = 1056,
  [1057] = 1057,
  [1058] = 613,
  [1059] = 1029,
  [1060] = 922,
  [1061] = 826,
  [1062] = 906,
  [1063] = 609,
  [1064] = 827,
  [1065] = 921,
  [1066] = 1051,
  [1067] = 1052,
  [1068] = 1056,
  [1069] = 1053,
  [1070] = 1048,
  [1071] = 1051,
  [1072] = 1052,
  [1073] = 1053,
  [1074] = 930,
  [1075] = 1075,
  [1076] = 1056,
  [1077] = 1077,
  [1078] = 1048,
  [1079] = 1051,
  [1080] = 1052,
  [1081] = 1053,
  [1082] = 1056,
  [1083] = 1033,
  [1084] = 927,
  [1085] = 846,
  [1086] = 912,
  [1087] = 1032,
  [1088] = 1075,
  [1089] = 1089,
  [1090] = 1030,
  [1091] = 1026,
  [1092] = 1032,
  [1093] = 906,
  [1094] = 1094,
  [1095] = 1057,
  [1096] = 636,
  [1097] = 912,
  [1098] = 1098,
  [1099] = 921,
  [1100] = 1100,
  [1101] = 1057,
  [1102] = 922,
  [1103] = 1032,
  [1104] = 121,
  [1105] = 1105,
  [1106] = 1030,
  [1107] = 1026,
  [1108] = 1032,
  [1109] = 1030,
  [1110] = 1026,
  [1111] = 1032,
  [1112] = 1030,
  [1113] = 1026,
  [1114] = 1011,
  [1115] = 1030,
  [1116] = 1026,
  [1117] = 1077,
  [1118] = 1032,
  [1119] = 1050,
  [1120] = 1030,
  [1121] = 1026,
  [1122] = 826,
  [1123] = 1056,
  [1124] = 1052,
  [1125] = 1053,
  [1126] = 1094,
  [1127] = 1056,
  [1128] = 1128,
  [1129] = 1048,
  [1130] = 1051,
  [1131] = 1052,
  [1132] = 1053,
  [1133] = 1011,
  [1134] = 912,
  [1135] = 1135,
  [1136] = 922,
  [1137] = 826,
  [1138] = 1050,
  [1139] = 1139,
  [1140] = 1140,
  [1141] = 1056,
  [1142] = 906,
  [1143] = 1048,
  [1144] = 1056,
  [1145] = 1145,
  [1146] = 1048,
  [1147] = 1105,
  [1148] = 1052,
  [1149] = 1053,
  [1150] = 1051,
  [1151] = 1052,
  [1152] = 1056,
  [1153] = 1053,
  [1154] = 1048,
  [1155] = 1051,
  [1156] = 1052,
  [1157] = 1053,
  [1158] = 1057,
  [1159] = 921,
  [1160] = 1160,
  [1161] = 1056,
  [1162] = 1048,
  [1163] = 1051,
  [1164] = 1052,
  [1165] = 1053,
  [1166] = 1145,
  [1167] = 1167,
  [1168] = 1098,
  [1169] = 1089,
  [1170] = 1048,
  [1171] = 1167,
  [1172] = 1051,
  [1173] = 1051,
  [1174] = 1026,
  [1175] = 609,
  [1176] = 1176,
  [1177] = 1177,
  [1178] = 1178,
  [1179] = 1179,
  [1180] = 611,
  [1181] = 613,
  [1182] = 1140,
  [1183] = 1183,
  [1184] = 1184,
  [1185] = 1185,
  [1186] = 1186,
  [1187] = 1160,
  [1188] = 1032,
  [1189] = 1189,
  [1190] = 1190,
  [1191] = 1191,
  [1192] = 1192,
  [1193] = 1193,
  [1194] = 1194,
  [1195] = 1195,
  [1196] = 1196,
  [1197] = 1197,
  [1198] = 1198,
  [1199] = 1199,
  [1200] = 1200,
  [1201] = 1201,
  [1202] = 1202,
  [1203] = 1026,
  [1204] = 1204,
  [1205] = 1205,
  [1206] = 1032,
  [1207] = 1207,
  [1208] = 1208,
  [1209] = 1201,
  [1210] = 1210,
  [1211] = 1204,
  [1212] = 1205,
  [1213] = 1207,
  [1214] = 1208,
  [1215] = 1215,
  [1216] = 1135,
  [1217] = 1139,
  [1218] = 1218,
  [1219] = 1030,
  [1220] = 1220,
  [1221] = 1221,
  [1222] = 1222,
  [1223] = 1223,
  [1224] = 1224,
  [1225] = 1225,
  [1226] = 1226,
  [1227] = 927,
  [1228] = 1228,
  [1229] = 1229,
  [1230] = 1185,
  [1231] = 1190,
  [1232] = 1193,
  [1233] = 1128,
  [1234] = 1030,
  [1235] = 1235,
  [1236] = 1048,
  [1237] = 1032,
  [1238] = 1179,
  [1239] = 1201,
  [1240] = 1030,
  [1241] = 1026,
  [1242] = 1178,
  [1243] = 1204,
  [1244] = 1205,
  [1245] = 1032,
  [1246] = 1057,
  [1247] = 1207,
  [1248] = 1208,
  [1249] = 927,
  [1250] = 609,
  [1251] = 1183,
  [1252] = 611,
  [1253] = 613,
  [1254] = 1176,
  [1255] = 1255,
  [1256] = 1256,
  [1257] = 1257,
  [1258] = 1177,
  [1259] = 1184,
  [1260] = 1215,
  [1261] = 1261,
  [1262] = 1262,
  [1263] = 1263,
  [1264] = 1201,
  [1265] = 1204,
  [1266] = 1205,
  [1267] = 1267,
  [1268] = 1207,
  [1269] = 1208,
  [1270] = 1201,
  [1271] = 1030,
  [1272] = 1026,
  [1273] = 1204,
  [1274] = 1205,
  [1275] = 1032,
  [1276] = 1207,
  [1277] = 1208,
  [1278] = 1202,
  [1279] = 1026,
  [1280] = 1032,
  [1281] = 1056,
  [1282] = 1282,
  [1283] = 1048,
  [1284] = 1284,
  [1285] = 1285,
  [1286] = 1051,
  [1287] = 1052,
  [1288] = 1053,
  [1289] = 1289,
  [1290] = 1189,
  [1291] = 1284,
  [1292] = 1285,
  [1293] = 1191,
  [1294] = 1284,
  [1295] = 1285,
  [1296] = 1192,
  [1297] = 1297,
  [1298] = 1284,
  [1299] = 1285,
  [1300] = 1263,
  [1301] = 1301,
  [1302] = 636,
  [1303] = 1210,
  [1304] = 1194,
  [1305] = 1195,
  [1306] = 121,
  [1307] = 1301,
  [1308] = 1282,
  [1309] = 1261,
  [1310] = 1196,
  [1311] = 1056,
  [1312] = 1051,
  [1313] = 1197,
  [1314] = 1052,
  [1315] = 1053,
  [1316] = 1030,
  [1317] = 1026,
  [1318] = 1218,
  [1319] = 1198,
  [1320] = 1220,
  [1321] = 1221,
  [1322] = 1222,
  [1323] = 1223,
  [1324] = 1224,
  [1325] = 1225,
  [1326] = 1226,
  [1327] = 1199,
  [1328] = 1200,
  [1329] = 1267,
  [1330] = 1228,
  [1331] = 1229,
  [1332] = 1030,
  [1333] = 143,
  [1334] = 1205,
  [1335] = 1335,
  [1336] = 1048,
  [1337] = 1207,
  [1338] = 921,
  [1339] = 1208,
  [1340] = 1257,
  [1341] = 351,
  [1342] = 352,
  [1343] = 353,
  [1344] = 1052,
  [1345] = 1053,
  [1346] = 159,
  [1347] = 1262,
  [1348] = 142,
  [1349] = 1255,
  [1350] = 1051,
  [1351] = 143,
  [1352] = 912,
  [1353] = 1204,
  [1354] = 1207,
  [1355] = 1208,
  [1356] = 1356,
  [1357] = 1205,
  [1358] = 1358,
  [1359] = 1052,
  [1360] = 1360,
  [1361] = 1289,
  [1362] = 1362,
  [1363] = 1053,
  [1364] = 1201,
  [1365] = 1365,
  [1366] = 1366,
  [1367] = 159,
  [1368] = 142,
  [1369] = 1204,
  [1370] = 159,
  [1371] = 142,
  [1372] = 1051,
  [1373] = 121,
  [1374] = 1335,
  [1375] = 1375,
  [1376] = 1256,
  [1377] = 636,
  [1378] = 1378,
  [1379] = 1056,
  [1380] = 1056,
  [1381] = 1297,
  [1382] = 1048,
  [1383] = 1383,
  [1384] = 1048,
  [1385] = 1051,
  [1386] = 1052,
  [1387] = 1053,
  [1388] = 1388,
  [1389] = 1378,
  [1390] = 1390,
  [1391] = 1056,
  [1392] = 1235,
  [1393] = 1048,
  [1394] = 1051,
  [1395] = 1052,
  [1396] = 1053,
  [1397] = 1397,
  [1398] = 1398,
  [1399] = 1399,
  [1400] = 1201,
  [1401] = 1056,
  [1402] = 1388,
  [1403] = 1397,
  [1404] = 143,
  [1405] = 1405,
  [1406] = 1406,
  [1407] = 1407,
  [1408] = 142,
  [1409] = 1207,
  [1410] = 1208,
  [1411] = 355,
  [1412] = 1366,
  [1413] = 1413,
  [1414] = 1375,
  [1415] = 1284,
  [1416] = 1416,
  [1417] = 1285,
  [1418] = 1418,
  [1419] = 1419,
  [1420] = 358,
  [1421] = 1421,
  [1422] = 1422,
  [1423] = 1423,
  [1424] = 1284,
  [1425] = 1425,
  [1426] = 1426,
  [1427] = 1285,
  [1428] = 1428,
  [1429] = 1429,
  [1430] = 1413,
  [1431] = 1284,
  [1432] = 1285,
  [1433] = 1433,
  [1434] = 1434,
  [1435] = 1435,
  [1436] = 1436,
  [1437] = 1405,
  [1438] = 1438,
  [1439] = 1439,
  [1440] = 1366,
  [1441] = 1284,
  [1442] = 1285,
  [1443] = 1443,
  [1444] = 1365,
  [1445] = 1375,
  [1446] = 143,
  [1447] = 1428,
  [1448] = 1448,
  [1449] = 1449,
  [1450] = 1405,
  [1451] = 1284,
  [1452] = 1285,
  [1453] = 1453,
  [1454] = 1454,
  [1455] = 1455,
  [1456] = 1422,
  [1457] = 1425,
  [1458] = 1458,
  [1459] = 912,
  [1460] = 159,
  [1461] = 159,
  [1462] = 142,
  [1463] = 143,
  [1464] = 1201,
  [1465] = 1423,
  [1466] = 1466,
  [1467] = 142,
  [1468] = 1204,
  [1469] = 1418,
  [1470] = 1419,
  [1471] = 1205,
  [1472] = 1466,
  [1473] = 1358,
  [1474] = 1436,
  [1475] = 1426,
  [1476] = 1448,
  [1477] = 1477,
  [1478] = 1478,
  [1479] = 1479,
  [1480] = 159,
  [1481] = 1434,
  [1482] = 1482,
  [1483] = 143,
  [1484] = 1399,
  [1485] = 1485,
  [1486] = 1486,
  [1487] = 1356,
  [1488] = 1207,
  [1489] = 1439,
  [1490] = 1477,
  [1491] = 1491,
  [1492] = 1208,
  [1493] = 1491,
  [1494] = 1360,
  [1495] = 1390,
  [1496] = 1496,
  [1497] = 1497,
  [1498] = 1498,
  [1499] = 1499,
  [1500] = 1500,
  [1501] = 1399,
  [1502] = 1502,
  [1503] = 1204,
  [1504] = 1205,
  [1505] = 1421,
  [1506] = 1284,
  [1507] = 1285,
  [1508] = 1201,
  [1509] = 1416,
  [1510] = 1510,
  [1511] = 1511,
  [1512] = 1485,
  [1513] = 921,
  [1514] = 1514,
  [1515] = 1515,
  [1516] = 1362,
  [1517] = 1517,
  [1518] = 1482,
  [1519] = 1519,
  [1520] = 1479,
  [1521] = 1498,
  [1522] = 1522,
  [1523] = 1405,
  [1524] = 1407,
  [1525] = 1454,
  [1526] = 1478,
  [1527] = 1455,
  [1528] = 1496,
  [1529] = 1497,
  [1530] = 1530,
  [1531] = 1405,
  [1532] = 1455,
  [1533] = 1486,
  [1534] = 1405,
  [1535] = 1455,
  [1536] = 1383,
  [1537] = 1405,
  [1538] = 1405,
  [1539] = 1405,
  [1540] = 1405,
  [1541] = 1405,
  [1542] = 1405,
  [1543] = 1405,
  [1544] = 1405,
  [1545] = 1405,
  [1546] = 1530,
  [1547] = 1405,
  [1548] = 1390,
  [1549] = 1549,
  [1550] = 1399,
  [1551] = 1551,
  [1552] = 1406,
  [1553] = 1553,
  [1554] = 1522,
  [1555] = 1429,
  [1556] = 1517,
  [1557] = 1557,
  [1558] = 1558,
  [1559] = 1557,
  [1560] = 1435,
  [1561] = 1561,
  [1562] = 1562,
  [1563] = 1563,
  [1564] = 1564,
  [1565] = 1406,
  [1566] = 1522,
  [1567] = 1557,
  [1568] = 1510,
  [1569] = 1569,
  [1570] = 1514,
  [1571] = 1571,
  [1572] = 1201,
  [1573] = 1573,
  [1574] = 1204,
  [1575] = 1205,
  [1576] = 1557,
  [1577] = 1557,
  [1578] = 1207,
  [1579] = 1208,
  [1580] = 1580,
  [1581] = 1581,
  [1582] = 1458,
  [1583] = 1502,
  [1584] = 1557,
  [1585] = 1557,
  [1586] = 1557,
  [1587] = 1587,
  [1588] = 1588,
  [1589] = 1589,
  [1590] = 1557,
  [1591] = 1591,
  [1592] = 1592,
  [1593] = 1390,
  [1594] = 1594,
  [1595] = 1595,
  [1596] = 1557,
  [1597] = 200,
  [1598] = 1443,
  [1599] = 1515,
  [1600] = 1557,
  [1601] = 205,
  [1602] = 1602,
  [1603] = 1603,
  [1604] = 1604,
  [1605] = 1605,
  [1606] = 1606,
  [1607] = 1557,
  [1608] = 1608,
  [1609] = 1557,
  [1610] = 1557,
  [1611] = 1571,
  [1612] = 200,
  [1613] = 121,
  [1614] = 205,
  [1615] = 200,
  [1616] = 205,
  [1617] = 1453,
  [1618] = 1573,
  [1619] = 358,
  [1620] = 1514,
  [1621] = 1433,
  [1622] = 1580,
  [1623] = 355,
  [1624] = 1449,
  [1625] = 1625,
  [1626] = 1626,
  [1627] = 1563,
  [1628] = 1589,
  [1629] = 1366,
  [1630] = 1375,
  [1631] = 1557,
  [1632] = 1557,
  [1633] = 1564,
  [1634] = 1634,
  [1635] = 1635,
  [1636] = 1636,
  [1637] = 1637,
  [1638] = 1638,
  [1639] = 1636,
  [1640] = 1514,
  [1641] = 1641,
  [1642] = 1636,
  [1643] = 205,
  [1644] = 1636,
  [1645] = 1645,
  [1646] = 1581,
  [1647] = 1636,
  [1648] = 205,
  [1649] = 1553,
  [1650] = 200,
  [1651] = 200,
  [1652] = 1284,
  [1653] = 1285,
  [1654] = 1636,
  [1655] = 1569,
  [1656] = 1656,
  [1657] = 1636,
  [1658] = 1658,
  [1659] = 1659,
  [1660] = 1660,
  [1661] = 1636,
  [1662] = 1662,
  [1663] = 1558,
  [1664] = 1664,
  [1665] = 1636,
  [1666] = 1636,
  [1667] = 1636,
  [1668] = 1636,
  [1669] = 1284,
  [1670] = 1587,
  [1671] = 1285,
  [1672] = 1636,
  [1673] = 200,
  [1674] = 121,
  [1675] = 205,
  [1676] = 1676,
  [1677] = 121,
  [1678] = 1588,
  [1679] = 1562,
  [1680] = 1641,
  [1681] = 1638,
  [1682] = 1561,
  [1683] = 1683,
  [1684] = 1551,
  [1685] = 1638,
  [1686] = 1636,
  [1687] = 1549,
  [1688] = 1638,
  [1689] = 1689,
  [1690] = 1638,
  [1691] = 1691,
  [1692] = 1406,
  [1693] = 1693,
  [1694] = 1636,
  [1695] = 1522,
  [1696] = 1605,
  [1697] = 1606,
  [1698] = 1608,
  [1699] = 1636,
  [1700] = 1562,
  [1701] = 1558,
  [1702] = 1702,
  [1703] = 199,
  [1704] = 1693,
  [1705] = 1705,
  [1706] = 1390,
  [1707] = 1707,
  [1708] = 1284,
  [1709] = 1284,
  [1710] = 1285,
  [1711] = 1285,
  [1712] = 1645,
  [1713] = 1713,
  [1714] = 1714,
  [1715] = 121,
  [1716] = 1201,
  [1717] = 159,
  [1718] = 142,
  [1719] = 1399,
  [1720] = 1720,
  [1721] = 143,
  [1722] = 1366,
  [1723] = 1723,
  [1724] = 1724,
  [1725] = 1725,
  [1726] = 959,
  [1727] = 1727,
  [1728] = 974,
  [1729] = 1729,
  [1730] = 1375,
  [1731] = 1731,
  [1732] = 1732,
  [1733] = 1733,
  [1734] = 1734,
  [1735] = 121,
  [1736] = 1736,
  [1737] = 1737,
  [1738] = 1738,
  [1739] = 1739,
  [1740] = 1740,
  [1741] = 1284,
  [1742] = 1742,
  [1743] = 963,
  [1744] = 1284,
  [1745] = 975,
  [1746] = 1707,
  [1747] = 1691,
  [1748] = 1748,
  [1749] = 1724,
  [1750] = 1733,
  [1751] = 1562,
  [1752] = 1752,
  [1753] = 1693,
  [1754] = 1754,
  [1755] = 1755,
  [1756] = 1756,
  [1757] = 1757,
  [1758] = 1635,
  [1759] = 1285,
  [1760] = 1285,
  [1761] = 1761,
  [1762] = 1762,
  [1763] = 1656,
  [1764] = 1204,
  [1765] = 274,
  [1766] = 1205,
  [1767] = 1676,
  [1768] = 1768,
  [1769] = 1769,
  [1770] = 1770,
  [1771] = 1658,
  [1772] = 1733,
  [1773] = 1683,
  [1774] = 1762,
  [1775] = 970,
  [1776] = 1770,
  [1777] = 1558,
  [1778] = 1778,
  [1779] = 1731,
  [1780] = 1780,
  [1781] = 1664,
  [1782] = 1207,
  [1783] = 1783,
  [1784] = 1762,
  [1785] = 1733,
  [1786] = 1768,
  [1787] = 1691,
  [1788] = 1762,
  [1789] = 1208,
  [1790] = 1660,
  [1791] = 1727,
  [1792] = 1792,
  [1793] = 1761,
  [1794] = 1794,
  [1795] = 1795,
  [1796] = 1796,
  [1797] = 274,
  [1798] = 1798,
  [1799] = 1799,
  [1800] = 1800,
  [1801] = 1801,
  [1802] = 1802,
  [1803] = 1803,
  [1804] = 1406,
  [1805] = 1805,
  [1806] = 1806,
  [1807] = 1807,
  [1808] = 1808,
  [1809] = 1809,
  [1810] = 1810,
  [1811] = 1811,
  [1812] = 1778,
  [1813] = 1813,
  [1814] = 121,
  [1815] = 1815,
  [1816] = 1725,
  [1817] = 1817,
  [1818] = 1818,
  [1819] = 1742,
  [1820] = 1522,
  [1821] = 1723,
  [1822] = 1822,
  [1823] = 1823,
  [1824] = 1207,
  [1825] = 1208,
  [1826] = 1783,
  [1827] = 1827,
  [1828] = 1828,
  [1829] = 1829,
  [1830] = 1813,
  [1831] = 1831,
  [1832] = 1832,
  [1833] = 1705,
  [1834] = 1834,
  [1835] = 1835,
  [1836] = 1720,
  [1837] = 1837,
  [1838] = 1514,
  [1839] = 159,
  [1840] = 1840,
  [1841] = 1841,
  [1842] = 1752,
  [1843] = 1843,
  [1844] = 1844,
  [1845] = 1740,
  [1846] = 1796,
  [1847] = 1756,
  [1848] = 1792,
  [1849] = 1835,
  [1850] = 1801,
  [1851] = 1792,
  [1852] = 1796,
  [1853] = 1792,
  [1854] = 1854,
  [1855] = 1201,
  [1856] = 1739,
  [1857] = 1796,
  [1858] = 1858,
  [1859] = 1859,
  [1860] = 1860,
  [1861] = 1748,
  [1862] = 199,
  [1863] = 1204,
  [1864] = 1205,
  [1865] = 1732,
  [1866] = 1866,
  [1867] = 1736,
  [1868] = 143,
  [1869] = 1738,
  [1870] = 1870,
  [1871] = 1870,
  [1872] = 1860,
  [1873] = 1866,
  [1874] = 1691,
  [1875] = 1875,
  [1876] = 1841,
  [1877] = 1693,
  [1878] = 1737,
  [1879] = 1835,
  [1880] = 1880,
  [1881] = 1754,
  [1882] = 1882,
  [1883] = 1835,
  [1884] = 1801,
  [1885] = 1734,
  [1886] = 1886,
  [1887] = 1757,
  [1888] = 1729,
  [1889] = 1801,
  [1890] = 1890,
  [1891] = 1713,
  [1892] = 1714,
  [1893] = 1893,
  [1894] = 1840,
  [1895] = 1755,
  [1896] = 1896,
  [1897] = 142,
  [1898] = 1831,
  [1899] = 1805,
  [1900] = 1795,
  [1901] = 1901,
  [1902] = 1800,
  [1903] = 1903,
  [1904] = 1733,
  [1905] = 1858,
  [1906] = 1859,
  [1907] = 1907,
  [1908] = 1762,
  [1909] = 1807,
  [1910] = 1910,
  [1911] = 1733,
  [1912] = 1912,
  [1913] = 1913,
  [1914] = 121,
  [1915] = 1733,
  [1916] = 1916,
  [1917] = 1917,
  [1918] = 1918,
  [1919] = 121,
  [1920] = 1920,
  [1921] = 1025,
  [1922] = 1803,
  [1923] = 121,
  [1924] = 1011,
  [1925] = 1562,
  [1926] = 1880,
  [1927] = 1882,
  [1928] = 1928,
  [1929] = 1929,
  [1930] = 1930,
  [1931] = 1762,
  [1932] = 1662,
  [1933] = 1933,
  [1934] = 1005,
  [1935] = 1019,
  [1936] = 1936,
  [1937] = 121,
  [1938] = 1938,
  [1939] = 1939,
  [1940] = 1558,
  [1941] = 1811,
  [1942] = 1762,
  [1943] = 1943,
  [1944] = 1944,
  [1945] = 1802,
  [1946] = 205,
  [1947] = 1827,
  [1948] = 1910,
  [1949] = 159,
  [1950] = 1950,
  [1951] = 1951,
  [1952] = 1798,
  [1953] = 1733,
  [1954] = 1799,
  [1955] = 1844,
  [1956] = 1936,
  [1957] = 1733,
  [1958] = 142,
  [1959] = 1959,
  [1960] = 200,
  [1961] = 1828,
  [1962] = 354,
  [1963] = 1951,
  [1964] = 1933,
  [1965] = 1965,
  [1966] = 1829,
  [1967] = 1733,
  [1968] = 143,
  [1969] = 1806,
  [1970] = 1808,
  [1971] = 1832,
  [1972] = 1959,
  [1973] = 1834,
  [1974] = 1815,
  [1975] = 1975,
  [1976] = 1762,
  [1977] = 1762,
  [1978] = 1978,
  [1979] = 1944,
  [1980] = 1809,
  [1981] = 1762,
  [1982] = 1810,
  [1983] = 1983,
  [1984] = 1984,
  [1985] = 1875,
  [1986] = 1886,
  [1987] = 1794,
  [1988] = 1893,
  [1989] = 1989,
  [1990] = 1938,
  [1991] = 142,
  [1992] = 1992,
  [1993] = 1993,
  [1994] = 1994,
  [1995] = 1995,
  [1996] = 1996,
  [1997] = 1801,
  [1998] = 1998,
  [1999] = 1792,
  [2000] = 143,
  [2001] = 1801,
  [2002] = 1801,
  [2003] = 2003,
  [2004] = 1920,
  [2005] = 2005,
  [2006] = 2006,
  [2007] = 2007,
  [2008] = 1801,
  [2009] = 1901,
  [2010] = 2010,
  [2011] = 2011,
  [2012] = 1975,
  [2013] = 1978,
  [2014] = 2014,
  [2015] = 2015,
  [2016] = 2016,
  [2017] = 1691,
  [2018] = 2018,
  [2019] = 2019,
  [2020] = 2020,
  [2021] = 2021,
  [2022] = 1792,
  [2023] = 121,
  [2024] = 1907,
  [2025] = 2005,
  [2026] = 2026,
  [2027] = 1913,
  [2028] = 1005,
  [2029] = 2029,
  [2030] = 2030,
  [2031] = 2031,
  [2032] = 1693,
  [2033] = 1950,
  [2034] = 1801,
  [2035] = 1984,
  [2036] = 2036,
  [2037] = 2037,
  [2038] = 2038,
  [2039] = 1929,
  [2040] = 2040,
  [2041] = 2041,
  [2042] = 1992,
  [2043] = 1011,
  [2044] = 2044,
  [2045] = 2045,
  [2046] = 2046,
  [2047] = 2047,
  [2048] = 2048,
  [2049] = 1917,
  [2050] = 2020,
  [2051] = 2021,
  [2052] = 2052,
  [2053] = 1930,
  [2054] = 1918,
  [2055] = 1916,
  [2056] = 2056,
  [2057] = 1912,
  [2058] = 2058,
  [2059] = 2011,
  [2060] = 2060,
  [2061] = 2061,
  [2062] = 2062,
  [2063] = 2041,
  [2064] = 2064,
  [2065] = 2065,
  [2066] = 2066,
  [2067] = 1939,
  [2068] = 1989,
  [2069] = 2069,
  [2070] = 2070,
  [2071] = 1943,
  [2072] = 2041,
  [2073] = 121,
  [2074] = 121,
  [2075] = 2075,
  [2076] = 1835,
  [2077] = 2041,
  [2078] = 2078,
  [2079] = 121,
  [2080] = 1792,
  [2081] = 1835,
  [2082] = 2041,
  [2083] = 2083,
  [2084] = 1792,
  [2085] = 1835,
  [2086] = 2086,
  [2087] = 1792,
  [2088] = 354,
  [2089] = 2089,
  [2090] = 2090,
  [2091] = 2091,
  [2092] = 2092,
  [2093] = 2029,
  [2094] = 1792,
  [2095] = 205,
  [2096] = 2037,
  [2097] = 2038,
  [2098] = 2098,
  [2099] = 1903,
  [2100] = 1965,
  [2101] = 1662,
  [2102] = 2102,
  [2103] = 1996,
  [2104] = 2064,
  [2105] = 2105,
  [2106] = 1835,
  [2107] = 2107,
  [2108] = 2065,
  [2109] = 1801,
  [2110] = 2066,
  [2111] = 1835,
  [2112] = 200,
  [2113] = 1835,
  [2114] = 2056,
  [2115] = 2115,
  [2116] = 2116,
  [2117] = 159,
  [2118] = 2118,
  [2119] = 2119,
  [2120] = 2083,
  [2121] = 2121,
  [2122] = 2046,
  [2123] = 2123,
  [2124] = 1817,
  [2125] = 2125,
  [2126] = 2126,
  [2127] = 2127,
  [2128] = 2128,
  [2129] = 1005,
  [2130] = 121,
  [2131] = 2131,
  [2132] = 2132,
  [2133] = 2133,
  [2134] = 2134,
  [2135] = 200,
  [2136] = 2048,
  [2137] = 142,
  [2138] = 2006,
  [2139] = 2098,
  [2140] = 2140,
  [2141] = 2102,
  [2142] = 2142,
  [2143] = 2003,
  [2144] = 96,
  [2145] = 2145,
  [2146] = 2010,
  [2147] = 2147,
  [2148] = 1762,
  [2149] = 2149,
  [2150] = 2150,
  [2151] = 2151,
  [2152] = 2007,
  [2153] = 2153,
  [2154] = 2030,
  [2155] = 1733,
  [2156] = 2156,
  [2157] = 97,
  [2158] = 2158,
  [2159] = 121,
  [2160] = 2160,
  [2161] = 2161,
  [2162] = 2115,
  [2163] = 2163,
  [2164] = 2026,
  [2165] = 2165,
  [2166] = 2058,
  [2167] = 121,
  [2168] = 2047,
  [2169] = 1995,
  [2170] = 2015,
  [2171] = 2016,
  [2172] = 2172,
  [2173] = 1011,
  [2174] = 2174,
  [2175] = 1733,
  [2176] = 2086,
  [2177] = 205,
  [2178] = 2178,
  [2179] = 2060,
  [2180] = 2031,
  [2181] = 2044,
  [2182] = 2018,
  [2183] = 2183,
  [2184] = 2061,
  [2185] = 1994,
  [2186] = 2036,
  [2187] = 2187,
  [2188] = 2188,
  [2189] = 2189,
  [2190] = 1762,
  [2191] = 2191,
  [2192] = 2069,
  [2193] = 2019,
  [2194] = 2045,
  [2195] = 2014,
  [2196] = 121,
  [2197] = 2197,
  [2198] = 2198,
  [2199] = 2199,
  [2200] = 2200,
  [2201] = 2201,
  [2202] = 2202,
  [2203] = 2200,
  [2204] = 98,
  [2205] = 1993,
  [2206] = 1822,
  [2207] = 159,
  [2208] = 143,
  [2209] = 2178,
  [2210] = 2052,
  [2211] = 2140,
  [2212] = 2212,
  [2213] = 2191,
  [2214] = 2214,
  [2215] = 2215,
  [2216] = 2216,
  [2217] = 1257,
  [2218] = 2218,
  [2219] = 2219,
  [2220] = 2220,
  [2221] = 2187,
  [2222] = 2222,
  [2223] = 2223,
  [2224] = 2224,
  [2225] = 2225,
  [2226] = 121,
  [2227] = 2227,
  [2228] = 2228,
  [2229] = 2223,
  [2230] = 2224,
  [2231] = 2214,
  [2232] = 2214,
  [2233] = 2233,
  [2234] = 2216,
  [2235] = 2218,
  [2236] = 2222,
  [2237] = 2216,
  [2238] = 2238,
  [2239] = 2225,
  [2240] = 2240,
  [2241] = 2218,
  [2242] = 2242,
  [2243] = 2243,
  [2244] = 2128,
  [2245] = 2216,
  [2246] = 2222,
  [2247] = 2220,
  [2248] = 2240,
  [2249] = 2225,
  [2250] = 2216,
  [2251] = 2222,
  [2252] = 2252,
  [2253] = 2225,
  [2254] = 2212,
  [2255] = 2222,
  [2256] = 2220,
  [2257] = 2225,
  [2258] = 2188,
  [2259] = 2222,
  [2260] = 2172,
  [2261] = 2225,
  [2262] = 96,
  [2263] = 2222,
  [2264] = 2225,
  [2265] = 2265,
  [2266] = 2222,
  [2267] = 2267,
  [2268] = 2225,
  [2269] = 97,
  [2270] = 2222,
  [2271] = 2271,
  [2272] = 2225,
  [2273] = 2223,
  [2274] = 2222,
  [2275] = 2275,
  [2276] = 2225,
  [2277] = 2222,
  [2278] = 2225,
  [2279] = 1792,
  [2280] = 2222,
  [2281] = 1235,
  [2282] = 2225,
  [2283] = 2224,
  [2284] = 2156,
  [2285] = 2163,
  [2286] = 2286,
  [2287] = 2183,
  [2288] = 1835,
  [2289] = 2161,
  [2290] = 1801,
  [2291] = 1801,
  [2292] = 1835,
  [2293] = 1733,
  [2294] = 2126,
  [2295] = 2222,
  [2296] = 1817,
  [2297] = 2228,
  [2298] = 2252,
  [2299] = 2299,
  [2300] = 2145,
  [2301] = 2151,
  [2302] = 2174,
  [2303] = 1792,
  [2304] = 2222,
  [2305] = 2153,
  [2306] = 1762,
  [2307] = 1762,
  [2308] = 1733,
  [2309] = 2309,
  [2310] = 1762,
  [2311] = 2243,
  [2312] = 2214,
  [2313] = 2134,
  [2314] = 2216,
  [2315] = 1762,
  [2316] = 2218,
  [2317] = 2220,
  [2318] = 2219,
  [2319] = 2319,
  [2320] = 2201,
  [2321] = 2222,
  [2322] = 2322,
  [2323] = 2323,
  [2324] = 2324,
  [2325] = 2225,
  [2326] = 2326,
  [2327] = 2223,
  [2328] = 2224,
  [2329] = 2329,
  [2330] = 98,
  [2331] = 2331,
  [2332] = 2160,
  [2333] = 2333,
  [2334] = 2199,
  [2335] = 2214,
  [2336] = 1733,
  [2337] = 2216,
  [2338] = 205,
  [2339] = 2218,
  [2340] = 2220,
  [2341] = 1255,
  [2342] = 2216,
  [2343] = 2222,
  [2344] = 2165,
  [2345] = 2147,
  [2346] = 1256,
  [2347] = 2189,
  [2348] = 2218,
  [2349] = 2225,
  [2350] = 1822,
  [2351] = 2142,
  [2352] = 2225,
  [2353] = 2353,
  [2354] = 1733,
  [2355] = 2149,
  [2356] = 2123,
  [2357] = 2223,
  [2358] = 2358,
  [2359] = 2224,
  [2360] = 101,
  [2361] = 200,
  [2362] = 2214,
  [2363] = 2158,
  [2364] = 2225,
  [2365] = 2265,
  [2366] = 2197,
  [2367] = 2367,
  [2368] = 2368,
  [2369] = 2369,
  [2370] = 2370,
  [2371] = 2371,
  [2372] = 2372,
  [2373] = 2373,
  [2374] = 2233,
  [2375] = 2238,
  [2376] = 2267,
  [2377] = 2377,
  [2378] = 2378,
  [2379] = 1835,
  [2380] = 2380,
  [2381] = 2381,
  [2382] = 2382,
  [2383] = 1792,
  [2384] = 2384,
  [2385] = 2385,
  [2386] = 2386,
  [2387] = 2387,
  [2388] = 2319,
  [2389] = 1801,
  [2390] = 2390,
  [2391] = 2391,
  [2392] = 2392,
  [2393] = 2393,
  [2394] = 2394,
  [2395] = 2395,
  [2396] = 2396,
  [2397] = 2397,
  [2398] = 2398,
  [2399] = 2399,
  [2400] = 2400,
  [2401] = 2401,
  [2402] = 1792,
  [2403] = 2403,
  [2404] = 2404,
  [2405] = 2405,
  [2406] = 2406,
  [2407] = 2407,
  [2408] = 1801,
  [2409] = 2409,
  [2410] = 2410,
  [2411] = 2411,
  [2412] = 2412,
  [2413] = 2413,
  [2414] = 2414,
  [2415] = 2415,
  [2416] = 2416,
  [2417] = 2417,
  [2418] = 2418,
  [2419] = 205,
  [2420] = 2420,
  [2421] = 2421,
  [2422] = 2422,
  [2423] = 2423,
  [2424] = 2424,
  [2425] = 2425,
  [2426] = 2426,
  [2427] = 2427,
  [2428] = 2428,
  [2429] = 2429,
  [2430] = 2430,
  [2431] = 2431,
  [2432] = 2432,
  [2433] = 2433,
  [2434] = 2434,
  [2435] = 2435,
  [2436] = 2436,
  [2437] = 2437,
  [2438] = 2438,
  [2439] = 2439,
  [2440] = 2440,
  [2441] = 2441,
  [2442] = 2442,
  [2443] = 2443,
  [2444] = 2444,
  [2445] = 2445,
  [2446] = 2372,
  [2447] = 2447,
  [2448] = 2448,
  [2449] = 2449,
  [2450] = 2450,
  [2451] = 2451,
  [2452] = 2452,
  [2453] = 2453,
  [2454] = 2454,
  [2455] = 2455,
  [2456] = 2456,
  [2457] = 2457,
  [2458] = 2458,
  [2459] = 2459,
  [2460] = 2460,
  [2461] = 2461,
  [2462] = 2462,
  [2463] = 2463,
  [2464] = 2464,
  [2465] = 2323,
  [2466] = 2466,
  [2467] = 2467,
  [2468] = 2468,
  [2469] = 2469,
  [2470] = 2470,
  [2471] = 2471,
  [2472] = 2472,
  [2473] = 2473,
  [2474] = 2474,
  [2475] = 2475,
  [2476] = 1792,
  [2477] = 2477,
  [2478] = 2478,
  [2479] = 1835,
  [2480] = 2480,
  [2481] = 2481,
  [2482] = 2482,
  [2483] = 2483,
  [2484] = 2484,
  [2485] = 2485,
  [2486] = 2486,
  [2487] = 2487,
  [2488] = 2488,
  [2489] = 2489,
  [2490] = 2490,
  [2491] = 2478,
  [2492] = 2368,
  [2493] = 2493,
  [2494] = 2494,
  [2495] = 2495,
  [2496] = 2420,
  [2497] = 2497,
  [2498] = 2498,
  [2499] = 1801,
  [2500] = 1255,
  [2501] = 1256,
  [2502] = 1257,
  [2503] = 1235,
  [2504] = 2504,
  [2505] = 2505,
  [2506] = 2485,
  [2507] = 2507,
  [2508] = 2508,
  [2509] = 2509,
  [2510] = 2510,
  [2511] = 2511,
  [2512] = 2512,
  [2513] = 2513,
  [2514] = 2514,
  [2515] = 2515,
  [2516] = 2494,
  [2517] = 2517,
  [2518] = 2518,
  [2519] = 2519,
  [2520] = 2520,
  [2521] = 2452,
  [2522] = 2497,
  [2523] = 2523,
  [2524] = 2493,
  [2525] = 2525,
  [2526] = 2431,
  [2527] = 200,
  [2528] = 2528,
  [2529] = 2529,
  [2530] = 2530,
  [2531] = 2372,
  [2532] = 2428,
  [2533] = 2483,
  [2534] = 2534,
  [2535] = 2511,
  [2536] = 2515,
  [2537] = 2517,
  [2538] = 2520,
  [2539] = 2539,
  [2540] = 2540,
  [2541] = 2541,
  [2542] = 2542,
  [2543] = 2543,
  [2544] = 2544,
  [2545] = 2545,
  [2546] = 2546,
  [2547] = 2547,
  [2548] = 2548,
  [2549] = 2549,
  [2550] = 2550,
  [2551] = 2551,
  [2552] = 2552,
  [2553] = 2553,
  [2554] = 2372,
  [2555] = 2555,
  [2556] = 2556,
  [2557] = 2557,
  [2558] = 2558,
  [2559] = 2523,
  [2560] = 2372,
  [2561] = 2561,
  [2562] = 2562,
  [2563] = 2563,
  [2564] = 2498,
  [2565] = 2561,
  [2566] = 2566,
  [2567] = 2567,
  [2568] = 2568,
  [2569] = 2450,
  [2570] = 2466,
  [2571] = 2470,
  [2572] = 2572,
  [2573] = 1792,
  [2574] = 1835,
  [2575] = 2575,
  [2576] = 2452,
  [2577] = 2497,
  [2578] = 2578,
  [2579] = 2523,
  [2580] = 2331,
  [2581] = 2428,
  [2582] = 2511,
  [2583] = 2515,
  [2584] = 2517,
  [2585] = 2520,
  [2586] = 2586,
  [2587] = 2509,
  [2588] = 2510,
  [2589] = 2552,
  [2590] = 2553,
  [2591] = 2552,
  [2592] = 2592,
  [2593] = 2271,
  [2594] = 2450,
  [2595] = 2595,
  [2596] = 1835,
  [2597] = 2518,
  [2598] = 2598,
  [2599] = 2599,
  [2600] = 2600,
  [2601] = 2601,
  [2602] = 2452,
  [2603] = 2497,
  [2604] = 2604,
  [2605] = 2605,
  [2606] = 2523,
  [2607] = 2607,
  [2608] = 1801,
  [2609] = 2609,
  [2610] = 2428,
  [2611] = 2611,
  [2612] = 2612,
  [2613] = 2613,
  [2614] = 2511,
  [2615] = 2515,
  [2616] = 2517,
  [2617] = 2520,
  [2618] = 2541,
  [2619] = 2553,
  [2620] = 2542,
  [2621] = 2552,
  [2622] = 2553,
  [2623] = 2623,
  [2624] = 2624,
  [2625] = 101,
  [2626] = 2626,
  [2627] = 2450,
  [2628] = 2628,
  [2629] = 2629,
  [2630] = 2452,
  [2631] = 2497,
  [2632] = 2523,
  [2633] = 2215,
  [2634] = 2322,
  [2635] = 2428,
  [2636] = 2511,
  [2637] = 2515,
  [2638] = 2517,
  [2639] = 2520,
  [2640] = 2640,
  [2641] = 2641,
  [2642] = 2642,
  [2643] = 2552,
  [2644] = 2553,
  [2645] = 2556,
  [2646] = 2646,
  [2647] = 2647,
  [2648] = 2450,
  [2649] = 2324,
  [2650] = 2650,
  [2651] = 2651,
  [2652] = 2652,
  [2653] = 2653,
  [2654] = 2557,
  [2655] = 2497,
  [2656] = 2656,
  [2657] = 2372,
  [2658] = 2658,
  [2659] = 2659,
  [2660] = 2660,
  [2661] = 2661,
  [2662] = 2662,
  [2663] = 2663,
  [2664] = 2664,
  [2665] = 2665,
  [2666] = 2666,
  [2667] = 2667,
  [2668] = 2668,
  [2669] = 2669,
  [2670] = 2670,
  [2671] = 2671,
  [2672] = 2672,
  [2673] = 2673,
  [2674] = 2674,
  [2675] = 2675,
  [2676] = 2676,
  [2677] = 2677,
  [2678] = 2678,
  [2679] = 2679,
  [2680] = 2680,
  [2681] = 2681,
  [2682] = 2682,
  [2683] = 2683,
  [2684] = 2684,
  [2685] = 2685,
  [2686] = 2686,
  [2687] = 2687,
  [2688] = 2534,
  [2689] = 2689,
  [2690] = 2690,
  [2691] = 2512,
  [2692] = 2692,
  [2693] = 2372,
  [2694] = 2694,
  [2695] = 2695,
  [2696] = 2572,
  [2697] = 2697,
  [2698] = 2698,
  [2699] = 2699,
  [2700] = 2700,
  [2701] = 2701,
  [2702] = 2227,
  [2703] = 2703,
  [2704] = 2704,
  [2705] = 2705,
  [2706] = 2706,
  [2707] = 2707,
  [2708] = 2708,
  [2709] = 2709,
  [2710] = 2710,
  [2711] = 2711,
  [2712] = 2712,
  [2713] = 2358,
  [2714] = 2490,
  [2715] = 2715,
  [2716] = 2716,
  [2717] = 2717,
  [2718] = 2372,
  [2719] = 2719,
  [2720] = 2720,
  [2721] = 2721,
  [2722] = 2722,
  [2723] = 2723,
  [2724] = 2724,
  [2725] = 2299,
  [2726] = 2726,
  [2727] = 2727,
  [2728] = 2728,
  [2729] = 2729,
  [2730] = 2242,
  [2731] = 2424,
  [2732] = 2732,
  [2733] = 2733,
  [2734] = 2539,
  [2735] = 2628,
  [2736] = 2736,
  [2737] = 2737,
  [2738] = 2484,
  [2739] = 2505,
  [2740] = 2740,
  [2741] = 2741,
  [2742] = 2505,
  [2743] = 2425,
  [2744] = 2505,
  [2745] = 2505,
  [2746] = 2746,
  [2747] = 2747,
  [2748] = 2414,
  [2749] = 2464,
  [2750] = 2443,
  [2751] = 2403,
  [2752] = 2705,
  [2753] = 2753,
  [2754] = 2719,
  [2755] = 2755,
  [2756] = 2405,
  [2757] = 2661,
  [2758] = 2426,
  [2759] = 2721,
  [2760] = 2563,
  [2761] = 2495,
  [2762] = 2471,
  [2763] = 2706,
  [2764] = 2462,
  [2765] = 2460,
  [2766] = 2671,
  [2767] = 2504,
  [2768] = 2707,
  [2769] = 2769,
  [2770] = 2675,
  [2771] = 2507,
  [2772] = 2566,
  [2773] = 2480,
  [2774] = 2513,
  [2775] = 2670,
  [2776] = 2672,
  [2777] = 2777,
  [2778] = 2732,
  [2779] = 2779,
  [2780] = 2669,
  [2781] = 2514,
  [2782] = 2746,
  [2783] = 2454,
  [2784] = 2392,
  [2785] = 2393,
  [2786] = 2455,
  [2787] = 2519,
  [2788] = 2753,
  [2789] = 2469,
  [2790] = 2790,
  [2791] = 2427,
  [2792] = 2792,
  [2793] = 2406,
  [2794] = 2394,
  [2795] = 2568,
  [2796] = 2395,
  [2797] = 2396,
  [2798] = 2575,
  [2799] = 2429,
  [2800] = 2397,
  [2801] = 2409,
  [2802] = 2398,
  [2803] = 2399,
  [2804] = 2640,
  [2805] = 2651,
  [2806] = 2806,
  [2807] = 2400,
  [2808] = 2777,
  [2809] = 2401,
  [2810] = 2412,
  [2811] = 2430,
  [2812] = 2380,
  [2813] = 2813,
  [2814] = 2814,
  [2815] = 2815,
  [2816] = 2816,
  [2817] = 2777,
  [2818] = 2710,
  [2819] = 2779,
  [2820] = 2676,
  [2821] = 2442,
  [2822] = 2456,
  [2823] = 2823,
  [2824] = 2373,
  [2825] = 2720,
  [2826] = 2695,
  [2827] = 2827,
  [2828] = 2444,
  [2829] = 2458,
  [2830] = 2459,
  [2831] = 2377,
  [2832] = 2529,
  [2833] = 2530,
  [2834] = 2468,
  [2835] = 1551,
  [2836] = 2432,
  [2837] = 2837,
  [2838] = 2813,
  [2839] = 2407,
  [2840] = 2673,
  [2841] = 2715,
  [2842] = 2410,
  [2843] = 2413,
  [2844] = 2668,
  [2845] = 2716,
  [2846] = 2415,
  [2847] = 2417,
  [2848] = 2777,
  [2849] = 2662,
  [2850] = 2378,
  [2851] = 2369,
  [2852] = 2663,
  [2853] = 2722,
  [2854] = 2562,
  [2855] = 2437,
  [2856] = 2438,
  [2857] = 2370,
  [2858] = 2371,
  [2859] = 2440,
  [2860] = 2755,
  [2861] = 2418,
  [2862] = 2540,
  [2863] = 2863,
  [2864] = 2717,
  [2865] = 2543,
  [2866] = 2567,
  [2867] = 2544,
  [2868] = 2595,
  [2869] = 2666,
  [2870] = 2545,
  [2871] = 2546,
  [2872] = 2381,
  [2873] = 2463,
  [2874] = 2384,
  [2875] = 2875,
  [2876] = 2740,
  [2877] = 2549,
  [2878] = 2599,
  [2879] = 2600,
  [2880] = 2453,
  [2881] = 2667,
  [2882] = 2678,
  [2883] = 2883,
  [2884] = 2689,
  [2885] = 2528,
  [2886] = 2708,
  [2887] = 2551,
  [2888] = 2737,
  [2889] = 2723,
  [2890] = 2674,
  [2891] = 2677,
  [2892] = 2445,
  [2893] = 2555,
  [2894] = 2711,
  [2895] = 2558,
  [2896] = 2391,
  [2897] = 2473,
  [2898] = 2724,
  [2899] = 2863,
  [2900] = 2612,
  [2901] = 2679,
  [2902] = 2680,
  [2903] = 2681,
  [2904] = 2682,
  [2905] = 2683,
  [2906] = 2467,
  [2907] = 2623,
  [2908] = 2728,
  [2909] = 2475,
  [2910] = 2477,
  [2911] = 2684,
  [2912] = 2685,
  [2913] = 2686,
  [2914] = 2687,
  [2915] = 2421,
  [2916] = 2367,
  [2917] = 2422,
  [2918] = 2729,
  [2919] = 2448,
  [2920] = 2920,
  [2921] = 2790,
  [2922] = 2387,
  [2923] = 2447,
  [2924] = 2423,
  [2925] = 2827,
  [2926] = 2474,
  [2927] = 2449,
  [2928] = 2726,
  [2929] = 2727,
  [2930] = 2624,
  [2931] = 2815,
  [2932] = 2601,
  [2933] = 2875,
  [2934] = 2605,
  [2935] = 2508,
  [2936] = 2641,
  [2937] = 2607,
  [2938] = 2690,
  [2939] = 2823,
  [2940] = 2626,
  [2941] = 2629,
  [2942] = 2692,
  [2943] = 2697,
  [2944] = 2698,
  [2945] = 2699,
  [2946] = 2646,
  [2947] = 2769,
  [2948] = 2700,
  [2949] = 2642,
  [2950] = 2390,
  [2951] = 2653,
  [2952] = 2656,
  [2953] = 2457,
  [2954] = 2658,
  [2955] = 2659,
  [2956] = 2461,
  [2957] = 2660,
  [2958] = 2481,
  [2959] = 2704,
  [2960] = 2482,
  [2961] = 2650,
  [2962] = 2664,
  [2963] = 2665,
  [2964] = 2486,
  [2965] = 2487,
  [2966] = 2883,
  [2967] = 2701,
  [2968] = 2433,
  [2969] = 2434,
  [2970] = 2435,
  [2971] = 2436,
  [2972] = 2439,
  [2973] = 2973,
  [2974] = 2488,
  [2975] = 2652,
  [2976] = 2489,
  [2977] = 2441,
  [2978] = 2451,
  [2979] = 2703,
  [2980] = 2472,
  [2981] = 2981,
  [2982] = 2712,
  [2983] = 2548,
  [2984] = 2984,
  [2985] = 2985,
  [2986] = 2986,
  [2987] = 2987,
  [2988] = 2988,
  [2989] = 2989,
  [2990] = 2990,
  [2991] = 2991,
  [2992] = 2986,
  [2993] = 2993,
  [2994] = 2994,
  [2995] = 2991,
  [2996] = 2996,
  [2997] = 2997,
  [2998] = 2998,
  [2999] = 2999,
  [3000] = 3000,
  [3001] = 3000,
  [3002] = 3002,
  [3003] = 3003,
  [3004] = 121,
  [3005] = 3005,
  [3006] = 3006,
  [3007] = 3002,
  [3008] = 3008,
  [3009] = 3009,
  [3010] = 2984,
  [3011] = 3011,
  [3012] = 3012,
  [3013] = 3013,
  [3014] = 3014,
  [3015] = 3015,
  [3016] = 3016,
  [3017] = 3013,
  [3018] = 3018,
  [3019] = 2985,
  [3020] = 3020,
  [3021] = 3021,
  [3022] = 3022,
  [3023] = 3009,
  [3024] = 3024,
  [3025] = 3025,
  [3026] = 3026,
  [3027] = 3027,
  [3028] = 3028,
  [3029] = 2997,
  [3030] = 3030,
  [3031] = 3031,
  [3032] = 3008,
  [3033] = 3033,
  [3034] = 2984,
  [3035] = 3035,
  [3036] = 2989,
  [3037] = 3030,
  [3038] = 3038,
  [3039] = 2990,
  [3040] = 3040,
  [3041] = 3041,
  [3042] = 3011,
  [3043] = 3043,
  [3044] = 3044,
  [3045] = 3045,
  [3046] = 3046,
  [3047] = 2989,
  [3048] = 2990,
  [3049] = 2986,
  [3050] = 3050,
  [3051] = 3051,
  [3052] = 3052,
  [3053] = 3024,
  [3054] = 3054,
  [3055] = 3025,
  [3056] = 2984,
  [3057] = 3057,
  [3058] = 3009,
  [3059] = 3059,
  [3060] = 3009,
  [3061] = 3024,
  [3062] = 3025,
  [3063] = 3063,
  [3064] = 2986,
  [3065] = 3030,
  [3066] = 3024,
  [3067] = 3011,
  [3068] = 3025,
  [3069] = 3069,
  [3070] = 2989,
  [3071] = 2990,
  [3072] = 2986,
  [3073] = 3073,
  [3074] = 3074,
  [3075] = 3075,
  [3076] = 3076,
  [3077] = 2984,
  [3078] = 3078,
  [3079] = 3024,
  [3080] = 3025,
  [3081] = 3030,
  [3082] = 3011,
  [3083] = 3083,
  [3084] = 2989,
  [3085] = 2990,
  [3086] = 2986,
  [3087] = 3027,
  [3088] = 3088,
  [3089] = 3089,
  [3090] = 3090,
  [3091] = 3091,
  [3092] = 3092,
  [3093] = 3024,
  [3094] = 2990,
  [3095] = 2986,
  [3096] = 2989,
  [3097] = 3097,
  [3098] = 3098,
  [3099] = 2984,
  [3100] = 3100,
  [3101] = 3024,
  [3102] = 2990,
  [3103] = 2986,
  [3104] = 2991,
  [3105] = 3105,
  [3106] = 3020,
  [3107] = 2984,
  [3108] = 3030,
  [3109] = 2990,
  [3110] = 2986,
  [3111] = 3111,
  [3112] = 3112,
  [3113] = 3044,
  [3114] = 2984,
  [3115] = 3115,
  [3116] = 2990,
  [3117] = 2986,
  [3118] = 3118,
  [3119] = 2999,
  [3120] = 3120,
  [3121] = 2984,
  [3122] = 3000,
  [3123] = 2986,
  [3124] = 3124,
  [3125] = 3002,
  [3126] = 3008,
  [3127] = 2984,
  [3128] = 3128,
  [3129] = 2986,
  [3130] = 3130,
  [3131] = 3131,
  [3132] = 3132,
  [3133] = 2984,
  [3134] = 3020,
  [3135] = 2986,
  [3136] = 3136,
  [3137] = 3030,
  [3138] = 3138,
  [3139] = 2984,
  [3140] = 3140,
  [3141] = 2986,
  [3142] = 3011,
  [3143] = 3143,
  [3144] = 3144,
  [3145] = 2984,
  [3146] = 3146,
  [3147] = 3147,
  [3148] = 3069,
  [3149] = 3149,
  [3150] = 3150,
  [3151] = 3151,
  [3152] = 3152,
  [3153] = 3153,
  [3154] = 3154,
  [3155] = 3155,
  [3156] = 3022,
  [3157] = 3157,
  [3158] = 3158,
  [3159] = 3159,
  [3160] = 3160,
  [3161] = 3161,
  [3162] = 3024,
  [3163] = 2989,
  [3164] = 2987,
  [3165] = 3076,
  [3166] = 3166,
  [3167] = 3167,
  [3168] = 3025,
  [3169] = 2990,
  [3170] = 3027,
  [3171] = 3171,
  [3172] = 3130,
  [3173] = 3173,
  [3174] = 2986,
  [3175] = 121,
  [3176] = 3140,
  [3177] = 3177,
  [3178] = 2991,
  [3179] = 3143,
  [3180] = 3180,
  [3181] = 3181,
  [3182] = 3182,
  [3183] = 3183,
  [3184] = 2990,
  [3185] = 3090,
  [3186] = 3100,
  [3187] = 2984,
  [3188] = 3188,
  [3189] = 3189,
  [3190] = 3190,
  [3191] = 3191,
  [3192] = 3192,
  [3193] = 3193,
  [3194] = 3063,
  [3195] = 3177,
  [3196] = 3190,
  [3197] = 3197,
  [3198] = 3098,
  [3199] = 3000,
  [3200] = 3200,
  [3201] = 3147,
  [3202] = 3202,
  [3203] = 3197,
  [3204] = 3204,
  [3205] = 3158,
  [3206] = 3000,
  [3207] = 3207,
  [3208] = 2988,
  [3209] = 3209,
  [3210] = 3210,
  [3211] = 3003,
  [3212] = 3005,
  [3213] = 3052,
  [3214] = 3115,
  [3215] = 3120,
  [3216] = 3124,
  [3217] = 3069,
  [3218] = 3218,
  [3219] = 3043,
  [3220] = 3031,
  [3221] = 3092,
  [3222] = 3002,
  [3223] = 3112,
  [3224] = 3146,
  [3225] = 3160,
  [3226] = 3209,
  [3227] = 3075,
  [3228] = 3228,
  [3229] = 3229,
  [3230] = 3204,
  [3231] = 3044,
  [3232] = 3200,
  [3233] = 3022,
  [3234] = 3028,
  [3235] = 3027,
  [3236] = 3218,
  [3237] = 3188,
  [3238] = 3177,
  [3239] = 3190,
  [3240] = 3197,
  [3241] = 3241,
  [3242] = 3147,
  [3243] = 3144,
  [3244] = 3158,
  [3245] = 3207,
  [3246] = 3014,
  [3247] = 3146,
  [3248] = 3248,
  [3249] = 3161,
  [3250] = 3250,
  [3251] = 3008,
  [3252] = 3171,
  [3253] = 3241,
  [3254] = 3050,
  [3255] = 3008,
  [3256] = 3051,
  [3257] = 3177,
  [3258] = 3190,
  [3259] = 3197,
  [3260] = 3016,
  [3261] = 3147,
  [3262] = 2984,
  [3263] = 3158,
  [3264] = 2984,
  [3265] = 3146,
  [3266] = 3266,
  [3267] = 3267,
  [3268] = 3054,
  [3269] = 3166,
  [3270] = 2994,
  [3271] = 3271,
  [3272] = 3272,
  [3273] = 3078,
  [3274] = 3177,
  [3275] = 3190,
  [3276] = 3197,
  [3277] = 3088,
  [3278] = 3147,
  [3279] = 3158,
  [3280] = 3026,
  [3281] = 3015,
  [3282] = 3038,
  [3283] = 3266,
  [3284] = 2998,
  [3285] = 3074,
  [3286] = 3158,
  [3287] = 2991,
  [3288] = 3018,
  [3289] = 3152,
  [3290] = 3105,
  [3291] = 3158,
  [3292] = 3180,
  [3293] = 3041,
  [3294] = 3011,
  [3295] = 3295,
  [3296] = 3181,
  [3297] = 3009,
  [3298] = 3024,
  [3299] = 3153,
  [3300] = 3025,
  [3301] = 2986,
  [3302] = 3272,
  [3303] = 3303,
  [3304] = 3304,
  [3305] = 3207,
  [3306] = 3069,
  [3307] = 3111,
  [3308] = 3210,
  [3309] = 3151,
  [3310] = 3138,
  [3311] = 3267,
  [3312] = 3118,
  [3313] = 3059,
  [3314] = 3157,
  [3315] = 3228,
  [3316] = 3002,
  [3317] = 3155,
  [3318] = 3012,
  [3319] = 3149,
  [3320] = 2990,
  [3321] = 3191,
  [3322] = 3020,
  [3323] = 3030,
  [3324] = 3324,
  [3325] = 3192,
  [3326] = 3193,
  [3327] = 3182,
  [3328] = 3328,
  [3329] = 3328,
  [3330] = 3271,
  [3331] = 2996,
  [3332] = 3332,
  [3333] = 3333,
  [3334] = 3035,
  [3335] = 3335,
  [3336] = 3045,
  [3337] = 3089,
  [3338] = 3183,
  [3339] = 3040,
  [3340] = 3295,
  [3341] = 3009,
  [3342] = 3342,
  [3343] = 3083,
  [3344] = 3011,
  [3345] = 2989,
  [3346] = 3097,
  [3347] = 3303,
  [3348] = 3022,
  [3349] = 3073,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(842);
      ADVANCE_MAP(
        '\n', 945,
        '!', 2214,
        '#', 2475,
        '$', 2283,
        '%', 3037,
        '&', 2217,
        '\'', 3322,
        '(', 2520,
        ')', 2252,
        '*', 2472,
        '+', 2276,
        ',', 3034,
        '-', 2479,
        '.', 856,
        '/', 2271,
        ':', 2223,
        ';', 2268,
        '<', 2389,
        '=', 2222,
        '>', 2394,
        '?', 2272,
        '@', 3493,
        '[', 2518,
        '\\', 2402,
        ']', 2519,
        '_', 1008,
        '{', 1027,
        '|', 964,
        '}', 1026,
        '~', 964,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(839);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(964);
      if (('2' <= lookahead && lookahead <= '9')) ADVANCE(964);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1008);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(964);
      END_STATE();
    case 1:
      if (lookahead == '\t') SKIP(1);
      if (lookahead == ' ') ADVANCE(2234);
      END_STATE();
    case 2:
      if (lookahead == '\t') SKIP(1);
      if (lookahead == ' ') ADVANCE(2234);
      if (lookahead == '\\') ADVANCE(2233);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2232);
      END_STATE();
    case 3:
      if (lookahead == '\t') SKIP(1);
      if (lookahead == ' ') ADVANCE(2234);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(970);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(985);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(973);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(968);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1002);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1005);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(995);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(998);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(990);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(992);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(965);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1000);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(984);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(996);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(975);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(983);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1004);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(989);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(964);
      END_STATE();
    case 4:
      if (lookahead == '\t') ADVANCE(2584);
      if (lookahead == ' ') SKIP(99);
      if (lookahead == '#') ADVANCE(2475);
      if (lookahead == '*') ADVANCE(2584);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '/') ADVANCE(2269);
      if (lookahead == '<') ADVANCE(2585);
      if (lookahead == '\\') ADVANCE(2402);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2584);
      if (lookahead == '$' ||
          lookahead == '%' ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2584);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1023);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2584);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2584);
      END_STATE();
    case 5:
      if (lookahead == '\t') ADVANCE(2584);
      if (lookahead == ' ') SKIP(100);
      if (lookahead == '#') ADVANCE(2475);
      if (lookahead == '*') ADVANCE(2584);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '/') ADVANCE(2269);
      if (lookahead == '\\') ADVANCE(2401);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2584);
      if (lookahead == '$' ||
          lookahead == '%' ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2584);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1023);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2584);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2584);
      END_STATE();
    case 6:
      if (lookahead == '\t') ADVANCE(2584);
      if (lookahead == ' ') SKIP(133);
      if (lookahead == '*') ADVANCE(2584);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '/') ADVANCE(2269);
      if (lookahead == '<') ADVANCE(2585);
      if (lookahead == '\\') ADVANCE(2402);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2584);
      if (('#' <= lookahead && lookahead <= '%') ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2584);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1023);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2584);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2584);
      END_STATE();
    case 7:
      if (lookahead == '\t') ADVANCE(2584);
      if (lookahead == ' ') SKIP(134);
      if (lookahead == '*') ADVANCE(2584);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '/') ADVANCE(2269);
      if (lookahead == '\\') ADVANCE(2401);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2584);
      if (('#' <= lookahead && lookahead <= '%') ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2584);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1023);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2584);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2584);
      END_STATE();
    case 8:
      if (lookahead == '\t') ADVANCE(2584);
      if (lookahead == ' ') SKIP(101);
      if (lookahead == '#') ADVANCE(2475);
      if (lookahead == '*') ADVANCE(2584);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '<') ADVANCE(2585);
      if (lookahead == '\\') ADVANCE(2402);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2584);
      if (lookahead == '$' ||
          lookahead == '%' ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2584);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2584);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2584);
      END_STATE();
    case 9:
      if (lookahead == '\t') ADVANCE(2584);
      if (lookahead == ' ') SKIP(135);
      if (lookahead == '*') ADVANCE(2584);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '<') ADVANCE(2585);
      if (lookahead == '\\') ADVANCE(2402);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2584);
      if (('#' <= lookahead && lookahead <= '%') ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2584);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2584);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2584);
      END_STATE();
    case 10:
      if (lookahead == '\t') ADVANCE(2584);
      if (lookahead == ' ') SKIP(102);
      if (lookahead == '#') ADVANCE(2475);
      if (lookahead == '*') ADVANCE(2584);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '\\') ADVANCE(2401);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2584);
      if (lookahead == '$' ||
          lookahead == '%' ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2584);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2584);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2584);
      END_STATE();
    case 11:
      if (lookahead == '\t') ADVANCE(2584);
      if (lookahead == ' ') SKIP(136);
      if (lookahead == '*') ADVANCE(2584);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '\\') ADVANCE(2401);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2584);
      if (('#' <= lookahead && lookahead <= '%') ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2584);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2584);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2584);
      END_STATE();
    case 12:
      if (lookahead == '\t') SKIP(13);
      if (lookahead == ' ') ADVANCE(2234);
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '&') ADVANCE(2217);
      if (lookahead == '+') ADVANCE(264);
      if (lookahead == '-') ADVANCE(265);
      if (lookahead == ':') ADVANCE(2223);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '=') ADVANCE(2222);
      if (lookahead == '?') ADVANCE(2221);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == '^') ADVANCE(266);
      if (lookahead == '{') ADVANCE(1027);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2037);
      END_STATE();
    case 13:
      if (lookahead == '\t') SKIP(13);
      if (lookahead == ' ') ADVANCE(2234);
      if (lookahead == '&') ADVANCE(2217);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '?') ADVANCE(2221);
      if (lookahead == '\\') ADVANCE(684);
      END_STATE();
    case 14:
      if (lookahead == '\t') SKIP(15);
      if (lookahead == ' ') ADVANCE(2234);
      if (lookahead == '+') ADVANCE(264);
      if (lookahead == '-') ADVANCE(265);
      if (lookahead == ':') ADVANCE(2223);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '=') ADVANCE(2222);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == '^') ADVANCE(266);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 15:
      if (lookahead == '\t') SKIP(15);
      if (lookahead == ' ') ADVANCE(2234);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 16:
      if (lookahead == '\t') SKIP(16);
      if (lookahead == ' ') ADVANCE(2255);
      if (lookahead == '<') ADVANCE(2264);
      if (lookahead == '\\') ADVANCE(2263);
      if (lookahead == 'c') ADVANCE(2261);
      if (lookahead == 'i') ADVANCE(2258);
      if (lookahead == 'l') ADVANCE(2260);
      if (lookahead == 'n') ADVANCE(2262);
      if (lookahead == 't') ADVANCE(2259);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(2254);
      END_STATE();
    case 17:
      if (lookahead == '\t') SKIP(17);
      if (lookahead == ' ') ADVANCE(2256);
      if (lookahead == 'c') ADVANCE(2261);
      if (lookahead == 'i') ADVANCE(2258);
      if (lookahead == 'l') ADVANCE(2260);
      if (lookahead == 'n') ADVANCE(2262);
      if (lookahead == 't') ADVANCE(2259);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(2254);
      END_STATE();
    case 18:
      if (lookahead == '\t') SKIP(18);
      if (lookahead == ' ') ADVANCE(2234);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      END_STATE();
    case 19:
      if (lookahead == '\t') SKIP(18);
      if (lookahead == ' ') ADVANCE(2234);
      if (lookahead == '<') ADVANCE(2230);
      if (lookahead == '\\') ADVANCE(2228);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2232);
      END_STATE();
    case 20:
      if (lookahead == '\t') ADVANCE(3344);
      if (lookahead == ' ') SKIP(20);
      if (lookahead == '<') ADVANCE(3354);
      if (lookahead == '\\') ADVANCE(3352);
      if (lookahead == 'c') ADVANCE(3350);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(3357);
      END_STATE();
    case 21:
      if (lookahead == '\t') ADVANCE(3345);
      if (lookahead == ' ') SKIP(21);
      if (lookahead == 'c') ADVANCE(3350);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(3357);
      END_STATE();
    case 22:
      if (lookahead == '\t') SKIP(22);
      if (lookahead == ' ') ADVANCE(2257);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(2254);
      END_STATE();
    case 23:
      if (lookahead == '\t') SKIP(23);
      if (lookahead == ' ') ADVANCE(845);
      END_STATE();
    case 24:
      if (lookahead == '\t') SKIP(23);
      if (lookahead == ' ') ADVANCE(845);
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '\'') ADVANCE(3322);
      if (lookahead == 'N') ADVANCE(3338);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3339);
      END_STATE();
    case 25:
      if (lookahead == '\t') SKIP(23);
      if (lookahead == ' ') ADVANCE(845);
      if (lookahead == '*') ADVANCE(2551);
      if (lookahead == '\\') ADVANCE(2550);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2548);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2547);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2535);
      END_STATE();
    case 26:
      if (lookahead == '\n') ADVANCE(945);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(26);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 27:
      if (lookahead == '\n') ADVANCE(943);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(27);
      if (lookahead != 0) ADVANCE(28);
      END_STATE();
    case 28:
      if (lookahead == '\n') ADVANCE(943);
      if (lookahead != 0) ADVANCE(28);
      END_STATE();
    case 29:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '#') ADVANCE(2475);
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2278);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(959);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(103);
      if (lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (lookahead == '$' ||
          lookahead == '%' ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 30:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '#') ADVANCE(2475);
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2278);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(104);
      if (lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (lookahead == '$' ||
          lookahead == '%' ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 31:
      ADVANCE_MAP(
        '!', 2214,
        '#', 681,
        '$', 2283,
        '&', 2217,
        '(', 2250,
        '+', 2281,
        ',', 2251,
        '-', 2481,
        '/', 2271,
        '0', 2510,
        ';', 2268,
        '<', 707,
        '=', 2222,
        '@', 835,
        '[', 2518,
        '\\', 115,
        'a', 1031,
        '{', 1024,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(63);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2512);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 32:
      ADVANCE_MAP(
        '!', 2214,
        '%', 256,
        '\'', 3324,
        '*', 257,
        '+', 258,
        ',', 2251,
        '-', 259,
        '.', 170,
        '/', 260,
        ';', 2268,
        '<', 707,
        '=', 939,
        '?', 2272,
        '\\', 115,
        'e', 2186,
        'u', 2057,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(110);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(3500);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 33:
      ADVANCE_MAP(
        '!', 2214,
        ')', 2252,
        ',', 2251,
        '.', 171,
        '0', 2513,
        '<', 707,
        '\\', 684,
        '{', 1024,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(121);
      if (('+' <= lookahead && lookahead <= '-')) ADVANCE(177);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2516);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 34:
      ADVANCE_MAP(
        '!', 2214,
        '*', 2473,
        ',', 2251,
        '/', 2271,
        ';', 2268,
        '<', 2573,
        '[', 2518,
        '\\', 956,
        '\t', 2558,
        ' ', 2558,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 35:
      ADVANCE_MAP(
        '!', 2214,
        '*', 2473,
        ',', 2251,
        '/', 2271,
        ';', 2268,
        '<', 2574,
        '[', 2518,
        '\\', 956,
        '\t', 2559,
        ' ', 2559,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 36:
      ADVANCE_MAP(
        '!', 2214,
        '*', 2473,
        ',', 2251,
        ';', 2268,
        '<', 2573,
        '?', 2272,
        '[', 2518,
        '\\', 956,
        '\t', 2558,
        ' ', 2558,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 37:
      ADVANCE_MAP(
        '!', 2214,
        '*', 2473,
        ',', 2251,
        ';', 2268,
        '<', 2574,
        '?', 2272,
        '[', 2518,
        '\\', 956,
        '\t', 2559,
        ' ', 2559,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 38:
      ADVANCE_MAP(
        '!', 2214,
        '*', 2473,
        '/', 2271,
        '<', 2573,
        '[', 2518,
        '\\', 956,
        '\t', 2561,
        ' ', 2561,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 39:
      ADVANCE_MAP(
        '!', 2214,
        '*', 2473,
        '/', 2271,
        '<', 2574,
        '[', 2518,
        '\\', 956,
        '\t', 2563,
        ' ', 2563,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 40:
      ADVANCE_MAP(
        '!', 2214,
        '*', 2473,
        '<', 2573,
        '?', 2272,
        '[', 2518,
        '\\', 956,
        '\t', 2561,
        ' ', 2561,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 41:
      ADVANCE_MAP(
        '!', 2214,
        '*', 2473,
        '<', 2574,
        '?', 2272,
        '[', 2518,
        '\\', 956,
        '\t', 2563,
        ' ', 2563,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 42:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2278);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(959);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(137);
      if (lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 43:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2278);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(138);
      if (lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 44:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(959);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(140);
      if (lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 45:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == 'A') ADVANCE(2524);
      if (lookahead == 'O') ADVANCE(2525);
      if (lookahead == 'P') ADVANCE(2523);
      if (lookahead == 'S') ADVANCE(2526);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(142);
      if (lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 46:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(144);
      if (lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 47:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '*') ADVANCE(2551);
      if (lookahead == '<') ADVANCE(951);
      if (lookahead == '\\') ADVANCE(960);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(249);
      if (lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2548);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2547);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2535);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(950);
      END_STATE();
    case 48:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '*') ADVANCE(2551);
      if (lookahead == '\\') ADVANCE(961);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(299);
      if (lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2548);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2547);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2535);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(950);
      END_STATE();
    case 49:
      ADVANCE_MAP(
        '!', 2214,
        ',', 2251,
        '-', 301,
        '/', 2271,
        ';', 2268,
        '<', 707,
        '=', 939,
        '?', 2272,
        '\\', 124,
        'i', 520,
        'm', 310,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(154);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(3030);
      END_STATE();
    case 50:
      ADVANCE_MAP(
        '!', 2214,
        ',', 2251,
        '/', 2271,
        ';', 2268,
        '<', 2575,
        '[', 2518,
        '\\', 957,
        '\t', 2564,
        ' ', 2564,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 51:
      ADVANCE_MAP(
        '!', 2214,
        ',', 2251,
        '/', 2271,
        ';', 2268,
        '[', 2518,
        '\\', 957,
        '\t', 2565,
        ' ', 2565,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 52:
      ADVANCE_MAP(
        '!', 2214,
        ',', 2251,
        ';', 2268,
        '<', 2575,
        '?', 2272,
        '[', 2518,
        '\\', 957,
        '\t', 2564,
        ' ', 2564,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 53:
      ADVANCE_MAP(
        '!', 2214,
        ',', 2251,
        ';', 2268,
        '?', 2272,
        '[', 2518,
        '\\', 957,
        '\t', 2565,
        ' ', 2565,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 54:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '/') ADVANCE(2271);
      if (lookahead == '<') ADVANCE(2575);
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(957);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2567);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 55:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '/') ADVANCE(2271);
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(957);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2572);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 56:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'c') ADVANCE(3166);
      if (lookahead == 'l') ADVANCE(3140);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(227);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 57:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '<') ADVANCE(2575);
      if (lookahead == '?') ADVANCE(2272);
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(957);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2567);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 58:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '<') ADVANCE(951);
      if (lookahead == '\\') ADVANCE(959);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(249);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(950);
      END_STATE();
    case 59:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '?') ADVANCE(2272);
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(957);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2572);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 60:
      if (lookahead == '!') ADVANCE(2214);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(299);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(950);
      END_STATE();
    case 61:
      ADVANCE_MAP(
        '!', 2506,
        '#', 979,
        '$', 2283,
        '&', 2217,
        '(', 2250,
        '+', 2281,
        '-', 2481,
        '0', 976,
        '<', 2389,
        '@', 1009,
        'A', 969,
        '[', 2518,
        '\\', 2401,
        'a', 966,
        '{', 1024,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(64);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(980);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(972);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(967);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1001);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1006);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(994);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(997);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(987);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(991);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(971);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(999);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(981);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(993);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(974);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(982);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1003);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(988);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(977);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(1007);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(964);
      END_STATE();
    case 62:
      ADVANCE_MAP(
        '!', 2506,
        '#', 979,
        '$', 2283,
        '&', 2217,
        '(', 2250,
        '+', 2281,
        '-', 2481,
        '0', 976,
        '<', 2389,
        '@', 1009,
        '[', 2518,
        '\\', 2401,
        'a', 978,
        '{', 1024,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(64);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(977);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1007);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(964);
      END_STATE();
    case 63:
      ADVANCE_MAP(
        '!', 2506,
        '#', 681,
        '$', 2283,
        '&', 2217,
        '(', 2250,
        '+', 2281,
        ',', 2251,
        '-', 2481,
        '0', 2510,
        ';', 2268,
        '<', 707,
        '@', 835,
        '[', 2518,
        '\\', 115,
        'a', 1031,
        '{', 1024,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(63);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2512);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 64:
      ADVANCE_MAP(
        '!', 2506,
        '#', 681,
        '$', 2283,
        '&', 2217,
        '(', 2250,
        '+', 2281,
        '-', 2481,
        '0', 2510,
        '@', 835,
        '[', 2518,
        'a', 1031,
        '{', 1024,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(64);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2512);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 65:
      ADVANCE_MAP(
        '!', 2506,
        '#', 2476,
        '$', 2283,
        '&', 2217,
        '(', 2250,
        ')', 2252,
        '+', 2281,
        ',', 2251,
        '-', 2480,
        '.', 856,
        '/', 2271,
        '0', 2510,
        ':', 843,
        ';', 2268,
        '<', 707,
        '=', 939,
        '?', 2221,
        '@', 835,
        '[', 2518,
        '\\', 115,
        ']', 2519,
        'a', 1031,
        '{', 1024,
        '}', 1026,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(66);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2512);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 66:
      ADVANCE_MAP(
        '!', 2506,
        '#', 2476,
        '$', 2283,
        '&', 2217,
        '(', 2250,
        ')', 2252,
        '+', 2281,
        ',', 2251,
        '-', 2480,
        '0', 2510,
        ':', 843,
        ';', 2268,
        '<', 707,
        '=', 939,
        '?', 2221,
        '@', 835,
        '[', 2518,
        '\\', 115,
        ']', 2519,
        'a', 1031,
        '{', 1024,
        '}', 1026,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(66);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2512);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 67:
      if (lookahead == '!') ADVANCE(2235);
      END_STATE();
    case 68:
      ADVANCE_MAP(
        '!', 262,
        '%', 2266,
        '&', 116,
        '(', 2250,
        ')', 2252,
        '*', 2473,
        '+', 2276,
        ',', 2251,
        '-', 2483,
        '.', 2275,
        '/', 2269,
        ':', 843,
        ';', 2268,
        '<', 2396,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        ']', 2519,
        'i', 1606,
        '{', 1027,
        '|', 685,
        '}', 1026,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(72);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 69:
      ADVANCE_MAP(
        '!', 262,
        '%', 2266,
        '&', 116,
        '(', 2250,
        ')', 2252,
        '*', 2473,
        '+', 2276,
        ',', 2251,
        '-', 2483,
        '.', 2275,
        '/', 2269,
        ':', 843,
        ';', 2268,
        '<', 2396,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        ']', 2519,
        'i', 1015,
        '|', 685,
        '}', 1026,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(72);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1023);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1019);
      END_STATE();
    case 70:
      ADVANCE_MAP(
        '!', 262,
        '%', 2266,
        '&', 116,
        '(', 2250,
        ')', 2252,
        '*', 2473,
        '+', 2276,
        ',', 2251,
        '-', 2483,
        '.', 2275,
        '/', 2269,
        ':', 843,
        ';', 2268,
        '<', 2396,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        ']', 2519,
        'i', 521,
        '|', 685,
        '}', 1026,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(70);
      END_STATE();
    case 71:
      ADVANCE_MAP(
        '!', 262,
        '%', 2266,
        '&', 116,
        '(', 2250,
        ')', 2252,
        '*', 2473,
        '+', 2276,
        ',', 2251,
        '-', 2483,
        '.', 2275,
        '/', 2269,
        ':', 843,
        ';', 2268,
        '<', 2396,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        ']', 2519,
        'i', 521,
        '|', 685,
        '}', 1026,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(70);
      if (lookahead == 'e' ||
          lookahead == 's') ADVANCE(3437);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(3439);
      END_STATE();
    case 72:
      ADVANCE_MAP(
        '!', 262,
        '%', 2266,
        '&', 116,
        '(', 2250,
        ')', 2252,
        '*', 2473,
        '+', 2276,
        ',', 2251,
        '-', 2483,
        '.', 2275,
        '/', 2269,
        ':', 843,
        ';', 2268,
        '<', 2396,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        ']', 2519,
        'i', 627,
        '|', 685,
        '}', 1026,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(72);
      END_STATE();
    case 73:
      ADVANCE_MAP(
        '!', 262,
        '%', 2266,
        '&', 116,
        '(', 2250,
        '*', 2473,
        '+', 2276,
        '-', 2483,
        '.', 2275,
        '/', 2269,
        '<', 2397,
        '=', 263,
        '>', 2489,
        '?', 2221,
        'N', 287,
        '[', 2518,
        '\\', 684,
        'b', 499,
        'c', 646,
        'f', 566,
        'g', 659,
        'i', 627,
        's', 635,
        't', 421,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(73);
      END_STATE();
    case 74:
      ADVANCE_MAP(
        '!', 262,
        '%', 2266,
        '&', 116,
        '(', 2250,
        '*', 2473,
        '+', 2276,
        '-', 2483,
        '.', 2275,
        '/', 2269,
        '<', 2397,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        '\\', 684,
        'a', 1031,
        'i', 1033,
        '{', 1024,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(74);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 75:
      ADVANCE_MAP(
        '!', 262,
        '%', 2266,
        '&', 116,
        '(', 2250,
        '*', 2473,
        '+', 2276,
        '-', 2483,
        '.', 2275,
        '/', 2269,
        '<', 2397,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        '\\', 684,
        'a', 1011,
        'i', 1014,
        '{', 1024,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(74);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1023);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1018);
      END_STATE();
    case 76:
      ADVANCE_MAP(
        '!', 262,
        '%', 2266,
        '&', 116,
        '(', 2250,
        '*', 2473,
        '+', 2276,
        '-', 2483,
        '.', 2275,
        '/', 2269,
        '<', 2397,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        '\\', 684,
        'i', 1606,
        '{', 1027,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(78);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 77:
      ADVANCE_MAP(
        '!', 262,
        '%', 2266,
        '&', 116,
        '(', 2250,
        '*', 2473,
        '+', 2276,
        '-', 2483,
        '.', 2275,
        '/', 2269,
        '<', 2397,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        '\\', 684,
        'i', 1015,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(78);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1023);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1019);
      END_STATE();
    case 78:
      ADVANCE_MAP(
        '!', 262,
        '%', 2266,
        '&', 116,
        '(', 2250,
        '*', 2473,
        '+', 2276,
        '-', 2483,
        '.', 2275,
        '/', 2269,
        '<', 2397,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        '\\', 684,
        'i', 627,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(78);
      END_STATE();
    case 79:
      ADVANCE_MAP(
        '!', 262,
        '%', 2266,
        '&', 116,
        '(', 2250,
        '*', 2473,
        '+', 2276,
        '-', 2483,
        '.', 2275,
        '/', 2269,
        '<', 2396,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        'a', 1031,
        'i', 1033,
        '{', 1024,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(79);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 80:
      ADVANCE_MAP(
        '!', 262,
        '%', 2266,
        '&', 116,
        '(', 2250,
        '*', 2473,
        '+', 2276,
        '-', 2483,
        '.', 2275,
        '/', 2269,
        '<', 2396,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        'a', 1011,
        'i', 1014,
        '{', 1024,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(79);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1023);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1018);
      END_STATE();
    case 81:
      ADVANCE_MAP(
        '!', 262,
        '%', 2267,
        '&', 116,
        '(', 2250,
        '*', 2474,
        '+', 2282,
        '-', 2482,
        '.', 2274,
        '/', 2270,
        '<', 2397,
        '=', 940,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        '\\', 684,
        'a', 1031,
        'i', 1033,
        '{', 1024,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(82);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1023);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 82:
      ADVANCE_MAP(
        '!', 262,
        '%', 2267,
        '&', 116,
        '(', 2250,
        '*', 2474,
        '+', 2282,
        '-', 2482,
        '.', 2274,
        '/', 2270,
        '<', 2397,
        '=', 940,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        '\\', 684,
        'a', 1031,
        'i', 1033,
        '{', 1024,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(82);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 83:
      ADVANCE_MAP(
        '!', 262,
        '%', 2267,
        '&', 116,
        '(', 2250,
        '*', 2474,
        '+', 2282,
        '-', 2482,
        '.', 2274,
        '/', 2270,
        '<', 2397,
        '=', 940,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        '\\', 684,
        'a', 1564,
        'i', 1605,
        '{', 1027,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(82);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(2035);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2033);
      END_STATE();
    case 84:
      ADVANCE_MAP(
        '!', 262,
        '%', 2267,
        '&', 116,
        '(', 2250,
        '*', 2474,
        '+', 2282,
        '-', 2482,
        '.', 2274,
        '/', 2270,
        '<', 2396,
        '=', 940,
        '>', 2489,
        '?', 2221,
        'N', 287,
        '[', 2518,
        'b', 499,
        'c', 646,
        'f', 566,
        'g', 659,
        'i', 627,
        's', 635,
        't', 421,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(84);
      END_STATE();
    case 85:
      ADVANCE_MAP(
        '!', 262,
        '%', 2267,
        '&', 116,
        '(', 2250,
        '*', 2474,
        '+', 2282,
        '-', 2482,
        '.', 2274,
        '/', 2270,
        '<', 2396,
        '=', 940,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        'a', 1031,
        'i', 1033,
        '{', 1024,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(85);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 86:
      ADVANCE_MAP(
        '!', 262,
        '%', 2267,
        '&', 116,
        '(', 2250,
        '*', 2474,
        '+', 2282,
        '-', 2482,
        '.', 2274,
        '/', 2270,
        '<', 2396,
        '=', 940,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        'a', 1564,
        'i', 1605,
        '{', 1027,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(85);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(2035);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2033);
      END_STATE();
    case 87:
      ADVANCE_MAP(
        '!', 262,
        '%', 2267,
        '&', 116,
        '(', 2250,
        '*', 2474,
        '+', 2282,
        '-', 2482,
        '.', 2274,
        '/', 2270,
        '<', 2396,
        '=', 940,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        'i', 1606,
        '{', 1027,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(88);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 88:
      ADVANCE_MAP(
        '!', 262,
        '%', 2267,
        '&', 116,
        '(', 2250,
        '*', 2474,
        '+', 2282,
        '-', 2482,
        '.', 2274,
        '/', 2270,
        '<', 2396,
        '=', 940,
        '>', 2489,
        '?', 2221,
        '[', 2518,
        'i', 627,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(88);
      END_STATE();
    case 89:
      ADVANCE_MAP(
        '!', 2507,
        '#', 681,
        '$', 2283,
        '%', 2266,
        '&', 2218,
        '(', 2250,
        '*', 2473,
        '+', 2281,
        '-', 2480,
        '.', 2275,
        '/', 2269,
        '0', 2510,
        '<', 2397,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '@', 835,
        '[', 2518,
        '\\', 684,
        'a', 1031,
        'i', 1033,
        '{', 1024,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(89);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2512);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 90:
      ADVANCE_MAP(
        '!', 2507,
        '#', 681,
        '$', 2283,
        '%', 2266,
        '&', 2218,
        '(', 2250,
        '*', 2473,
        '+', 2281,
        '-', 2480,
        '.', 2275,
        '/', 2269,
        '0', 2510,
        '<', 2396,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '@', 835,
        '[', 2518,
        'a', 1031,
        'i', 1033,
        '{', 1024,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(90);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2512);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 91:
      ADVANCE_MAP(
        '!', 2507,
        '#', 681,
        '$', 2283,
        '%', 2266,
        '&', 2218,
        '(', 2250,
        '*', 2473,
        '+', 2281,
        '-', 2480,
        '.', 2275,
        '/', 2269,
        '0', 1020,
        '<', 2397,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '@', 835,
        '[', 2518,
        '\\', 684,
        'a', 1011,
        'i', 1014,
        '{', 1024,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(89);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1022);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1018);
      END_STATE();
    case 92:
      ADVANCE_MAP(
        '!', 2507,
        '#', 681,
        '$', 2283,
        '%', 2266,
        '&', 2218,
        '(', 2250,
        '*', 2473,
        '+', 2281,
        '-', 2480,
        '.', 2275,
        '/', 2269,
        '0', 1020,
        '<', 2396,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '@', 835,
        '[', 2518,
        'a', 1011,
        'i', 1014,
        '{', 1024,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(90);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1022);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1018);
      END_STATE();
    case 93:
      ADVANCE_MAP(
        '!', 2507,
        '#', 1617,
        '$', 2283,
        '%', 2266,
        '&', 2218,
        '(', 2250,
        '*', 2473,
        '+', 2281,
        '-', 2480,
        '.', 2275,
        '/', 2269,
        '0', 1561,
        '<', 2397,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '@', 835,
        '[', 2518,
        '\\', 684,
        'a', 1564,
        'i', 1605,
        '{', 1027,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(89);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1563);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2033);
      END_STATE();
    case 94:
      ADVANCE_MAP(
        '!', 2507,
        '#', 1617,
        '$', 2283,
        '%', 2266,
        '&', 2218,
        '(', 2250,
        '*', 2473,
        '+', 2281,
        '-', 2480,
        '.', 2275,
        '/', 2269,
        '0', 1561,
        '<', 2396,
        '=', 263,
        '>', 2489,
        '?', 2221,
        '@', 835,
        '[', 2518,
        'a', 1564,
        'i', 1605,
        '{', 1027,
        '|', 685,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(90);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1563);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2033);
      END_STATE();
    case 95:
      if (lookahead == '!') ADVANCE(2216);
      if (lookahead == '<') ADVANCE(2643);
      if (lookahead == '\\') ADVANCE(2609);
      if (lookahead == '{') ADVANCE(1025);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(246);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1523);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1231);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1246);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1338);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1247);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1527);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1344);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1472);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1157);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1414);
      if (lookahead == 'Q' ||
          lookahead == 'q') ADVANCE(1530);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1143);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1041);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1037);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1248);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1249);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1261);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 96:
      if (lookahead == '!') ADVANCE(2216);
      if (lookahead == '{') ADVANCE(1025);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(682);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1523);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1231);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1246);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1338);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1247);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1527);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1344);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1472);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1157);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1414);
      if (lookahead == 'Q' ||
          lookahead == 'q') ADVANCE(1530);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1143);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1041);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1037);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1248);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1249);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1261);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 97:
      if (lookahead == '!') ADVANCE(2215);
      if (lookahead == '<') ADVANCE(2247);
      if (lookahead == '\\') ADVANCE(2245);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(253);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(2249);
      END_STATE();
    case 98:
      if (lookahead == '!') ADVANCE(2215);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(688);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(2249);
      END_STATE();
    case 99:
      if (lookahead == '#') ADVANCE(2475);
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '/') ADVANCE(2269);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(959);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(99);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (lookahead == '$' ||
          lookahead == '%' ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 100:
      if (lookahead == '#') ADVANCE(2475);
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '/') ADVANCE(2269);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(100);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (lookahead == '$' ||
          lookahead == '%' ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 101:
      if (lookahead == '#') ADVANCE(2475);
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(959);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(101);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (lookahead == '$' ||
          lookahead == '%' ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 102:
      if (lookahead == '#') ADVANCE(2475);
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(102);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (lookahead == '$' ||
          lookahead == '%' ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 103:
      if (lookahead == '#') ADVANCE(2475);
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2278);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(959);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(103);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (lookahead == '$' ||
          lookahead == '%' ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 104:
      if (lookahead == '#') ADVANCE(2475);
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2278);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(104);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (lookahead == '$' ||
          lookahead == '%' ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 105:
      ADVANCE_MAP(
        '#', 67,
        '$', 2283,
        '%', 2266,
        '\'', 837,
        '+', 2277,
        ',', 2251,
        '-', 177,
        '.', 2273,
        '/', 2269,
        '0', 2513,
        ':', 843,
        '<', 707,
        '=', 938,
        '?', 2221,
        '@', 835,
        '\\', 114,
        'a', 360,
        'b', 656,
        'c', 331,
        'd', 463,
        'e', 673,
        'f', 466,
        'g', 600,
        'k', 399,
        'l', 487,
        'n', 317,
        'p', 612,
        'r', 395,
        's', 489,
        't', 603,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(105);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2516);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(3030);
      END_STATE();
    case 106:
      ADVANCE_MAP(
        '#', 67,
        '$', 2283,
        '%', 2266,
        '\'', 837,
        '+', 2279,
        ',', 3034,
        '-', 177,
        '.', 2273,
        '/', 2269,
        '0', 2513,
        ':', 843,
        '=', 938,
        '?', 2221,
        '@', 835,
        '\\', 113,
        'a', 2210,
        't', 2208,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(107);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2516);
      if (('b' <= lookahead && lookahead <= 'z')) ADVANCE(2211);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(3030);
      END_STATE();
    case 107:
      ADVANCE_MAP(
        '#', 67,
        '$', 2283,
        '%', 2266,
        '\'', 837,
        '+', 2279,
        '-', 177,
        '.', 2273,
        '/', 2269,
        '0', 2513,
        ':', 843,
        '=', 938,
        '?', 2221,
        '@', 835,
        '\\', 113,
        'a', 2210,
        't', 2208,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(107);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2516);
      if (('b' <= lookahead && lookahead <= 'z')) ADVANCE(2211);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(3030);
      END_STATE();
    case 108:
      if (lookahead == '#') ADVANCE(833);
      if (lookahead == '\'') ADVANCE(3322);
      if (lookahead == 'N') ADVANCE(3328);
      if (lookahead == '_') ADVANCE(2199);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(687);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(3315);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3329);
      END_STATE();
    case 109:
      if (lookahead == '%') ADVANCE(3037);
      if (lookahead == '/') ADVANCE(175);
      if (lookahead == '?') ADVANCE(278);
      if (lookahead == 'f') ADVANCE(2102);
      if (lookahead == 's') ADVANCE(2195);
      if (lookahead == 'u') ADVANCE(2168);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(174);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1023);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 110:
      ADVANCE_MAP(
        '%', 256,
        '\'', 3324,
        '*', 257,
        '+', 258,
        ',', 2251,
        '-', 259,
        '.', 170,
        '/', 260,
        ';', 2268,
        '<', 707,
        '=', 939,
        '\\', 115,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(110);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(3500);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 111:
      ADVANCE_MAP(
        '%', 256,
        '*', 257,
        '+', 258,
        '-', 259,
        '.', 172,
        '/', 260,
        '=', 939,
        'i', 520,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(111);
      END_STATE();
    case 112:
      if (lookahead == '&') ADVANCE(2286);
      if (lookahead == ')') ADVANCE(2577);
      if (lookahead == '/') ADVANCE(2284);
      if (lookahead == '?') ADVANCE(2285);
      if (lookahead == '|') ADVANCE(2406);
      END_STATE();
    case 113:
      if (lookahead == '&') ADVANCE(2286);
      if (lookahead == '/') ADVANCE(2284);
      if (lookahead == '?') ADVANCE(2285);
      END_STATE();
    case 114:
      if (lookahead == '&') ADVANCE(2286);
      if (lookahead == '/') ADVANCE(2284);
      if (lookahead == '?') ADVANCE(2285);
      if (lookahead == '|') ADVANCE(2406);
      END_STATE();
    case 115:
      if (lookahead == '&') ADVANCE(2286);
      if (lookahead == '|') ADVANCE(2406);
      END_STATE();
    case 116:
      if (lookahead == '&') ADVANCE(2478);
      END_STATE();
    case 117:
      ADVANCE_MAP(
        '(', 2520,
        ')', 2252,
        ',', 2251,
        '-', 267,
        '<', 707,
        '=', 939,
        '\\', 684,
        '{', 1027,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(120);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(1618);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 118:
      if (lookahead == '(') ADVANCE(2578);
      END_STATE();
    case 119:
      if (lookahead == '(') ADVANCE(2579);
      END_STATE();
    case 120:
      if (lookahead == ')') ADVANCE(2252);
      if (lookahead == ',') ADVANCE(2251);
      if (lookahead == '-') ADVANCE(267);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '=') ADVANCE(939);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(120);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(3030);
      END_STATE();
    case 121:
      if (lookahead == ')') ADVANCE(2252);
      if (lookahead == ',') ADVANCE(2251);
      if (lookahead == '.') ADVANCE(171);
      if (lookahead == '0') ADVANCE(2513);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == '{') ADVANCE(1024);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(121);
      if (('+' <= lookahead && lookahead <= '-')) ADVANCE(177);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2516);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 122:
      if (lookahead == ')') ADVANCE(2252);
      if (lookahead == ',') ADVANCE(2251);
      if (lookahead == '=') ADVANCE(938);
      if (lookahead == '{') ADVANCE(1027);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(123);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 123:
      if (lookahead == ')') ADVANCE(2252);
      if (lookahead == ',') ADVANCE(2251);
      if (lookahead == '=') ADVANCE(938);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(123);
      END_STATE();
    case 124:
      if (lookahead == ')') ADVANCE(2577);
      if (lookahead == '|') ADVANCE(2406);
      END_STATE();
    case 125:
      if (lookahead == '*') ADVANCE(2472);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(234);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 126:
      if (lookahead == '*') ADVANCE(2473);
      if (lookahead == '/') ADVANCE(2271);
      if (lookahead == '<') ADVANCE(2573);
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(956);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2561);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 127:
      if (lookahead == '*') ADVANCE(2473);
      if (lookahead == '<') ADVANCE(2573);
      if (lookahead == '?') ADVANCE(2272);
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(956);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2561);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 128:
      if (lookahead == '*') ADVANCE(2473);
      if (lookahead == '<') ADVANCE(2573);
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(956);
      if (lookahead == 'm') ADVANCE(2568);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 129:
      if (lookahead == '*') ADVANCE(2473);
      if (lookahead == '<') ADVANCE(2573);
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(956);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2561);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 130:
      if (lookahead == '*') ADVANCE(2473);
      if (lookahead == '<') ADVANCE(2573);
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(954);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2561);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 131:
      if (lookahead == '*') ADVANCE(2473);
      if (lookahead == '<') ADVANCE(2574);
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(956);
      if (lookahead == 'm') ADVANCE(2568);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2562);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 132:
      if (lookahead == '*') ADVANCE(2473);
      if (lookahead == '<') ADVANCE(2574);
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(956);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2563);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 133:
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '/') ADVANCE(2269);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(959);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(133);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 134:
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '/') ADVANCE(2269);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(134);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          (',' <= lookahead && lookahead <= '.') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 135:
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(959);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(135);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 136:
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2276);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(136);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 137:
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2278);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(959);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(137);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 138:
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '+') ADVANCE(2278);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(138);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          (',' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 139:
      ADVANCE_MAP(
        '*', 2534,
        '<', 707,
        '\\', 959,
        'c', 2530,
        'i', 2527,
        'l', 2529,
        'n', 2531,
        't', 2528,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(139);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 140:
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(959);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(140);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 141:
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '@') ADVANCE(3493);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(141);
      if (lookahead == '!' ||
          lookahead == ':' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 142:
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == 'A') ADVANCE(2524);
      if (lookahead == 'O') ADVANCE(2525);
      if (lookahead == 'P') ADVANCE(2523);
      if (lookahead == 'S') ADVANCE(2526);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(142);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 143:
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == 'c') ADVANCE(2530);
      if (lookahead == 'i') ADVANCE(2527);
      if (lookahead == 'l') ADVANCE(2529);
      if (lookahead == 'n') ADVANCE(2531);
      if (lookahead == 't') ADVANCE(2528);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(143);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 144:
      if (lookahead == '*') ADVANCE(2534);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(144);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2533);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2522);
      END_STATE();
    case 145:
      ADVANCE_MAP(
        '*', 2551,
        '<', 707,
        '\\', 2549,
        'b', 2544,
        'f', 2539,
        'g', 2542,
        'l', 2541,
        'n', 2536,
        'p', 2543,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(215);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2548);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2547);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2535);
      END_STATE();
    case 146:
      if (lookahead == '*') ADVANCE(2551);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(2549);
      if (lookahead == 'b') ADVANCE(2544);
      if (lookahead == 'f') ADVANCE(2539);
      if (lookahead == 'g') ADVANCE(2542);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(216);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2548);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2547);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2535);
      END_STATE();
    case 147:
      ADVANCE_MAP(
        '*', 2551,
        '<', 707,
        '\\', 2549,
        'c', 2545,
        'i', 2537,
        'l', 2540,
        'n', 2546,
        't', 2538,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(226);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2548);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2547);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2535);
      END_STATE();
    case 148:
      if (lookahead == '*') ADVANCE(2551);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(2549);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(233);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2548);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2547);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2535);
      END_STATE();
    case 149:
      if (lookahead == '*') ADVANCE(2551);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(960);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(140);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2548);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2547);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2535);
      END_STATE();
    case 150:
      ADVANCE_MAP(
        '*', 2551,
        '\\', 2550,
        'b', 2544,
        'f', 2539,
        'g', 2542,
        'l', 2541,
        'n', 2536,
        'p', 2543,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(326);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2548);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2547);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2535);
      END_STATE();
    case 151:
      if (lookahead == '*') ADVANCE(2551);
      if (lookahead == '\\') ADVANCE(2550);
      if (lookahead == 'b') ADVANCE(2544);
      if (lookahead == 'f') ADVANCE(2539);
      if (lookahead == 'g') ADVANCE(2542);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(327);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2548);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2547);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2535);
      END_STATE();
    case 152:
      if (lookahead == '*') ADVANCE(2551);
      if (lookahead == '\\') ADVANCE(2550);
      if (lookahead == 'c') ADVANCE(2545);
      if (lookahead == 'i') ADVANCE(2537);
      if (lookahead == 'l') ADVANCE(2540);
      if (lookahead == 'n') ADVANCE(2546);
      if (lookahead == 't') ADVANCE(2538);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(342);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2548);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2547);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2535);
      END_STATE();
    case 153:
      if (lookahead == '*') ADVANCE(2551);
      if (lookahead == '\\') ADVANCE(961);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(144);
      if (lookahead == '!' ||
          lookahead == ':' ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          lookahead == '{' ||
          lookahead == '}') ADVANCE(2548);
      if (('#' <= lookahead && lookahead <= '%') ||
          ('+' <= lookahead && lookahead <= '/') ||
          lookahead == '=' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(2547);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2535);
      END_STATE();
    case 154:
      ADVANCE_MAP(
        ',', 2251,
        '-', 301,
        ';', 2268,
        '<', 707,
        '=', 939,
        '\\', 124,
        'i', 520,
        'm', 310,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(154);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(3030);
      END_STATE();
    case 155:
      if (lookahead == ',') ADVANCE(2251);
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'c') ADVANCE(3445);
      if (lookahead == 'n') ADVANCE(3448);
      if (lookahead == 's') ADVANCE(3460);
      if (lookahead == 't') ADVANCE(3474);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(155);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= ']') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 156:
      if (lookahead == ',') ADVANCE(2251);
      if (lookahead == '<') ADVANCE(2643);
      if (lookahead == '\\') ADVANCE(2609);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(156);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(3027);
      END_STATE();
    case 157:
      if (lookahead == ',') ADVANCE(2251);
      if (lookahead == '}') ADVANCE(1026);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(157);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2581);
      END_STATE();
    case 158:
      if (lookahead == ',') ADVANCE(2251);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(158);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(3027);
      END_STATE();
    case 159:
      if (lookahead == ',') ADVANCE(686);
      if (lookahead == '-') ADVANCE(160);
      if (lookahead == '}') ADVANCE(2554);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(160);
      END_STATE();
    case 160:
      if (lookahead == ',') ADVANCE(686);
      if (lookahead == '}') ADVANCE(2554);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(160);
      END_STATE();
    case 161:
      if (lookahead == '-') ADVANCE(344);
      END_STATE();
    case 162:
      if (lookahead == '-') ADVANCE(188);
      if (lookahead == '2') ADVANCE(328);
      END_STATE();
    case 163:
      if (lookahead == '-') ADVANCE(184);
      if (lookahead == '8') ADVANCE(908);
      END_STATE();
    case 164:
      if (lookahead == '-') ADVANCE(2293);
      END_STATE();
    case 165:
      if (lookahead == '-') ADVANCE(301);
      if (lookahead == '=') ADVANCE(2222);
      if (lookahead == 't') ADVANCE(2208);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(166);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(2211);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(3030);
      END_STATE();
    case 166:
      if (lookahead == '-') ADVANCE(301);
      if (lookahead == 't') ADVANCE(2208);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(166);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(2211);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(3030);
      END_STATE();
    case 167:
      if (lookahead == '-') ADVANCE(182);
      END_STATE();
    case 168:
      if (lookahead == '.') ADVANCE(2253);
      END_STATE();
    case 169:
      if (lookahead == '.') ADVANCE(2253);
      if (lookahead == '=') ADVANCE(2206);
      END_STATE();
    case 170:
      if (lookahead == '.') ADVANCE(169);
      if (lookahead == '=') ADVANCE(2205);
      END_STATE();
    case 171:
      if (lookahead == '.') ADVANCE(168);
      END_STATE();
    case 172:
      if (lookahead == '.') ADVANCE(261);
      if (lookahead == '=') ADVANCE(2205);
      END_STATE();
    case 173:
      if (lookahead == '/') ADVANCE(2271);
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(957);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2572);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 174:
      if (lookahead == '/') ADVANCE(175);
      if (lookahead == '?') ADVANCE(278);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(174);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 175:
      if (lookahead == '/') ADVANCE(948);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(175);
      END_STATE();
    case 176:
      ADVANCE_MAP(
        '0', 2513,
        '>', 2521,
        'a', 362,
        'b', 305,
        'c', 558,
        'k', 404,
        'n', 308,
        'r', 311,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2516);
      END_STATE();
    case 177:
      if (lookahead == '0') ADVANCE(2513);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2516);
      END_STATE();
    case 178:
      if (lookahead == '0') ADVANCE(865);
      if (lookahead == '2') ADVANCE(866);
      if (lookahead == '5') ADVANCE(867);
      if (lookahead == '7') ADVANCE(868);
      END_STATE();
    case 179:
      if (lookahead == '0') ADVANCE(869);
      if (lookahead == '1') ADVANCE(870);
      if (lookahead == '2') ADVANCE(871);
      if (lookahead == '3') ADVANCE(872);
      if (lookahead == '5') ADVANCE(873);
      if (lookahead == '6') ADVANCE(874);
      if (lookahead == '9') ADVANCE(875);
      END_STATE();
    case 180:
      if (lookahead == '0') ADVANCE(892);
      END_STATE();
    case 181:
      ADVANCE_MAP(
        '0', 877,
        '1', 878,
        '3', 879,
        '4', 880,
        '5', 881,
        '6', 882,
        '7', 883,
        '8', 884,
      );
      END_STATE();
    case 182:
      if (lookahead == '0') ADVANCE(2383);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2385);
      END_STATE();
    case 183:
      if (lookahead == '1') ADVANCE(192);
      if (lookahead == '4') ADVANCE(193);
      if (lookahead == '7') ADVANCE(195);
      if (lookahead == '8') ADVANCE(198);
      if (lookahead == '9') ADVANCE(194);
      END_STATE();
    case 184:
      if (lookahead == '1') ADVANCE(201);
      if (lookahead == '3') ADVANCE(189);
      if (lookahead == '8') ADVANCE(895);
      END_STATE();
    case 185:
      if (lookahead == '1') ADVANCE(858);
      END_STATE();
    case 186:
      if (lookahead == '1') ADVANCE(202);
      if (lookahead == '3') ADVANCE(191);
      if (lookahead == '8') ADVANCE(921);
      END_STATE();
    case 187:
      if (lookahead == '2') ADVANCE(885);
      if (lookahead == '6') ADVANCE(890);
      END_STATE();
    case 188:
      if (lookahead == '2') ADVANCE(896);
      if (lookahead == '4') ADVANCE(900);
      END_STATE();
    case 189:
      if (lookahead == '2') ADVANCE(913);
      END_STATE();
    case 190:
      if (lookahead == '2') ADVANCE(922);
      if (lookahead == '4') ADVANCE(926);
      END_STATE();
    case 191:
      if (lookahead == '2') ADVANCE(930);
      END_STATE();
    case 192:
      if (lookahead == '2') ADVANCE(199);
      END_STATE();
    case 193:
      if (lookahead == '3') ADVANCE(203);
      END_STATE();
    case 194:
      if (lookahead == '3') ADVANCE(187);
      if (lookahead == '4') ADVANCE(206);
      if (lookahead == '5') ADVANCE(180);
      END_STATE();
    case 195:
      if (lookahead == '3') ADVANCE(204);
      if (lookahead == '7') ADVANCE(200);
      END_STATE();
    case 196:
      if (lookahead == '4') ADVANCE(876);
      END_STATE();
    case 197:
      if (lookahead == '5') ADVANCE(893);
      END_STATE();
    case 198:
      if (lookahead == '5') ADVANCE(178);
      if (lookahead == '6') ADVANCE(179);
      if (lookahead == '7') ADVANCE(196);
      END_STATE();
    case 199:
      if (lookahead == '5') ADVANCE(181);
      END_STATE();
    case 200:
      if (lookahead == '5') ADVANCE(864);
      END_STATE();
    case 201:
      if (lookahead == '6') ADVANCE(898);
      END_STATE();
    case 202:
      if (lookahead == '6') ADVANCE(924);
      END_STATE();
    case 203:
      if (lookahead == '7') ADVANCE(862);
      END_STATE();
    case 204:
      if (lookahead == '7') ADVANCE(863);
      END_STATE();
    case 205:
      if (lookahead == '8') ADVANCE(860);
      END_STATE();
    case 206:
      if (lookahead == '9') ADVANCE(888);
      END_STATE();
    case 207:
      ADVANCE_MAP(
        '<', 2389,
        '\\', 2401,
        'A', 2426,
        'a', 2426,
        'B', 2431,
        'b', 2431,
        'C', 2427,
        'c', 2427,
        'D', 2425,
        'd', 2425,
        'E', 2439,
        'e', 2439,
        'F', 2441,
        'f', 2441,
        'H', 2435,
        'h', 2435,
        'I', 2437,
        'i', 2437,
        'K', 2433,
        'k', 2433,
        'L', 2434,
        'l', 2434,
        'M', 2424,
        'm', 2424,
        'N', 2438,
        'n', 2438,
        'P', 2430,
        'p', 2430,
        'R', 2436,
        'r', 2436,
        'S', 2428,
        's', 2428,
        'T', 2429,
        't', 2429,
        'U', 2440,
        'u', 2440,
        'X', 2432,
        'x', 2432,
      );
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '|') ADVANCE(2423);
      END_STATE();
    case 208:
      if (lookahead == '<') ADVANCE(2389);
      if (lookahead == '\\') ADVANCE(2401);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '|') ADVANCE(2423);
      END_STATE();
    case 209:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '=') ADVANCE(939);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'a') ADVANCE(1031);
      if (lookahead == '{') ADVANCE(1024);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(209);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 210:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '=') ADVANCE(939);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'a') ADVANCE(1564);
      if (lookahead == '{') ADVANCE(1027);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(209);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(2035);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2033);
      END_STATE();
    case 211:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'a') ADVANCE(1031);
      if (lookahead == '{') ADVANCE(1024);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(211);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 212:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'a') ADVANCE(1011);
      if (lookahead == '{') ADVANCE(1024);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(211);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1023);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1018);
      END_STATE();
    case 213:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'a') ADVANCE(3093);
      if (lookahead == 'c') ADVANCE(3204);
      if (lookahead == 'r') ADVANCE(3106);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(213);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 214:
      ADVANCE_MAP(
        '<', 707,
        '\\', 684,
        'b', 1611,
        'f', 1578,
        'g', 1602,
        'l', 1579,
        'n', 1565,
        'p', 1603,
        '{', 1027,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(215);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 215:
      ADVANCE_MAP(
        '<', 707,
        '\\', 684,
        'b', 656,
        'f', 464,
        'g', 600,
        'l', 487,
        'n', 316,
        'p', 612,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(215);
      END_STATE();
    case 216:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'b') ADVANCE(656);
      if (lookahead == 'f') ADVANCE(464);
      if (lookahead == 'g') ADVANCE(600);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(216);
      END_STATE();
    case 217:
      ADVANCE_MAP(
        '<', 707,
        '\\', 684,
        'b', 499,
        'c', 646,
        'f', 566,
        'g', 659,
        's', 635,
        't', 421,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(217);
      END_STATE();
    case 218:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'c') ADVANCE(2122);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(219);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(3035);
      if (lookahead == '*' ||
          lookahead == '+' ||
          lookahead == '?') ADVANCE(3036);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 219:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'c') ADVANCE(2122);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(219);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 220:
      ADVANCE_MAP(
        '<', 707,
        '\\', 684,
        'c', 2059,
        'd', 2103,
        'e', 2130,
        'f', 2149,
        'k', 2090,
        'm', 2048,
        'n', 2081,
        'o', 2141,
        's', 2112,
        't', 2164,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(220);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 221:
      ADVANCE_MAP(
        '<', 707,
        '\\', 684,
        'c', 2059,
        'd', 2103,
        'e', 2130,
        'f', 2149,
        'k', 2090,
        'm', 2048,
        'n', 2081,
        'o', 2141,
        's', 2113,
        't', 2164,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(221);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 222:
      ADVANCE_MAP(
        '<', 707,
        '\\', 684,
        'c', 3075,
        'd', 3132,
        'e', 3173,
        'f', 3199,
        'k', 3104,
        'm', 3058,
        'n', 3094,
        'o', 3184,
        's', 3149,
        't', 3224,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(222);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 223:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'c') ADVANCE(3077);
      if (lookahead == 'n') ADVANCE(3098);
      if (lookahead == 's') ADVANCE(3146);
      if (lookahead == 't') ADVANCE(3219);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(223);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (('[' <= lookahead && lookahead <= ']')) ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 224:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'c') ADVANCE(3253);
      if (lookahead == 'i') ADVANCE(3081);
      if (lookahead == 'l') ADVANCE(3143);
      if (lookahead == 'n') ADVANCE(3248);
      if (lookahead == 't') ADVANCE(3117);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(224);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 225:
      ADVANCE_MAP(
        '<', 707,
        '\\', 684,
        'c', 1613,
        'i', 1566,
        'l', 1582,
        'n', 1614,
        't', 1570,
        '{', 1027,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(226);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 226:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'c') ADVANCE(657);
      if (lookahead == 'i') ADVANCE(336);
      if (lookahead == 'l') ADVANCE(481);
      if (lookahead == 'n') ADVANCE(658);
      if (lookahead == 't') ADVANCE(419);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(226);
      END_STATE();
    case 227:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'c') ADVANCE(3166);
      if (lookahead == 'l') ADVANCE(3140);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(227);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 228:
      ADVANCE_MAP(
        '<', 707,
        '\\', 684,
        'c', 2060,
        'd', 2103,
        'e', 2192,
        'f', 2149,
        'k', 2090,
        'n', 2081,
        's', 2112,
        't', 2164,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(228);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 229:
      ADVANCE_MAP(
        '<', 707,
        '\\', 684,
        'c', 3076,
        'd', 3132,
        'e', 3255,
        'f', 3199,
        'k', 3104,
        'n', 3094,
        's', 3149,
        't', 3224,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(229);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 230:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'd') ADVANCE(2078);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(230);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 231:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 'm') ADVANCE(3066);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(231);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 232:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == 's') ADVANCE(2184);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(232);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 233:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(233);
      END_STATE();
    case 234:
      if (lookahead == '<') ADVANCE(707);
      if (lookahead == '\\') ADVANCE(684);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(234);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 235:
      if (lookahead == '<') ADVANCE(2207);
      END_STATE();
    case 236:
      if (lookahead == '<') ADVANCE(2392);
      if (lookahead == '\\') ADVANCE(2401);
      if (lookahead == '|') ADVANCE(964);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(238);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(970);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(985);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(973);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(968);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1002);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1005);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(995);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(998);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(990);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(992);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(965);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1000);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(984);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(996);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(975);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(983);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1004);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(989);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(964);
      END_STATE();
    case 237:
      if (lookahead == '<') ADVANCE(2392);
      if (lookahead == '\\') ADVANCE(2401);
      if (lookahead == '|') ADVANCE(964);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(238);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(964);
      END_STATE();
    case 238:
      if (lookahead == '<') ADVANCE(2400);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(238);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '|') ADVANCE(2422);
      END_STATE();
    case 239:
      ADVANCE_MAP(
        '<', 2390,
        '\\', 2402,
        '\t', 2423,
        ' ', 2423,
        'A', 2426,
        'a', 2426,
        'B', 2431,
        'b', 2431,
        'C', 2427,
        'c', 2427,
        'D', 2425,
        'd', 2425,
        'E', 2439,
        'e', 2439,
        'F', 2441,
        'f', 2441,
        'H', 2435,
        'h', 2435,
        'I', 2437,
        'i', 2437,
        'K', 2433,
        'k', 2433,
        'L', 2434,
        'l', 2434,
        'M', 2424,
        'm', 2424,
        'N', 2438,
        'n', 2438,
        'P', 2430,
        'p', 2430,
        'R', 2436,
        'r', 2436,
        'S', 2428,
        's', 2428,
        'T', 2429,
        't', 2429,
        'U', 2440,
        'u', 2440,
        'X', 2432,
        'x', 2432,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '|') ADVANCE(2423);
      END_STATE();
    case 240:
      if (lookahead == '<') ADVANCE(2390);
      if (lookahead == '\\') ADVANCE(2402);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2423);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '|') ADVANCE(2423);
      END_STATE();
    case 241:
      ADVANCE_MAP(
        '<', 2391,
        '\\', 3304,
        'b', 3288,
        'c', 3302,
        'f', 3293,
        'g', 3303,
        's', 3299,
        't', 3280,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(217);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(3307);
      END_STATE();
    case 242:
      if (lookahead == '<') ADVANCE(2575);
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(957);
      if (lookahead == 'm') ADVANCE(2568);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2566);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 243:
      if (lookahead == '<') ADVANCE(2575);
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(957);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2567);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 244:
      if (lookahead == '<') ADVANCE(2393);
      if (lookahead == 'b') ADVANCE(3288);
      if (lookahead == 'c') ADVANCE(3302);
      if (lookahead == 'f') ADVANCE(3293);
      if (lookahead == 'g') ADVANCE(3303);
      if (lookahead == 's') ADVANCE(3299);
      if (lookahead == 't') ADVANCE(3280);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(329);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(3307);
      END_STATE();
    case 245:
      if (lookahead == '<') ADVANCE(2393);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 246:
      if (lookahead == '<') ADVANCE(2643);
      if (lookahead == '\\') ADVANCE(2609);
      if (lookahead == '{') ADVANCE(1025);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(246);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1523);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1231);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1246);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1338);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1247);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1527);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1344);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1472);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1157);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1414);
      if (lookahead == 'Q' ||
          lookahead == 'q') ADVANCE(1530);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1143);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1041);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1037);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1248);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1249);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1261);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 247:
      if (lookahead == '<') ADVANCE(2643);
      if (lookahead == '\\') ADVANCE(2609);
      if (lookahead == '{') ADVANCE(1028);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(248);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(2007);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1778);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1789);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1861);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1790);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2008);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1866);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1968);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1712);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1923);
      if (lookahead == 'Q' ||
          lookahead == 'q') ADVANCE(2010);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1700);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1622);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1619);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1791);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1792);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1800);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 248:
      if (lookahead == '<') ADVANCE(2643);
      if (lookahead == '\\') ADVANCE(2609);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(248);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(3002);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2771);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2782);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2854);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2783);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(3003);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2859);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2963);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(2703);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2916);
      if (lookahead == 'Q' ||
          lookahead == 'q') ADVANCE(3005);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2693);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2613);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2610);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2784);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(2785);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(2793);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 249:
      if (lookahead == '<') ADVANCE(951);
      if (lookahead == '\\') ADVANCE(959);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(249);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(950);
      END_STATE();
    case 250:
      if (lookahead == '<') ADVANCE(2398);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(250);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(950);
      END_STATE();
    case 251:
      if (lookahead == '<') ADVANCE(2399);
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(251);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(950);
      END_STATE();
    case 252:
      if (lookahead == '<') ADVANCE(986);
      if (lookahead == '\\') ADVANCE(960);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(249);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(964);
      END_STATE();
    case 253:
      if (lookahead == '<') ADVANCE(2247);
      if (lookahead == '\\') ADVANCE(2245);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(253);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(2249);
      END_STATE();
    case 254:
      if (lookahead == '<') ADVANCE(2241);
      if (lookahead == '\\') ADVANCE(2238);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2236);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2243);
      END_STATE();
    case 255:
      if (lookahead == '<') ADVANCE(941);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(255);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(942);
      END_STATE();
    case 256:
      if (lookahead == '=') ADVANCE(2204);
      END_STATE();
    case 257:
      if (lookahead == '=') ADVANCE(2202);
      END_STATE();
    case 258:
      if (lookahead == '=') ADVANCE(2200);
      END_STATE();
    case 259:
      if (lookahead == '=') ADVANCE(2201);
      END_STATE();
    case 260:
      if (lookahead == '=') ADVANCE(2203);
      END_STATE();
    case 261:
      if (lookahead == '=') ADVANCE(2206);
      END_STATE();
    case 262:
      if (lookahead == '=') ADVANCE(2487);
      if (lookahead == '~') ADVANCE(2493);
      END_STATE();
    case 263:
      if (lookahead == '=') ADVANCE(2486);
      if (lookahead == '~') ADVANCE(2492);
      END_STATE();
    case 264:
      if (lookahead == '=') ADVANCE(2224);
      END_STATE();
    case 265:
      if (lookahead == '=') ADVANCE(2226);
      END_STATE();
    case 266:
      if (lookahead == '=') ADVANCE(2225);
      END_STATE();
    case 267:
      if (lookahead == '>') ADVANCE(2521);
      if (lookahead == 'a') ADVANCE(362);
      if (lookahead == 'b') ADVANCE(305);
      if (lookahead == 'c') ADVANCE(558);
      if (lookahead == 'k') ADVANCE(404);
      if (lookahead == 'n') ADVANCE(308);
      if (lookahead == 'r') ADVANCE(311);
      END_STATE();
    case 268:
      if (lookahead == '>') ADVANCE(2418);
      END_STATE();
    case 269:
      if (lookahead == '>') ADVANCE(2414);
      END_STATE();
    case 270:
      if (lookahead == '>') ADVANCE(2405);
      END_STATE();
    case 271:
      if (lookahead == '>') ADVANCE(2292);
      END_STATE();
    case 272:
      if (lookahead == '>') ADVANCE(2287);
      END_STATE();
    case 273:
      if (lookahead == '>') ADVANCE(2288);
      END_STATE();
    case 274:
      if (lookahead == '>') ADVANCE(2291);
      END_STATE();
    case 275:
      if (lookahead == '>') ADVANCE(2289);
      END_STATE();
    case 276:
      if (lookahead == '>') ADVANCE(2290);
      END_STATE();
    case 277:
      if (lookahead == '?') ADVANCE(2272);
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(957);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2572);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 278:
      if (lookahead == '?') ADVANCE(949);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(278);
      END_STATE();
    case 279:
      if (lookahead == 'A') ADVANCE(288);
      END_STATE();
    case 280:
      if (lookahead == 'C') ADVANCE(283);
      END_STATE();
    case 281:
      if (lookahead == 'E') ADVANCE(3269);
      END_STATE();
    case 282:
      if (lookahead == 'F') ADVANCE(847);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(282);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(854);
      END_STATE();
    case 283:
      if (lookahead == 'K') ADVANCE(934);
      END_STATE();
    case 284:
      if (lookahead == 'L') ADVANCE(935);
      END_STATE();
    case 285:
      if (lookahead == 'N') ADVANCE(281);
      END_STATE();
    case 286:
      if (lookahead == 'N') ADVANCE(2043);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(687);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 287:
      if (lookahead == 'O') ADVANCE(285);
      END_STATE();
    case 288:
      if (lookahead == 'R') ADVANCE(290);
      END_STATE();
    case 289:
      if (lookahead == 'T') ADVANCE(933);
      END_STATE();
    case 290:
      if (lookahead == 'T') ADVANCE(932);
      END_STATE();
    case 291:
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(957);
      if (lookahead == 'm') ADVANCE(2568);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2570);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 292:
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(957);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2572);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 293:
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(958);
      if (lookahead == 'g') ADVANCE(2571);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2569);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 294:
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(958);
      if (lookahead == 'm') ADVANCE(2568);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2570);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 295:
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(958);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2572);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 296:
      if (lookahead == '[') ADVANCE(2518);
      if (lookahead == '\\') ADVANCE(955);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2572);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2557);
      END_STATE();
    case 297:
      if (lookahead == '\\') ADVANCE(2401);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(2584);
      END_STATE();
    case 298:
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == ']') ADVANCE(2519);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2556);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2555);
      END_STATE();
    case 299:
      if (lookahead == '\\') ADVANCE(953);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(299);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(950);
      END_STATE();
    case 300:
      if (lookahead == '\\') ADVANCE(961);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(299);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(964);
      END_STATE();
    case 301:
      if (lookahead == 'a') ADVANCE(362);
      if (lookahead == 'b') ADVANCE(305);
      if (lookahead == 'c') ADVANCE(558);
      if (lookahead == 'k') ADVANCE(404);
      if (lookahead == 'n') ADVANCE(308);
      if (lookahead == 'r') ADVANCE(311);
      END_STATE();
    case 302:
      if (lookahead == 'a') ADVANCE(589);
      END_STATE();
    case 303:
      if (lookahead == 'a') ADVANCE(650);
      if (lookahead == 'i') ADVANCE(543);
      END_STATE();
    case 304:
      if (lookahead == 'a') ADVANCE(341);
      if (lookahead == 'i') ADVANCE(557);
      END_STATE();
    case 305:
      if (lookahead == 'a') ADVANCE(534);
      if (lookahead == 'u') ADVANCE(436);
      END_STATE();
    case 306:
      if (lookahead == 'a') ADVANCE(904);
      END_STATE();
    case 307:
      if (lookahead == 'a') ADVANCE(678);
      END_STATE();
    case 308:
      if (lookahead == 'a') ADVANCE(606);
      END_STATE();
    case 309:
      if (lookahead == 'a') ADVANCE(661);
      END_STATE();
    case 310:
      if (lookahead == 'a') ADVANCE(675);
      if (lookahead == 'i') ADVANCE(557);
      END_STATE();
    case 311:
      if (lookahead == 'a') ADVANCE(536);
      if (lookahead == 'e') ADVANCE(447);
      END_STATE();
    case 312:
      if (lookahead == 'a') ADVANCE(609);
      if (lookahead == 'o') ADVANCE(573);
      END_STATE();
    case 313:
      if (lookahead == 'a') ADVANCE(460);
      if (lookahead == 'e') ADVANCE(605);
      if (lookahead == 'r') ADVANCE(314);
      END_STATE();
    case 314:
      if (lookahead == 'a') ADVANCE(535);
      END_STATE();
    case 315:
      if (lookahead == 'a') ADVANCE(594);
      END_STATE();
    case 316:
      if (lookahead == 'a') ADVANCE(517);
      END_STATE();
    case 317:
      if (lookahead == 'a') ADVANCE(517);
      if (lookahead == 'e') ADVANCE(674);
      END_STATE();
    case 318:
      if (lookahead == 'a') ADVANCE(523);
      END_STATE();
    case 319:
      if (lookahead == 'a') ADVANCE(526);
      END_STATE();
    case 320:
      if (lookahead == 'a') ADVANCE(495);
      END_STATE();
    case 321:
      if (lookahead == 'a') ADVANCE(617);
      END_STATE();
    case 322:
      if (lookahead == 'a') ADVANCE(528);
      END_STATE();
    case 323:
      if (lookahead == 'a') ADVANCE(497);
      END_STATE();
    case 324:
      if (lookahead == 'a') ADVANCE(475);
      END_STATE();
    case 325:
      if (lookahead == 'a') ADVANCE(478);
      END_STATE();
    case 326:
      if (lookahead == 'b') ADVANCE(656);
      if (lookahead == 'f') ADVANCE(464);
      if (lookahead == 'g') ADVANCE(600);
      if (lookahead == 'l') ADVANCE(487);
      if (lookahead == 'n') ADVANCE(316);
      if (lookahead == 'p') ADVANCE(612);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(326);
      END_STATE();
    case 327:
      if (lookahead == 'b') ADVANCE(656);
      if (lookahead == 'f') ADVANCE(464);
      if (lookahead == 'g') ADVANCE(600);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(327);
      END_STATE();
    case 328:
      if (lookahead == 'b') ADVANCE(371);
      END_STATE();
    case 329:
      if (lookahead == 'b') ADVANCE(499);
      if (lookahead == 'c') ADVANCE(646);
      if (lookahead == 'f') ADVANCE(566);
      if (lookahead == 'g') ADVANCE(659);
      if (lookahead == 's') ADVANCE(635);
      if (lookahead == 't') ADVANCE(421);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(329);
      END_STATE();
    case 330:
      if (lookahead == 'c') ADVANCE(454);
      if (lookahead == 'h') ADVANCE(482);
      if (lookahead == 'o') ADVANCE(531);
      if (lookahead == 'p') ADVANCE(183);
      if (lookahead == 't') ADVANCE(396);
      if (lookahead == 'u') ADVANCE(498);
      END_STATE();
    case 331:
      if (lookahead == 'c') ADVANCE(454);
      if (lookahead == 'o') ADVANCE(556);
      END_STATE();
    case 332:
      if (lookahead == 'c') ADVANCE(161);
      END_STATE();
    case 333:
      if (lookahead == 'c') ADVANCE(905);
      END_STATE();
    case 334:
      ADVANCE_MAP(
        'c', 3075,
        'd', 3132,
        'e', 3173,
        'f', 3199,
        'k', 3104,
        'm', 3058,
        'n', 3094,
        'o', 3184,
        's', 3150,
        't', 3224,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(334);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 335:
      ADVANCE_MAP(
        'c', 3075,
        'd', 3132,
        'e', 3255,
        'f', 3199,
        'k', 3104,
        'm', 3058,
        'n', 3094,
        'o', 3184,
        's', 3148,
        't', 3224,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(335);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 336:
      if (lookahead == 'c') ADVANCE(563);
      END_STATE();
    case 337:
      if (lookahead == 'c') ADVANCE(563);
      if (lookahead == 'n') ADVANCE(946);
      if (lookahead == 's') ADVANCE(560);
      END_STATE();
    case 338:
      if (lookahead == 'c') ADVANCE(621);
      if (lookahead == 'n') ADVANCE(469);
      if (lookahead == 't') ADVANCE(430);
      END_STATE();
    case 339:
      if (lookahead == 'c') ADVANCE(456);
      END_STATE();
    case 340:
      if (lookahead == 'c') ADVANCE(500);
      if (lookahead == 't') ADVANCE(422);
      END_STATE();
    case 341:
      if (lookahead == 'c') ADVANCE(611);
      if (lookahead == 't') ADVANCE(339);
      if (lookahead == 'x') ADVANCE(509);
      END_STATE();
    case 342:
      if (lookahead == 'c') ADVANCE(657);
      if (lookahead == 'i') ADVANCE(336);
      if (lookahead == 'l') ADVANCE(481);
      if (lookahead == 'n') ADVANCE(658);
      if (lookahead == 't') ADVANCE(419);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(342);
      END_STATE();
    case 343:
      if (lookahead == 'c') ADVANCE(569);
      END_STATE();
    case 344:
      if (lookahead == 'c') ADVANCE(525);
      if (lookahead == 'j') ADVANCE(576);
      if (lookahead == 'k') ADVANCE(596);
      if (lookahead == 't') ADVANCE(669);
      END_STATE();
    case 345:
      if (lookahead == 'c') ADVANCE(618);
      END_STATE();
    case 346:
      if (lookahead == 'c') ADVANCE(403);
      if (lookahead == 't') ADVANCE(324);
      END_STATE();
    case 347:
      if (lookahead == 'c') ADVANCE(530);
      if (lookahead == 'j') ADVANCE(580);
      if (lookahead == 'k') ADVANCE(599);
      if (lookahead == 't') ADVANCE(670);
      END_STATE();
    case 348:
      if (lookahead == 'c') ADVANCE(385);
      END_STATE();
    case 349:
      if (lookahead == 'c') ADVANCE(2123);
      if (lookahead == 'l') ADVANCE(2109);
      if (lookahead == 'm') ADVANCE(2051);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(349);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 350:
      if (lookahead == 'c') ADVANCE(423);
      if (lookahead == 't') ADVANCE(324);
      END_STATE();
    case 351:
      if (lookahead == 'c') ADVANCE(620);
      if (lookahead == 'i') ADVANCE(508);
      END_STATE();
    case 352:
      if (lookahead == 'd') ADVANCE(3433);
      END_STATE();
    case 353:
      if (lookahead == 'd') ADVANCE(3490);
      END_STATE();
    case 354:
      if (lookahead == 'd') ADVANCE(3409);
      END_STATE();
    case 355:
      if (lookahead == 'd') ADVANCE(3342);
      END_STATE();
    case 356:
      if (lookahead == 'd') ADVANCE(3415);
      END_STATE();
    case 357:
      if (lookahead == 'd') ADVANCE(3418);
      END_STATE();
    case 358:
      if (lookahead == 'd') ADVANCE(3375);
      END_STATE();
    case 359:
      if (lookahead == 'd') ADVANCE(3029);
      END_STATE();
    case 360:
      if (lookahead == 'd') ADVANCE(352);
      END_STATE();
    case 361:
      if (lookahead == 'd') ADVANCE(352);
      if (lookahead == 'n') ADVANCE(630);
      END_STATE();
    case 362:
      if (lookahead == 'd') ADVANCE(363);
      END_STATE();
    case 363:
      if (lookahead == 'd') ADVANCE(593);
      END_STATE();
    case 364:
      if (lookahead == 'd') ADVANCE(626);
      END_STATE();
    case 365:
      if (lookahead == 'd') ADVANCE(420);
      END_STATE();
    case 366:
      if (lookahead == 'd') ADVANCE(378);
      END_STATE();
    case 367:
      if (lookahead == 'e') ADVANCE(674);
      if (lookahead == 'u') ADVANCE(518);
      END_STATE();
    case 368:
      if (lookahead == 'e') ADVANCE(2470);
      END_STATE();
    case 369:
      if (lookahead == 'e') ADVANCE(3040);
      END_STATE();
    case 370:
      if (lookahead == 'e') ADVANCE(3435);
      END_STATE();
    case 371:
      if (lookahead == 'e') ADVANCE(910);
      END_STATE();
    case 372:
      if (lookahead == 'e') ADVANCE(906);
      END_STATE();
    case 373:
      if (lookahead == 'e') ADVANCE(3427);
      END_STATE();
    case 374:
      if (lookahead == 'e') ADVANCE(897);
      END_STATE();
    case 375:
      if (lookahead == 'e') ADVANCE(911);
      END_STATE();
    case 376:
      if (lookahead == 'e') ADVANCE(912);
      END_STATE();
    case 377:
      if (lookahead == 'e') ADVANCE(901);
      END_STATE();
    case 378:
      if (lookahead == 'e') ADVANCE(909);
      END_STATE();
    case 379:
      if (lookahead == 'e') ADVANCE(899);
      END_STATE();
    case 380:
      if (lookahead == 'e') ADVANCE(914);
      END_STATE();
    case 381:
      if (lookahead == 'e') ADVANCE(3039);
      END_STATE();
    case 382:
      if (lookahead == 'e') ADVANCE(3391);
      END_STATE();
    case 383:
      if (lookahead == 'e') ADVANCE(2460);
      END_STATE();
    case 384:
      if (lookahead == 'e') ADVANCE(2462);
      END_STATE();
    case 385:
      if (lookahead == 'e') ADVANCE(3028);
      END_STATE();
    case 386:
      if (lookahead == 'e') ADVANCE(923);
      END_STATE();
    case 387:
      if (lookahead == 'e') ADVANCE(928);
      END_STATE();
    case 388:
      if (lookahead == 'e') ADVANCE(929);
      END_STATE();
    case 389:
      if (lookahead == 'e') ADVANCE(927);
      END_STATE();
    case 390:
      if (lookahead == 'e') ADVANCE(925);
      END_STATE();
    case 391:
      if (lookahead == 'e') ADVANCE(931);
      END_STATE();
    case 392:
      if (lookahead == 'e') ADVANCE(3502);
      END_STATE();
    case 393:
      if (lookahead == 'e') ADVANCE(3503);
      END_STATE();
    case 394:
      if (lookahead == 'e') ADVANCE(431);
      if (lookahead == 'i') ADVANCE(628);
      END_STATE();
    case 395:
      if (lookahead == 'e') ADVANCE(514);
      END_STATE();
    case 396:
      if (lookahead == 'e') ADVANCE(607);
      END_STATE();
    case 397:
      if (lookahead == 'e') ADVANCE(591);
      END_STATE();
    case 398:
      if (lookahead == 'e') ADVANCE(538);
      END_STATE();
    case 399:
      if (lookahead == 'e') ADVANCE(397);
      END_STATE();
    case 400:
      if (lookahead == 'e') ADVANCE(397);
      if (lookahead == 'o') ADVANCE(459);
      END_STATE();
    case 401:
      if (lookahead == 'e') ADVANCE(306);
      END_STATE();
    case 402:
      if (lookahead == 'e') ADVANCE(516);
      if (lookahead == 'n') ADVANCE(493);
      if (lookahead == 'w') ADVANCE(451);
      END_STATE();
    case 403:
      if (lookahead == 'e') ADVANCE(320);
      END_STATE();
    case 404:
      if (lookahead == 'e') ADVANCE(405);
      END_STATE();
    case 405:
      if (lookahead == 'e') ADVANCE(582);
      END_STATE();
    case 406:
      if (lookahead == 'e') ADVANCE(595);
      END_STATE();
    case 407:
      if (lookahead == 'e') ADVANCE(632);
      END_STATE();
    case 408:
      if (lookahead == 'e') ADVANCE(276);
      END_STATE();
    case 409:
      if (lookahead == 'e') ADVANCE(358);
      if (lookahead == 's') ADVANCE(3406);
      END_STATE();
    case 410:
      if (lookahead == 'e') ADVANCE(624);
      END_STATE();
    case 411:
      if (lookahead == 'e') ADVANCE(597);
      END_STATE();
    case 412:
      if (lookahead == 'e') ADVANCE(625);
      END_STATE();
    case 413:
      if (lookahead == 'e') ADVANCE(359);
      END_STATE();
    case 414:
      if (lookahead == 'e') ADVANCE(598);
      END_STATE();
    case 415:
      if (lookahead == 'e') ADVANCE(545);
      END_STATE();
    case 416:
      if (lookahead == 'e') ADVANCE(614);
      END_STATE();
    case 417:
      if (lookahead == 'e') ADVANCE(549);
      END_STATE();
    case 418:
      if (lookahead == 'e') ADVANCE(610);
      END_STATE();
    case 419:
      if (lookahead == 'e') ADVANCE(676);
      END_STATE();
    case 420:
      if (lookahead == 'e') ADVANCE(547);
      END_STATE();
    case 421:
      if (lookahead == 'e') ADVANCE(604);
      END_STATE();
    case 422:
      if (lookahead == 'e') ADVANCE(541);
      END_STATE();
    case 423:
      if (lookahead == 'e') ADVANCE(323);
      END_STATE();
    case 424:
      if (lookahead == 'e') ADVANCE(653);
      END_STATE();
    case 425:
      if (lookahead == 'e') ADVANCE(634);
      END_STATE();
    case 426:
      if (lookahead == 'e') ADVANCE(615);
      END_STATE();
    case 427:
      if (lookahead == 'e') ADVANCE(452);
      END_STATE();
    case 428:
      if (lookahead == 'e') ADVANCE(542);
      END_STATE();
    case 429:
      if (lookahead == 'e') ADVANCE(511);
      END_STATE();
    case 430:
      if (lookahead == 'f') ADVANCE(163);
      END_STATE();
    case 431:
      if (lookahead == 'f') ADVANCE(309);
      END_STATE();
    case 432:
      if (lookahead == 'f') ADVANCE(433);
      END_STATE();
    case 433:
      if (lookahead == 'f') ADVANCE(406);
      END_STATE();
    case 434:
      if (lookahead == 'f') ADVANCE(411);
      END_STATE();
    case 435:
      if (lookahead == 'f') ADVANCE(418);
      END_STATE();
    case 436:
      if (lookahead == 'f') ADVANCE(434);
      END_STATE();
    case 437:
      if (lookahead == 'f') ADVANCE(435);
      END_STATE();
    case 438:
      if (lookahead == 'g') ADVANCE(197);
      END_STATE();
    case 439:
      if (lookahead == 'g') ADVANCE(3043);
      END_STATE();
    case 440:
      if (lookahead == 'g') ADVANCE(3332);
      END_STATE();
    case 441:
      if (lookahead == 'g') ADVANCE(3330);
      END_STATE();
    case 442:
      if (lookahead == 'g') ADVANCE(3318);
      END_STATE();
    case 443:
      if (lookahead == 'g') ADVANCE(3316);
      END_STATE();
    case 444:
      if (lookahead == 'g') ADVANCE(623);
      END_STATE();
    case 445:
      if (lookahead == 'g') ADVANCE(616);
      END_STATE();
    case 446:
      if (lookahead == 'g') ADVANCE(369);
      END_STATE();
    case 447:
      if (lookahead == 'g') ADVANCE(472);
      END_STATE();
    case 448:
      if (lookahead == 'g') ADVANCE(619);
      END_STATE();
    case 449:
      if (lookahead == 'h') ADVANCE(490);
      END_STATE();
    case 450:
      if (lookahead == 'h') ADVANCE(491);
      END_STATE();
    case 451:
      if (lookahead == 'h') ADVANCE(483);
      END_STATE();
    case 452:
      if (lookahead == 'h') ADVANCE(492);
      END_STATE();
    case 453:
      if (lookahead == 'h') ADVANCE(416);
      if (lookahead == 't') ADVANCE(455);
      END_STATE();
    case 454:
      if (lookahead == 'h') ADVANCE(315);
      END_STATE();
    case 455:
      if (lookahead == 'h') ADVANCE(426);
      END_STATE();
    case 456:
      if (lookahead == 'h') ADVANCE(448);
      END_STATE();
    case 457:
      if (lookahead == 'i') ADVANCE(438);
      if (lookahead == 'l') ADVANCE(398);
      if (lookahead == 'u') ADVANCE(432);
      END_STATE();
    case 458:
      if (lookahead == 'i') ADVANCE(3321);
      END_STATE();
    case 459:
      if (lookahead == 'i') ADVANCE(205);
      if (lookahead == 'r') ADVANCE(401);
      END_STATE();
    case 460:
      if (lookahead == 'i') ADVANCE(672);
      END_STATE();
    case 461:
      if (lookahead == 'i') ADVANCE(902);
      END_STATE();
    case 462:
      if (lookahead == 'i') ADVANCE(592);
      END_STATE();
    case 463:
      if (lookahead == 'i') ADVANCE(628);
      END_STATE();
    case 464:
      if (lookahead == 'i') ADVANCE(504);
      END_STATE();
    case 465:
      if (lookahead == 'i') ADVANCE(504);
      if (lookahead == 'o') ADVANCE(502);
      END_STATE();
    case 466:
      if (lookahead == 'i') ADVANCE(504);
      if (lookahead == 'o') ADVANCE(501);
      END_STATE();
    case 467:
      if (lookahead == 'i') ADVANCE(1592);
      if (lookahead == '{') ADVANCE(1027);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(480);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 468:
      if (lookahead == 'i') ADVANCE(622);
      END_STATE();
    case 469:
      if (lookahead == 'i') ADVANCE(343);
      END_STATE();
    case 470:
      if (lookahead == 'i') ADVANCE(572);
      END_STATE();
    case 471:
      if (lookahead == 'i') ADVANCE(565);
      END_STATE();
    case 472:
      if (lookahead == 'i') ADVANCE(631);
      END_STATE();
    case 473:
      if (lookahead == 'i') ADVANCE(524);
      END_STATE();
    case 474:
      if (lookahead == 'i') ADVANCE(645);
      END_STATE();
    case 475:
      if (lookahead == 'i') ADVANCE(527);
      END_STATE();
    case 476:
      if (lookahead == 'i') ADVANCE(585);
      END_STATE();
    case 477:
      if (lookahead == 'i') ADVANCE(579);
      END_STATE();
    case 478:
      if (lookahead == 'i') ADVANCE(647);
      END_STATE();
    case 479:
      if (lookahead == 'i') ADVANCE(586);
      END_STATE();
    case 480:
      if (lookahead == 'i') ADVANCE(520);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(480);
      END_STATE();
    case 481:
      if (lookahead == 'i') ADVANCE(543);
      END_STATE();
    case 482:
      if (lookahead == 'i') ADVANCE(546);
      END_STATE();
    case 483:
      if (lookahead == 'i') ADVANCE(654);
      END_STATE();
    case 484:
      if (lookahead == 'i') ADVANCE(550);
      END_STATE();
    case 485:
      if (lookahead == 'i') ADVANCE(551);
      END_STATE();
    case 486:
      if (lookahead == 'i') ADVANCE(552);
      END_STATE();
    case 487:
      if (lookahead == 'i') ADVANCE(555);
      END_STATE();
    case 488:
      if (lookahead == 'j') ADVANCE(468);
      if (lookahead == 'k') ADVANCE(470);
      if (lookahead == 't') ADVANCE(312);
      END_STATE();
    case 489:
      if (lookahead == 'k') ADVANCE(477);
      END_STATE();
    case 490:
      if (lookahead == 'l') ADVANCE(2457);
      END_STATE();
    case 491:
      if (lookahead == 'l') ADVANCE(2448);
      END_STATE();
    case 492:
      if (lookahead == 'l') ADVANCE(2445);
      END_STATE();
    case 493:
      if (lookahead == 'l') ADVANCE(3396);
      END_STATE();
    case 494:
      if (lookahead == 'l') ADVANCE(2454);
      END_STATE();
    case 495:
      if (lookahead == 'l') ADVANCE(3361);
      END_STATE();
    case 496:
      if (lookahead == 'l') ADVANCE(3421);
      END_STATE();
    case 497:
      if (lookahead == 'l') ADVANCE(3358);
      END_STATE();
    case 498:
      if (lookahead == 'l') ADVANCE(449);
      END_STATE();
    case 499:
      if (lookahead == 'l') ADVANCE(398);
      END_STATE();
    case 500:
      if (lookahead == 'l') ADVANCE(660);
      END_STATE();
    case 501:
      if (lookahead == 'l') ADVANCE(354);
      END_STATE();
    case 502:
      if (lookahead == 'l') ADVANCE(354);
      if (lookahead == 'n') ADVANCE(636);
      END_STATE();
    case 503:
      if (lookahead == 'l') ADVANCE(307);
      END_STATE();
    case 504:
      if (lookahead == 'l') ADVANCE(368);
      END_STATE();
    case 505:
      if (lookahead == 'l') ADVANCE(640);
      END_STATE();
    case 506:
      if (lookahead == 'l') ADVANCE(424);
      END_STATE();
    case 507:
      if (lookahead == 'l') ADVANCE(3140);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(507);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 508:
      if (lookahead == 'l') ADVANCE(417);
      END_STATE();
    case 509:
      if (lookahead == 'l') ADVANCE(484);
      END_STATE();
    case 510:
      if (lookahead == 'l') ADVANCE(485);
      END_STATE();
    case 511:
      if (lookahead == 'l') ADVANCE(486);
      END_STATE();
    case 512:
      if (lookahead == 'm') ADVANCE(3273);
      END_STATE();
    case 513:
      if (lookahead == 'm') ADVANCE(3276);
      END_STATE();
    case 514:
      if (lookahead == 'm') ADVANCE(561);
      END_STATE();
    case 515:
      if (lookahead == 'm') ADVANCE(588);
      if (lookahead == 'u') ADVANCE(540);
      END_STATE();
    case 516:
      if (lookahead == 'm') ADVANCE(584);
      END_STATE();
    case 517:
      if (lookahead == 'm') ADVANCE(384);
      END_STATE();
    case 518:
      if (lookahead == 'm') ADVANCE(450);
      END_STATE();
    case 519:
      if (lookahead == 'm') ADVANCE(322);
      END_STATE();
    case 520:
      if (lookahead == 'n') ADVANCE(946);
      END_STATE();
    case 521:
      if (lookahead == 'n') ADVANCE(946);
      if (lookahead == 's') ADVANCE(2499);
      END_STATE();
    case 522:
      if (lookahead == 'n') ADVANCE(2442);
      END_STATE();
    case 523:
      if (lookahead == 'n') ADVANCE(903);
      END_STATE();
    case 524:
      if (lookahead == 'n') ADVANCE(185);
      END_STATE();
    case 525:
      if (lookahead == 'n') ADVANCE(891);
      END_STATE();
    case 526:
      if (lookahead == 'n') ADVANCE(907);
      END_STATE();
    case 527:
      if (lookahead == 'n') ADVANCE(409);
      END_STATE();
    case 528:
      if (lookahead == 'n') ADVANCE(861);
      END_STATE();
    case 529:
      if (lookahead == 'n') ADVANCE(3376);
      END_STATE();
    case 530:
      if (lookahead == 'n') ADVANCE(919);
      END_STATE();
    case 531:
      if (lookahead == 'n') ADVANCE(346);
      END_STATE();
    case 532:
      if (lookahead == 'n') ADVANCE(636);
      END_STATE();
    case 533:
      if (lookahead == 'n') ADVANCE(353);
      if (lookahead == 'u') ADVANCE(332);
      if (lookahead == 'x') ADVANCE(340);
      END_STATE();
    case 534:
      if (lookahead == 'n') ADVANCE(439);
      if (lookahead == 'r') ADVANCE(3044);
      END_STATE();
    case 535:
      if (lookahead == 'n') ADVANCE(633);
      END_STATE();
    case 536:
      if (lookahead == 'n') ADVANCE(446);
      END_STATE();
    case 537:
      if (lookahead == 'n') ADVANCE(429);
      END_STATE();
    case 538:
      if (lookahead == 'n') ADVANCE(355);
      END_STATE();
    case 539:
      if (lookahead == 'n') ADVANCE(348);
      END_STATE();
    case 540:
      if (lookahead == 'n') ADVANCE(639);
      END_STATE();
    case 541:
      if (lookahead == 'n') ADVANCE(356);
      END_STATE();
    case 542:
      if (lookahead == 'n') ADVANCE(357);
      END_STATE();
    case 543:
      if (lookahead == 'n') ADVANCE(427);
      END_STATE();
    case 544:
      if (lookahead == 'n') ADVANCE(364);
      END_STATE();
    case 545:
      if (lookahead == 'n') ADVANCE(642);
      END_STATE();
    case 546:
      if (lookahead == 'n') ADVANCE(407);
      END_STATE();
    case 547:
      if (lookahead == 'n') ADVANCE(496);
      END_STATE();
    case 548:
      if (lookahead == 'n') ADVANCE(462);
      END_STATE();
    case 549:
      if (lookahead == 'n') ADVANCE(651);
      END_STATE();
    case 550:
      if (lookahead == 'n') ADVANCE(410);
      END_STATE();
    case 551:
      if (lookahead == 'n') ADVANCE(412);
      END_STATE();
    case 552:
      if (lookahead == 'n') ADVANCE(373);
      END_STATE();
    case 553:
      if (lookahead == 'n') ADVANCE(425);
      END_STATE();
    case 554:
      if (lookahead == 'n') ADVANCE(425);
      if (lookahead == 'o') ADVANCE(539);
      END_STATE();
    case 555:
      if (lookahead == 'n') ADVANCE(383);
      END_STATE();
    case 556:
      if (lookahead == 'n') ADVANCE(350);
      END_STATE();
    case 557:
      if (lookahead == 'n') ADVANCE(510);
      END_STATE();
    case 558:
      if (lookahead == 'o') ADVANCE(515);
      END_STATE();
    case 559:
      if (lookahead == 'o') ADVANCE(662);
      END_STATE();
    case 560:
      if (lookahead == 'o') ADVANCE(859);
      END_STATE();
    case 561:
      if (lookahead == 'o') ADVANCE(668);
      END_STATE();
    case 562:
      if (lookahead == 'o') ADVANCE(519);
      END_STATE();
    case 563:
      if (lookahead == 'o') ADVANCE(522);
      END_STATE();
    case 564:
      if (lookahead == 'o') ADVANCE(643);
      END_STATE();
    case 565:
      if (lookahead == 'o') ADVANCE(613);
      END_STATE();
    case 566:
      if (lookahead == 'o') ADVANCE(532);
      END_STATE();
    case 567:
      if (lookahead == 'o') ADVANCE(663);
      END_STATE();
    case 568:
      if (lookahead == 'o') ADVANCE(671);
      END_STATE();
    case 569:
      if (lookahead == 'o') ADVANCE(366);
      END_STATE();
    case 570:
      if (lookahead == 'o') ADVANCE(664);
      END_STATE();
    case 571:
      if (lookahead == 'o') ADVANCE(665);
      END_STATE();
    case 572:
      if (lookahead == 'p') ADVANCE(3489);
      END_STATE();
    case 573:
      if (lookahead == 'p') ADVANCE(3312);
      END_STATE();
    case 574:
      if (lookahead == 'p') ADVANCE(2466);
      END_STATE();
    case 575:
      if (lookahead == 'p') ADVANCE(3334);
      END_STATE();
    case 576:
      if (lookahead == 'p') ADVANCE(886);
      END_STATE();
    case 577:
      if (lookahead == 'p') ADVANCE(3381);
      END_STATE();
    case 578:
      if (lookahead == 'p') ADVANCE(3424);
      END_STATE();
    case 579:
      if (lookahead == 'p') ADVANCE(402);
      END_STATE();
    case 580:
      if (lookahead == 'p') ADVANCE(917);
      END_STATE();
    case 581:
      if (lookahead == 'p') ADVANCE(453);
      END_STATE();
    case 582:
      if (lookahead == 'p') ADVANCE(629);
      END_STATE();
    case 583:
      if (lookahead == 'p') ADVANCE(503);
      END_STATE();
    case 584:
      if (lookahead == 'p') ADVANCE(644);
      END_STATE();
    case 585:
      if (lookahead == 'p') ADVANCE(641);
      END_STATE();
    case 586:
      if (lookahead == 'p') ADVANCE(648);
      END_STATE();
    case 587:
      if (lookahead == 'p') ADVANCE(608);
      END_STATE();
    case 588:
      if (lookahead == 'p') ADVANCE(506);
      END_STATE();
    case 589:
      if (lookahead == 'p') ADVANCE(318);
      END_STATE();
    case 590:
      if (lookahead == 'p') ADVANCE(321);
      END_STATE();
    case 591:
      if (lookahead == 'p') ADVANCE(428);
      END_STATE();
    case 592:
      if (lookahead == 'q') ADVANCE(666);
      END_STATE();
    case 593:
      if (lookahead == 'r') ADVANCE(3042);
      END_STATE();
    case 594:
      if (lookahead == 'r') ADVANCE(3366);
      END_STATE();
    case 595:
      if (lookahead == 'r') ADVANCE(2464);
      END_STATE();
    case 596:
      if (lookahead == 'r') ADVANCE(889);
      END_STATE();
    case 597:
      if (lookahead == 'r') ADVANCE(3046);
      END_STATE();
    case 598:
      if (lookahead == 'r') ADVANCE(3045);
      END_STATE();
    case 599:
      if (lookahead == 'r') ADVANCE(918);
      END_STATE();
    case 600:
      if (lookahead == 'r') ADVANCE(559);
      END_STATE();
    case 601:
      if (lookahead == 'r') ADVANCE(559);
      if (lookahead == 'u') ADVANCE(458);
      END_STATE();
    case 602:
      if (lookahead == 'r') ADVANCE(333);
      END_STATE();
    case 603:
      if (lookahead == 'r') ADVANCE(314);
      END_STATE();
    case 604:
      if (lookahead == 'r') ADVANCE(512);
      END_STATE();
    case 605:
      if (lookahead == 'r') ADVANCE(512);
      if (lookahead == 'x') ADVANCE(637);
      END_STATE();
    case 606:
      if (lookahead == 'r') ADVANCE(444);
      END_STATE();
    case 607:
      if (lookahead == 'r') ADVANCE(513);
      END_STATE();
    case 608:
      if (lookahead == 'r') ADVANCE(271);
      END_STATE();
    case 609:
      if (lookahead == 'r') ADVANCE(638);
      END_STATE();
    case 610:
      if (lookahead == 'r') ADVANCE(272);
      END_STATE();
    case 611:
      if (lookahead == 'r') ADVANCE(562);
      END_STATE();
    case 612:
      if (lookahead == 'r') ADVANCE(471);
      END_STATE();
    case 613:
      if (lookahead == 'r') ADVANCE(474);
      END_STATE();
    case 614:
      if (lookahead == 'r') ADVANCE(392);
      END_STATE();
    case 615:
      if (lookahead == 'r') ADVANCE(393);
      END_STATE();
    case 616:
      if (lookahead == 'r') ADVANCE(567);
      END_STATE();
    case 617:
      if (lookahead == 'r') ADVANCE(415);
      END_STATE();
    case 618:
      if (lookahead == 'r') ADVANCE(476);
      END_STATE();
    case 619:
      if (lookahead == 'r') ADVANCE(570);
      END_STATE();
    case 620:
      if (lookahead == 'r') ADVANCE(479);
      END_STATE();
    case 621:
      if (lookahead == 's') ADVANCE(162);
      END_STATE();
    case 622:
      if (lookahead == 's') ADVANCE(887);
      END_STATE();
    case 623:
      if (lookahead == 's') ADVANCE(3038);
      END_STATE();
    case 624:
      if (lookahead == 's') ADVANCE(3497);
      END_STATE();
    case 625:
      if (lookahead == 's') ADVANCE(3494);
      END_STATE();
    case 626:
      if (lookahead == 's') ADVANCE(3430);
      END_STATE();
    case 627:
      if (lookahead == 's') ADVANCE(2499);
      END_STATE();
    case 628:
      if (lookahead == 's') ADVANCE(583);
      END_STATE();
    case 629:
      if (lookahead == 's') ADVANCE(345);
      END_STATE();
    case 630:
      if (lookahead == 's') ADVANCE(461);
      END_STATE();
    case 631:
      if (lookahead == 's') ADVANCE(652);
      END_STATE();
    case 632:
      if (lookahead == 's') ADVANCE(372);
      END_STATE();
    case 633:
      if (lookahead == 's') ADVANCE(590);
      END_STATE();
    case 634:
      if (lookahead == 's') ADVANCE(655);
      END_STATE();
    case 635:
      if (lookahead == 't') ADVANCE(312);
      END_STATE();
    case 636:
      if (lookahead == 't') ADVANCE(3340);
      END_STATE();
    case 637:
      if (lookahead == 't') ADVANCE(2452);
      END_STATE();
    case 638:
      if (lookahead == 't') ADVANCE(3308);
      END_STATE();
    case 639:
      if (lookahead == 't') ADVANCE(3041);
      END_STATE();
    case 640:
      if (lookahead == 't') ADVANCE(915);
      END_STATE();
    case 641:
      if (lookahead == 't') ADVANCE(3047);
      END_STATE();
    case 642:
      if (lookahead == 't') ADVANCE(3386);
      END_STATE();
    case 643:
      if (lookahead == 't') ADVANCE(2500);
      END_STATE();
    case 644:
      if (lookahead == 't') ADVANCE(679);
      END_STATE();
    case 645:
      if (lookahead == 't') ADVANCE(680);
      END_STATE();
    case 646:
      if (lookahead == 't') ADVANCE(396);
      END_STATE();
    case 647:
      if (lookahead == 't') ADVANCE(273);
      END_STATE();
    case 648:
      if (lookahead == 't') ADVANCE(274);
      END_STATE();
    case 649:
      if (lookahead == 't') ADVANCE(445);
      END_STATE();
    case 650:
      if (lookahead == 't') ADVANCE(473);
      END_STATE();
    case 651:
      if (lookahead == 't') ADVANCE(275);
      END_STATE();
    case 652:
      if (lookahead == 't') ADVANCE(414);
      END_STATE();
    case 653:
      if (lookahead == 't') ADVANCE(381);
      END_STATE();
    case 654:
      if (lookahead == 't') ADVANCE(382);
      END_STATE();
    case 655:
      if (lookahead == 't') ADVANCE(413);
      END_STATE();
    case 656:
      if (lookahead == 'u') ADVANCE(432);
      END_STATE();
    case 657:
      if (lookahead == 'u') ADVANCE(498);
      END_STATE();
    case 658:
      if (lookahead == 'u') ADVANCE(518);
      END_STATE();
    case 659:
      if (lookahead == 'u') ADVANCE(458);
      END_STATE();
    case 660:
      if (lookahead == 'u') ADVANCE(365);
      END_STATE();
    case 661:
      if (lookahead == 'u') ADVANCE(505);
      END_STATE();
    case 662:
      if (lookahead == 'u') ADVANCE(574);
      END_STATE();
    case 663:
      if (lookahead == 'u') ADVANCE(577);
      END_STATE();
    case 664:
      if (lookahead == 'u') ADVANCE(578);
      END_STATE();
    case 665:
      if (lookahead == 'u') ADVANCE(581);
      END_STATE();
    case 666:
      if (lookahead == 'u') ADVANCE(408);
      END_STATE();
    case 667:
      if (lookahead == 'u') ADVANCE(437);
      END_STATE();
    case 668:
      if (lookahead == 'v') ADVANCE(370);
      END_STATE();
    case 669:
      if (lookahead == 'w') ADVANCE(894);
      END_STATE();
    case 670:
      if (lookahead == 'w') ADVANCE(920);
      END_STATE();
    case 671:
      if (lookahead == 'w') ADVANCE(325);
      END_STATE();
    case 672:
      if (lookahead == 'w') ADVANCE(319);
      END_STATE();
    case 673:
      if (lookahead == 'x') ADVANCE(340);
      END_STATE();
    case 674:
      if (lookahead == 'x') ADVANCE(649);
      END_STATE();
    case 675:
      if (lookahead == 'x') ADVANCE(509);
      END_STATE();
    case 676:
      if (lookahead == 'x') ADVANCE(637);
      END_STATE();
    case 677:
      if (lookahead == 'x') ADVANCE(587);
      END_STATE();
    case 678:
      if (lookahead == 'y') ADVANCE(3412);
      END_STATE();
    case 679:
      if (lookahead == 'y') ADVANCE(3401);
      END_STATE();
    case 680:
      if (lookahead == 'y') ADVANCE(2468);
      END_STATE();
    case 681:
      if (lookahead == '{') ADVANCE(2582);
      END_STATE();
    case 682:
      if (lookahead == '{') ADVANCE(1025);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(682);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1523);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1231);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1246);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1338);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1247);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1527);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1344);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1472);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1157);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1414);
      if (lookahead == 'Q' ||
          lookahead == 'q') ADVANCE(1530);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1143);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1041);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1037);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1248);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1249);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1261);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 683:
      if (lookahead == '{') ADVANCE(1028);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(689);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(2007);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1778);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1789);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1861);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1790);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2008);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1866);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1968);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1712);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1923);
      if (lookahead == 'Q' ||
          lookahead == 'q') ADVANCE(2010);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1700);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1622);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1619);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1791);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1792);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1800);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 684:
      if (lookahead == '|') ADVANCE(2406);
      END_STATE();
    case 685:
      if (lookahead == '|') ADVANCE(2477);
      END_STATE();
    case 686:
      if (lookahead == '}') ADVANCE(2554);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(686);
      END_STATE();
    case 687:
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(687);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 688:
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(688);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(2249);
      END_STATE();
    case 689:
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(689);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(3002);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2771);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2782);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2854);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2783);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(3003);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2859);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2963);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(2703);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2916);
      if (lookahead == 'Q' ||
          lookahead == 'q') ADVANCE(3005);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2693);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2613);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2610);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2784);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(2785);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(2793);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 690:
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2403);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2404);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2403);
      END_STATE();
    case 691:
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2239);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2243);
      END_STATE();
    case 692:
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(692);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(854);
      END_STATE();
    case 693:
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(963);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(962);
      END_STATE();
    case 694:
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(694);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2213);
      END_STATE();
    case 695:
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(695);
      if (('<' <= lookahead && lookahead <= '>') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(936);
      END_STATE();
    case 696:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(823);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2509);
      END_STATE();
    case 697:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2372);
      END_STATE();
    case 698:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(788);
      END_STATE();
    case 699:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(737);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(810);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(746);
      END_STATE();
    case 700:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(797);
      END_STATE();
    case 701:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(711);
      END_STATE();
    case 702:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(716);
      END_STATE();
    case 703:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(716);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(799);
      END_STATE();
    case 704:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(757);
      END_STATE();
    case 705:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(753);
      END_STATE();
    case 706:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(787);
      END_STATE();
    case 707:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(706);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(783);
      END_STATE();
    case 708:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(2300);
      END_STATE();
    case 709:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2310);
      END_STATE();
    case 710:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(704);
      END_STATE();
    case 711:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(725);
      END_STATE();
    case 712:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2356);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(728);
      END_STATE();
    case 713:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2379);
      END_STATE();
    case 714:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(270);
      END_STATE();
    case 715:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(772);
      END_STATE();
    case 716:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(731);
      END_STATE();
    case 717:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(727);
      END_STATE();
    case 718:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(776);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(781);
      END_STATE();
    case 719:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(733);
      END_STATE();
    case 720:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2342);
      END_STATE();
    case 721:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2344);
      END_STATE();
    case 722:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(750);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(815);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(816);
      END_STATE();
    case 723:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2354);
      END_STATE();
    case 724:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(718);
      END_STATE();
    case 725:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2312);
      END_STATE();
    case 726:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2326);
      END_STATE();
    case 727:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2368);
      END_STATE();
    case 728:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(785);
      END_STATE();
    case 729:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(702);
      END_STATE();
    case 730:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(790);
      END_STATE();
    case 731:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(786);
      END_STATE();
    case 732:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(734);
      END_STATE();
    case 733:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(799);
      END_STATE();
    case 734:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(801);
      END_STATE();
    case 735:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2381);
      END_STATE();
    case 736:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(740);
      END_STATE();
    case 737:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(724);
      END_STATE();
    case 738:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(741);
      END_STATE();
    case 739:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(2316);
      END_STATE();
    case 740:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(800);
      END_STATE();
    case 741:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(804);
      END_STATE();
    case 742:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(698);
      END_STATE();
    case 743:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(736);
      END_STATE();
    case 744:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2322);
      END_STATE();
    case 745:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(769);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(756);
      END_STATE();
    case 746:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(768);
      END_STATE();
    case 747:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(782);
      END_STATE();
    case 748:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(717);
      END_STATE();
    case 749:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(738);
      END_STATE();
    case 750:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2320);
      END_STATE();
    case 751:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2324);
      END_STATE();
    case 752:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2296);
      END_STATE();
    case 753:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2374);
      END_STATE();
    case 754:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(818);
      END_STATE();
    case 755:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(780);
      END_STATE();
    case 756:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(807);
      END_STATE();
    case 757:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(758);
      END_STATE();
    case 758:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(729);
      END_STATE();
    case 759:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(714);
      END_STATE();
    case 760:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(761);
      END_STATE();
    case 761:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(697);
      END_STATE();
    case 762:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(723);
      END_STATE();
    case 763:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2332);
      END_STATE();
    case 764:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(712);
      if (lookahead == 'Q' ||
          lookahead == 'q') ADVANCE(814);
      END_STATE();
    case 765:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2306);
      END_STATE();
    case 766:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2360);
      END_STATE();
    case 767:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(775);
      END_STATE();
    case 768:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(803);
      END_STATE();
    case 769:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(811);
      END_STATE();
    case 770:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(816);
      END_STATE();
    case 771:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(808);
      END_STATE();
    case 772:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2350);
      END_STATE();
    case 773:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(762);
      END_STATE();
    case 774:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(760);
      END_STATE();
    case 775:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(791);
      END_STATE();
    case 776:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(817);
      END_STATE();
    case 777:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(813);
      END_STATE();
    case 778:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2330);
      END_STATE();
    case 779:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2328);
      END_STATE();
    case 780:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2348);
      END_STATE();
    case 781:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2358);
      END_STATE();
    case 782:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(754);
      END_STATE();
    case 783:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(268);
      END_STATE();
    case 784:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2318);
      END_STATE();
    case 785:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2308);
      END_STATE();
    case 786:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2377);
      END_STATE();
    case 787:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(269);
      END_STATE();
    case 788:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(167);
      END_STATE();
    case 789:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(765);
      END_STATE();
    case 790:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(802);
      END_STATE();
    case 791:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(726);
      END_STATE();
    case 792:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2362);
      END_STATE();
    case 793:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2364);
      END_STATE();
    case 794:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(720);
      END_STATE();
    case 795:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(744);
      END_STATE();
    case 796:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(721);
      END_STATE();
    case 797:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(739);
      END_STATE();
    case 798:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(730);
      END_STATE();
    case 799:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2335);
      END_STATE();
    case 800:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2339);
      END_STATE();
    case 801:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2334);
      END_STATE();
    case 802:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2352);
      END_STATE();
    case 803:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2370);
      END_STATE();
    case 804:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2338);
      END_STATE();
    case 805:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(164);
      END_STATE();
    case 806:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(812);
      END_STATE();
    case 807:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(747);
      END_STATE();
    case 808:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(794);
      END_STATE();
    case 809:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(735);
      END_STATE();
    case 810:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(792);
      END_STATE();
    case 811:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(793);
      END_STATE();
    case 812:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(789);
      END_STATE();
    case 813:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(796);
      END_STATE();
    case 814:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(705);
      END_STATE();
    case 815:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(748);
      END_STATE();
    case 816:
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(763);
      END_STATE();
    case 817:
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(766);
      END_STATE();
    case 818:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(2366);
      END_STATE();
    case 819:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(2514);
      END_STATE();
    case 820:
      if (lookahead == '!' ||
          lookahead == '=' ||
          lookahead == '>') ADVANCE(2553);
      END_STATE();
    case 821:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2347);
      END_STATE();
    case 822:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2508);
      END_STATE();
    case 823:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2509);
      END_STATE();
    case 824:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1023);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1019);
      END_STATE();
    case 825:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(3438);
      END_STATE();
    case 826:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(2517);
      END_STATE();
    case 827:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(2388);
      END_STATE();
    case 828:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(3325);
      END_STATE();
    case 829:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(828);
      END_STATE();
    case 830:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(829);
      END_STATE();
    case 831:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(830);
      END_STATE();
    case 832:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(831);
      END_STATE();
    case 833:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(832);
      END_STATE();
    case 834:
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 835:
      if (lookahead == '"' ||
          lookahead == '#' ||
          lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('.' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2580);
      END_STATE();
    case 836:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\'') ADVANCE(3323);
      END_STATE();
    case 837:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(2265);
      END_STATE();
    case 838:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(2403);
      END_STATE();
    case 839:
      if (eof) ADVANCE(842);
      ADVANCE_MAP(
        '\n', 945,
        '!', 2506,
        '#', 2475,
        '$', 2283,
        '%', 2266,
        '&', 2217,
        '\'', 3324,
        '(', 2250,
        ')', 2252,
        '*', 2473,
        '+', 2276,
        ',', 2251,
        '-', 2479,
        '.', 2273,
        '/', 2269,
        ':', 843,
        ';', 2268,
        '<', 2395,
        '=', 938,
        '>', 2488,
        '?', 2221,
        '@', 3493,
        '[', 2518,
        '\\', 959,
        ']', 2519,
        '_', 952,
        '{', 1024,
        '|', 950,
        '}', 1026,
        '~', 950,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(839);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(950);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(937);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(950);
      END_STATE();
    case 840:
      if (eof) ADVANCE(842);
      ADVANCE_MAP(
        '!', 2214,
        '#', 67,
        '$', 2283,
        '%', 2266,
        '\'', 837,
        '(', 2520,
        ')', 2252,
        '*', 2473,
        '+', 2280,
        ',', 2251,
        '-', 176,
        '.', 2273,
        '/', 2269,
        '0', 2513,
        ':', 843,
        ';', 2268,
        '<', 707,
        '=', 938,
        '>', 2394,
        '?', 2221,
        '@', 835,
        '\\', 112,
        ']', 2519,
        'a', 361,
        'b', 457,
        'c', 330,
        'd', 394,
        'e', 533,
        'f', 465,
        'g', 601,
        'i', 337,
        'j', 302,
        'k', 400,
        'l', 303,
        'm', 304,
        'n', 367,
        'o', 537,
        'p', 602,
        'r', 395,
        's', 488,
        't', 313,
        'u', 338,
        '}', 1026,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(841);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2516);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(3030);
      END_STATE();
    case 841:
      if (eof) ADVANCE(842);
      ADVANCE_MAP(
        '#', 67,
        '$', 2283,
        '%', 2266,
        '\'', 837,
        ')', 2252,
        '*', 2473,
        '+', 2280,
        ',', 2251,
        '-', 176,
        '.', 2273,
        '/', 2269,
        '0', 2513,
        ':', 843,
        ';', 2268,
        '<', 707,
        '=', 938,
        '?', 2221,
        '@', 835,
        '\\', 112,
        ']', 2519,
        'a', 361,
        'b', 457,
        'c', 330,
        'd', 394,
        'e', 533,
        'f', 465,
        'g', 601,
        'i', 337,
        'j', 302,
        'k', 400,
        'l', 303,
        'm', 304,
        'n', 367,
        'o', 537,
        'p', 602,
        'r', 395,
        's', 488,
        't', 313,
        'u', 338,
        '}', 1026,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(841);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2516);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(3030);
      END_STATE();
    case 842:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 843:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 844:
      ACCEPT_TOKEN(anon_sym_a_COLON);
      END_STATE();
    case 845:
      ACCEPT_TOKEN(aux_sym_normal_statement_token1);
      if (lookahead == '\t') ADVANCE(845);
      if (lookahead == ' ') ADVANCE(845);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(846);
      END_STATE();
    case 846:
      ACCEPT_TOKEN(aux_sym_normal_statement_token1);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(846);
      END_STATE();
    case 847:
      ACCEPT_TOKEN(sym_filetype);
      if (lookahead == 'A') ADVANCE(853);
      if (lookahead == '-' ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(854);
      END_STATE();
    case 848:
      ACCEPT_TOKEN(sym_filetype);
      if (lookahead == 'A') ADVANCE(850);
      if (lookahead == '-' ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(854);
      END_STATE();
    case 849:
      ACCEPT_TOKEN(sym_filetype);
      if (lookahead == 'B') ADVANCE(848);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(854);
      END_STATE();
    case 850:
      ACCEPT_TOKEN(sym_filetype);
      if (lookahead == 'C') ADVANCE(851);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(854);
      END_STATE();
    case 851:
      ACCEPT_TOKEN(sym_filetype);
      if (lookahead == 'K') ADVANCE(857);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(854);
      END_STATE();
    case 852:
      ACCEPT_TOKEN(sym_filetype);
      if (lookahead == 'L') ADVANCE(849);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(854);
      END_STATE();
    case 853:
      ACCEPT_TOKEN(sym_filetype);
      if (lookahead == 'L') ADVANCE(852);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(854);
      END_STATE();
    case 854:
      ACCEPT_TOKEN(sym_filetype);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(854);
      END_STATE();
    case 855:
      ACCEPT_TOKEN(aux_sym__filetype_immediate_token1);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 856:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 857:
      ACCEPT_TOKEN(anon_sym_FALLBACK);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(854);
      END_STATE();
    case 858:
      ACCEPT_TOKEN(anon_sym_latin1);
      END_STATE();
    case 859:
      ACCEPT_TOKEN(anon_sym_iso);
      END_STATE();
    case 860:
      ACCEPT_TOKEN(anon_sym_koi8);
      END_STATE();
    case 861:
      ACCEPT_TOKEN(anon_sym_macroman);
      END_STATE();
    case 862:
      ACCEPT_TOKEN(anon_sym_cp437);
      END_STATE();
    case 863:
      ACCEPT_TOKEN(anon_sym_cp737);
      END_STATE();
    case 864:
      ACCEPT_TOKEN(anon_sym_cp775);
      END_STATE();
    case 865:
      ACCEPT_TOKEN(anon_sym_cp850);
      END_STATE();
    case 866:
      ACCEPT_TOKEN(anon_sym_cp852);
      END_STATE();
    case 867:
      ACCEPT_TOKEN(anon_sym_cp855);
      END_STATE();
    case 868:
      ACCEPT_TOKEN(anon_sym_cp857);
      END_STATE();
    case 869:
      ACCEPT_TOKEN(anon_sym_cp860);
      END_STATE();
    case 870:
      ACCEPT_TOKEN(anon_sym_cp861);
      END_STATE();
    case 871:
      ACCEPT_TOKEN(anon_sym_cp862);
      END_STATE();
    case 872:
      ACCEPT_TOKEN(anon_sym_cp863);
      END_STATE();
    case 873:
      ACCEPT_TOKEN(anon_sym_cp865);
      END_STATE();
    case 874:
      ACCEPT_TOKEN(anon_sym_cp866);
      END_STATE();
    case 875:
      ACCEPT_TOKEN(anon_sym_cp869);
      END_STATE();
    case 876:
      ACCEPT_TOKEN(anon_sym_cp874);
      END_STATE();
    case 877:
      ACCEPT_TOKEN(anon_sym_cp1250);
      END_STATE();
    case 878:
      ACCEPT_TOKEN(anon_sym_cp1251);
      END_STATE();
    case 879:
      ACCEPT_TOKEN(anon_sym_cp1253);
      END_STATE();
    case 880:
      ACCEPT_TOKEN(anon_sym_cp1254);
      END_STATE();
    case 881:
      ACCEPT_TOKEN(anon_sym_cp1255);
      END_STATE();
    case 882:
      ACCEPT_TOKEN(anon_sym_cp1256);
      END_STATE();
    case 883:
      ACCEPT_TOKEN(anon_sym_cp1257);
      END_STATE();
    case 884:
      ACCEPT_TOKEN(anon_sym_cp1258);
      END_STATE();
    case 885:
      ACCEPT_TOKEN(anon_sym_cp932);
      END_STATE();
    case 886:
      ACCEPT_TOKEN(anon_sym_euc_DASHjp);
      END_STATE();
    case 887:
      ACCEPT_TOKEN(anon_sym_sjis);
      END_STATE();
    case 888:
      ACCEPT_TOKEN(anon_sym_cp949);
      END_STATE();
    case 889:
      ACCEPT_TOKEN(anon_sym_euc_DASHkr);
      END_STATE();
    case 890:
      ACCEPT_TOKEN(anon_sym_cp936);
      END_STATE();
    case 891:
      ACCEPT_TOKEN(anon_sym_euc_DASHcn);
      END_STATE();
    case 892:
      ACCEPT_TOKEN(anon_sym_cp950);
      END_STATE();
    case 893:
      ACCEPT_TOKEN(anon_sym_big5);
      END_STATE();
    case 894:
      ACCEPT_TOKEN(anon_sym_euc_DASHtw);
      END_STATE();
    case 895:
      ACCEPT_TOKEN(anon_sym_utf_DASH8);
      END_STATE();
    case 896:
      ACCEPT_TOKEN(anon_sym_ucs_DASH2);
      if (lookahead == '1') ADVANCE(374);
      if (lookahead == 'b') ADVANCE(375);
      END_STATE();
    case 897:
      ACCEPT_TOKEN(anon_sym_ucs_DASH21e);
      END_STATE();
    case 898:
      ACCEPT_TOKEN(anon_sym_utf_DASH16);
      if (lookahead == 'l') ADVANCE(379);
      END_STATE();
    case 899:
      ACCEPT_TOKEN(anon_sym_utf_DASH16le);
      END_STATE();
    case 900:
      ACCEPT_TOKEN(anon_sym_ucs_DASH4);
      if (lookahead == 'b') ADVANCE(376);
      if (lookahead == 'l') ADVANCE(377);
      END_STATE();
    case 901:
      ACCEPT_TOKEN(anon_sym_ucs_DASH4le);
      END_STATE();
    case 902:
      ACCEPT_TOKEN(anon_sym_ansi);
      END_STATE();
    case 903:
      ACCEPT_TOKEN(anon_sym_japan);
      END_STATE();
    case 904:
      ACCEPT_TOKEN(anon_sym_korea);
      END_STATE();
    case 905:
      ACCEPT_TOKEN(anon_sym_prc);
      END_STATE();
    case 906:
      ACCEPT_TOKEN(anon_sym_chinese);
      END_STATE();
    case 907:
      ACCEPT_TOKEN(anon_sym_taiwan);
      END_STATE();
    case 908:
      ACCEPT_TOKEN(anon_sym_utf8);
      END_STATE();
    case 909:
      ACCEPT_TOKEN(anon_sym_unicode);
      END_STATE();
    case 910:
      ACCEPT_TOKEN(anon_sym_ucs2be);
      END_STATE();
    case 911:
      ACCEPT_TOKEN(anon_sym_ucs_DASH2be);
      END_STATE();
    case 912:
      ACCEPT_TOKEN(anon_sym_ucs_DASH4be);
      END_STATE();
    case 913:
      ACCEPT_TOKEN(anon_sym_utf_DASH32);
      if (lookahead == 'l') ADVANCE(380);
      END_STATE();
    case 914:
      ACCEPT_TOKEN(anon_sym_utf_DASH32le);
      END_STATE();
    case 915:
      ACCEPT_TOKEN(anon_sym_default);
      END_STATE();
    case 916:
      ACCEPT_TOKEN(anon_sym_default);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 917:
      ACCEPT_TOKEN(anon_sym_euc_DASHjp2);
      END_STATE();
    case 918:
      ACCEPT_TOKEN(anon_sym_euc_DASHkr2);
      END_STATE();
    case 919:
      ACCEPT_TOKEN(anon_sym_euc_DASHcn2);
      END_STATE();
    case 920:
      ACCEPT_TOKEN(anon_sym_euc_DASHtw2);
      END_STATE();
    case 921:
      ACCEPT_TOKEN(anon_sym_utf_DASH82);
      END_STATE();
    case 922:
      ACCEPT_TOKEN(anon_sym_ucs_DASH22);
      if (lookahead == '1') ADVANCE(386);
      if (lookahead == 'b') ADVANCE(387);
      END_STATE();
    case 923:
      ACCEPT_TOKEN(anon_sym_ucs_DASH21e2);
      END_STATE();
    case 924:
      ACCEPT_TOKEN(anon_sym_utf_DASH162);
      if (lookahead == 'l') ADVANCE(390);
      END_STATE();
    case 925:
      ACCEPT_TOKEN(anon_sym_utf_DASH16le2);
      END_STATE();
    case 926:
      ACCEPT_TOKEN(anon_sym_ucs_DASH42);
      if (lookahead == 'b') ADVANCE(388);
      if (lookahead == 'l') ADVANCE(389);
      END_STATE();
    case 927:
      ACCEPT_TOKEN(anon_sym_ucs_DASH4le2);
      END_STATE();
    case 928:
      ACCEPT_TOKEN(anon_sym_ucs_DASH2be2);
      END_STATE();
    case 929:
      ACCEPT_TOKEN(anon_sym_ucs_DASH4be2);
      END_STATE();
    case 930:
      ACCEPT_TOKEN(anon_sym_utf_DASH322);
      if (lookahead == 'l') ADVANCE(391);
      END_STATE();
    case 931:
      ACCEPT_TOKEN(anon_sym_utf_DASH32le2);
      END_STATE();
    case 932:
      ACCEPT_TOKEN(anon_sym_START);
      END_STATE();
    case 933:
      ACCEPT_TOKEN(anon_sym_OPT);
      END_STATE();
    case 934:
      ACCEPT_TOKEN(anon_sym_PACK);
      END_STATE();
    case 935:
      ACCEPT_TOKEN(anon_sym_ALL);
      END_STATE();
    case 936:
      ACCEPT_TOKEN(aux_sym_wincmd_statement_token1);
      END_STATE();
    case 937:
      ACCEPT_TOKEN(aux_sym_wincmd_statement_token1);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 938:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 939:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '<') ADVANCE(235);
      END_STATE();
    case 940:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '<') ADVANCE(235);
      if (lookahead == '=') ADVANCE(2486);
      if (lookahead == '~') ADVANCE(2492);
      END_STATE();
    case 941:
      ACCEPT_TOKEN(sym_chunk);
      if (lookahead == '<') ADVANCE(944);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(942);
      END_STATE();
    case 942:
      ACCEPT_TOKEN(sym_chunk);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(942);
      END_STATE();
    case 943:
      ACCEPT_TOKEN(sym__heredoc_line);
      END_STATE();
    case 944:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 945:
      ACCEPT_TOKEN(anon_sym_LF);
      END_STATE();
    case 946:
      ACCEPT_TOKEN(anon_sym_in);
      END_STATE();
    case 947:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 948:
      ACCEPT_TOKEN(aux_sym__au_pattern_token1);
      if (lookahead == '/') ADVANCE(948);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(175);
      END_STATE();
    case 949:
      ACCEPT_TOKEN(aux_sym__au_pattern_token2);
      if (lookahead == '?') ADVANCE(949);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(278);
      END_STATE();
    case 950:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token1);
      END_STATE();
    case 951:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(706);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(783);
      END_STATE();
    case 952:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token1);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 953:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      END_STATE();
    case 954:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      ADVANCE_MAP(
        '%', 118,
        '&', 2286,
        '(', 2576,
        ')', 2577,
        '@', 820,
        'z', 119,
        '{', 159,
        '|', 2406,
        '+', 2552,
        '=', 2552,
        '?', 2552,
      );
      END_STATE();
    case 955:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      if (lookahead == '%') ADVANCE(118);
      if (lookahead == '&') ADVANCE(2286);
      if (lookahead == '(') ADVANCE(2576);
      if (lookahead == ')') ADVANCE(2577);
      if (lookahead == 'z') ADVANCE(119);
      if (lookahead == '|') ADVANCE(2406);
      END_STATE();
    case 956:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      ADVANCE_MAP(
        '%', 118,
        '&', 2286,
        '(', 2576,
        '@', 820,
        'z', 119,
        '{', 159,
        '|', 2406,
        '+', 2552,
        '=', 2552,
        '?', 2552,
      );
      END_STATE();
    case 957:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      if (lookahead == '%') ADVANCE(118);
      if (lookahead == '&') ADVANCE(2286);
      if (lookahead == '(') ADVANCE(2576);
      if (lookahead == 'z') ADVANCE(119);
      if (lookahead == '|') ADVANCE(2406);
      END_STATE();
    case 958:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      if (lookahead == '%') ADVANCE(118);
      if (lookahead == '(') ADVANCE(2576);
      if (lookahead == 'z') ADVANCE(119);
      END_STATE();
    case 959:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      if (lookahead == '|') ADVANCE(2406);
      END_STATE();
    case 960:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      if (lookahead == '|') ADVANCE(2406);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1010);
      END_STATE();
    case 961:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1010);
      END_STATE();
    case 962:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token2);
      END_STATE();
    case 963:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token2);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(963);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(962);
      END_STATE();
    case 964:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      END_STATE();
    case 965:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '-') ADVANCE(2293);
      END_STATE();
    case 966:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '-') ADVANCE(2293);
      if (lookahead == ':') ADVANCE(844);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1492);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 967:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '-') ADVANCE(2293);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1291);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1549);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 968:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '-') ADVANCE(2293);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(750);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(816);
      END_STATE();
    case 969:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '-') ADVANCE(2293);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1492);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 970:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '-') ADVANCE(2293);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(805);
      END_STATE();
    case 971:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '-') ADVANCE(2293);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 972:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '-') ADVANCE(2295);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1040);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2305);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1245);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 973:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '-') ADVANCE(2295);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(698);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2304);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(744);
      END_STATE();
    case 974:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '-') ADVANCE(2294);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1106);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1044);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 975:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '-') ADVANCE(2294);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(713);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(701);
      END_STATE();
    case 976:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '.') ADVANCE(822);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(819);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(826);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(2512);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(2511);
      END_STATE();
    case 977:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '.') ADVANCE(822);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2512);
      END_STATE();
    case 978:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == ':') ADVANCE(844);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 979:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '{') ADVANCE(2582);
      END_STATE();
    case 980:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1436);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2299);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 981:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1218);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1524);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 982:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1076);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 983:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(708);
      END_STATE();
    case 984:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(737);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(809);
      END_STATE();
    case 985:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(784);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2298);
      END_STATE();
    case 986:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(706);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(783);
      END_STATE();
    case 987:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      ADVANCE_MAP(
        'C', 1381,
        'c', 1381,
        'D', 1134,
        'd', 1134,
        'E', 1334,
        'e', 1334,
        'H', 1378,
        'h', 1378,
        'L', 1135,
        'l', 1135,
        'M', 1256,
        'm', 1256,
        'P', 1035,
        'p', 1035,
        'R', 1279,
        'r', 1279,
        'U', 1410,
        'u', 1410,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2376);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 988:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1465);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 989:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(795);
      END_STATE();
    case 990:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      ADVANCE_MAP(
        'C', 774,
        'c', 774,
        'D', 722,
        'd', 722,
        'E', 764,
        'e', 764,
        'H', 773,
        'h', 773,
        'L', 732,
        'l', 732,
        'M', 745,
        'm', 745,
        'P', 699,
        'p', 699,
        'R', 749,
        'r', 749,
        'U', 778,
        'u', 778,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2376);
      END_STATE();
    case 991:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1046);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1087);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2315);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 992:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(703);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(710);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2314);
      END_STATE();
    case 993:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1503);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1214);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 994:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1302);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1326);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 995:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(755);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(762);
      END_STATE();
    case 996:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(806);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(736);
      END_STATE();
    case 997:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1346);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1485);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 998:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(767);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(798);
      END_STATE();
    case 999:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2303);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1411);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1293);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1000:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2302);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(779);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(752);
      END_STATE();
    case 1001:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1105);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1292);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1078);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1002:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(712);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(751);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(709);
      END_STATE();
    case 1003:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1115);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2331);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1004:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(715);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2330);
      END_STATE();
    case 1005:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2347);
      END_STATE();
    case 1006:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2347);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1007:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1008:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 1009:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token3);
      if (lookahead == '"' ||
          lookahead == '#' ||
          lookahead == '%' ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('.' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2580);
      END_STATE();
    case 1010:
      ACCEPT_TOKEN(aux_sym__bang_filter_command_argument_token4);
      END_STATE();
    case 1011:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == ':') ADVANCE(844);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(1019);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1018);
      END_STATE();
    case 1012:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'o') ADVANCE(1016);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(1019);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1018);
      END_STATE();
    case 1013:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 'o') ADVANCE(1017);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1019);
      END_STATE();
    case 1014:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 's') ADVANCE(2496);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(1019);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1018);
      END_STATE();
    case 1015:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 's') ADVANCE(2498);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1019);
      END_STATE();
    case 1016:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 't') ADVANCE(2502);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(1019);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1018);
      END_STATE();
    case 1017:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == 't') ADVANCE(2505);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1019);
      END_STATE();
    case 1018:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(1019);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1018);
      END_STATE();
    case 1019:
      ACCEPT_TOKEN(aux_sym_argument_token1);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1019);
      END_STATE();
    case 1020:
      ACCEPT_TOKEN(aux_sym_argument_token2);
      if (lookahead == '.') ADVANCE(822);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(819);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(826);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(1022);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(1021);
      END_STATE();
    case 1021:
      ACCEPT_TOKEN(aux_sym_argument_token2);
      if (lookahead == '.') ADVANCE(822);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(1022);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(1021);
      END_STATE();
    case 1022:
      ACCEPT_TOKEN(aux_sym_argument_token2);
      if (lookahead == '.') ADVANCE(822);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1022);
      END_STATE();
    case 1023:
      ACCEPT_TOKEN(aux_sym_argument_token2);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1023);
      END_STATE();
    case 1024:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 1025:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1026:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 1027:
      ACCEPT_TOKEN(anon_sym_LBRACE2);
      END_STATE();
    case 1028:
      ACCEPT_TOKEN(anon_sym_LBRACE2);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1029:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == '-') ADVANCE(2293);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1030:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == '-') ADVANCE(182);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1031:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == ':') ADVANCE(844);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1032:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'o') ADVANCE(1034);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1033:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 's') ADVANCE(2495);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1034:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 't') ADVANCE(2503);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1035:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1218);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1525);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1258);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1036:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2373);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1037:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1077);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1443);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1038:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1543);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1039:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1373);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1040:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1442);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1041:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      ADVANCE_MAP(
        'A', 1207,
        'a', 1207,
        'E', 1042,
        'e', 1042,
        'H', 1153,
        'h', 1153,
        'I', 1219,
        'i', 1219,
        'O', 1538,
        'o', 1538,
        'P', 1188,
        'p', 1188,
        'T', 1126,
        't', 1126,
        'W', 1048,
        'w', 1048,
        'Y', 1347,
        'y', 1347,
      );
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1042:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1445);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1477);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1043:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1552);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1044:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1090);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1045:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1471);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1046:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1127);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1493);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1047:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1127);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1048:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1421);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1049:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      ADVANCE_MAP(
        'A', 1117,
        'a', 1117,
        'C', 1460,
        'c', 1460,
        'D', 1204,
        'd', 1204,
        'E', 1368,
        'e', 1368,
        'F', 1280,
        'f', 1280,
        'H', 1262,
        'h', 1262,
        'L', 1167,
        'l', 1167,
        'M', 1387,
        'm', 1387,
        'N', 1146,
        'n', 1146,
        'R', 1169,
        'r', 1169,
        'U', 1367,
        'u', 1367,
        'W', 1252,
        'w', 1252,
      );
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1050:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1108);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1051:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1518);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1190);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1382);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1052:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1306);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1053:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1342);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1054:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1294);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1055:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1298);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1056:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      ADVANCE_MAP(
        'A', 1430,
        'a', 1430,
        'C', 1240,
        'c', 1240,
        'E', 1377,
        'e', 1377,
        'R', 1194,
        'r', 1194,
        'T', 1557,
        't', 1557,
        'W', 1458,
        'w', 1458,
      );
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1057:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1110);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1058:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1091);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1059:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1109);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1060:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1129);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1061:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1121);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1062:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1345);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1063:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1349);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1064:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1221);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1211);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1079);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1065:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1544);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1066:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1365);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1067:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1513);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1068:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1369);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1069:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1372);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1070:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1517);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1071:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1516);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1072:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1281);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1073:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1275);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1074:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1282);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1075:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1433);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1076:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(2301);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1077:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1093);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1078:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2311);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1079:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1239);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1080:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1288);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1427);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1081:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      ADVANCE_MAP(
        'C', 1241,
        'c', 1241,
        'E', 1368,
        'e', 1368,
        'L', 1167,
        'l', 1167,
        'O', 1424,
        'o', 1424,
        'R', 1196,
        'r', 1196,
      );
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1082:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1405);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1083:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1233);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1084:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1329);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1264);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1085:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1385);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1386);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1086:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1238);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1087:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1052);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1088:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1528);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1089:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1236);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1368);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1193);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1090:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1138);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1091:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1232);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1092:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1534);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1093:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      ADVANCE_MAP(
        'C', 1308,
        'c', 1308,
        'E', 1368,
        'e', 1368,
        'L', 1167,
        'l', 1167,
        'N', 1154,
        'n', 1154,
      );
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1094:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      ADVANCE_MAP(
        'C', 1308,
        'c', 1308,
        'E', 1368,
        'e', 1368,
        'L', 1167,
        'l', 1167,
        'N', 1159,
        'n', 1159,
        'R', 1191,
        'r', 1191,
        'S', 1095,
        's', 1095,
      );
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1095:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1452);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1096:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1148);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1097:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1328);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1393);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1098:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1330);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1099:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1102);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1100:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1242);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1101:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1242);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1368);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1167);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1102:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1242);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1103:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1243);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1063);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1104:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1409);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1105:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2357);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1156);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1106:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2380);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1107:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1319);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1108:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2586);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1109:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1097);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1110:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2590);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1111:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2600);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1112:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2599);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1113:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1453);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1114:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2606);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1115:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1379);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1116:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1203);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1117:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1108);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1118:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1396);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1413);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1119:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1140);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1120:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1067);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1121:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1417);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1122:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1283);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1123:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1185);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1124:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1166);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1125:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1483);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1126:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1269);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1127:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1168);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1128:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1123);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1129:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1428);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1130:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1274);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1131:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1276);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1132:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1277);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1133:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1071);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1134:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1291);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1542);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1549);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1135:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1206);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1136:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2355);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1137:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1118);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1138:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2313);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1139:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2327);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1140:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2369);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1141:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2343);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1142:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2345);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1143:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1085);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1144:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1056);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1175);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1145:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2586);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1146:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1547);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1147:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1554);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1148:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1097);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1149:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2590);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1150:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1100);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1151:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2600);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1152:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2587);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1153:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1303);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1154:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1548);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1155:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1101);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1156:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1437);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1157:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1352);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1116);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1158:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1439);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1159:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1546);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1160:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1449);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1161:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1108);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1162:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1451);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1163:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1331);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1164:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1047);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1165:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1489);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1166:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1212);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1167:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1038);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1168:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1438);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1169:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1057);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1170:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1368);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1074);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1171:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1368);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1167);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1172:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      ADVANCE_MAP(
        'E', 1368,
        'e', 1368,
        'L', 1193,
        'l', 1193,
        'R', 1173,
        'r', 1173,
        'S', 1537,
        's', 1537,
      );
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1173:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1470);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1174:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1067);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1175:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1441);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1176:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1500);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1177:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1417);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1178:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1459);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1179:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1112);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1180:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1389);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1181:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1111);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1182:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1125);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1183:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1113);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1184:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1114);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1185:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1343);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1186:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1358);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1187:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1354);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1188:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1305);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1189:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1423);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1190:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1508);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1191:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1480);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1192:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1333);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1193:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1065);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1194:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1059);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1195:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1515);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1196:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1488);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1197:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1456);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1198:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1061);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1199:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1513);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1200:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1309);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1201:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1455);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1202:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1376);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1203:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1102);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1204:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1322);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1205:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1049);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1206:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1494);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1207:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1165);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1208:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1257);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1209:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1380);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1210:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1278);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1211:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1532);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1212:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1281);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1213:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1284);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1214:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1234);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1215:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2382);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1216:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1171);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1217:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2586);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1218:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1137);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1219:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1350);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1220:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1072);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1394);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1221:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1356);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1222:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1145);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1223:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1161);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1224:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1181);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1225:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1183);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1226:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1184);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1227:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1235);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1228:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1102);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1229:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1073);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1230:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(2317);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1231:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      ADVANCE_MAP(
        'H', 1053,
        'h', 1053,
        'M', 1107,
        'm', 1107,
        'O', 1296,
        'o', 1296,
        'U', 1444,
        'u', 1444,
      );
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1232:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(2586);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1233:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1551);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1234:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1495);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1235:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1498);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1236:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1039);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1237:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1392);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1398);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1238:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1192);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1239:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1062);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1240:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1066);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1241:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1068);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1402);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1242:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1068);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1243:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1069);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1244:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1200);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1245:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2323);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1246:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1064);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1247:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1297);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1088);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1364);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1248:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1171);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1158);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1249:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1323);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1250:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1170);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1251:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1080);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1252:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1339);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1265);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1253:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1558);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1332);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1254:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1558);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1255:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1505);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1256:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1366);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1304);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1257:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1553);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1258:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1357);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1259:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1119);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1260:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1420);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1261:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1341);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1262:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1128);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1263:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1404);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1264:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1321);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1265:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1514);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1266:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1407);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1267:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1099);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1268:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1478);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1269:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1374);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1270:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1353);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1424);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1271:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1479);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1272:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1359);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1273:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1340);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1274:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1348);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1275:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1343);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1276:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1351);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1277:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1355);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1278:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1182);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1279:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1227);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1280:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1313);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1281:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1360);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1282:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1316);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1283:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1210);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1284:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1317);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1285:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1510);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1286:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1315);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1287:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1511);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1288:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(1208);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1289:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(1202);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1290:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(1428);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1291:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2321);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1292:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2325);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1293:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2297);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1294:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2375);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1295:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1555);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1296:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1397);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1418);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1297:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1144);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1298:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2586);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1299:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1300:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1556);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1301:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2604);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1302:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1412);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1303:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1299);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1304:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1504);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1305:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1318);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1306:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1307);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1307:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1164);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1308:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1399);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1309:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1301);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1310:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1395);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1311:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1195);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1312:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1112);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1313:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1177);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1314:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1403);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1315:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1145);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1316:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1161);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1317:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1163);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1318:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1213);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1319:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1272);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1363);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1273);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1320:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1316);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1321:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1520);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1322:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1199);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1323:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1172);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1324:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1081);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1325:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1327);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1326:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1136);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1327:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1036);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1328:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1108);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1329:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1330:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1121);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1331:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1271);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1332:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1145);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1333:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1151);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1334:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1105);
      if (lookahead == 'Q' ||
          lookahead == 'q') ADVANCE(1539);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1335:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2333);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1336:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2307);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1337:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2361);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1338:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1082);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1255);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1339:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1171);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1180);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1340:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1171);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1341:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1094);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1342:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1270);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1343:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2586);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1344:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1486);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1345:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1224);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1346:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1383);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1347:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1506);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1348:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1228);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1349:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1290);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1350:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1055);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1351:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1216);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1352:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1531);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1353:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1209);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1354:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1108);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1355:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1217);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1356:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1390);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1357:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1497);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1358:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1109);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1359:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1155);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1360:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1161);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1361:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1151);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1362:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1483);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1363:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1124);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1364:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1092);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1365:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1225);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1366:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1526);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1367:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1310);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1368:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1502);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1369:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1223);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1370:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1314);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1371:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1481);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1372:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1226);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1373:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1222);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1427);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1374:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1462);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1375:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1521);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1376:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1541);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1377:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1104);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1378:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1326);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1379:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2351);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1380:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2586);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1381:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1325);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1382:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1289);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1383:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1448);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1384:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1536);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1385:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1464);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1386:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1519);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1387:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1122);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1388:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1440);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1389:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1533);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1390:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1484);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1391:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1431);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1392:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1312);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1393:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1475);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1145);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1394:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1475);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1395:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1050);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1396:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1550);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1397:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1450);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1398:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1545);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1399:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1482);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1400:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1320);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1401:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1361);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1402:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1481);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1403:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1060);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1404:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1362);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1405:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1130);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1406:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1540);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1407:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1370);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1408:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1371);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1409:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1132);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1410:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2331);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1411:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2329);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1412:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2349);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1413:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2359);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1414:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1507);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1415:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1051);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1416:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2586);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1417:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1393);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1418:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1311);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1419:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1391);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1420:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1295);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1421:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1147);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1422:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1133);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1423:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1300);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1424:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1185);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1425:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1145);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1426:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1161);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1427:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1454);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1428:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1394);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1429:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1186);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1430:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1429);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1431:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1535);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1432:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1187);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1433:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1426);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1434:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1120);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1435:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1408);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1436:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2319);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1437:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2309);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1438:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2378);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1439:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2586);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1440:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1237);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1441:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1461);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1442:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1030);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1443:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1324);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1499);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1444:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1487);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1445:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1083);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1446:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1336);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1447:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1096);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1448:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1139);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1449:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1496);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1450:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1473);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1451:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1501);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1452:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1400);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1453:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1380);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1244);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1454:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1145);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1455:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1161);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1456:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1189);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1457:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1075);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1458:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1285);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1459:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1428);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1460:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1174);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1461:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1198);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1463);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1462:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1198);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1463:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1287);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1464:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1131);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1465:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1245);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1466:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2363);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1467:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2365);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1468:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2586);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1469:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1220);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1470:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1253);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1471:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1230);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1472:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1415);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1473:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1086);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1474:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1141);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1475:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1500);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1476:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1142);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1477:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1266);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1478:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1509);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1479:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1491);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1480:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1254);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1481:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1145);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1482:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1161);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1483:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1176);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1484:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1512);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1485:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1160);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1486:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1162);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1487:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1388);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1488:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1435);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1489:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1522);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1490:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1432);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1491:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1277);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1492:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1029);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1493:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2336);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1494:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2337);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1495:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2340);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1496:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2353);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1497:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2371);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1498:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2341);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1499:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1103);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1500:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2586);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1501:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1089);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1502:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1158);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1503:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1529);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1504:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1260);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1505:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1427);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1506:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1043);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1507:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1263);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1508:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1058);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1509:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1468);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1510:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1148);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1511:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1177);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1512:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1267);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1513:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1145);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1514:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1149);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1515:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1150);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1516:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1161);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1517:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1152);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1518:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1508);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1519:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1197);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1520:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1178);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1521:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1201);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1522:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1070);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1523:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1205);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1524:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1215);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1525:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1466);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1526:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1467);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1527:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1250);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1528:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1469);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1529:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1446);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1530:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1251);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1531:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1419);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1532:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1422);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1533:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1500);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1534:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1363);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1535:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1416);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1536:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1474);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1537:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1490);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1538:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1447);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1539:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1054);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1540:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1476);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1541:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1434);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1542:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1259);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1543:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1145);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1544:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1151);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1545:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1179);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1546:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(2586);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1547:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(2596);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1548:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(2593);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1549:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1335);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1550:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1337);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1551:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1457);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1552:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(2586);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1553:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1098);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1554:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1268);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1555:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(2367);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1556:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(2586);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1557:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1425);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1558:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(1161);
      if (('A' <= lookahead && lookahead <= 'Y') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'y')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1559:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 1560:
      ACCEPT_TOKEN(aux_sym_identifier_token1);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1561:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == '.') ADVANCE(822);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(2032);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(2034);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(1563);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(1562);
      if (lookahead == '#' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1562:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == '.') ADVANCE(822);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(1563);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(1562);
      if (lookahead == '#' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1563:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == '.') ADVANCE(822);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1563);
      if (lookahead == '#' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1564:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == ':') ADVANCE(844);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(2035);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2033);
      END_STATE();
    case 1565:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'a') ADVANCE(1589);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1566:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'c') ADVANCE(1598);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1567:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'e') ADVANCE(2471);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1568:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'e') ADVANCE(2461);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1569:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'e') ADVANCE(2463);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1570:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'e') ADVANCE(1615);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1571:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'e') ADVANCE(1601);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1572:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'e') ADVANCE(1577);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1573:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'f') ADVANCE(1574);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1574:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'f') ADVANCE(1571);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1575:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'h') ADVANCE(1585);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1576:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'h') ADVANCE(1586);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1577:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'h') ADVANCE(1587);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1578:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'i') ADVANCE(1583);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1579:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'i') ADVANCE(1593);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1580:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'i') ADVANCE(1609);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1581:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'i') ADVANCE(1599);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1582:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'i') ADVANCE(1594);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1583:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'l') ADVANCE(1567);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1584:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'l') ADVANCE(1575);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1585:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'l') ADVANCE(2458);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1586:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'l') ADVANCE(2449);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1587:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'l') ADVANCE(2446);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1588:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'l') ADVANCE(2455);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1589:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'm') ADVANCE(1569);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1590:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'm') ADVANCE(1576);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1591:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'n') ADVANCE(2443);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1592:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'n') ADVANCE(947);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1593:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'n') ADVANCE(1568);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1594:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'n') ADVANCE(1572);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1595:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'o') ADVANCE(1607);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(2035);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2033);
      END_STATE();
    case 1596:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'o') ADVANCE(1608);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1597:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'o') ADVANCE(1612);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1598:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'o') ADVANCE(1591);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1599:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'o') ADVANCE(1604);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1600:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'p') ADVANCE(2467);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1601:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'r') ADVANCE(2465);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1602:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'r') ADVANCE(1597);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1603:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'r') ADVANCE(1581);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1604:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'r') ADVANCE(1580);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1605:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 's') ADVANCE(2494);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(2035);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2033);
      END_STATE();
    case 1606:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 's') ADVANCE(2497);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1607:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 't') ADVANCE(2501);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(2035);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2033);
      END_STATE();
    case 1608:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 't') ADVANCE(2504);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1609:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 't') ADVANCE(1616);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1610:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 't') ADVANCE(2451);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1611:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'u') ADVANCE(1573);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1612:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'u') ADVANCE(1600);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1613:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'u') ADVANCE(1584);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1614:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'u') ADVANCE(1590);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1615:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'x') ADVANCE(1610);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1616:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'y') ADVANCE(2469);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1617:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == '{') ADVANCE(2582);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 1618:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == '#' ||
          lookahead == '_') ADVANCE(2035);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1618);
      END_STATE();
    case 1619:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1651);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1946);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1620:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2019);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1621:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1892);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1622:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      ADVANCE_MAP(
        'A', 1758,
        'a', 1758,
        'E', 1623,
        'e', 1623,
        'H', 1708,
        'h', 1708,
        'I', 1767,
        'i', 1767,
        'O', 2017,
        'o', 2017,
        'P', 1740,
        'p', 1740,
        'T', 1692,
        't', 1692,
        'W', 1625,
        'w', 1625,
        'Y', 1868,
        'y', 1868,
      );
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1623:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1948);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1971);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1624:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2026);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1625:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1928);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1626:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      ADVANCE_MAP(
        'A', 1685,
        'a', 1685,
        'C', 1960,
        'c', 1960,
        'D', 1756,
        'd', 1756,
        'E', 1887,
        'e', 1887,
        'F', 1818,
        'f', 1818,
        'H', 1801,
        'h', 1801,
        'L', 1720,
        'l', 1720,
        'M', 1901,
        'm', 1901,
        'N', 1702,
        'n', 1702,
        'R', 1721,
        'r', 1721,
        'U', 1886,
        'u', 1886,
        'W', 1795,
        'w', 1795,
      );
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1627:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1676);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1628:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2002);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1742);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1898);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1629:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1865);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1630:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1829);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1631:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      ADVANCE_MAP(
        'A', 1937,
        'a', 1937,
        'C', 1784,
        'c', 1784,
        'E', 1896,
        'e', 1896,
        'R', 1746,
        'r', 1746,
        'T', 2030,
        't', 2030,
        'W', 1958,
        'w', 1958,
      );
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1632:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1682);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1633:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1662);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1634:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1680);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1635:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1694);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1636:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1687);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1637:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1867);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1638:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1870);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1639:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1769);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1762);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1652);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1640:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2020);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1641:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1885);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1642:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1997);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1643:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1888);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1644:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1891);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1645:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2001);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1646:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2000);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1647:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1819);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1648:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1814);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1649:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1820);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1650:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1940);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1651:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1664);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1652:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1783);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1653:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1826);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1934);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1654:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      ADVANCE_MAP(
        'C', 1785,
        'c', 1785,
        'E', 1887,
        'e', 1887,
        'L', 1720,
        'l', 1720,
        'O', 1931,
        'o', 1931,
        'R', 1748,
        'r', 1748,
      );
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1655:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1918);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1656:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1779);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1657:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1855);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1803);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1658:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1899);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1900);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1659:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1782);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1660:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2009);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1661:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1780);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1887);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1745);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1662:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1777);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1663:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2014);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1664:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      ADVANCE_MAP(
        'C', 1837,
        'c', 1837,
        'E', 1887,
        'e', 1887,
        'L', 1720,
        'l', 1720,
        'N', 1709,
        'n', 1709,
      );
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1665:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      ADVANCE_MAP(
        'C', 1837,
        'c', 1837,
        'E', 1887,
        'e', 1887,
        'L', 1720,
        'l', 1720,
        'N', 1714,
        'n', 1714,
        'R', 1743,
        'r', 1743,
        'S', 1666,
        's', 1666,
      );
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1666:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1952);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1667:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1704);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1668:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1854);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1907);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1669:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1856);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1670:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1673);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1671:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1786);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1914);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1672:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1786);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1887);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1720);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1673:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1786);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1674:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1787);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1638);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1675:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1921);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1676:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2586);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1677:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2599);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1678:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2606);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1679:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1848);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1680:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1668);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1681:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1953);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1682:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2591);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1683:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2601);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1684:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1755);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1685:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1676);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1686:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1642);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1687:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1925);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1688:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1821);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1689:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1737);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1690:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1719);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1691:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1977);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1692:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1808);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1693:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1689);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1694:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1935);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1695:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1813);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1696:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1815);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1697:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1816);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1698:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1646);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1699:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2586);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1700:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1658);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1701:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1631);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1727);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1702:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2023);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1703:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2028);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1704:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1668);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1705:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1671);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1706:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2591);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1707:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2588);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1708:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1834);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1709:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2024);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1710:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1672);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1711:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2601);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1712:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1873);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1684);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1713:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1943);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1714:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2022);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1715:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1676);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1716:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1951);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1717:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1857);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1718:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1982);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1719:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1763);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1720:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1620);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1721:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1632);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1722:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1887);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1649);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1723:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1887);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1720);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1724:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      ADVANCE_MAP(
        'E', 1887,
        'e', 1887,
        'L', 1745,
        'l', 1745,
        'R', 1725,
        'r', 1725,
        'S', 2016,
        's', 2016,
      );
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1725:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1967);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1726:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1642);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1727:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1945);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1728:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1985);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1729:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1925);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1730:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1959);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1731:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1677);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1732:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1903);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1733:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1683);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1734:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1691);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1735:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1681);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1736:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1678);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1737:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1860);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1738:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1878);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1739:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1875);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1740:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1836);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1741:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1930);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1742:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1992);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1743:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1974);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1744:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1859);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1745:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1640);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1746:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1634);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1747:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1999);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1748:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1981);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1749:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1956);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1750:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1636);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1751:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1997);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1752:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1838);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1753:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1955);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1754:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1895);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1755:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1673);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1756:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1851);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1757:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1626);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1758:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1718);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1759:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1799);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1760:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1897);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1761:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1817);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1762:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2012);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1763:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1819);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1764:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1822);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1765:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2586);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1766:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1723);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1767:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1871);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1768:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1647);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1908);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1769:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1877);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1770:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1699);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1771:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1715);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1772:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1733);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1773:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1735);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1774:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1736);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1775:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1673);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1776:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1648);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1777:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(2586);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1778:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      ADVANCE_MAP(
        'H', 1629,
        'h', 1629,
        'M', 1679,
        'm', 1679,
        'O', 1830,
        'o', 1830,
        'U', 1947,
        'u', 1947,
      );
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1779:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(2025);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1780:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1621);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1781:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1906);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1911);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1782:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1744);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1783:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1637);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1784:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1641);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1785:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1643);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1915);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1786:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1643);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1787:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1644);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1788:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1752);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1789:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1639);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1790:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1831);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1660);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1884);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1791:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1723);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1713);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1792:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1852);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1793:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1722);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1794:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1653);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1795:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1862);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1804);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1796:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2031);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1858);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1797:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2031);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1798:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1989);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1799:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2027);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1800:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1864);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1801:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1693);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1802:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1917);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1803:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1850);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1804:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1998);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1805:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1919);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1806:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1670);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1807:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1972);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1808:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1893);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1809:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1874);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1931);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1810:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1973);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1811:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1879);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1812:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1863);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1813:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1869);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1814:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1860);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1815:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1872);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1816:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1876);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1817:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1734);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1818:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1842);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1819:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1880);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1820:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1845);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1821:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1761);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1822:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1846);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1823:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1994);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1824:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1844);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1825:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1995);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1826:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(1759);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1827:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(1754);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1828:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(1935);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1829:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2586);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1830:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1910);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1926);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1831:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1701);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1832:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1657);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1833:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2029);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1834:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1832);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1835:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2605);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1836:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1847);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1837:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1912);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1838:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1835);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1839:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1909);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1840:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1747);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1841:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1677);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1842:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1729);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1843:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1916);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1844:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1699);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1845:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1715);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1846:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1717);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1847:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1764);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1848:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1811);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1883);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1812);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1849:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1845);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1850:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2004);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1851:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1751);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1852:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1724);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1853:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1654);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1854:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1676);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1855:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1694);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1856:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1687);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1857:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1810);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1858:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1699);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1859:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1711);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1860:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2586);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1861:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1655);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1798);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1862:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1723);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1732);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1863:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1723);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1864:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1665);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1865:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1809);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1866:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1979);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1867:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1772);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1868:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1990);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1869:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1775);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1870:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1828);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1871:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1630);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1872:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1766);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1873:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2011);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1874:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1760);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1875:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1676);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1876:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1765);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1877:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1904);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1878:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1680);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1879:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1710);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1880:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1715);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1881:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1711);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1882:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1977);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1883:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1690);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1884:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1663);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1885:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1773);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1886:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1839);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1887:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1988);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1888:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1771);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1889:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1843);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1890:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1975);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1891:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1774);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1892:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1770);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1934);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1893:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1962);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1894:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2005);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1895:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2018);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1896:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1675);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1897:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2586);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1898:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1827);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1899:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1964);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1900:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2003);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1901:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1688);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1902:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1944);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1903:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2013);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1904:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1978);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1905:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1938);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1906:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1841);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1907:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1970);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1699);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1908:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1970);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1909:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1627);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1910:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1950);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1911:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2021);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1912:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1976);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1913:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1849);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1914:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1881);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1915:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1975);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1916:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1635);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1917:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1882);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1918:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1695);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1919:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1889);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1920:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1890);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1921:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1697);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1922:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2586);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1923:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1991);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1924:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1628);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1925:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1907);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1926:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1840);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1927:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1905);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1928:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1703);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1929:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1698);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1930:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1833);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1931:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1737);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1932:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1699);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1933:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1715);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1934:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1954);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1935:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1908);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1936:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1738);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1937:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1936);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1938:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2015);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1939:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1739);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1940:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1933);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1941:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1686);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1942:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1920);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1943:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2586);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1944:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1781);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1945:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1961);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1946:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1853);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1986);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1947:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1980);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1948:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1656);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1949:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1667);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1950:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1969);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1951:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1987);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1952:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1913);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1953:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1897);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1788);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1954:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1699);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1955:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1715);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1956:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1741);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1957:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1650);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1958:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1823);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1959:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1935);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1960:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1726);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1961:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1750);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1963);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1962:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1750);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1963:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1825);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1964:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1696);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1965:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2586);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1966:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1768);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1967:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1796);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1968:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1924);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1969:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1659);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1970:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1985);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1971:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1805);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1972:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1993);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1973:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1984);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1974:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1797);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1975:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1699);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1976:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1715);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1977:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1728);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1978:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1996);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1979:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1716);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1980:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1902);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1981:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1942);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1982:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2006);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1983:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1939);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1984:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1816);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1985:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2586);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1986:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1674);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1987:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1661);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1988:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1713);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1989:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1934);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1990:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1624);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1991:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1802);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1992:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1633);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1993:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1965);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1994:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1704);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1995:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1729);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1996:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1806);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1997:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1699);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1998:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1706);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 1999:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1705);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2000:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1715);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2001:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1707);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2002:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1992);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2003:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1749);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2004:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1730);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2005:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1753);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2006:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1645);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2007:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1757);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2008:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1793);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2009:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1966);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2010:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1794);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2011:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1927);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2012:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1929);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2013:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1985);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2014:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1883);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2015:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1922);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2016:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1983);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2017:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1949);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2018:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1941);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2019:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1699);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2020:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1711);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2021:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1731);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2022:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(2586);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2023:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(2597);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2024:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(2594);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2025:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1957);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2026:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(2586);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2027:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1669);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2028:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1807);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2029:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(2586);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2030:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1932);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2031:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(1715);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Y') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'y')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2032:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(2032);
      if (lookahead == '#' ||
          ('2' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2033:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(2035);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2033);
      END_STATE();
    case 2034:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(2034);
      if (lookahead == '#' ||
          ('G' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2035:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2036:
      ACCEPT_TOKEN(aux_sym_identifier_token2);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2036);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2037:
      ACCEPT_TOKEN(aux_sym__immediate_identifier_token1);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2037);
      END_STATE();
    case 2038:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == '-') ADVANCE(190);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2039:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == '-') ADVANCE(186);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2040:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == '-') ADVANCE(347);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2041:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'E') ADVANCE(3272);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2042:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'N') ADVANCE(2041);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2043:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'O') ADVANCE(2042);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2044:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'a') ADVANCE(2191);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2045:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'a') ADVANCE(2114);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2046:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'a') ADVANCE(2161);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2047:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'a') ADVANCE(2197);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2048:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'a') ADVANCE(2182);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2049:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'a') ADVANCE(2190);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2050:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'a') ADVANCE(2162);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2051:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'a') ADVANCE(2194);
      if (lookahead == 'i') ADVANCE(2147);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2052:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'a') ADVANCE(2106);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2053:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'a') ADVANCE(2135);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2054:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'a') ADVANCE(2166);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2055:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'a') ADVANCE(2165);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2056:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'a') ADVANCE(2116);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2057:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'c') ADVANCE(2173);
      if (lookahead == 't') ADVANCE(2095);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2058:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'c') ADVANCE(2040);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2059:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'c') ADVANCE(2100);
      if (lookahead == 'o') ADVANCE(2134);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2060:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'c') ADVANCE(2100);
      if (lookahead == 'o') ADVANCE(2146);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2061:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'c') ADVANCE(2101);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2062:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'c') ADVANCE(2118);
      if (lookahead == 't') ADVANCE(2085);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2063:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'c') ADVANCE(2082);
      if (lookahead == 't') ADVANCE(2052);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2064:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'c') ADVANCE(2082);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2065:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'c') ADVANCE(2091);
      if (lookahead == 't') ADVANCE(2052);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2066:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'd') ADVANCE(3491);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2067:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'd') ADVANCE(3410);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2068:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'd') ADVANCE(3416);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2069:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'd') ADVANCE(3419);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2070:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'd') ADVANCE(3374);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2071:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'd') ADVANCE(2169);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2072:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'd') ADVANCE(2092);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2073:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2160);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2074:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(3031);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2075:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2128);
      if (lookahead == 'n') ADVANCE(2115);
      if (lookahead == 'w') ADVANCE(2099);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2076:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(3428);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2077:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(3393);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2078:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2096);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2079:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2181);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2080:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2046);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2081:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2193);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2082:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2045);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2083:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2121);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2084:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2170);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2085:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2136);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2086:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2070);
      if (lookahead == 's') ADVANCE(3407);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2087:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2171);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2088:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2137);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2089:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2172);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2090:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2094);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2091:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2056);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2092:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2140);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2093:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2138);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2094:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'e') ADVANCE(2159);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2095:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'f') ADVANCE(2039);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2096:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'f') ADVANCE(2049);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2097:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'g') ADVANCE(2163);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2098:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'g') ADVANCE(2167);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2099:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'h') ADVANCE(2105);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2100:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'h') ADVANCE(2050);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2101:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'h') ADVANCE(2098);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2102:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'i') ADVANCE(2119);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2103:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'i') ADVANCE(2174);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2104:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'i') ADVANCE(2151);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2105:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'i') ADVANCE(2185);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2106:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'i') ADVANCE(2131);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2107:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'i') ADVANCE(2154);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2108:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'i') ADVANCE(2142);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2109:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'i') ADVANCE(2143);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2110:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'i') ADVANCE(2144);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2111:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'i') ADVANCE(2145);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2112:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'k') ADVANCE(2104);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2113:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'k') ADVANCE(2107);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2114:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'l') ADVANCE(3363);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2115:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'l') ADVANCE(3398);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2116:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'l') ADVANCE(3359);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2117:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'l') ADVANCE(3422);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2118:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'l') ADVANCE(2187);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2119:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'l') ADVANCE(2079);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2120:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'l') ADVANCE(2067);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2121:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'l') ADVANCE(2108);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2122:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'l') ADVANCE(2080);
      if (lookahead == 'o') ADVANCE(2133);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2123:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'l') ADVANCE(2080);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2124:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'l') ADVANCE(2179);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2125:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'l') ADVANCE(2047);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2126:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'l') ADVANCE(2110);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2127:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'l') ADVANCE(2111);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2128:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'm') ADVANCE(2156);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2129:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2176);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2130:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2066);
      if (lookahead == 'x') ADVANCE(2062);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2131:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2086);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2132:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(3378);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2133:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2064);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2134:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2065);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2135:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2175);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2136:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2068);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2137:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2069);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2138:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2178);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2139:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2071);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2140:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2117);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2141:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2083);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2142:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2076);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2143:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2084);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2144:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2087);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2145:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2089);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2146:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2063);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2147:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'n') ADVANCE(2127);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2148:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'o') ADVANCE(2188);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2149:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'o') ADVANCE(2120);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2150:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'o') ADVANCE(2189);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2151:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'p') ADVANCE(2075);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2152:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'p') ADVANCE(3383);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2153:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'p') ADVANCE(3425);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2154:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'p') ADVANCE(3487);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2155:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'p') ADVANCE(2074);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2156:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'p') ADVANCE(2183);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2157:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'p') ADVANCE(2125);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2158:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'p') ADVANCE(2054);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2159:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'p') ADVANCE(2088);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2160:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'r') ADVANCE(3033);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2161:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'r') ADVANCE(3266);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2162:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'r') ADVANCE(3368);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2163:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'r') ADVANCE(2148);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2164:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'r') ADVANCE(2053);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2165:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'r') ADVANCE(2180);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2166:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'r') ADVANCE(2093);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2167:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'r') ADVANCE(2150);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2168:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 's') ADVANCE(2073);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2169:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 's') ADVANCE(3431);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2170:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 's') ADVANCE(3501);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2171:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 's') ADVANCE(3498);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2172:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 's') ADVANCE(3495);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2173:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 's') ADVANCE(2038);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2174:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 's') ADVANCE(2157);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2175:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 's') ADVANCE(2158);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2176:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 't') ADVANCE(2044);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2177:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 't') ADVANCE(2097);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2178:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 't') ADVANCE(3388);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2179:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 't') ADVANCE(916);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2180:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 't') ADVANCE(3309);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2181:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 't') ADVANCE(2196);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2182:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 't') ADVANCE(2061);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2183:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 't') ADVANCE(2198);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2184:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 't') ADVANCE(2055);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2185:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 't') ADVANCE(2077);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2186:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'u') ADVANCE(2058);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2187:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'u') ADVANCE(2072);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2188:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'u') ADVANCE(2152);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2189:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'u') ADVANCE(2153);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2190:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'u') ADVANCE(2124);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2191:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'x') ADVANCE(3032);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2192:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'x') ADVANCE(2062);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2193:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'x') ADVANCE(2177);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2194:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'x') ADVANCE(2126);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2195:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'y') ADVANCE(2129);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2196:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'y') ADVANCE(2155);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2197:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'y') ADVANCE(3413);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2198:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == 'y') ADVANCE(3403);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2199:
      ACCEPT_TOKEN(sym_keyword);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2200:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 2201:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 2202:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 2203:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 2204:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 2205:
      ACCEPT_TOKEN(anon_sym_DOT_EQ);
      END_STATE();
    case 2206:
      ACCEPT_TOKEN(anon_sym_DOT_DOT_EQ);
      END_STATE();
    case 2207:
      ACCEPT_TOKEN(anon_sym_EQ_LT_LT);
      END_STATE();
    case 2208:
      ACCEPT_TOKEN(aux_sym_option_name_token1);
      if (lookahead == '_') ADVANCE(2212);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(2211);
      END_STATE();
    case 2209:
      ACCEPT_TOKEN(aux_sym_option_name_token1);
      if (lookahead == 'l') ADVANCE(2219);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(2211);
      END_STATE();
    case 2210:
      ACCEPT_TOKEN(aux_sym_option_name_token1);
      if (lookahead == 'l') ADVANCE(2209);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(2211);
      END_STATE();
    case 2211:
      ACCEPT_TOKEN(aux_sym_option_name_token1);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(2211);
      END_STATE();
    case 2212:
      ACCEPT_TOKEN(anon_sym_t_);
      END_STATE();
    case 2213:
      ACCEPT_TOKEN(aux_sym_option_name_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2213);
      END_STATE();
    case 2214:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 2215:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(2249);
      END_STATE();
    case 2216:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2217:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 2218:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(2478);
      END_STATE();
    case 2219:
      ACCEPT_TOKEN(anon_sym_all);
      if (lookahead == '&') ADVANCE(2220);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(2211);
      END_STATE();
    case 2220:
      ACCEPT_TOKEN(anon_sym_all_AMP);
      END_STATE();
    case 2221:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 2222:
      ACCEPT_TOKEN(anon_sym_EQ2);
      END_STATE();
    case 2223:
      ACCEPT_TOKEN(anon_sym_COLON2);
      END_STATE();
    case 2224:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ2);
      END_STATE();
    case 2225:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 2226:
      ACCEPT_TOKEN(anon_sym_DASH_EQ2);
      END_STATE();
    case 2227:
      ACCEPT_TOKEN(sym_set_value);
      if (lookahead == '>') ADVANCE(2232);
      if (lookahead == '\\') ADVANCE(2233);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(2232);
      END_STATE();
    case 2228:
      ACCEPT_TOKEN(sym_set_value);
      if (lookahead == '\\') ADVANCE(2233);
      if (lookahead == '|') ADVANCE(2407);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(2232);
      END_STATE();
    case 2229:
      ACCEPT_TOKEN(sym_set_value);
      if (lookahead == '\\') ADVANCE(2233);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2231);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(2232);
      END_STATE();
    case 2230:
      ACCEPT_TOKEN(sym_set_value);
      if (lookahead == '\\') ADVANCE(2233);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(2229);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2231);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(2232);
      END_STATE();
    case 2231:
      ACCEPT_TOKEN(sym_set_value);
      if (lookahead == '\\') ADVANCE(2233);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2227);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(2232);
      END_STATE();
    case 2232:
      ACCEPT_TOKEN(sym_set_value);
      if (lookahead == '\\') ADVANCE(2233);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(2232);
      END_STATE();
    case 2233:
      ACCEPT_TOKEN(sym_set_value);
      if (lookahead == '\\') ADVANCE(2233);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(2232);
      END_STATE();
    case 2234:
      ACCEPT_TOKEN(anon_sym_SPACE);
      if (lookahead == ' ') ADVANCE(2234);
      END_STATE();
    case 2235:
      ACCEPT_TOKEN(anon_sym_POUND_BANG);
      END_STATE();
    case 2236:
      ACCEPT_TOKEN(aux_sym_shebang_token1);
      if (lookahead == '<') ADVANCE(2241);
      if (lookahead == '\\') ADVANCE(2238);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2236);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2243);
      END_STATE();
    case 2237:
      ACCEPT_TOKEN(aux_sym_shebang_token1);
      if (lookahead == '>') ADVANCE(2243);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(2243);
      END_STATE();
    case 2238:
      ACCEPT_TOKEN(aux_sym_shebang_token1);
      if (lookahead == '|') ADVANCE(2413);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(2243);
      END_STATE();
    case 2239:
      ACCEPT_TOKEN(aux_sym_shebang_token1);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2239);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(2243);
      END_STATE();
    case 2240:
      ACCEPT_TOKEN(aux_sym_shebang_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2242);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(2243);
      END_STATE();
    case 2241:
      ACCEPT_TOKEN(aux_sym_shebang_token1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(2240);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2242);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(2243);
      END_STATE();
    case 2242:
      ACCEPT_TOKEN(aux_sym_shebang_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2237);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(2243);
      END_STATE();
    case 2243:
      ACCEPT_TOKEN(aux_sym_shebang_token1);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(2243);
      END_STATE();
    case 2244:
      ACCEPT_TOKEN(aux_sym_command_argument_token1);
      if (lookahead == '>') ADVANCE(2249);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(2249);
      END_STATE();
    case 2245:
      ACCEPT_TOKEN(aux_sym_command_argument_token1);
      if (lookahead == '|') ADVANCE(2409);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(2249);
      END_STATE();
    case 2246:
      ACCEPT_TOKEN(aux_sym_command_argument_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2248);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(2249);
      END_STATE();
    case 2247:
      ACCEPT_TOKEN(aux_sym_command_argument_token1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(2246);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2248);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(2249);
      END_STATE();
    case 2248:
      ACCEPT_TOKEN(aux_sym_command_argument_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2244);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(2249);
      END_STATE();
    case 2249:
      ACCEPT_TOKEN(aux_sym_command_argument_token1);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(2249);
      END_STATE();
    case 2250:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 2251:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 2252:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 2253:
      ACCEPT_TOKEN(sym_spread);
      END_STATE();
    case 2254:
      ACCEPT_TOKEN(sym__printable);
      END_STATE();
    case 2255:
      ACCEPT_TOKEN(sym__printable);
      ADVANCE_MAP(
        ' ', 2255,
        '<', 2264,
        '\\', 2263,
        'c', 2261,
        'i', 2258,
        'l', 2260,
        'n', 2262,
        't', 2259,
      );
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(2254);
      END_STATE();
    case 2256:
      ACCEPT_TOKEN(sym__printable);
      if (lookahead == ' ') ADVANCE(2256);
      if (lookahead == 'c') ADVANCE(2261);
      if (lookahead == 'i') ADVANCE(2258);
      if (lookahead == 'l') ADVANCE(2260);
      if (lookahead == 'n') ADVANCE(2262);
      if (lookahead == 't') ADVANCE(2259);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(2254);
      END_STATE();
    case 2257:
      ACCEPT_TOKEN(sym__printable);
      if (lookahead == ' ') ADVANCE(2257);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(2254);
      END_STATE();
    case 2258:
      ACCEPT_TOKEN(sym__printable);
      if (lookahead == 'c') ADVANCE(563);
      END_STATE();
    case 2259:
      ACCEPT_TOKEN(sym__printable);
      if (lookahead == 'e') ADVANCE(676);
      END_STATE();
    case 2260:
      ACCEPT_TOKEN(sym__printable);
      if (lookahead == 'i') ADVANCE(543);
      END_STATE();
    case 2261:
      ACCEPT_TOKEN(sym__printable);
      if (lookahead == 'u') ADVANCE(498);
      END_STATE();
    case 2262:
      ACCEPT_TOKEN(sym__printable);
      if (lookahead == 'u') ADVANCE(518);
      END_STATE();
    case 2263:
      ACCEPT_TOKEN(sym__printable);
      if (lookahead == '|') ADVANCE(2406);
      END_STATE();
    case 2264:
      ACCEPT_TOKEN(sym__printable);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(706);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(783);
      END_STATE();
    case 2265:
      ACCEPT_TOKEN(sym_mark);
      END_STATE();
    case 2266:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 2267:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(2204);
      END_STATE();
    case 2268:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 2269:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 2270:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '=') ADVANCE(2203);
      END_STATE();
    case 2271:
      ACCEPT_TOKEN(anon_sym_SLASH2);
      END_STATE();
    case 2272:
      ACCEPT_TOKEN(anon_sym_QMARK2);
      END_STATE();
    case 2273:
      ACCEPT_TOKEN(anon_sym_DOT2);
      END_STATE();
    case 2274:
      ACCEPT_TOKEN(anon_sym_DOT2);
      if (lookahead == '.') ADVANCE(2485);
      if (lookahead == '=') ADVANCE(2205);
      END_STATE();
    case 2275:
      ACCEPT_TOKEN(anon_sym_DOT2);
      if (lookahead == '.') ADVANCE(2484);
      END_STATE();
    case 2276:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 2277:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(554);
      if (lookahead == '0') ADVANCE(2513);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2516);
      END_STATE();
    case 2278:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(2583);
      END_STATE();
    case 2279:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(553);
      if (lookahead == '0') ADVANCE(2513);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2516);
      END_STATE();
    case 2280:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '0') ADVANCE(2513);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2516);
      END_STATE();
    case 2281:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '0') ADVANCE(2510);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2512);
      END_STATE();
    case 2282:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '=') ADVANCE(2200);
      END_STATE();
    case 2283:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      END_STATE();
    case 2284:
      ACCEPT_TOKEN(anon_sym_BSLASH_SLASH);
      END_STATE();
    case 2285:
      ACCEPT_TOKEN(anon_sym_BSLASH_QMARK);
      END_STATE();
    case 2286:
      ACCEPT_TOKEN(anon_sym_BSLASH_AMP);
      END_STATE();
    case 2287:
      ACCEPT_TOKEN(anon_sym_LTbuffer_GT);
      END_STATE();
    case 2288:
      ACCEPT_TOKEN(anon_sym_LTnowait_GT);
      END_STATE();
    case 2289:
      ACCEPT_TOKEN(anon_sym_LTsilent_GT);
      END_STATE();
    case 2290:
      ACCEPT_TOKEN(anon_sym_LTunique_GT);
      END_STATE();
    case 2291:
      ACCEPT_TOKEN(anon_sym_LTscript_GT);
      END_STATE();
    case 2292:
      ACCEPT_TOKEN(anon_sym_LTexpr_GT);
      END_STATE();
    case 2293:
      ACCEPT_TOKEN(sym__keycode_modifier);
      END_STATE();
    case 2294:
      ACCEPT_TOKEN(sym__keycode_modifier);
      ADVANCE_MAP(
        'C', 742,
        'c', 742,
        'D', 770,
        'd', 770,
        'F', 821,
        'f', 821,
        'L', 719,
        'l', 719,
        'R', 743,
        'r', 743,
        'U', 778,
        'u', 778,
      );
      END_STATE();
    case 2295:
      ACCEPT_TOKEN(sym__keycode_modifier);
      ADVANCE_MAP(
        'D', 770,
        'd', 770,
        'L', 719,
        'l', 719,
        'R', 743,
        'r', 743,
        'U', 778,
        'u', 778,
      );
      END_STATE();
    case 2296:
      ACCEPT_TOKEN(aux_sym__keycode_in_token1);
      END_STATE();
    case 2297:
      ACCEPT_TOKEN(aux_sym__keycode_in_token1);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2298:
      ACCEPT_TOKEN(aux_sym__keycode_in_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(700);
      END_STATE();
    case 2299:
      ACCEPT_TOKEN(aux_sym__keycode_in_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1045);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2300:
      ACCEPT_TOKEN(aux_sym__keycode_in_token3);
      END_STATE();
    case 2301:
      ACCEPT_TOKEN(aux_sym__keycode_in_token3);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2302:
      ACCEPT_TOKEN(aux_sym__keycode_in_token4);
      END_STATE();
    case 2303:
      ACCEPT_TOKEN(aux_sym__keycode_in_token4);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2304:
      ACCEPT_TOKEN(aux_sym__keycode_in_token5);
      END_STATE();
    case 2305:
      ACCEPT_TOKEN(aux_sym__keycode_in_token5);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2306:
      ACCEPT_TOKEN(aux_sym__keycode_in_token6);
      END_STATE();
    case 2307:
      ACCEPT_TOKEN(aux_sym__keycode_in_token6);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2308:
      ACCEPT_TOKEN(aux_sym__keycode_in_token7);
      END_STATE();
    case 2309:
      ACCEPT_TOKEN(aux_sym__keycode_in_token7);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2310:
      ACCEPT_TOKEN(aux_sym__keycode_in_token8);
      END_STATE();
    case 2311:
      ACCEPT_TOKEN(aux_sym__keycode_in_token8);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2312:
      ACCEPT_TOKEN(aux_sym__keycode_in_token9);
      END_STATE();
    case 2313:
      ACCEPT_TOKEN(aux_sym__keycode_in_token9);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2314:
      ACCEPT_TOKEN(aux_sym__keycode_in_token10);
      END_STATE();
    case 2315:
      ACCEPT_TOKEN(aux_sym__keycode_in_token10);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2316:
      ACCEPT_TOKEN(aux_sym__keycode_in_token11);
      END_STATE();
    case 2317:
      ACCEPT_TOKEN(aux_sym__keycode_in_token11);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2318:
      ACCEPT_TOKEN(aux_sym__keycode_in_token12);
      END_STATE();
    case 2319:
      ACCEPT_TOKEN(aux_sym__keycode_in_token12);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2320:
      ACCEPT_TOKEN(aux_sym__keycode_in_token13);
      END_STATE();
    case 2321:
      ACCEPT_TOKEN(aux_sym__keycode_in_token13);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2322:
      ACCEPT_TOKEN(aux_sym__keycode_in_token14);
      END_STATE();
    case 2323:
      ACCEPT_TOKEN(aux_sym__keycode_in_token14);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2324:
      ACCEPT_TOKEN(aux_sym__keycode_in_token15);
      END_STATE();
    case 2325:
      ACCEPT_TOKEN(aux_sym__keycode_in_token15);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2326:
      ACCEPT_TOKEN(aux_sym__keycode_in_token16);
      END_STATE();
    case 2327:
      ACCEPT_TOKEN(aux_sym__keycode_in_token16);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2328:
      ACCEPT_TOKEN(aux_sym__keycode_in_token17);
      END_STATE();
    case 2329:
      ACCEPT_TOKEN(aux_sym__keycode_in_token17);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2330:
      ACCEPT_TOKEN(aux_sym__keycode_in_token18);
      END_STATE();
    case 2331:
      ACCEPT_TOKEN(aux_sym__keycode_in_token18);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2332:
      ACCEPT_TOKEN(aux_sym__keycode_in_token19);
      END_STATE();
    case 2333:
      ACCEPT_TOKEN(aux_sym__keycode_in_token19);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2334:
      ACCEPT_TOKEN(aux_sym__keycode_in_token20);
      END_STATE();
    case 2335:
      ACCEPT_TOKEN(aux_sym__keycode_in_token20);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(771);
      END_STATE();
    case 2336:
      ACCEPT_TOKEN(aux_sym__keycode_in_token20);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1384);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2337:
      ACCEPT_TOKEN(aux_sym__keycode_in_token20);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2338:
      ACCEPT_TOKEN(aux_sym__keycode_in_token21);
      END_STATE();
    case 2339:
      ACCEPT_TOKEN(aux_sym__keycode_in_token21);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(777);
      END_STATE();
    case 2340:
      ACCEPT_TOKEN(aux_sym__keycode_in_token21);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1406);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2341:
      ACCEPT_TOKEN(aux_sym__keycode_in_token21);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2342:
      ACCEPT_TOKEN(aux_sym__keycode_in_token22);
      END_STATE();
    case 2343:
      ACCEPT_TOKEN(aux_sym__keycode_in_token22);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2344:
      ACCEPT_TOKEN(aux_sym__keycode_in_token23);
      END_STATE();
    case 2345:
      ACCEPT_TOKEN(aux_sym__keycode_in_token23);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2346:
      ACCEPT_TOKEN(aux_sym__keycode_in_token24);
      END_STATE();
    case 2347:
      ACCEPT_TOKEN(aux_sym__keycode_in_token24);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2346);
      END_STATE();
    case 2348:
      ACCEPT_TOKEN(aux_sym__keycode_in_token25);
      END_STATE();
    case 2349:
      ACCEPT_TOKEN(aux_sym__keycode_in_token25);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2350:
      ACCEPT_TOKEN(aux_sym__keycode_in_token26);
      END_STATE();
    case 2351:
      ACCEPT_TOKEN(aux_sym__keycode_in_token26);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2352:
      ACCEPT_TOKEN(aux_sym__keycode_in_token27);
      END_STATE();
    case 2353:
      ACCEPT_TOKEN(aux_sym__keycode_in_token27);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2354:
      ACCEPT_TOKEN(aux_sym__keycode_in_token28);
      END_STATE();
    case 2355:
      ACCEPT_TOKEN(aux_sym__keycode_in_token28);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2356:
      ACCEPT_TOKEN(aux_sym__keycode_in_token29);
      END_STATE();
    case 2357:
      ACCEPT_TOKEN(aux_sym__keycode_in_token29);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2358:
      ACCEPT_TOKEN(aux_sym__keycode_in_token30);
      END_STATE();
    case 2359:
      ACCEPT_TOKEN(aux_sym__keycode_in_token30);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2360:
      ACCEPT_TOKEN(aux_sym__keycode_in_token31);
      END_STATE();
    case 2361:
      ACCEPT_TOKEN(aux_sym__keycode_in_token31);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2362:
      ACCEPT_TOKEN(aux_sym__keycode_in_token32);
      END_STATE();
    case 2363:
      ACCEPT_TOKEN(aux_sym__keycode_in_token32);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2364:
      ACCEPT_TOKEN(aux_sym__keycode_in_token33);
      END_STATE();
    case 2365:
      ACCEPT_TOKEN(aux_sym__keycode_in_token33);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2366:
      ACCEPT_TOKEN(aux_sym__keycode_in_token34);
      END_STATE();
    case 2367:
      ACCEPT_TOKEN(aux_sym__keycode_in_token34);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2368:
      ACCEPT_TOKEN(aux_sym__keycode_in_token35);
      END_STATE();
    case 2369:
      ACCEPT_TOKEN(aux_sym__keycode_in_token35);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2370:
      ACCEPT_TOKEN(aux_sym__keycode_in_token36);
      END_STATE();
    case 2371:
      ACCEPT_TOKEN(aux_sym__keycode_in_token36);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2372:
      ACCEPT_TOKEN(aux_sym__keycode_in_token37);
      END_STATE();
    case 2373:
      ACCEPT_TOKEN(aux_sym__keycode_in_token37);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2374:
      ACCEPT_TOKEN(aux_sym__keycode_in_token38);
      END_STATE();
    case 2375:
      ACCEPT_TOKEN(aux_sym__keycode_in_token38);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2376:
      ACCEPT_TOKEN(aux_sym__keycode_in_token39);
      END_STATE();
    case 2377:
      ACCEPT_TOKEN(aux_sym__keycode_in_token40);
      END_STATE();
    case 2378:
      ACCEPT_TOKEN(aux_sym__keycode_in_token40);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2379:
      ACCEPT_TOKEN(aux_sym__keycode_in_token41);
      END_STATE();
    case 2380:
      ACCEPT_TOKEN(aux_sym__keycode_in_token41);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2381:
      ACCEPT_TOKEN(aux_sym__keycode_in_token42);
      END_STATE();
    case 2382:
      ACCEPT_TOKEN(aux_sym__keycode_in_token42);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2383:
      ACCEPT_TOKEN(aux_sym__keycode_in_token43);
      if (lookahead == '0') ADVANCE(2383);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(827);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(2385);
      if (('1' <= lookahead && lookahead <= '7')) ADVANCE(2384);
      END_STATE();
    case 2384:
      ACCEPT_TOKEN(aux_sym__keycode_in_token43);
      if (lookahead == '0') ADVANCE(2383);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(2385);
      if (('1' <= lookahead && lookahead <= '7')) ADVANCE(2384);
      END_STATE();
    case 2385:
      ACCEPT_TOKEN(aux_sym__keycode_in_token43);
      if (lookahead == '0') ADVANCE(2383);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2385);
      END_STATE();
    case 2386:
      ACCEPT_TOKEN(aux_sym__keycode_in_token43);
      if (lookahead == '0') ADVANCE(2386);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(827);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(2388);
      if (('1' <= lookahead && lookahead <= '7')) ADVANCE(2387);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(2388);
      END_STATE();
    case 2387:
      ACCEPT_TOKEN(aux_sym__keycode_in_token43);
      if (lookahead == '0') ADVANCE(2386);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(2388);
      if (('1' <= lookahead && lookahead <= '7')) ADVANCE(2387);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(2388);
      END_STATE();
    case 2388:
      ACCEPT_TOKEN(aux_sym__keycode_in_token43);
      if (lookahead == '0') ADVANCE(2386);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2388);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(2388);
      END_STATE();
    case 2389:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 2390:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(706);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(783);
      END_STATE();
    case 2391:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(3305);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(3306);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 2392:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(759);
      END_STATE();
    case 2393:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 2394:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 2395:
      ACCEPT_TOKEN(anon_sym_LT2);
      END_STATE();
    case 2396:
      ACCEPT_TOKEN(anon_sym_LT2);
      if (lookahead == '=') ADVANCE(2491);
      END_STATE();
    case 2397:
      ACCEPT_TOKEN(anon_sym_LT2);
      if (lookahead == '=') ADVANCE(2491);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(706);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(783);
      END_STATE();
    case 2398:
      ACCEPT_TOKEN(anon_sym_LT2);
      if (lookahead == 'b') ADVANCE(667);
      if (lookahead == 'e') ADVANCE(677);
      if (lookahead == 'n') ADVANCE(568);
      if (lookahead == 's') ADVANCE(351);
      if (lookahead == 'u') ADVANCE(548);
      END_STATE();
    case 2399:
      ACCEPT_TOKEN(anon_sym_LT2);
      if (lookahead == 'b') ADVANCE(667);
      if (lookahead == 'n') ADVANCE(568);
      if (lookahead == 's') ADVANCE(351);
      if (lookahead == 'u') ADVANCE(548);
      END_STATE();
    case 2400:
      ACCEPT_TOKEN(anon_sym_LT2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(759);
      END_STATE();
    case 2401:
      ACCEPT_TOKEN(anon_sym_BSLASH2);
      END_STATE();
    case 2402:
      ACCEPT_TOKEN(anon_sym_BSLASH2);
      if (lookahead == '|') ADVANCE(2406);
      END_STATE();
    case 2403:
      ACCEPT_TOKEN(aux_sym__map_lhs_token1);
      END_STATE();
    case 2404:
      ACCEPT_TOKEN(aux_sym__map_lhs_token1);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 2405:
      ACCEPT_TOKEN(aux_sym__map_rhs_statement_token1);
      END_STATE();
    case 2406:
      ACCEPT_TOKEN(anon_sym_BSLASH_PIPE);
      END_STATE();
    case 2407:
      ACCEPT_TOKEN(anon_sym_BSLASH_PIPE);
      if (lookahead == '\\') ADVANCE(2233);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(2232);
      END_STATE();
    case 2408:
      ACCEPT_TOKEN(anon_sym_BSLASH_PIPE);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 2409:
      ACCEPT_TOKEN(anon_sym_BSLASH_PIPE);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(2249);
      END_STATE();
    case 2410:
      ACCEPT_TOKEN(anon_sym_BSLASH_PIPE);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2411:
      ACCEPT_TOKEN(anon_sym_BSLASH_PIPE);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 2412:
      ACCEPT_TOKEN(anon_sym_BSLASH_PIPE);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(3057);
      END_STATE();
    case 2413:
      ACCEPT_TOKEN(anon_sym_BSLASH_PIPE);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(2243);
      END_STATE();
    case 2414:
      ACCEPT_TOKEN(aux_sym__map_rhs_statement_token2);
      END_STATE();
    case 2415:
      ACCEPT_TOKEN(aux_sym__map_rhs_statement_token2);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2416:
      ACCEPT_TOKEN(aux_sym__map_rhs_statement_token2);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 2417:
      ACCEPT_TOKEN(aux_sym__map_rhs_statement_token2);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(3057);
      END_STATE();
    case 2418:
      ACCEPT_TOKEN(aux_sym__map_rhs_statement_token3);
      END_STATE();
    case 2419:
      ACCEPT_TOKEN(aux_sym__map_rhs_statement_token3);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2420:
      ACCEPT_TOKEN(aux_sym__map_rhs_statement_token3);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 2421:
      ACCEPT_TOKEN(aux_sym__map_rhs_statement_token3);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(3057);
      END_STATE();
    case 2422:
      ACCEPT_TOKEN(aux_sym__map_rhs_token1);
      END_STATE();
    case 2423:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      END_STATE();
    case 2424:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == '-') ADVANCE(2293);
      END_STATE();
    case 2425:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == '-') ADVANCE(2293);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(750);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(816);
      END_STATE();
    case 2426:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == '-') ADVANCE(2293);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(805);
      END_STATE();
    case 2427:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == '-') ADVANCE(2295);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(698);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2304);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(744);
      END_STATE();
    case 2428:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == '-') ADVANCE(2294);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(713);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(701);
      END_STATE();
    case 2429:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(708);
      END_STATE();
    case 2430:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(737);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(809);
      END_STATE();
    case 2431:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(784);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2298);
      END_STATE();
    case 2432:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(795);
      END_STATE();
    case 2433:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      ADVANCE_MAP(
        'C', 774,
        'c', 774,
        'D', 722,
        'd', 722,
        'E', 764,
        'e', 764,
        'H', 773,
        'h', 773,
        'L', 732,
        'l', 732,
        'M', 745,
        'm', 745,
        'P', 699,
        'p', 699,
        'R', 749,
        'r', 749,
        'U', 778,
        'u', 778,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2376);
      END_STATE();
    case 2434:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(703);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(710);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2314);
      END_STATE();
    case 2435:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(755);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(762);
      END_STATE();
    case 2436:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(806);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(736);
      END_STATE();
    case 2437:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(767);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(798);
      END_STATE();
    case 2438:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2302);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(779);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(752);
      END_STATE();
    case 2439:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(712);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(751);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(709);
      END_STATE();
    case 2440:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(715);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2330);
      END_STATE();
    case 2441:
      ACCEPT_TOKEN(aux_sym__map_rhs_token2);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2347);
      END_STATE();
    case 2442:
      ACCEPT_TOKEN(anon_sym_icon);
      END_STATE();
    case 2443:
      ACCEPT_TOKEN(anon_sym_icon);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2444:
      ACCEPT_TOKEN(anon_sym_icon);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 2445:
      ACCEPT_TOKEN(anon_sym_linehl);
      END_STATE();
    case 2446:
      ACCEPT_TOKEN(anon_sym_linehl);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2447:
      ACCEPT_TOKEN(anon_sym_linehl);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 2448:
      ACCEPT_TOKEN(anon_sym_numhl);
      END_STATE();
    case 2449:
      ACCEPT_TOKEN(anon_sym_numhl);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2450:
      ACCEPT_TOKEN(anon_sym_numhl);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 2451:
      ACCEPT_TOKEN(anon_sym_text);
      if (lookahead == 'h') ADVANCE(1588);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2452:
      ACCEPT_TOKEN(anon_sym_text);
      if (lookahead == 'h') ADVANCE(494);
      END_STATE();
    case 2453:
      ACCEPT_TOKEN(anon_sym_text);
      if (lookahead == 'h') ADVANCE(3161);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 2454:
      ACCEPT_TOKEN(anon_sym_texthl);
      END_STATE();
    case 2455:
      ACCEPT_TOKEN(anon_sym_texthl);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2456:
      ACCEPT_TOKEN(anon_sym_texthl);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 2457:
      ACCEPT_TOKEN(anon_sym_culhl);
      END_STATE();
    case 2458:
      ACCEPT_TOKEN(anon_sym_culhl);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2459:
      ACCEPT_TOKEN(anon_sym_culhl);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 2460:
      ACCEPT_TOKEN(anon_sym_line);
      END_STATE();
    case 2461:
      ACCEPT_TOKEN(anon_sym_line);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2462:
      ACCEPT_TOKEN(anon_sym_name);
      END_STATE();
    case 2463:
      ACCEPT_TOKEN(anon_sym_name);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2464:
      ACCEPT_TOKEN(anon_sym_buffer);
      END_STATE();
    case 2465:
      ACCEPT_TOKEN(anon_sym_buffer);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2466:
      ACCEPT_TOKEN(anon_sym_group);
      END_STATE();
    case 2467:
      ACCEPT_TOKEN(anon_sym_group);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2468:
      ACCEPT_TOKEN(anon_sym_priority);
      END_STATE();
    case 2469:
      ACCEPT_TOKEN(anon_sym_priority);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2470:
      ACCEPT_TOKEN(anon_sym_file);
      END_STATE();
    case 2471:
      ACCEPT_TOKEN(anon_sym_file);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2472:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 2473:
      ACCEPT_TOKEN(anon_sym_STAR2);
      END_STATE();
    case 2474:
      ACCEPT_TOKEN(anon_sym_STAR2);
      if (lookahead == '=') ADVANCE(2202);
      END_STATE();
    case 2475:
      ACCEPT_TOKEN(anon_sym_POUND);
      END_STATE();
    case 2476:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == '{') ADVANCE(2582);
      END_STATE();
    case 2477:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 2478:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 2479:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 2480:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '0') ADVANCE(2510);
      if (lookahead == '>') ADVANCE(2521);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2512);
      END_STATE();
    case 2481:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '0') ADVANCE(2510);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(2512);
      END_STATE();
    case 2482:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(2201);
      if (lookahead == '>') ADVANCE(2521);
      END_STATE();
    case 2483:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '>') ADVANCE(2521);
      END_STATE();
    case 2484:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 2485:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      if (lookahead == '=') ADVANCE(2206);
      END_STATE();
    case 2486:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 2487:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 2488:
      ACCEPT_TOKEN(anon_sym_GT2);
      END_STATE();
    case 2489:
      ACCEPT_TOKEN(anon_sym_GT2);
      if (lookahead == '=') ADVANCE(2490);
      END_STATE();
    case 2490:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 2491:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 2492:
      ACCEPT_TOKEN(anon_sym_EQ_TILDE);
      END_STATE();
    case 2493:
      ACCEPT_TOKEN(anon_sym_BANG_TILDE);
      END_STATE();
    case 2494:
      ACCEPT_TOKEN(anon_sym_is);
      if (lookahead == 'n') ADVANCE(1595);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(2035);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2033);
      END_STATE();
    case 2495:
      ACCEPT_TOKEN(anon_sym_is);
      if (lookahead == 'n') ADVANCE(1032);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2496:
      ACCEPT_TOKEN(anon_sym_is);
      if (lookahead == 'n') ADVANCE(1012);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(1019);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1018);
      END_STATE();
    case 2497:
      ACCEPT_TOKEN(anon_sym_is);
      if (lookahead == 'n') ADVANCE(1596);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2498:
      ACCEPT_TOKEN(anon_sym_is);
      if (lookahead == 'n') ADVANCE(1013);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1019);
      END_STATE();
    case 2499:
      ACCEPT_TOKEN(anon_sym_is);
      if (lookahead == 'n') ADVANCE(564);
      END_STATE();
    case 2500:
      ACCEPT_TOKEN(anon_sym_isnot);
      END_STATE();
    case 2501:
      ACCEPT_TOKEN(anon_sym_isnot);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(2035);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2033);
      END_STATE();
    case 2502:
      ACCEPT_TOKEN(anon_sym_isnot);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9')) ADVANCE(1019);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1018);
      END_STATE();
    case 2503:
      ACCEPT_TOKEN(anon_sym_isnot);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1559);
      END_STATE();
    case 2504:
      ACCEPT_TOKEN(anon_sym_isnot);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2035);
      END_STATE();
    case 2505:
      ACCEPT_TOKEN(anon_sym_isnot);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1019);
      END_STATE();
    case 2506:
      ACCEPT_TOKEN(anon_sym_BANG2);
      END_STATE();
    case 2507:
      ACCEPT_TOKEN(anon_sym_BANG2);
      if (lookahead == '=') ADVANCE(2487);
      if (lookahead == '~') ADVANCE(2493);
      END_STATE();
    case 2508:
      ACCEPT_TOKEN(sym_float_literal);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(696);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2508);
      END_STATE();
    case 2509:
      ACCEPT_TOKEN(sym_float_literal);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2509);
      END_STATE();
    case 2510:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == '.') ADVANCE(822);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(819);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(826);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(2512);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(2511);
      END_STATE();
    case 2511:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == '.') ADVANCE(822);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(2512);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(2511);
      END_STATE();
    case 2512:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == '.') ADVANCE(822);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2512);
      END_STATE();
    case 2513:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(819);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(826);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(2516);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(2515);
      END_STATE();
    case 2514:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(2514);
      END_STATE();
    case 2515:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(2516);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(2515);
      END_STATE();
    case 2516:
      ACCEPT_TOKEN(sym_integer_literal);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(2516);
      END_STATE();
    case 2517:
      ACCEPT_TOKEN(sym_integer_literal);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(2517);
      END_STATE();
    case 2518:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 2519:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 2520:
      ACCEPT_TOKEN(anon_sym_LPAREN2);
      END_STATE();
    case 2521:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 2522:
      ACCEPT_TOKEN(aux_sym_filename_token1);
      END_STATE();
    case 2523:
      ACCEPT_TOKEN(aux_sym_filename_token1);
      if (lookahead == 'A') ADVANCE(280);
      END_STATE();
    case 2524:
      ACCEPT_TOKEN(aux_sym_filename_token1);
      if (lookahead == 'L') ADVANCE(284);
      END_STATE();
    case 2525:
      ACCEPT_TOKEN(aux_sym_filename_token1);
      if (lookahead == 'P') ADVANCE(289);
      END_STATE();
    case 2526:
      ACCEPT_TOKEN(aux_sym_filename_token1);
      if (lookahead == 'T') ADVANCE(279);
      END_STATE();
    case 2527:
      ACCEPT_TOKEN(aux_sym_filename_token1);
      if (lookahead == 'c') ADVANCE(563);
      END_STATE();
    case 2528:
      ACCEPT_TOKEN(aux_sym_filename_token1);
      if (lookahead == 'e') ADVANCE(676);
      END_STATE();
    case 2529:
      ACCEPT_TOKEN(aux_sym_filename_token1);
      if (lookahead == 'i') ADVANCE(543);
      END_STATE();
    case 2530:
      ACCEPT_TOKEN(aux_sym_filename_token1);
      if (lookahead == 'u') ADVANCE(498);
      END_STATE();
    case 2531:
      ACCEPT_TOKEN(aux_sym_filename_token1);
      if (lookahead == 'u') ADVANCE(518);
      END_STATE();
    case 2532:
      ACCEPT_TOKEN(aux_sym_filename_token2);
      END_STATE();
    case 2533:
      ACCEPT_TOKEN(aux_sym_filename_token3);
      END_STATE();
    case 2534:
      ACCEPT_TOKEN(aux_sym_filename_token4);
      END_STATE();
    case 2535:
      ACCEPT_TOKEN(aux_sym_filename_token5);
      END_STATE();
    case 2536:
      ACCEPT_TOKEN(aux_sym_filename_token5);
      if (lookahead == 'a') ADVANCE(517);
      END_STATE();
    case 2537:
      ACCEPT_TOKEN(aux_sym_filename_token5);
      if (lookahead == 'c') ADVANCE(563);
      END_STATE();
    case 2538:
      ACCEPT_TOKEN(aux_sym_filename_token5);
      if (lookahead == 'e') ADVANCE(676);
      END_STATE();
    case 2539:
      ACCEPT_TOKEN(aux_sym_filename_token5);
      if (lookahead == 'i') ADVANCE(504);
      END_STATE();
    case 2540:
      ACCEPT_TOKEN(aux_sym_filename_token5);
      if (lookahead == 'i') ADVANCE(543);
      END_STATE();
    case 2541:
      ACCEPT_TOKEN(aux_sym_filename_token5);
      if (lookahead == 'i') ADVANCE(555);
      END_STATE();
    case 2542:
      ACCEPT_TOKEN(aux_sym_filename_token5);
      if (lookahead == 'r') ADVANCE(559);
      END_STATE();
    case 2543:
      ACCEPT_TOKEN(aux_sym_filename_token5);
      if (lookahead == 'r') ADVANCE(471);
      END_STATE();
    case 2544:
      ACCEPT_TOKEN(aux_sym_filename_token5);
      if (lookahead == 'u') ADVANCE(432);
      END_STATE();
    case 2545:
      ACCEPT_TOKEN(aux_sym_filename_token5);
      if (lookahead == 'u') ADVANCE(498);
      END_STATE();
    case 2546:
      ACCEPT_TOKEN(aux_sym_filename_token5);
      if (lookahead == 'u') ADVANCE(518);
      END_STATE();
    case 2547:
      ACCEPT_TOKEN(aux_sym_filename_token6);
      END_STATE();
    case 2548:
      ACCEPT_TOKEN(aux_sym_filename_token7);
      END_STATE();
    case 2549:
      ACCEPT_TOKEN(aux_sym_filename_token7);
      if (lookahead == '|') ADVANCE(2406);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1010);
      END_STATE();
    case 2550:
      ACCEPT_TOKEN(aux_sym_filename_token7);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1010);
      END_STATE();
    case 2551:
      ACCEPT_TOKEN(aux_sym_filename_token8);
      END_STATE();
    case 2552:
      ACCEPT_TOKEN(aux_sym_pattern_multi_token1);
      END_STATE();
    case 2553:
      ACCEPT_TOKEN(aux_sym_pattern_multi_token2);
      END_STATE();
    case 2554:
      ACCEPT_TOKEN(aux_sym_pattern_multi_token3);
      END_STATE();
    case 2555:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token1);
      END_STATE();
    case 2556:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token1);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2556);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '\\' &&
          lookahead != ']') ADVANCE(2555);
      END_STATE();
    case 2557:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      END_STATE();
    case 2558:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == '*') ADVANCE(2473);
      if (lookahead == ',') ADVANCE(2251);
      if (lookahead == ';') ADVANCE(2268);
      if (lookahead == '<') ADVANCE(2573);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2558);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '[' &&
          lookahead != '\\') ADVANCE(2557);
      END_STATE();
    case 2559:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == '*') ADVANCE(2473);
      if (lookahead == ',') ADVANCE(2251);
      if (lookahead == ';') ADVANCE(2268);
      if (lookahead == '<') ADVANCE(2574);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2559);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '[' &&
          lookahead != '\\') ADVANCE(2557);
      END_STATE();
    case 2560:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == '*') ADVANCE(2473);
      if (lookahead == '<') ADVANCE(2573);
      if (lookahead == 'm') ADVANCE(2568);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2560);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '[' &&
          lookahead != '\\') ADVANCE(2557);
      END_STATE();
    case 2561:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == '*') ADVANCE(2473);
      if (lookahead == '<') ADVANCE(2573);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2561);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '[' &&
          lookahead != '\\') ADVANCE(2557);
      END_STATE();
    case 2562:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == '*') ADVANCE(2473);
      if (lookahead == '<') ADVANCE(2574);
      if (lookahead == 'm') ADVANCE(2568);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2562);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '[' &&
          lookahead != '\\') ADVANCE(2557);
      END_STATE();
    case 2563:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == '*') ADVANCE(2473);
      if (lookahead == '<') ADVANCE(2574);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2563);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '[' &&
          lookahead != '\\') ADVANCE(2557);
      END_STATE();
    case 2564:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == ',') ADVANCE(2251);
      if (lookahead == ';') ADVANCE(2268);
      if (lookahead == '<') ADVANCE(2575);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2564);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '[' &&
          lookahead != '\\') ADVANCE(2557);
      END_STATE();
    case 2565:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == ',') ADVANCE(2251);
      if (lookahead == ';') ADVANCE(2268);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2565);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '[' &&
          lookahead != '\\') ADVANCE(2557);
      END_STATE();
    case 2566:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == '<') ADVANCE(2575);
      if (lookahead == 'm') ADVANCE(2568);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2566);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '[' &&
          lookahead != '\\') ADVANCE(2557);
      END_STATE();
    case 2567:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == '<') ADVANCE(2575);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2567);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '[' &&
          lookahead != '\\') ADVANCE(2557);
      END_STATE();
    case 2568:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == 'a') ADVANCE(675);
      if (lookahead == 'i') ADVANCE(557);
      END_STATE();
    case 2569:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == 'g') ADVANCE(2571);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2569);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '[' &&
          lookahead != '\\') ADVANCE(2557);
      END_STATE();
    case 2570:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == 'm') ADVANCE(2568);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2570);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '[' &&
          lookahead != '\\') ADVANCE(2557);
      END_STATE();
    case 2571:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == 'r') ADVANCE(571);
      END_STATE();
    case 2572:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(2572);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '[' &&
          lookahead != '\\') ADVANCE(2557);
      END_STATE();
    case 2573:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == '!' ||
          lookahead == '=') ADVANCE(2553);
      END_STATE();
    case 2574:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == '!' ||
          lookahead == '=') ADVANCE(2553);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(706);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(783);
      END_STATE();
    case 2575:
      ACCEPT_TOKEN(aux_sym__pattern_ordinary_atom_token2);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(706);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(783);
      END_STATE();
    case 2576:
      ACCEPT_TOKEN(anon_sym_BSLASH_LPAREN);
      END_STATE();
    case 2577:
      ACCEPT_TOKEN(anon_sym_BSLASH_RPAREN);
      END_STATE();
    case 2578:
      ACCEPT_TOKEN(anon_sym_BSLASH_PERCENT_LPAREN);
      END_STATE();
    case 2579:
      ACCEPT_TOKEN(anon_sym_BSLASHz_LPAREN);
      END_STATE();
    case 2580:
      ACCEPT_TOKEN(sym_register);
      END_STATE();
    case 2581:
      ACCEPT_TOKEN(sym_literal_key);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2581);
      END_STATE();
    case 2582:
      ACCEPT_TOKEN(anon_sym_POUND_LBRACE);
      END_STATE();
    case 2583:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 2584:
      ACCEPT_TOKEN(aux_sym__plus_cmd_arg_token1);
      END_STATE();
    case 2585:
      ACCEPT_TOKEN(aux_sym__plus_cmd_arg_token1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(706);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(783);
      END_STATE();
    case 2586:
      ACCEPT_TOKEN(sym_au_event);
      END_STATE();
    case 2587:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1229);
      END_STATE();
    case 2588:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1776);
      END_STATE();
    case 2589:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2769);
      END_STATE();
    case 2590:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1328);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1393);
      END_STATE();
    case 2591:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1854);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1907);
      END_STATE();
    case 2592:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2847);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2900);
      END_STATE();
    case 2593:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1375);
      END_STATE();
    case 2594:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1894);
      END_STATE();
    case 2595:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2887);
      END_STATE();
    case 2596:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1286);
      END_STATE();
    case 2597:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1824);
      END_STATE();
    case 2598:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2817);
      END_STATE();
    case 2599:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2586);
      END_STATE();
    case 2600:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1454);
      END_STATE();
    case 2601:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1954);
      END_STATE();
    case 2602:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2949);
      END_STATE();
    case 2603:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2901);
      END_STATE();
    case 2604:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1394);
      END_STATE();
    case 2605:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1908);
      END_STATE();
    case 2606:
      ACCEPT_TOKEN(sym_au_event);
      if (lookahead == 'I' ||
          lookahead == 'P' ||
          lookahead == 'T' ||
          lookahead == 'i' ||
          lookahead == 'p' ||
          lookahead == 't') ADVANCE(2586);
      END_STATE();
    case 2607:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == '>') ADVANCE(2419);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2608:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == '>') ADVANCE(2415);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2609:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == '|') ADVANCE(2410);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2610:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2644);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2941);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2611:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(3014);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2612:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2885);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2613:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      ADVANCE_MAP(
        'A', 2751,
        'a', 2751,
        'E', 2615,
        'e', 2615,
        'H', 2699,
        'h', 2699,
        'I', 2760,
        'i', 2760,
        'O', 3012,
        'o', 3012,
        'P', 2733,
        'p', 2733,
        'T', 2685,
        't', 2685,
        'W', 2616,
        'w', 2616,
        'Y', 2861,
        'y', 2861,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2614:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(3021);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2615:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2943);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2966);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2616:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2921);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2617:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      ADVANCE_MAP(
        'A', 2678,
        'a', 2678,
        'C', 2955,
        'c', 2955,
        'D', 2749,
        'd', 2749,
        'E', 2880,
        'e', 2880,
        'F', 2811,
        'f', 2811,
        'H', 2795,
        'h', 2795,
        'L', 2712,
        'l', 2712,
        'M', 2894,
        'm', 2894,
        'N', 2695,
        'n', 2695,
        'R', 2713,
        'r', 2713,
        'U', 2879,
        'u', 2879,
        'W', 2788,
        'w', 2788,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2618:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2669);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2619:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2997);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2735);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2891);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2620:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2858);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2621:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2822);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2622:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      ADVANCE_MAP(
        'A', 2930,
        'a', 2930,
        'C', 2777,
        'c', 2777,
        'E', 2889,
        'e', 2889,
        'R', 2739,
        'r', 2739,
        'T', 3025,
        't', 3025,
        'W', 2954,
        'w', 2954,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2623:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2675);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2624:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2653);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2625:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2673);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2626:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2686);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2627:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2680);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2628:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2860);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2629:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2863);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2630:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2940);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2631:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2762);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2755);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2645);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2632:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(3015);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2633:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2878);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2634:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2992);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2635:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2881);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2636:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2884);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2637:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2996);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2638:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2995);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2639:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2812);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2640:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2807);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2641:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2813);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2642:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(2933);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2643:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(2630);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2936);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2644:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(2655);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2645:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2776);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2646:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2819);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2927);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2647:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      ADVANCE_MAP(
        'C', 2778,
        'c', 2778,
        'E', 2880,
        'e', 2880,
        'L', 2712,
        'l', 2712,
        'O', 2924,
        'o', 2924,
        'R', 2741,
        'r', 2741,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2648:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2911);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2649:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2772);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2650:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2848);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2796);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2651:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2775);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2652:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(3004);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2653:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2770);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2654:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(3009);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2655:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      ADVANCE_MAP(
        'C', 2830,
        'c', 2830,
        'E', 2880,
        'e', 2880,
        'L', 2712,
        'l', 2712,
        'N', 2700,
        'n', 2700,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2656:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      ADVANCE_MAP(
        'C', 2830,
        'c', 2830,
        'E', 2880,
        'e', 2880,
        'L', 2712,
        'l', 2712,
        'N', 2704,
        'n', 2704,
        'R', 2736,
        'r', 2736,
        'S', 2657,
        's', 2657,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2657:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2947);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2658:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2697);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2659:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2893);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(2892);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2660:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2773);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2880);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2738);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2661:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2847);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2900);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2662:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2849);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2663:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2666);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2664:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2779);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2907);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2665:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2779);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2880);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2712);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2666:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2779);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2667:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2780);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(2629);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2668:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(2914);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2669:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2586);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2670:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2599);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2671:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2606);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2672:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2841);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2673:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2661);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2674:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2948);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2675:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2592);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2676:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2602);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2677:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2748);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2678:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2669);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2679:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2634);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2680:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2918);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2681:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2814);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2682:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2729);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2683:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2711);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2684:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2973);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2685:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2801);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2686:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2928);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2687:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2682);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2688:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2806);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2689:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2808);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2690:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2809);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2691:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(2638);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2692:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2586);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2693:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2659);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2694:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2622);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2720);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2695:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(3018);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2696:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(3023);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2697:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2661);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2698:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2664);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2699:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2827);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2700:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(3019);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2701:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2592);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2702:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2589);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2703:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2866);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2677);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2704:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(3017);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2705:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2937);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2706:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2602);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2707:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2669);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2708:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2850);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2709:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2946);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2710:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2977);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2711:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2756);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2712:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2611);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2713:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2623);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2714:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2880);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2641);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2715:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2880);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2712);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2716:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      ADVANCE_MAP(
        'E', 2880,
        'e', 2880,
        'L', 2738,
        'l', 2738,
        'R', 2717,
        'r', 2717,
        'S', 3011,
        's', 3011,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2717:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2962);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2718:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2634);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2719:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2980);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2720:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2939);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2721:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2918);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2722:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2896);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2723:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2953);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2724:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2670);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2725:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2676);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2726:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2684);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2727:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2674);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2728:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2671);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2729:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2853);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2730:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2871);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2731:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2868);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2732:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2665);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2733:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2828);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2734:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2923);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2735:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2987);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2736:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2970);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2737:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2852);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2738:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2632);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2739:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2625);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2740:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2994);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2741:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2968);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2742:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2951);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2743:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2627);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2744:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2992);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2745:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2832);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2746:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2950);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2747:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2888);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2748:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2666);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2749:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(2844);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2750:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2617);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2751:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2710);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2752:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2792);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2753:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2890);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2754:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2810);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2755:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(3007);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2756:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2812);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2757:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(2815);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2758:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2586);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2759:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2715);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2760:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2865);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2761:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2639);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2901);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2762:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2870);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2763:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2692);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2764:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2707);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2765:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2725);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2766:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2727);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2767:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2728);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2768:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2666);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2769:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(2640);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2770:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(2586);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2771:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      ADVANCE_MAP(
        'H', 2620,
        'h', 2620,
        'M', 2672,
        'm', 2672,
        'O', 2823,
        'o', 2823,
        'U', 2942,
        'u', 2942,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2772:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(3020);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2773:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(2612);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2774:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(2899);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(2904);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2775:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(2737);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2776:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(2628);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2777:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(2633);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2778:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(2635);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2908);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2779:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(2635);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2780:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(2636);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2781:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(2745);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2782:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2631);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2783:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2824);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2652);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2877);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2784:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2715);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2705);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2785:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2845);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2786:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2714);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2787:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2646);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2788:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2855);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2797);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2789:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(3026);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2851);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2790:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(3026);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2791:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2984);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2792:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(3022);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2793:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2857);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2794:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2910);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2795:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2687);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2796:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2843);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2797:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2993);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2798:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2912);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2799:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2663);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2800:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2967);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2801:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2886);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2802:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2867);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2924);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2803:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2969);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2804:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2872);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2805:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2856);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2806:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2862);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2807:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2853);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2808:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2864);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2809:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2869);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2810:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2726);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2811:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2835);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2812:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2873);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2813:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2838);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2814:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2754);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2815:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2839);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2816:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2989);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2817:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2837);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2818:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(2990);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2819:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(2752);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2820:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(2747);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2821:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(2928);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2822:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2586);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2823:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2903);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(2919);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2824:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2694);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2825:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2650);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2826:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(3024);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2827:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2825);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2828:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2840);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2829:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2603);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2830:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2905);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2831:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2902);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2832:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2829);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2833:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2740);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2834:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2670);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2835:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2721);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2836:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2909);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2837:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2692);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2838:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2707);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2839:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2708);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2840:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2757);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2841:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2804);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2876);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(2805);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2842:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2838);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2843:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2999);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2844:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(2744);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2845:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(2716);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2846:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(2647);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2847:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(2669);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2848:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(2686);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2849:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(2680);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2850:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(2803);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2851:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(2692);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2852:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(2706);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2853:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2586);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2854:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2648);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(2791);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2855:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2715);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2722);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2856:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2715);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2857:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2656);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2858:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2802);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2859:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2975);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2860:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2765);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2861:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2985);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2862:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2768);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2863:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2821);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2864:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2759);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2865:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2621);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2866:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(3006);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2867:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2753);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2868:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2669);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2869:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2758);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2870:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2897);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2871:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2673);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2872:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2732);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2873:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2707);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2874:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2706);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2875:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2973);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2876:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2683);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2877:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2654);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2878:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2766);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2879:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2831);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2880:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2983);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2881:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2764);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2882:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2836);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2883:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2971);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2884:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2767);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2885:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2763);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2927);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2886:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2957);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2887:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(3000);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2888:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(3013);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2889:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(2668);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2890:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2586);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2891:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2820);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2892:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2998);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2893:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2959);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2894:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2681);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2895:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2938);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2896:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(3008);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2897:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2974);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2898:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2931);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2899:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2834);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2900:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2965);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2692);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2901:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2965);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2902:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2618);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2903:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2945);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2904:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(3016);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2905:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2972);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2906:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2842);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2907:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2874);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2908:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2971);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2909:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2626);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2910:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2875);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2911:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2688);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2912:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2882);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2913:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2883);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2914:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(2690);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2915:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2586);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2916:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2986);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2917:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2619);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2918:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2900);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2919:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2833);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2920:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2898);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2921:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2696);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2922:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2691);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2923:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2826);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2924:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2729);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2925:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2692);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2926:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2707);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2927:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2949);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2928:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2901);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2929:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2730);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2930:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2929);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2931:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(3010);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2932:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2731);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2933:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2926);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2934:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2679);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2935:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(2913);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2936:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2607);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2937:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2586);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2938:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2774);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2939:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2956);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2940:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2608);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2941:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2846);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(2981);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2942:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2976);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2943:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2649);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2944:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2658);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2945:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2964);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2946:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2982);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2947:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2906);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2948:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2890);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2781);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2949:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2692);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2950:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2707);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2951:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2734);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2952:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2642);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2953:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2928);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2954:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2816);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2955:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2718);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2956:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2743);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(2958);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2957:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2743);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2958:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2818);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2959:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(2689);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2960:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2586);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2961:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2761);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2962:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2789);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2963:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2917);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2964:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2651);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2965:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2980);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2966:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2798);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2967:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2988);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2968:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2935);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2969:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2979);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2970:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2790);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2971:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2692);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2972:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2707);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2973:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2719);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2974:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2991);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2975:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2709);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2976:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2895);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2977:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(3001);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2978:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2932);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2979:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(2809);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2980:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2586);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2981:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2667);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2982:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2660);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2983:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2705);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2984:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2927);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2985:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2614);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2986:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2794);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2987:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2624);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2988:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2960);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2989:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2697);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2990:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2721);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2991:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2799);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2992:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2692);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2993:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2701);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2994:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2698);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2995:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2707);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2996:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2702);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2997:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2987);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2998:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2742);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 2999:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2723);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3000:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2746);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3001:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(2637);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3002:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2750);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3003:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2786);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3004:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2961);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3005:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2787);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3006:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2920);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3007:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2922);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3008:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2980);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3009:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2876);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3010:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2915);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3011:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2978);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3012:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2944);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3013:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(2934);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3014:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(2692);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3015:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(2706);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3016:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(2724);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3017:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(2586);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3018:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(2598);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3019:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(2595);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3020:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(2952);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3021:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(2586);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3022:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(2662);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3023:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(2800);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3024:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(2586);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3025:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(2925);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3026:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(2707);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3027:
      ACCEPT_TOKEN(aux_sym__autocmd_pattern_token1);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ' &&
          lookahead != ',') ADVANCE(3027);
      END_STATE();
    case 3028:
      ACCEPT_TOKEN(sym_au_once);
      END_STATE();
    case 3029:
      ACCEPT_TOKEN(sym_au_nested);
      END_STATE();
    case 3030:
      ACCEPT_TOKEN(sym_command_name);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3030);
      END_STATE();
    case 3031:
      ACCEPT_TOKEN(anon_sym_filetype);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3032:
      ACCEPT_TOKEN(anon_sym_syntax);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3033:
      ACCEPT_TOKEN(anon_sym_user);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3034:
      ACCEPT_TOKEN(anon_sym_COMMA2);
      END_STATE();
    case 3035:
      ACCEPT_TOKEN(aux_sym__command_attribute_nargs_value_token1);
      END_STATE();
    case 3036:
      ACCEPT_TOKEN(aux_sym__command_attribute_nargs_value_token2);
      END_STATE();
    case 3037:
      ACCEPT_TOKEN(anon_sym_PERCENT2);
      END_STATE();
    case 3038:
      ACCEPT_TOKEN(anon_sym_DASHnargs);
      END_STATE();
    case 3039:
      ACCEPT_TOKEN(anon_sym_DASHcomplete);
      END_STATE();
    case 3040:
      ACCEPT_TOKEN(anon_sym_DASHrange);
      END_STATE();
    case 3041:
      ACCEPT_TOKEN(anon_sym_DASHcount);
      END_STATE();
    case 3042:
      ACCEPT_TOKEN(anon_sym_DASHaddr);
      END_STATE();
    case 3043:
      ACCEPT_TOKEN(anon_sym_DASHbang);
      END_STATE();
    case 3044:
      ACCEPT_TOKEN(anon_sym_DASHbar);
      END_STATE();
    case 3045:
      ACCEPT_TOKEN(anon_sym_DASHregister);
      END_STATE();
    case 3046:
      ACCEPT_TOKEN(anon_sym_DASHbuffer);
      END_STATE();
    case 3047:
      ACCEPT_TOKEN(anon_sym_DASHkeepscript);
      END_STATE();
    case 3048:
      ACCEPT_TOKEN(aux_sym_command_statement_token1);
      if (lookahead == '<') ADVANCE(3054);
      if (lookahead == '\\') ADVANCE(3051);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(3048);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(3057);
      END_STATE();
    case 3049:
      ACCEPT_TOKEN(aux_sym_command_statement_token1);
      if (lookahead == '>') ADVANCE(2421);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(3057);
      END_STATE();
    case 3050:
      ACCEPT_TOKEN(aux_sym_command_statement_token1);
      if (lookahead == '>') ADVANCE(2417);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(3057);
      END_STATE();
    case 3051:
      ACCEPT_TOKEN(aux_sym_command_statement_token1);
      if (lookahead == '|') ADVANCE(2412);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(3057);
      END_STATE();
    case 3052:
      ACCEPT_TOKEN(aux_sym_command_statement_token1);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(3052);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(3057);
      END_STATE();
    case 3053:
      ACCEPT_TOKEN(aux_sym_command_statement_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(3056);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(3057);
      END_STATE();
    case 3054:
      ACCEPT_TOKEN(aux_sym_command_statement_token1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(3053);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(3055);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(3057);
      END_STATE();
    case 3055:
      ACCEPT_TOKEN(aux_sym_command_statement_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(3049);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(3057);
      END_STATE();
    case 3056:
      ACCEPT_TOKEN(aux_sym_command_statement_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(3050);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(3057);
      END_STATE();
    case 3057:
      ACCEPT_TOKEN(aux_sym_command_statement_token1);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(3057);
      END_STATE();
    case 3058:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3236);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3059:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3260);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3060:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3218);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3061:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3220);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3062:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3177);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3063:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3135);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3064:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3157);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3065:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3196);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3066:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3259);
      if (lookahead == 'i') ADVANCE(3198);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3067:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3138);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3068:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3227);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3069:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3225);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3070:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3226);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3071:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3222);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3072:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3153);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3073:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3155);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3074:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'a') ADVANCE(3141);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3075:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'c') ADVANCE(3125);
      if (lookahead == 'o') ADVANCE(3181);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3076:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'c') ADVANCE(3125);
      if (lookahead == 'o') ADVANCE(3197);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3077:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'c') ADVANCE(3124);
      if (lookahead == 'o') ADVANCE(3176);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3078:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'c') ADVANCE(3131);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3079:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'c') ADVANCE(3151);
      if (lookahead == 't') ADVANCE(3107);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3080:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'c') ADVANCE(3110);
      if (lookahead == 't') ADVANCE(3063);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3081:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'c') ADVANCE(3203);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3082:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'c') ADVANCE(3111);
      if (lookahead == 't') ADVANCE(3067);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3083:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'c') ADVANCE(3119);
      if (lookahead == 't') ADVANCE(3067);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3084:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'd') ADVANCE(3492);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3085:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'd') ADVANCE(3411);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3086:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'd') ADVANCE(3417);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3087:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'd') ADVANCE(3420);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3088:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'd') ADVANCE(3373);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3089:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'd') ADVANCE(3372);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3090:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'd') ADVANCE(3434);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3091:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'd') ADVANCE(3231);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3092:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'd') ADVANCE(3113);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3093:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'd') ADVANCE(3090);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3094:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3257);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3095:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3171);
      if (lookahead == 'n') ADVANCE(3152);
      if (lookahead == 'w') ADVANCE(3127);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3096:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3429);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3097:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3394);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3098:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3256);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3099:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3169);
      if (lookahead == 'n') ADVANCE(3156);
      if (lookahead == 'w') ADVANCE(3126);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3100:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3089);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3101:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3392);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3102:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3436);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3103:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3217);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3104:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3103);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3105:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3163);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3106:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3170);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3107:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3185);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3108:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3232);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3109:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3186);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3110:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3064);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3111:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3072);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3112:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3233);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3113:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3190);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3114:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3088);
      if (lookahead == 's') ADVANCE(3408);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3115:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3188);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3116:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3071);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3117:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3258);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3118:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3187);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3119:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3073);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3120:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'e') ADVANCE(3130);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3121:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'g') ADVANCE(3223);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3122:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'g') ADVANCE(3221);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3123:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'g') ADVANCE(3228);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3124:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'h') ADVANCE(3061);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3125:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'h') ADVANCE(3060);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3126:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'h') ADVANCE(3136);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3127:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'h') ADVANCE(3137);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3128:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'h') ADVANCE(3158);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3129:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'h') ADVANCE(3159);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3130:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'h') ADVANCE(3160);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3131:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'h') ADVANCE(3123);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3132:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'i') ADVANCE(3229);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3133:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'i') ADVANCE(3210);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3134:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'i') ADVANCE(3206);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3135:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'i') ADVANCE(3183);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3136:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'i') ADVANCE(3245);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3137:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'i') ADVANCE(3246);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3138:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'i') ADVANCE(3174);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3139:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'i') ADVANCE(3209);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3140:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'i') ADVANCE(3180);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3141:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'i') ADVANCE(3182);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3142:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'i') ADVANCE(3191);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3143:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'i') ADVANCE(3193);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3144:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'i') ADVANCE(3194);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3145:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'i') ADVANCE(3195);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3146:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'k') ADVANCE(3133);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3147:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'k') ADVANCE(3265);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3148:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'k') ADVANCE(3134);
      if (lookahead == 't') ADVANCE(3070);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3149:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'k') ADVANCE(3134);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3150:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'k') ADVANCE(3139);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3151:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(3249);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3152:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(3399);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3153:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(3360);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3154:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(3423);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3155:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(3364);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3156:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(3397);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3157:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(3362);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3158:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(2459);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3159:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(2450);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3160:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(2447);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3161:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(2456);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3162:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(3085);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3163:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(3142);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3164:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(3128);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3165:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(3059);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3166:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(3116);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3167:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(3144);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3168:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'l') ADVANCE(3145);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3169:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'm') ADVANCE(3212);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3170:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'm') ADVANCE(3201);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3171:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'm') ADVANCE(3213);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3172:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'm') ADVANCE(3129);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3173:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3084);
      if (lookahead == 'x') ADVANCE(3079);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3174:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3114);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3175:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3379);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3176:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3080);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3177:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3234);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3178:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3377);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3179:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(2444);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3180:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3147);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3181:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3082);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3182:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3230);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3183:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3100);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3184:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3105);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3185:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3086);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3186:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3242);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3187:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3087);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3188:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3238);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3189:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3091);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3190:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3154);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3191:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3096);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3192:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3247);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3193:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3120);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3194:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3108);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3195:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3112);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3196:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3235);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3197:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3083);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3198:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'n') ADVANCE(3168);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3199:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'o') ADVANCE(3162);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3200:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'o') ADVANCE(3250);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3201:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'o') ADVANCE(3254);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3202:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'o') ADVANCE(3251);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3203:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'o') ADVANCE(3179);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3204:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'o') ADVANCE(3192);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3205:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'o') ADVANCE(3252);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3206:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'p') ADVANCE(3095);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3207:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'p') ADVANCE(3384);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3208:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'p') ADVANCE(3426);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3209:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'p') ADVANCE(3488);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3210:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'p') ADVANCE(3099);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3211:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'p') ADVANCE(3382);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3212:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'p') ADVANCE(3241);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3213:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'p') ADVANCE(3244);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3214:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'p') ADVANCE(3165);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3215:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'p') ADVANCE(3069);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3216:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'p') ADVANCE(3068);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3217:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'p') ADVANCE(3118);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3218:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'r') ADVANCE(3369);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3219:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'r') ADVANCE(3062);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3220:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'r') ADVANCE(3367);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3221:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'r') ADVANCE(3200);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3222:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'r') ADVANCE(3267);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3223:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'r') ADVANCE(3202);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3224:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'r') ADVANCE(3065);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3225:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'r') ADVANCE(3109);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3226:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'r') ADVANCE(3239);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3227:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'r') ADVANCE(3115);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3228:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'r') ADVANCE(3205);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3229:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 's') ADVANCE(3214);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3230:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 's') ADVANCE(3408);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3231:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 's') ADVANCE(3432);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3232:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 's') ADVANCE(3499);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3233:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 's') ADVANCE(3496);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3234:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 's') ADVANCE(3215);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3235:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 's') ADVANCE(3216);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3236:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 't') ADVANCE(3078);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3237:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 't') ADVANCE(3121);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3238:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 't') ADVANCE(3389);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3239:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 't') ADVANCE(3310);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3240:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 't') ADVANCE(3122);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3241:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 't') ADVANCE(3262);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3242:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 't') ADVANCE(3387);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3243:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 't') ADVANCE(2453);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3244:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 't') ADVANCE(3261);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3245:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 't') ADVANCE(3101);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3246:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 't') ADVANCE(3097);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3247:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 't') ADVANCE(3074);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3248:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'u') ADVANCE(3172);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3249:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'u') ADVANCE(3092);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3250:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'u') ADVANCE(3211);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3251:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'u') ADVANCE(3207);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3252:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'u') ADVANCE(3208);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3253:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'u') ADVANCE(3164);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3254:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'v') ADVANCE(3102);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3255:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'x') ADVANCE(3079);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3256:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'x') ADVANCE(3240);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3257:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'x') ADVANCE(3237);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3258:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'x') ADVANCE(3243);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3259:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'x') ADVANCE(3167);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3260:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'y') ADVANCE(3414);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3261:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'y') ADVANCE(3404);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3262:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == 'y') ADVANCE(3402);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3263:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3264:
      ACCEPT_TOKEN(sym_hl_group);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3265:
      ACCEPT_TOKEN(anon_sym_link);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3266:
      ACCEPT_TOKEN(anon_sym_clear);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3267:
      ACCEPT_TOKEN(anon_sym_clear);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3268:
      ACCEPT_TOKEN(anon_sym_clear);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 3269:
      ACCEPT_TOKEN(anon_sym_NONE);
      END_STATE();
    case 3270:
      ACCEPT_TOKEN(anon_sym_NONE2);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(2199);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3329);
      END_STATE();
    case 3271:
      ACCEPT_TOKEN(anon_sym_NONE2);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3339);
      END_STATE();
    case 3272:
      ACCEPT_TOKEN(anon_sym_NONE2);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3273:
      ACCEPT_TOKEN(anon_sym_term);
      END_STATE();
    case 3274:
      ACCEPT_TOKEN(anon_sym_term);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3275:
      ACCEPT_TOKEN(anon_sym_cterm);
      if (lookahead == 'b') ADVANCE(3285);
      if (lookahead == 'f') ADVANCE(3286);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3276:
      ACCEPT_TOKEN(anon_sym_cterm);
      if (lookahead == 'b') ADVANCE(442);
      if (lookahead == 'f') ADVANCE(443);
      END_STATE();
    case 3277:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == '>') ADVANCE(3307);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3278:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'a') ADVANCE(3298);
      if (lookahead == 'o') ADVANCE(3294);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3279:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'd') ADVANCE(3343);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3280:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'e') ADVANCE(3296);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3281:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'e') ADVANCE(3291);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3282:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'e') ADVANCE(3297);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3283:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'g') ADVANCE(3333);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3284:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'g') ADVANCE(3331);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3285:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'g') ADVANCE(3319);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3286:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'g') ADVANCE(3317);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3287:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'i') ADVANCE(3320);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3288:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'l') ADVANCE(3281);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3289:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'm') ADVANCE(3274);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3290:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'm') ADVANCE(3275);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3291:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'n') ADVANCE(3279);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3292:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'n') ADVANCE(3300);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3293:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'o') ADVANCE(3292);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3294:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'p') ADVANCE(3313);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3295:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'p') ADVANCE(3335);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3296:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'r') ADVANCE(3289);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3297:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'r') ADVANCE(3290);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3298:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'r') ADVANCE(3301);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3299:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 't') ADVANCE(3278);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3300:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 't') ADVANCE(3341);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3301:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 't') ADVANCE(3311);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3302:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 't') ADVANCE(3282);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3303:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'u') ADVANCE(3287);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3304:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == '|') ADVANCE(2408);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3305:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(3306);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3306:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(3277);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3307:
      ACCEPT_TOKEN(aux_sym__hl_term_list_token1);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3308:
      ACCEPT_TOKEN(anon_sym_start);
      END_STATE();
    case 3309:
      ACCEPT_TOKEN(anon_sym_start);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3310:
      ACCEPT_TOKEN(anon_sym_start);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3311:
      ACCEPT_TOKEN(anon_sym_start);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3312:
      ACCEPT_TOKEN(anon_sym_stop);
      END_STATE();
    case 3313:
      ACCEPT_TOKEN(anon_sym_stop);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3314:
      ACCEPT_TOKEN(sym__hl_color_nr);
      END_STATE();
    case 3315:
      ACCEPT_TOKEN(sym__hl_color_nr);
      if (lookahead == '*') ADVANCE(3314);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(3315);
      END_STATE();
    case 3316:
      ACCEPT_TOKEN(anon_sym_ctermfg);
      END_STATE();
    case 3317:
      ACCEPT_TOKEN(anon_sym_ctermfg);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3318:
      ACCEPT_TOKEN(anon_sym_ctermbg);
      END_STATE();
    case 3319:
      ACCEPT_TOKEN(anon_sym_ctermbg);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3320:
      ACCEPT_TOKEN(anon_sym_gui);
      if (lookahead == 'b') ADVANCE(3283);
      if (lookahead == 'f') ADVANCE(3284);
      if (lookahead == 's') ADVANCE(3295);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3321:
      ACCEPT_TOKEN(anon_sym_gui);
      if (lookahead == 'b') ADVANCE(440);
      if (lookahead == 'f') ADVANCE(441);
      if (lookahead == 's') ADVANCE(575);
      END_STATE();
    case 3322:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 3323:
      ACCEPT_TOKEN(aux_sym__hl_quoted_name_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\'') ADVANCE(3323);
      END_STATE();
    case 3324:
      ACCEPT_TOKEN(anon_sym_SQUOTE2);
      END_STATE();
    case 3325:
      ACCEPT_TOKEN(aux_sym_color_token1);
      END_STATE();
    case 3326:
      ACCEPT_TOKEN(aux_sym_color_token2);
      if (lookahead == 'E') ADVANCE(3270);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(2199);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3329);
      END_STATE();
    case 3327:
      ACCEPT_TOKEN(aux_sym_color_token2);
      if (lookahead == 'N') ADVANCE(3326);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(2199);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3329);
      END_STATE();
    case 3328:
      ACCEPT_TOKEN(aux_sym_color_token2);
      if (lookahead == 'O') ADVANCE(3327);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(2199);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3329);
      END_STATE();
    case 3329:
      ACCEPT_TOKEN(aux_sym_color_token2);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(2199);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3329);
      END_STATE();
    case 3330:
      ACCEPT_TOKEN(anon_sym_guifg);
      END_STATE();
    case 3331:
      ACCEPT_TOKEN(anon_sym_guifg);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3332:
      ACCEPT_TOKEN(anon_sym_guibg);
      END_STATE();
    case 3333:
      ACCEPT_TOKEN(anon_sym_guibg);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3334:
      ACCEPT_TOKEN(anon_sym_guisp);
      END_STATE();
    case 3335:
      ACCEPT_TOKEN(anon_sym_guisp);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3336:
      ACCEPT_TOKEN(aux_sym_font_token1);
      if (lookahead == 'E') ADVANCE(3271);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3339);
      END_STATE();
    case 3337:
      ACCEPT_TOKEN(aux_sym_font_token1);
      if (lookahead == 'N') ADVANCE(3336);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3339);
      END_STATE();
    case 3338:
      ACCEPT_TOKEN(aux_sym_font_token1);
      if (lookahead == 'O') ADVANCE(3337);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3339);
      END_STATE();
    case 3339:
      ACCEPT_TOKEN(aux_sym_font_token1);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3339);
      END_STATE();
    case 3340:
      ACCEPT_TOKEN(anon_sym_font);
      END_STATE();
    case 3341:
      ACCEPT_TOKEN(anon_sym_font);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3342:
      ACCEPT_TOKEN(anon_sym_blend);
      END_STATE();
    case 3343:
      ACCEPT_TOKEN(anon_sym_blend);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != ' ') ADVANCE(3307);
      END_STATE();
    case 3344:
      ACCEPT_TOKEN(aux_sym__syn_iskeyword_token1);
      if (lookahead == '\t') ADVANCE(3344);
      if (lookahead == '<') ADVANCE(3354);
      if (lookahead == '\\') ADVANCE(3352);
      if (lookahead == 'c') ADVANCE(3350);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 3345:
      ACCEPT_TOKEN(aux_sym__syn_iskeyword_token1);
      if (lookahead == '\t') ADVANCE(3345);
      if (lookahead == 'c') ADVANCE(3350);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 3346:
      ACCEPT_TOKEN(aux_sym__syn_iskeyword_token1);
      if (lookahead == '>') ADVANCE(2420);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 3347:
      ACCEPT_TOKEN(aux_sym__syn_iskeyword_token1);
      if (lookahead == '>') ADVANCE(2416);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 3348:
      ACCEPT_TOKEN(aux_sym__syn_iskeyword_token1);
      if (lookahead == 'a') ADVANCE(3351);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 3349:
      ACCEPT_TOKEN(aux_sym__syn_iskeyword_token1);
      if (lookahead == 'e') ADVANCE(3348);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 3350:
      ACCEPT_TOKEN(aux_sym__syn_iskeyword_token1);
      if (lookahead == 'l') ADVANCE(3349);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 3351:
      ACCEPT_TOKEN(aux_sym__syn_iskeyword_token1);
      if (lookahead == 'r') ADVANCE(3268);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 3352:
      ACCEPT_TOKEN(aux_sym__syn_iskeyword_token1);
      if (lookahead == '|') ADVANCE(2411);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 3353:
      ACCEPT_TOKEN(aux_sym__syn_iskeyword_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(3356);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 3354:
      ACCEPT_TOKEN(aux_sym__syn_iskeyword_token1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(3353);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(3355);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 3355:
      ACCEPT_TOKEN(aux_sym__syn_iskeyword_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(3346);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 3356:
      ACCEPT_TOKEN(aux_sym__syn_iskeyword_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(3347);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 3357:
      ACCEPT_TOKEN(aux_sym__syn_iskeyword_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != ' ') ADVANCE(3357);
      END_STATE();
    case 3358:
      ACCEPT_TOKEN(anon_sym_conceal);
      END_STATE();
    case 3359:
      ACCEPT_TOKEN(anon_sym_conceal);
      if (lookahead == 'e') ADVANCE(2139);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3360:
      ACCEPT_TOKEN(anon_sym_conceal);
      if (lookahead == 'e') ADVANCE(3189);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3361:
      ACCEPT_TOKEN(anon_sym_conceal);
      if (lookahead == 'e') ADVANCE(544);
      END_STATE();
    case 3362:
      ACCEPT_TOKEN(anon_sym_conceal);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3363:
      ACCEPT_TOKEN(anon_sym_conceal);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3364:
      ACCEPT_TOKEN(anon_sym_conceal);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3365:
      ACCEPT_TOKEN(anon_sym_conceal);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3366:
      ACCEPT_TOKEN(anon_sym_cchar);
      END_STATE();
    case 3367:
      ACCEPT_TOKEN(anon_sym_cchar);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3368:
      ACCEPT_TOKEN(anon_sym_cchar);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3369:
      ACCEPT_TOKEN(anon_sym_cchar);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3370:
      ACCEPT_TOKEN(anon_sym_cchar);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3371:
      ACCEPT_TOKEN(anon_sym_contained);
      if (lookahead == 'i') ADVANCE(3466);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3372:
      ACCEPT_TOKEN(anon_sym_contained);
      if (lookahead == 'i') ADVANCE(3178);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3373:
      ACCEPT_TOKEN(anon_sym_contained);
      if (lookahead == 'i') ADVANCE(3175);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3374:
      ACCEPT_TOKEN(anon_sym_contained);
      if (lookahead == 'i') ADVANCE(2132);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3375:
      ACCEPT_TOKEN(anon_sym_contained);
      if (lookahead == 'i') ADVANCE(529);
      END_STATE();
    case 3376:
      ACCEPT_TOKEN(anon_sym_containedin);
      END_STATE();
    case 3377:
      ACCEPT_TOKEN(anon_sym_containedin);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3378:
      ACCEPT_TOKEN(anon_sym_containedin);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3379:
      ACCEPT_TOKEN(anon_sym_containedin);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3380:
      ACCEPT_TOKEN(anon_sym_containedin);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3381:
      ACCEPT_TOKEN(anon_sym_nextgroup);
      END_STATE();
    case 3382:
      ACCEPT_TOKEN(anon_sym_nextgroup);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3383:
      ACCEPT_TOKEN(anon_sym_nextgroup);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3384:
      ACCEPT_TOKEN(anon_sym_nextgroup);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3385:
      ACCEPT_TOKEN(anon_sym_nextgroup);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3386:
      ACCEPT_TOKEN(anon_sym_transparent);
      END_STATE();
    case 3387:
      ACCEPT_TOKEN(anon_sym_transparent);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3388:
      ACCEPT_TOKEN(anon_sym_transparent);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3389:
      ACCEPT_TOKEN(anon_sym_transparent);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3390:
      ACCEPT_TOKEN(anon_sym_transparent);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3391:
      ACCEPT_TOKEN(anon_sym_skipwhite);
      END_STATE();
    case 3392:
      ACCEPT_TOKEN(anon_sym_skipwhite);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3393:
      ACCEPT_TOKEN(anon_sym_skipwhite);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3394:
      ACCEPT_TOKEN(anon_sym_skipwhite);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3395:
      ACCEPT_TOKEN(anon_sym_skipwhite);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3396:
      ACCEPT_TOKEN(anon_sym_skipnl);
      END_STATE();
    case 3397:
      ACCEPT_TOKEN(anon_sym_skipnl);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3398:
      ACCEPT_TOKEN(anon_sym_skipnl);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3399:
      ACCEPT_TOKEN(anon_sym_skipnl);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3400:
      ACCEPT_TOKEN(anon_sym_skipnl);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3401:
      ACCEPT_TOKEN(anon_sym_skipempty);
      END_STATE();
    case 3402:
      ACCEPT_TOKEN(anon_sym_skipempty);
      if (lookahead == '.' ||
          lookahead == '@') ADVANCE(3264);
      if (lookahead == '[' ||
          lookahead == ']') ADVANCE(3486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3263);
      END_STATE();
    case 3403:
      ACCEPT_TOKEN(anon_sym_skipempty);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3404:
      ACCEPT_TOKEN(anon_sym_skipempty);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3405:
      ACCEPT_TOKEN(anon_sym_skipempty);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3406:
      ACCEPT_TOKEN(anon_sym_contains);
      END_STATE();
    case 3407:
      ACCEPT_TOKEN(anon_sym_contains);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3408:
      ACCEPT_TOKEN(anon_sym_contains);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3409:
      ACCEPT_TOKEN(anon_sym_fold);
      END_STATE();
    case 3410:
      ACCEPT_TOKEN(anon_sym_fold);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3411:
      ACCEPT_TOKEN(anon_sym_fold);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3412:
      ACCEPT_TOKEN(anon_sym_display);
      END_STATE();
    case 3413:
      ACCEPT_TOKEN(anon_sym_display);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3414:
      ACCEPT_TOKEN(anon_sym_display);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3415:
      ACCEPT_TOKEN(anon_sym_extend);
      END_STATE();
    case 3416:
      ACCEPT_TOKEN(anon_sym_extend);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3417:
      ACCEPT_TOKEN(anon_sym_extend);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3418:
      ACCEPT_TOKEN(anon_sym_keepend);
      END_STATE();
    case 3419:
      ACCEPT_TOKEN(anon_sym_keepend);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3420:
      ACCEPT_TOKEN(anon_sym_keepend);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3421:
      ACCEPT_TOKEN(anon_sym_excludenl);
      END_STATE();
    case 3422:
      ACCEPT_TOKEN(anon_sym_excludenl);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3423:
      ACCEPT_TOKEN(anon_sym_excludenl);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3424:
      ACCEPT_TOKEN(anon_sym_matchgroup);
      END_STATE();
    case 3425:
      ACCEPT_TOKEN(anon_sym_matchgroup);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3426:
      ACCEPT_TOKEN(anon_sym_matchgroup);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3427:
      ACCEPT_TOKEN(anon_sym_oneline);
      END_STATE();
    case 3428:
      ACCEPT_TOKEN(anon_sym_oneline);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3429:
      ACCEPT_TOKEN(anon_sym_oneline);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3430:
      ACCEPT_TOKEN(anon_sym_concealends);
      END_STATE();
    case 3431:
      ACCEPT_TOKEN(anon_sym_concealends);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3432:
      ACCEPT_TOKEN(anon_sym_concealends);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3433:
      ACCEPT_TOKEN(anon_sym_add);
      END_STATE();
    case 3434:
      ACCEPT_TOKEN(anon_sym_add);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3435:
      ACCEPT_TOKEN(anon_sym_remove);
      END_STATE();
    case 3436:
      ACCEPT_TOKEN(anon_sym_remove);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3437:
      ACCEPT_TOKEN(aux_sym__syn_pattern_offset_token1);
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(825);
      END_STATE();
    case 3438:
      ACCEPT_TOKEN(aux_sym__syn_pattern_offset_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(3438);
      END_STATE();
    case 3439:
      ACCEPT_TOKEN(aux_sym__syn_pattern_offset_token2);
      END_STATE();
    case 3440:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'a') ADVANCE(3475);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3441:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'a') ADVANCE(3465);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3442:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'a') ADVANCE(3458);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3443:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'a') ADVANCE(3462);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3444:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'a') ADVANCE(3477);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3445:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'c') ADVANCE(3455);
      if (lookahead == 'o') ADVANCE(3464);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3446:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'c') ADVANCE(3453);
      if (lookahead == 't') ADVANCE(3442);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3447:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'd') ADVANCE(3371);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3448:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'e') ADVANCE(3484);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3449:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'e') ADVANCE(3463);
      if (lookahead == 'n') ADVANCE(3461);
      if (lookahead == 'w') ADVANCE(3456);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3450:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'e') ADVANCE(3447);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3451:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'e') ADVANCE(3395);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3452:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'e') ADVANCE(3468);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3453:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'e') ADVANCE(3443);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3454:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'g') ADVANCE(3476);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3455:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'h') ADVANCE(3440);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3456:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'h') ADVANCE(3459);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3457:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'i') ADVANCE(3470);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3458:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'i') ADVANCE(3467);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3459:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'i') ADVANCE(3482);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3460:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'k') ADVANCE(3457);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3461:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'l') ADVANCE(3400);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3462:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'l') ADVANCE(3365);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3463:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'm') ADVANCE(3472);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3464:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'n') ADVANCE(3446);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3465:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'n') ADVANCE(3478);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3466:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'n') ADVANCE(3380);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3467:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'n') ADVANCE(3450);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3468:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'n') ADVANCE(3481);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3469:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'o') ADVANCE(3483);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3470:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'p') ADVANCE(3449);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3471:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'p') ADVANCE(3385);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3472:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'p') ADVANCE(3480);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3473:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'p') ADVANCE(3444);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3474:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'r') ADVANCE(3441);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3475:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'r') ADVANCE(3370);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3476:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'r') ADVANCE(3469);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3477:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'r') ADVANCE(3452);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3478:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 's') ADVANCE(3473);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3479:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 't') ADVANCE(3454);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3480:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 't') ADVANCE(3485);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3481:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 't') ADVANCE(3390);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3482:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 't') ADVANCE(3451);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3483:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'u') ADVANCE(3471);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3484:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'x') ADVANCE(3479);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3485:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (lookahead == 'y') ADVANCE(3405);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3486:
      ACCEPT_TOKEN(aux_sym__syn_keyword_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= '[') ||
          lookahead == ']' ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3486);
      END_STATE();
    case 3487:
      ACCEPT_TOKEN(anon_sym_skip);
      if (lookahead == 'e') ADVANCE(2128);
      if (lookahead == 'n') ADVANCE(2115);
      if (lookahead == 'w') ADVANCE(2099);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3488:
      ACCEPT_TOKEN(anon_sym_skip);
      if (lookahead == 'e') ADVANCE(3171);
      if (lookahead == 'n') ADVANCE(3152);
      if (lookahead == 'w') ADVANCE(3127);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3489:
      ACCEPT_TOKEN(anon_sym_skip);
      if (lookahead == 'e') ADVANCE(516);
      if (lookahead == 'n') ADVANCE(493);
      if (lookahead == 'w') ADVANCE(451);
      END_STATE();
    case 3490:
      ACCEPT_TOKEN(anon_sym_end);
      END_STATE();
    case 3491:
      ACCEPT_TOKEN(anon_sym_end);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3492:
      ACCEPT_TOKEN(anon_sym_end);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3493:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 3494:
      ACCEPT_TOKEN(anon_sym_minlines);
      END_STATE();
    case 3495:
      ACCEPT_TOKEN(anon_sym_minlines);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3496:
      ACCEPT_TOKEN(anon_sym_minlines);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3497:
      ACCEPT_TOKEN(anon_sym_maxlines);
      END_STATE();
    case 3498:
      ACCEPT_TOKEN(anon_sym_maxlines);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3499:
      ACCEPT_TOKEN(anon_sym_maxlines);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(3264);
      END_STATE();
    case 3500:
      ACCEPT_TOKEN(aux_sym__syn_sync_lines_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(3500);
      END_STATE();
    case 3501:
      ACCEPT_TOKEN(anon_sym_lines2);
      if (lookahead == '#' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(2199);
      END_STATE();
    case 3502:
      ACCEPT_TOKEN(anon_sym_grouphere);
      END_STATE();
    case 3503:
      ACCEPT_TOKEN(anon_sym_groupthere);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'a', 1,
        'b', 2,
        'c', 3,
        'd', 4,
        'e', 5,
        'f', 6,
        'h', 7,
        'i', 8,
        'j', 9,
        'k', 10,
        'l', 11,
        'm', 12,
        'n', 13,
        'o', 14,
        'p', 15,
        'q', 16,
        'r', 17,
        's', 18,
        't', 19,
        'u', 20,
        'v', 21,
        'w', 22,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(23);
      END_STATE();
    case 1:
      if (lookahead == 'b') ADVANCE(24);
      if (lookahead == 'n') ADVANCE(25);
      if (lookahead == 'r') ADVANCE(26);
      if (lookahead == 'u') ADVANCE(27);
      END_STATE();
    case 2:
      if (lookahead == 'a') ADVANCE(28);
      if (lookahead == 'e') ADVANCE(29);
      if (lookahead == 'g') ADVANCE(30);
      if (lookahead == 'i') ADVANCE(31);
      if (lookahead == 'o') ADVANCE(32);
      if (lookahead == 'u') ADVANCE(33);
      END_STATE();
    case 3:
      if (lookahead == 'a') ADVANCE(34);
      if (lookahead == 'c') ADVANCE(35);
      if (lookahead == 'h') ADVANCE(36);
      if (lookahead == 'l') ADVANCE(37);
      if (lookahead == 'o') ADVANCE(38);
      if (lookahead == 'p') ADVANCE(39);
      if (lookahead == 'u') ADVANCE(40);
      END_STATE();
    case 4:
      if (lookahead == 'e') ADVANCE(41);
      if (lookahead == 'i') ADVANCE(42);
      if (lookahead == 'o') ADVANCE(43);
      if (lookahead == 'r') ADVANCE(44);
      END_STATE();
    case 5:
      if (lookahead == 'd') ADVANCE(45);
      if (lookahead == 'n') ADVANCE(46);
      if (lookahead == 'v') ADVANCE(47);
      if (lookahead == 'x') ADVANCE(48);
      END_STATE();
    case 6:
      if (lookahead == 'f') ADVANCE(49);
      if (lookahead == 'g') ADVANCE(50);
      if (lookahead == 'i') ADVANCE(51);
      if (lookahead == 'o') ADVANCE(52);
      if (lookahead == 'r') ADVANCE(53);
      if (lookahead == 'u') ADVANCE(54);
      END_STATE();
    case 7:
      if (lookahead == 'e') ADVANCE(55);
      if (lookahead == 'i') ADVANCE(56);
      if (lookahead == 's') ADVANCE(57);
      END_STATE();
    case 8:
      if (lookahead == 'g') ADVANCE(58);
      if (lookahead == 'n') ADVANCE(59);
      if (lookahead == 's') ADVANCE(60);
      if (lookahead == 't') ADVANCE(61);
      END_STATE();
    case 9:
      if (lookahead == 'a') ADVANCE(62);
      if (lookahead == 'u') ADVANCE(63);
      END_STATE();
    case 10:
      if (lookahead == 'e') ADVANCE(64);
      if (lookahead == 'o') ADVANCE(65);
      END_STATE();
    case 11:
      if (lookahead == 'a') ADVANCE(66);
      if (lookahead == 'c') ADVANCE(67);
      if (lookahead == 'i') ADVANCE(68);
      if (lookahead == 'o') ADVANCE(69);
      if (lookahead == 'u') ADVANCE(70);
      END_STATE();
    case 12:
      if (lookahead == 'a') ADVANCE(71);
      if (lookahead == 'e') ADVANCE(72);
      if (lookahead == 'i') ADVANCE(73);
      if (lookahead == 's') ADVANCE(74);
      END_STATE();
    case 13:
      if (lookahead == 'o') ADVANCE(75);
      END_STATE();
    case 14:
      if (lookahead == 'f') ADVANCE(76);
      if (lookahead == 'n') ADVANCE(77);
      if (lookahead == 'p') ADVANCE(78);
      if (lookahead == 't') ADVANCE(79);
      END_STATE();
    case 15:
      if (lookahead == 'a') ADVANCE(80);
      if (lookahead == 'l') ADVANCE(81);
      if (lookahead == 'r') ADVANCE(82);
      END_STATE();
    case 16:
      if (lookahead == 'u') ADVANCE(83);
      END_STATE();
    case 17:
      if (lookahead == 'a') ADVANCE(84);
      if (lookahead == 'e') ADVANCE(85);
      if (lookahead == 's') ADVANCE(86);
      END_STATE();
    case 18:
      if (lookahead == 'h') ADVANCE(87);
      if (lookahead == 'i') ADVANCE(88);
      if (lookahead == 'j') ADVANCE(89);
      if (lookahead == 'p') ADVANCE(90);
      if (lookahead == 't') ADVANCE(91);
      if (lookahead == 'y') ADVANCE(92);
      END_STATE();
    case 19:
      if (lookahead == 'a') ADVANCE(93);
      if (lookahead == 'o') ADVANCE(94);
      if (lookahead == 'r') ADVANCE(95);
      END_STATE();
    case 20:
      if (lookahead == 'c') ADVANCE(96);
      if (lookahead == 'n') ADVANCE(97);
      if (lookahead == 't') ADVANCE(98);
      END_STATE();
    case 21:
      if (lookahead == 'a') ADVANCE(99);
      if (lookahead == 'i') ADVANCE(100);
      END_STATE();
    case 22:
      if (lookahead == 'i') ADVANCE(101);
      END_STATE();
    case 23:
      ADVANCE_MAP(
        'a', 102,
        'c', 103,
        'd', 104,
        'e', 105,
        'f', 106,
        'i', 107,
        'j', 108,
        'k', 109,
        'l', 110,
        'm', 111,
        'n', 112,
        'o', 113,
        'p', 114,
        'r', 115,
        's', 116,
        't', 117,
        'u', 118,
        'v', 119,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(23);
      END_STATE();
    case 24:
      if (lookahead == 'o') ADVANCE(120);
      END_STATE();
    case 25:
      if (lookahead == 's') ADVANCE(121);
      END_STATE();
    case 26:
      if (lookahead == 'g') ADVANCE(122);
      END_STATE();
    case 27:
      if (lookahead == 'g') ADVANCE(123);
      END_STATE();
    case 28:
      if (lookahead == 'c') ADVANCE(124);
      if (lookahead == 'd') ADVANCE(125);
      END_STATE();
    case 29:
      if (lookahead == 'h') ADVANCE(126);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(anon_sym_bg);
      END_STATE();
    case 31:
      if (lookahead == 'g') ADVANCE(127);
      if (lookahead == 'n') ADVANCE(128);
      END_STATE();
    case 32:
      if (lookahead == 'l') ADVANCE(129);
      END_STATE();
    case 33:
      if (lookahead == 'f') ADVANCE(130);
      END_STATE();
    case 34:
      if (lookahead == 's') ADVANCE(131);
      END_STATE();
    case 35:
      if (lookahead == 'o') ADVANCE(132);
      END_STATE();
    case 36:
      if (lookahead == 'i') ADVANCE(133);
      END_STATE();
    case 37:
      if (lookahead == 'o') ADVANCE(134);
      if (lookahead == 'u') ADVANCE(135);
      END_STATE();
    case 38:
      if (lookahead == 'l') ADVANCE(136);
      if (lookahead == 'm') ADVANCE(137);
      END_STATE();
    case 39:
      if (lookahead == '1') ADVANCE(138);
      if (lookahead == '4') ADVANCE(139);
      if (lookahead == '7') ADVANCE(140);
      if (lookahead == '8') ADVANCE(141);
      if (lookahead == '9') ADVANCE(142);
      END_STATE();
    case 40:
      if (lookahead == 's') ADVANCE(143);
      END_STATE();
    case 41:
      if (lookahead == 'f') ADVANCE(144);
      if (lookahead == 't') ADVANCE(145);
      END_STATE();
    case 42:
      if (lookahead == 'c') ADVANCE(146);
      if (lookahead == 'r') ADVANCE(147);
      END_STATE();
    case 43:
      if (lookahead == 's') ADVANCE(148);
      END_STATE();
    case 44:
      if (lookahead == 'o') ADVANCE(149);
      END_STATE();
    case 45:
      if (lookahead == 'i') ADVANCE(150);
      END_STATE();
    case 46:
      if (lookahead == 'a') ADVANCE(151);
      if (lookahead == 'c') ADVANCE(152);
      if (lookahead == 'v') ADVANCE(153);
      END_STATE();
    case 47:
      if (lookahead == 'a') ADVANCE(154);
      if (lookahead == 'e') ADVANCE(155);
      END_STATE();
    case 48:
      if (lookahead == 'p') ADVANCE(156);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(anon_sym_ff);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(anon_sym_fg);
      END_STATE();
    case 51:
      if (lookahead == 'l') ADVANCE(157);
      END_STATE();
    case 52:
      if (lookahead == 'l') ADVANCE(158);
      if (lookahead == 'r') ADVANCE(159);
      END_STATE();
    case 53:
      if (lookahead == 'o') ADVANCE(160);
      END_STATE();
    case 54:
      if (lookahead == 'n') ADVANCE(161);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(anon_sym_he);
      if (lookahead == 'l') ADVANCE(162);
      END_STATE();
    case 56:
      if (lookahead == 'g') ADVANCE(163);
      if (lookahead == 's') ADVANCE(164);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(anon_sym_hs);
      END_STATE();
    case 58:
      if (lookahead == 'n') ADVANCE(165);
      END_STATE();
    case 59:
      if (lookahead == 'c') ADVANCE(166);
      if (lookahead == 'd') ADVANCE(167);
      if (lookahead == 'v') ADVANCE(168);
      END_STATE();
    case 60:
      if (lookahead == 'k') ADVANCE(169);
      if (lookahead == 'o') ADVANCE(170);
      END_STATE();
    case 61:
      if (lookahead == 'a') ADVANCE(171);
      END_STATE();
    case 62:
      if (lookahead == 'p') ADVANCE(172);
      END_STATE();
    case 63:
      if (lookahead == 'm') ADVANCE(173);
      END_STATE();
    case 64:
      if (lookahead == 'e') ADVANCE(174);
      if (lookahead == 'y') ADVANCE(175);
      END_STATE();
    case 65:
      if (lookahead == 'i') ADVANCE(176);
      if (lookahead == 'r') ADVANCE(177);
      END_STATE();
    case 66:
      if (lookahead == 't') ADVANCE(178);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(anon_sym_lc);
      END_STATE();
    case 68:
      if (lookahead == 'n') ADVANCE(179);
      if (lookahead == 's') ADVANCE(180);
      END_STATE();
    case 69:
      if (lookahead == 'a') ADVANCE(181);
      if (lookahead == 'c') ADVANCE(182);
      END_STATE();
    case 70:
      if (lookahead == 'a') ADVANCE(183);
      END_STATE();
    case 71:
      if (lookahead == 'c') ADVANCE(184);
      if (lookahead == 'p') ADVANCE(185);
      if (lookahead == 't') ADVANCE(186);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(anon_sym_me);
      if (lookahead == 'n') ADVANCE(187);
      if (lookahead == 's') ADVANCE(188);
      END_STATE();
    case 73:
      if (lookahead == 'n') ADVANCE(189);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(anon_sym_ms);
      END_STATE();
    case 75:
      if (lookahead == 'b') ADVANCE(190);
      if (lookahead == 'c') ADVANCE(191);
      if (lookahead == 't') ADVANCE(192);
      END_STATE();
    case 76:
      if (lookahead == 'f') ADVANCE(193);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(anon_sym_on);
      END_STATE();
    case 78:
      if (lookahead == 't') ADVANCE(194);
      END_STATE();
    case 79:
      if (lookahead == 'h') ADVANCE(195);
      END_STATE();
    case 80:
      if (lookahead == 'c') ADVANCE(196);
      END_STATE();
    case 81:
      if (lookahead == 'a') ADVANCE(197);
      if (lookahead == 'u') ADVANCE(198);
      END_STATE();
    case 82:
      if (lookahead == 'c') ADVANCE(199);
      END_STATE();
    case 83:
      if (lookahead == 'i') ADVANCE(200);
      END_STATE();
    case 84:
      if (lookahead == 'n') ADVANCE(201);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(anon_sym_re);
      if (lookahead == 'g') ADVANCE(202);
      if (lookahead == 's') ADVANCE(203);
      if (lookahead == 'v') ADVANCE(204);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_rs);
      END_STATE();
    case 87:
      if (lookahead == 'e') ADVANCE(205);
      END_STATE();
    case 88:
      if (lookahead == 'g') ADVANCE(206);
      END_STATE();
    case 89:
      if (lookahead == 'i') ADVANCE(207);
      END_STATE();
    case 90:
      if (lookahead == 'e') ADVANCE(208);
      END_STATE();
    case 91:
      if (lookahead == 'a') ADVANCE(209);
      if (lookahead == 'r') ADVANCE(210);
      END_STATE();
    case 92:
      if (lookahead == 'n') ADVANCE(211);
      END_STATE();
    case 93:
      if (lookahead == 'b') ADVANCE(212);
      if (lookahead == 'g') ADVANCE(213);
      if (lookahead == 'i') ADVANCE(214);
      END_STATE();
    case 94:
      if (lookahead == 'p') ADVANCE(215);
      END_STATE();
    case 95:
      if (lookahead == 'i') ADVANCE(216);
      END_STATE();
    case 96:
      if (lookahead == 's') ADVANCE(217);
      END_STATE();
    case 97:
      if (lookahead == 'd') ADVANCE(218);
      if (lookahead == 'i') ADVANCE(219);
      if (lookahead == 'p') ADVANCE(220);
      END_STATE();
    case 98:
      if (lookahead == 'f') ADVANCE(221);
      END_STATE();
    case 99:
      if (lookahead == 'r') ADVANCE(222);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_vi);
      if (lookahead == 'm') ADVANCE(223);
      END_STATE();
    case 101:
      if (lookahead == 'n') ADVANCE(224);
      END_STATE();
    case 102:
      if (lookahead == 'b') ADVANCE(24);
      END_STATE();
    case 103:
      if (lookahead == 'a') ADVANCE(34);
      if (lookahead == 'c') ADVANCE(35);
      if (lookahead == 'l') ADVANCE(37);
      END_STATE();
    case 104:
      if (lookahead == 'e') ADVANCE(225);
      if (lookahead == 'i') ADVANCE(226);
      END_STATE();
    case 105:
      if (lookahead == 'n') ADVANCE(227);
      if (lookahead == 'v') ADVANCE(228);
      END_STATE();
    case 106:
      if (lookahead == 'o') ADVANCE(229);
      if (lookahead == 'r') ADVANCE(53);
      END_STATE();
    case 107:
      if (lookahead == 'g') ADVANCE(58);
      if (lookahead == 'n') ADVANCE(230);
      if (lookahead == 's') ADVANCE(231);
      END_STATE();
    case 108:
      if (lookahead == 'u') ADVANCE(63);
      END_STATE();
    case 109:
      if (lookahead == 'e') ADVANCE(232);
      END_STATE();
    case 110:
      if (lookahead == 'i') ADVANCE(233);
      END_STATE();
    case 111:
      if (lookahead == 'a') ADVANCE(234);
      if (lookahead == 'i') ADVANCE(73);
      END_STATE();
    case 112:
      if (lookahead == 'o') ADVANCE(235);
      END_STATE();
    case 113:
      if (lookahead == 'f') ADVANCE(76);
      if (lookahead == 'n') ADVANCE(77);
      END_STATE();
    case 114:
      if (lookahead == 'l') ADVANCE(81);
      END_STATE();
    case 115:
      if (lookahead == 'a') ADVANCE(84);
      if (lookahead == 'e') ADVANCE(236);
      END_STATE();
    case 116:
      if (lookahead == 'p') ADVANCE(90);
      if (lookahead == 'y') ADVANCE(237);
      END_STATE();
    case 117:
      if (lookahead == 'o') ADVANCE(94);
      if (lookahead == 'r') ADVANCE(95);
      END_STATE();
    case 118:
      if (lookahead == 'n') ADVANCE(238);
      END_STATE();
    case 119:
      if (lookahead == 'i') ADVANCE(100);
      END_STATE();
    case 120:
      if (lookahead == 'r') ADVANCE(239);
      END_STATE();
    case 121:
      if (lookahead == 'i') ADVANCE(240);
      END_STATE();
    case 122:
      if (lookahead == 'l') ADVANCE(241);
      if (lookahead == 'u') ADVANCE(242);
      END_STATE();
    case 123:
      if (lookahead == 'r') ADVANCE(243);
      END_STATE();
    case 124:
      if (lookahead == 'k') ADVANCE(244);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_bad);
      END_STATE();
    case 126:
      if (lookahead == 'a') ADVANCE(245);
      END_STATE();
    case 127:
      if (lookahead == '5') ADVANCE(246);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_bin);
      if (lookahead == 'a') ADVANCE(247);
      END_STATE();
    case 129:
      if (lookahead == 'd') ADVANCE(248);
      END_STATE();
    case 130:
      if (lookahead == 'f') ADVANCE(249);
      END_STATE();
    case 131:
      if (lookahead == 'e') ADVANCE(250);
      END_STATE();
    case 132:
      if (lookahead == 'm') ADVANCE(251);
      END_STATE();
    case 133:
      if (lookahead == 'n') ADVANCE(252);
      END_STATE();
    case 134:
      if (lookahead == 's') ADVANCE(253);
      END_STATE();
    case 135:
      if (lookahead == 's') ADVANCE(254);
      END_STATE();
    case 136:
      if (lookahead == 'o') ADVANCE(255);
      END_STATE();
    case 137:
      if (lookahead == 'm') ADVANCE(256);
      if (lookahead == 'p') ADVANCE(257);
      END_STATE();
    case 138:
      if (lookahead == '2') ADVANCE(258);
      END_STATE();
    case 139:
      if (lookahead == '3') ADVANCE(259);
      END_STATE();
    case 140:
      if (lookahead == '3') ADVANCE(260);
      if (lookahead == '7') ADVANCE(261);
      END_STATE();
    case 141:
      if (lookahead == '5') ADVANCE(262);
      if (lookahead == '6') ADVANCE(263);
      if (lookahead == '7') ADVANCE(264);
      END_STATE();
    case 142:
      if (lookahead == '3') ADVANCE(265);
      if (lookahead == '4') ADVANCE(266);
      if (lookahead == '5') ADVANCE(267);
      END_STATE();
    case 143:
      if (lookahead == 't') ADVANCE(268);
      END_STATE();
    case 144:
      if (lookahead == 'a') ADVANCE(269);
      if (lookahead == 'i') ADVANCE(270);
      END_STATE();
    case 145:
      if (lookahead == 'e') ADVANCE(271);
      END_STATE();
    case 146:
      if (lookahead == 't') ADVANCE(272);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_dir);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_dos);
      END_STATE();
    case 149:
      if (lookahead == 'p') ADVANCE(273);
      END_STATE();
    case 150:
      if (lookahead == 't') ADVANCE(274);
      END_STATE();
    case 151:
      if (lookahead == 'b') ADVANCE(275);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_enc);
      if (lookahead == 'o') ADVANCE(276);
      END_STATE();
    case 153:
      if (lookahead == 'i') ADVANCE(277);
      END_STATE();
    case 154:
      if (lookahead == 'l') ADVANCE(278);
      END_STATE();
    case 155:
      if (lookahead == 'n') ADVANCE(279);
      END_STATE();
    case 156:
      if (lookahead == 'r') ADVANCE(280);
      END_STATE();
    case 157:
      if (lookahead == 'e') ADVANCE(281);
      END_STATE();
    case 158:
      if (lookahead == 'd') ADVANCE(282);
      END_STATE();
    case 159:
      if (lookahead == 'e') ADVANCE(283);
      END_STATE();
    case 160:
      if (lookahead == 'm') ADVANCE(284);
      END_STATE();
    case 161:
      if (lookahead == 'c') ADVANCE(285);
      END_STATE();
    case 162:
      if (lookahead == 'p') ADVANCE(286);
      END_STATE();
    case 163:
      if (lookahead == 'h') ADVANCE(287);
      END_STATE();
    case 164:
      if (lookahead == 't') ADVANCE(288);
      END_STATE();
    case 165:
      if (lookahead == 'o') ADVANCE(289);
      END_STATE();
    case 166:
      if (lookahead == 'l') ADVANCE(290);
      END_STATE();
    case 167:
      if (lookahead == 'e') ADVANCE(291);
      END_STATE();
    case 168:
      if (lookahead == 'e') ADVANCE(292);
      END_STATE();
    case 169:
      if (lookahead == 'e') ADVANCE(293);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(anon_sym_iso2);
      END_STATE();
    case 171:
      if (lookahead == 'l') ADVANCE(294);
      END_STATE();
    case 172:
      if (lookahead == 'a') ADVANCE(295);
      END_STATE();
    case 173:
      if (lookahead == 'p') ADVANCE(296);
      END_STATE();
    case 174:
      if (lookahead == 'p') ADVANCE(297);
      END_STATE();
    case 175:
      if (lookahead == 'w') ADVANCE(298);
      END_STATE();
    case 176:
      if (lookahead == '8') ADVANCE(299);
      END_STATE();
    case 177:
      if (lookahead == 'e') ADVANCE(300);
      END_STATE();
    case 178:
      if (lookahead == 'i') ADVANCE(301);
      END_STATE();
    case 179:
      if (lookahead == 'e') ADVANCE(302);
      END_STATE();
    case 180:
      if (lookahead == 't') ADVANCE(303);
      END_STATE();
    case 181:
      if (lookahead == 'd') ADVANCE(304);
      END_STATE();
    case 182:
      if (lookahead == 'a') ADVANCE(305);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(anon_sym_lua);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(anon_sym_mac);
      if (lookahead == 'r') ADVANCE(306);
      END_STATE();
    case 185:
      if (lookahead == 'c') ADVANCE(307);
      if (lookahead == 'p') ADVANCE(308);
      END_STATE();
    case 186:
      if (lookahead == 'c') ADVANCE(309);
      END_STATE();
    case 187:
      if (lookahead == 'u') ADVANCE(310);
      END_STATE();
    case 188:
      if (lookahead == 's') ADVANCE(311);
      END_STATE();
    case 189:
      if (lookahead == 'i') ADVANCE(312);
      END_STATE();
    case 190:
      if (lookahead == 'i') ADVANCE(313);
      END_STATE();
    case 191:
      if (lookahead == 'o') ADVANCE(314);
      END_STATE();
    case 192:
      if (lookahead == 'o') ADVANCE(315);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_off);
      END_STATE();
    case 194:
      if (lookahead == 'i') ADVANCE(316);
      END_STATE();
    case 195:
      if (lookahead == 'e') ADVANCE(317);
      END_STATE();
    case 196:
      if (lookahead == 'k') ADVANCE(318);
      END_STATE();
    case 197:
      if (lookahead == 'c') ADVANCE(319);
      END_STATE();
    case 198:
      if (lookahead == 'g') ADVANCE(320);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(anon_sym_prc2);
      END_STATE();
    case 200:
      if (lookahead == 'c') ADVANCE(321);
      END_STATE();
    case 201:
      if (lookahead == 'g') ADVANCE(322);
      END_STATE();
    case 202:
      if (lookahead == 'i') ADVANCE(323);
      END_STATE();
    case 203:
      if (lookahead == 'e') ADVANCE(324);
      END_STATE();
    case 204:
      if (lookahead == 'e') ADVANCE(325);
      END_STATE();
    case 205:
      if (lookahead == 'l') ADVANCE(326);
      END_STATE();
    case 206:
      if (lookahead == 'n') ADVANCE(327);
      END_STATE();
    case 207:
      if (lookahead == 's') ADVANCE(328);
      END_STATE();
    case 208:
      if (lookahead == 'l') ADVANCE(329);
      END_STATE();
    case 209:
      if (lookahead == 'n') ADVANCE(330);
      END_STATE();
    case 210:
      if (lookahead == 'i') ADVANCE(331);
      END_STATE();
    case 211:
      if (lookahead == 'c') ADVANCE(332);
      if (lookahead == 't') ADVANCE(333);
      END_STATE();
    case 212:
      if (lookahead == 's') ADVANCE(334);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(anon_sym_tag);
      if (lookahead == '_') ADVANCE(335);
      END_STATE();
    case 214:
      if (lookahead == 'w') ADVANCE(336);
      END_STATE();
    case 215:
      if (lookahead == 'l') ADVANCE(337);
      END_STATE();
    case 216:
      if (lookahead == 'm') ADVANCE(338);
      END_STATE();
    case 217:
      if (lookahead == '2') ADVANCE(339);
      END_STATE();
    case 218:
      if (lookahead == 'e') ADVANCE(340);
      END_STATE();
    case 219:
      if (lookahead == 'c') ADVANCE(341);
      if (lookahead == 'x') ADVANCE(342);
      END_STATE();
    case 220:
      if (lookahead == 'l') ADVANCE(343);
      END_STATE();
    case 221:
      if (lookahead == '8') ADVANCE(344);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(anon_sym_var);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(anon_sym_vim);
      END_STATE();
    case 224:
      if (lookahead == 'd') ADVANCE(345);
      END_STATE();
    case 225:
      if (lookahead == 'f') ADVANCE(346);
      if (lookahead == 't') ADVANCE(145);
      END_STATE();
    case 226:
      if (lookahead == 'c') ADVANCE(146);
      END_STATE();
    case 227:
      if (lookahead == 'a') ADVANCE(151);
      END_STATE();
    case 228:
      if (lookahead == 'a') ADVANCE(154);
      END_STATE();
    case 229:
      if (lookahead == 'l') ADVANCE(158);
      END_STATE();
    case 230:
      if (lookahead == 'c') ADVANCE(166);
      if (lookahead == 'd') ADVANCE(167);
      END_STATE();
    case 231:
      if (lookahead == 'k') ADVANCE(169);
      END_STATE();
    case 232:
      if (lookahead == 'y') ADVANCE(175);
      END_STATE();
    case 233:
      if (lookahead == 'n') ADVANCE(347);
      if (lookahead == 's') ADVANCE(180);
      END_STATE();
    case 234:
      if (lookahead == 't') ADVANCE(186);
      END_STATE();
    case 235:
      if (lookahead == 't') ADVANCE(192);
      END_STATE();
    case 236:
      if (lookahead == 'g') ADVANCE(202);
      if (lookahead == 's') ADVANCE(203);
      END_STATE();
    case 237:
      if (lookahead == 'n') ADVANCE(348);
      END_STATE();
    case 238:
      if (lookahead == 'd') ADVANCE(349);
      if (lookahead == 'p') ADVANCE(220);
      END_STATE();
    case 239:
      if (lookahead == 't') ADVANCE(350);
      END_STATE();
    case 240:
      ACCEPT_TOKEN(anon_sym_ansi2);
      END_STATE();
    case 241:
      if (lookahead == 'i') ADVANCE(351);
      END_STATE();
    case 242:
      if (lookahead == 'm') ADVANCE(352);
      END_STATE();
    case 243:
      if (lookahead == 'o') ADVANCE(353);
      END_STATE();
    case 244:
      if (lookahead == 'g') ADVANCE(354);
      END_STATE();
    case 245:
      if (lookahead == 'v') ADVANCE(355);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(anon_sym_big52);
      END_STATE();
    case 247:
      if (lookahead == 'r') ADVANCE(356);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(anon_sym_bold);
      END_STATE();
    case 249:
      if (lookahead == 'e') ADVANCE(357);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 251:
      if (lookahead == 'm') ADVANCE(358);
      END_STATE();
    case 252:
      if (lookahead == 'e') ADVANCE(359);
      END_STATE();
    case 253:
      if (lookahead == 'u') ADVANCE(360);
      END_STATE();
    case 254:
      if (lookahead == 't') ADVANCE(361);
      END_STATE();
    case 255:
      if (lookahead == 'r') ADVANCE(362);
      END_STATE();
    case 256:
      if (lookahead == 'a') ADVANCE(363);
      END_STATE();
    case 257:
      if (lookahead == 'i') ADVANCE(364);
      END_STATE();
    case 258:
      if (lookahead == '5') ADVANCE(365);
      END_STATE();
    case 259:
      if (lookahead == '7') ADVANCE(366);
      END_STATE();
    case 260:
      if (lookahead == '7') ADVANCE(367);
      END_STATE();
    case 261:
      if (lookahead == '5') ADVANCE(368);
      END_STATE();
    case 262:
      if (lookahead == '0') ADVANCE(369);
      if (lookahead == '2') ADVANCE(370);
      if (lookahead == '5') ADVANCE(371);
      if (lookahead == '7') ADVANCE(372);
      END_STATE();
    case 263:
      if (lookahead == '0') ADVANCE(373);
      if (lookahead == '1') ADVANCE(374);
      if (lookahead == '2') ADVANCE(375);
      if (lookahead == '3') ADVANCE(376);
      if (lookahead == '5') ADVANCE(377);
      if (lookahead == '6') ADVANCE(378);
      if (lookahead == '9') ADVANCE(379);
      END_STATE();
    case 264:
      if (lookahead == '4') ADVANCE(380);
      END_STATE();
    case 265:
      if (lookahead == '2') ADVANCE(381);
      if (lookahead == '6') ADVANCE(382);
      END_STATE();
    case 266:
      if (lookahead == '9') ADVANCE(383);
      END_STATE();
    case 267:
      if (lookahead == '0') ADVANCE(384);
      END_STATE();
    case 268:
      if (lookahead == 'o') ADVANCE(385);
      END_STATE();
    case 269:
      if (lookahead == 'u') ADVANCE(386);
      END_STATE();
    case 270:
      if (lookahead == 'n') ADVANCE(387);
      END_STATE();
    case 271:
      if (lookahead == 'c') ADVANCE(388);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(anon_sym_dict);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(anon_sym_drop);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(anon_sym_edit);
      END_STATE();
    case 275:
      if (lookahead == 'l') ADVANCE(389);
      END_STATE();
    case 276:
      if (lookahead == 'd') ADVANCE(390);
      END_STATE();
    case 277:
      if (lookahead == 'r') ADVANCE(391);
      END_STATE();
    case 278:
      ACCEPT_TOKEN(anon_sym_eval);
      END_STATE();
    case 279:
      ACCEPT_TOKEN(anon_sym_even);
      END_STATE();
    case 280:
      if (lookahead == 'e') ADVANCE(392);
      END_STATE();
    case 281:
      ACCEPT_TOKEN(anon_sym_file2);
      if (lookahead == '_') ADVANCE(393);
      if (lookahead == 'f') ADVANCE(394);
      END_STATE();
    case 282:
      if (lookahead == 'l') ADVANCE(395);
      END_STATE();
    case 283:
      if (lookahead == 'g') ADVANCE(396);
      END_STATE();
    case 284:
      if (lookahead == 's') ADVANCE(397);
      END_STATE();
    case 285:
      if (lookahead == 't') ADVANCE(398);
      END_STATE();
    case 286:
      ACCEPT_TOKEN(anon_sym_help);
      END_STATE();
    case 287:
      if (lookahead == 'l') ADVANCE(399);
      END_STATE();
    case 288:
      if (lookahead == 'o') ADVANCE(400);
      END_STATE();
    case 289:
      if (lookahead == 'r') ADVANCE(401);
      END_STATE();
    case 290:
      if (lookahead == 'u') ADVANCE(402);
      END_STATE();
    case 291:
      if (lookahead == 'n') ADVANCE(403);
      END_STATE();
    case 292:
      if (lookahead == 'r') ADVANCE(404);
      END_STATE();
    case 293:
      if (lookahead == 'y') ADVANCE(405);
      END_STATE();
    case 294:
      if (lookahead == 'i') ADVANCE(406);
      END_STATE();
    case 295:
      if (lookahead == 'n') ADVANCE(407);
      END_STATE();
    case 296:
      ACCEPT_TOKEN(anon_sym_jump);
      END_STATE();
    case 297:
      ACCEPT_TOKEN(anon_sym_keep);
      END_STATE();
    case 298:
      if (lookahead == 'o') ADVANCE(408);
      END_STATE();
    case 299:
      ACCEPT_TOKEN(anon_sym_koi82);
      END_STATE();
    case 300:
      if (lookahead == 'a') ADVANCE(409);
      END_STATE();
    case 301:
      if (lookahead == 'n') ADVANCE(410);
      END_STATE();
    case 302:
      if (lookahead == 'b') ADVANCE(411);
      if (lookahead == 'c') ADVANCE(412);
      if (lookahead == 's') ADVANCE(413);
      END_STATE();
    case 303:
      ACCEPT_TOKEN(anon_sym_list);
      END_STATE();
    case 304:
      if (lookahead == 'e') ADVANCE(414);
      END_STATE();
    case 305:
      if (lookahead == 'l') ADVANCE(415);
      END_STATE();
    case 306:
      if (lookahead == 'o') ADVANCE(416);
      END_STATE();
    case 307:
      if (lookahead == 'l') ADVANCE(417);
      END_STATE();
    case 308:
      if (lookahead == 'i') ADVANCE(418);
      END_STATE();
    case 309:
      if (lookahead == 'h') ADVANCE(419);
      END_STATE();
    case 310:
      ACCEPT_TOKEN(anon_sym_menu);
      END_STATE();
    case 311:
      if (lookahead == 'a') ADVANCE(420);
      END_STATE();
    case 312:
      if (lookahead == 'm') ADVANCE(421);
      END_STATE();
    case 313:
      if (lookahead == 'n') ADVANCE(422);
      END_STATE();
    case 314:
      if (lookahead == 'm') ADVANCE(423);
      END_STATE();
    case 315:
      if (lookahead == 'p') ADVANCE(424);
      END_STATE();
    case 316:
      if (lookahead == 'o') ADVANCE(425);
      END_STATE();
    case 317:
      if (lookahead == 'r') ADVANCE(426);
      END_STATE();
    case 318:
      if (lookahead == 'a') ADVANCE(427);
      END_STATE();
    case 319:
      if (lookahead == 'e') ADVANCE(428);
      END_STATE();
    case 320:
      if (lookahead == 'i') ADVANCE(429);
      END_STATE();
    case 321:
      if (lookahead == 'k') ADVANCE(430);
      END_STATE();
    case 322:
      if (lookahead == 'e') ADVANCE(431);
      END_STATE();
    case 323:
      if (lookahead == 'o') ADVANCE(432);
      END_STATE();
    case 324:
      if (lookahead == 't') ADVANCE(433);
      END_STATE();
    case 325:
      if (lookahead == 'r') ADVANCE(434);
      END_STATE();
    case 326:
      if (lookahead == 'l') ADVANCE(435);
      END_STATE();
    case 327:
      ACCEPT_TOKEN(anon_sym_sign);
      END_STATE();
    case 328:
      ACCEPT_TOKEN(anon_sym_sjis2);
      END_STATE();
    case 329:
      if (lookahead == 'l') ADVANCE(436);
      END_STATE();
    case 330:
      if (lookahead == 'd') ADVANCE(437);
      END_STATE();
    case 331:
      if (lookahead == 'k') ADVANCE(438);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(anon_sym_sync);
      END_STATE();
    case 333:
      if (lookahead == 'i') ADVANCE(439);
      END_STATE();
    case 334:
      ACCEPT_TOKEN(anon_sym_tabs);
      END_STATE();
    case 335:
      if (lookahead == 'l') ADVANCE(440);
      END_STATE();
    case 336:
      if (lookahead == 'a') ADVANCE(441);
      END_STATE();
    case 337:
      if (lookahead == 'e') ADVANCE(442);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(anon_sym_trim);
      END_STATE();
    case 339:
      if (lookahead == 'b') ADVANCE(443);
      END_STATE();
    case 340:
      if (lookahead == 'f') ADVANCE(444);
      if (lookahead == 'r') ADVANCE(445);
      END_STATE();
    case 341:
      if (lookahead == 'o') ADVANCE(446);
      END_STATE();
    case 342:
      ACCEPT_TOKEN(anon_sym_unix);
      END_STATE();
    case 343:
      if (lookahead == 'a') ADVANCE(447);
      END_STATE();
    case 344:
      ACCEPT_TOKEN(anon_sym_utf82);
      END_STATE();
    case 345:
      if (lookahead == 'o') ADVANCE(448);
      END_STATE();
    case 346:
      if (lookahead == 'i') ADVANCE(270);
      END_STATE();
    case 347:
      if (lookahead == 'e') ADVANCE(449);
      END_STATE();
    case 348:
      if (lookahead == 'c') ADVANCE(332);
      END_STATE();
    case 349:
      if (lookahead == 'e') ADVANCE(450);
      END_STATE();
    case 350:
      ACCEPT_TOKEN(anon_sym_abort);
      END_STATE();
    case 351:
      if (lookahead == 's') ADVANCE(451);
      END_STATE();
    case 352:
      if (lookahead == 'e') ADVANCE(452);
      END_STATE();
    case 353:
      if (lookahead == 'u') ADVANCE(453);
      END_STATE();
    case 354:
      if (lookahead == 'r') ADVANCE(454);
      END_STATE();
    case 355:
      if (lookahead == 'e') ADVANCE(455);
      END_STATE();
    case 356:
      if (lookahead == 'y') ADVANCE(456);
      END_STATE();
    case 357:
      if (lookahead == 'r') ADVANCE(457);
      END_STATE();
    case 358:
      if (lookahead == 'e') ADVANCE(458);
      END_STATE();
    case 359:
      if (lookahead == 's') ADVANCE(459);
      END_STATE();
    case 360:
      if (lookahead == 'r') ADVANCE(460);
      END_STATE();
    case 361:
      if (lookahead == 'e') ADVANCE(461);
      END_STATE();
    case 362:
      ACCEPT_TOKEN(anon_sym_color);
      END_STATE();
    case 363:
      if (lookahead == 'n') ADVANCE(462);
      END_STATE();
    case 364:
      if (lookahead == 'l') ADVANCE(463);
      END_STATE();
    case 365:
      ADVANCE_MAP(
        '0', 464,
        '1', 465,
        '3', 466,
        '4', 467,
        '5', 468,
        '6', 469,
        '7', 470,
        '8', 471,
      );
      END_STATE();
    case 366:
      ACCEPT_TOKEN(anon_sym_cp4372);
      END_STATE();
    case 367:
      ACCEPT_TOKEN(anon_sym_cp7372);
      END_STATE();
    case 368:
      ACCEPT_TOKEN(anon_sym_cp7752);
      END_STATE();
    case 369:
      ACCEPT_TOKEN(anon_sym_cp8502);
      END_STATE();
    case 370:
      ACCEPT_TOKEN(anon_sym_cp8522);
      END_STATE();
    case 371:
      ACCEPT_TOKEN(anon_sym_cp8552);
      END_STATE();
    case 372:
      ACCEPT_TOKEN(anon_sym_cp8572);
      END_STATE();
    case 373:
      ACCEPT_TOKEN(anon_sym_cp8602);
      END_STATE();
    case 374:
      ACCEPT_TOKEN(anon_sym_cp8612);
      END_STATE();
    case 375:
      ACCEPT_TOKEN(anon_sym_cp8622);
      END_STATE();
    case 376:
      ACCEPT_TOKEN(anon_sym_cp8632);
      END_STATE();
    case 377:
      ACCEPT_TOKEN(anon_sym_cp8652);
      END_STATE();
    case 378:
      ACCEPT_TOKEN(anon_sym_cp8662);
      END_STATE();
    case 379:
      ACCEPT_TOKEN(anon_sym_cp8692);
      END_STATE();
    case 380:
      ACCEPT_TOKEN(anon_sym_cp8742);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(anon_sym_cp9322);
      END_STATE();
    case 382:
      ACCEPT_TOKEN(anon_sym_cp9362);
      END_STATE();
    case 383:
      ACCEPT_TOKEN(anon_sym_cp9492);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(anon_sym_cp9502);
      END_STATE();
    case 385:
      if (lookahead == 'm') ADVANCE(472);
      END_STATE();
    case 386:
      if (lookahead == 'l') ADVANCE(473);
      END_STATE();
    case 387:
      if (lookahead == 'e') ADVANCE(474);
      END_STATE();
    case 388:
      if (lookahead == 't') ADVANCE(475);
      END_STATE();
    case 389:
      if (lookahead == 'e') ADVANCE(476);
      END_STATE();
    case 390:
      if (lookahead == 'i') ADVANCE(477);
      END_STATE();
    case 391:
      if (lookahead == 'o') ADVANCE(478);
      END_STATE();
    case 392:
      if (lookahead == 's') ADVANCE(479);
      END_STATE();
    case 393:
      if (lookahead == 'i') ADVANCE(480);
      END_STATE();
    case 394:
      if (lookahead == 'o') ADVANCE(481);
      END_STATE();
    case 395:
      if (lookahead == 'e') ADVANCE(482);
      END_STATE();
    case 396:
      if (lookahead == 'r') ADVANCE(483);
      END_STATE();
    case 397:
      if (lookahead == 't') ADVANCE(484);
      END_STATE();
    case 398:
      if (lookahead == 'i') ADVANCE(485);
      END_STATE();
    case 399:
      if (lookahead == 'i') ADVANCE(486);
      END_STATE();
    case 400:
      if (lookahead == 'r') ADVANCE(487);
      END_STATE();
    case 401:
      if (lookahead == 'e') ADVANCE(488);
      END_STATE();
    case 402:
      if (lookahead == 'd') ADVANCE(489);
      END_STATE();
    case 403:
      if (lookahead == 't') ADVANCE(490);
      END_STATE();
    case 404:
      if (lookahead == 's') ADVANCE(491);
      END_STATE();
    case 405:
      if (lookahead == 'w') ADVANCE(492);
      END_STATE();
    case 406:
      if (lookahead == 'c') ADVANCE(493);
      END_STATE();
    case 407:
      ACCEPT_TOKEN(anon_sym_japan2);
      END_STATE();
    case 408:
      if (lookahead == 'r') ADVANCE(494);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(anon_sym_korea2);
      END_STATE();
    case 410:
      if (lookahead == '1') ADVANCE(495);
      END_STATE();
    case 411:
      if (lookahead == 'r') ADVANCE(496);
      END_STATE();
    case 412:
      if (lookahead == 'o') ADVANCE(497);
      END_STATE();
    case 413:
      ACCEPT_TOKEN(anon_sym_lines);
      END_STATE();
    case 414:
      if (lookahead == 'd') ADVANCE(498);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(anon_sym_local);
      END_STATE();
    case 416:
      if (lookahead == 'm') ADVANCE(499);
      END_STATE();
    case 417:
      if (lookahead == 'e') ADVANCE(500);
      END_STATE();
    case 418:
      if (lookahead == 'n') ADVANCE(501);
      END_STATE();
    case 419:
      ACCEPT_TOKEN(anon_sym_match);
      END_STATE();
    case 420:
      if (lookahead == 'g') ADVANCE(502);
      END_STATE();
    case 421:
      if (lookahead == 'u') ADVANCE(503);
      END_STATE();
    case 422:
      ACCEPT_TOKEN(anon_sym_nobin);
      if (lookahead == 'a') ADVANCE(504);
      END_STATE();
    case 423:
      if (lookahead == 'b') ADVANCE(505);
      END_STATE();
    case 424:
      if (lookahead == 'l') ADVANCE(506);
      END_STATE();
    case 425:
      if (lookahead == 'n') ADVANCE(507);
      END_STATE();
    case 426:
      ACCEPT_TOKEN(anon_sym_other);
      END_STATE();
    case 427:
      if (lookahead == 'd') ADVANCE(508);
      END_STATE();
    case 428:
      ACCEPT_TOKEN(anon_sym_place);
      END_STATE();
    case 429:
      if (lookahead == 'n') ADVANCE(509);
      END_STATE();
    case 430:
      if (lookahead == 'f') ADVANCE(510);
      END_STATE();
    case 431:
      ACCEPT_TOKEN(anon_sym_range);
      END_STATE();
    case 432:
      if (lookahead == 'n') ADVANCE(511);
      END_STATE();
    case 433:
      ACCEPT_TOKEN(anon_sym_reset);
      END_STATE();
    case 434:
      if (lookahead == 's') ADVANCE(512);
      END_STATE();
    case 435:
      if (lookahead == 'c') ADVANCE(513);
      END_STATE();
    case 436:
      ACCEPT_TOKEN(anon_sym_spell);
      END_STATE();
    case 437:
      if (lookahead == 'o') ADVANCE(514);
      END_STATE();
    case 438:
      if (lookahead == 'e') ADVANCE(515);
      END_STATE();
    case 439:
      if (lookahead == 'm') ADVANCE(516);
      END_STATE();
    case 440:
      if (lookahead == 'i') ADVANCE(517);
      END_STATE();
    case 441:
      if (lookahead == 'n') ADVANCE(518);
      END_STATE();
    case 442:
      if (lookahead == 'v') ADVANCE(519);
      END_STATE();
    case 443:
      if (lookahead == 'e') ADVANCE(520);
      END_STATE();
    case 444:
      if (lookahead == 'i') ADVANCE(521);
      END_STATE();
    case 445:
      if (lookahead == 'c') ADVANCE(522);
      if (lookahead == 'd') ADVANCE(523);
      if (lookahead == 'l') ADVANCE(524);
      END_STATE();
    case 446:
      if (lookahead == 'd') ADVANCE(525);
      END_STATE();
    case 447:
      if (lookahead == 'c') ADVANCE(526);
      END_STATE();
    case 448:
      if (lookahead == 'w') ADVANCE(527);
      END_STATE();
    case 449:
      if (lookahead == 'b') ADVANCE(411);
      if (lookahead == 'c') ADVANCE(412);
      END_STATE();
    case 450:
      if (lookahead == 'f') ADVANCE(444);
      END_STATE();
    case 451:
      if (lookahead == 't') ADVANCE(528);
      END_STATE();
    case 452:
      if (lookahead == 'n') ADVANCE(529);
      END_STATE();
    case 453:
      if (lookahead == 'p') ADVANCE(530);
      END_STATE();
    case 454:
      if (lookahead == 'o') ADVANCE(531);
      END_STATE();
    case 455:
      ACCEPT_TOKEN(anon_sym_behave);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(anon_sym_binary);
      END_STATE();
    case 457:
      ACCEPT_TOKEN(anon_sym_buffer2);
      if (lookahead == 's') ADVANCE(532);
      END_STATE();
    case 458:
      if (lookahead == 'n') ADVANCE(533);
      END_STATE();
    case 459:
      if (lookahead == 'e') ADVANCE(534);
      END_STATE();
    case 460:
      if (lookahead == 'e') ADVANCE(535);
      END_STATE();
    case 461:
      if (lookahead == 'r') ADVANCE(536);
      END_STATE();
    case 462:
      if (lookahead == 'd') ADVANCE(537);
      END_STATE();
    case 463:
      if (lookahead == 'e') ADVANCE(538);
      END_STATE();
    case 464:
      ACCEPT_TOKEN(anon_sym_cp12502);
      END_STATE();
    case 465:
      ACCEPT_TOKEN(anon_sym_cp12512);
      END_STATE();
    case 466:
      ACCEPT_TOKEN(anon_sym_cp12532);
      END_STATE();
    case 467:
      ACCEPT_TOKEN(anon_sym_cp12542);
      END_STATE();
    case 468:
      ACCEPT_TOKEN(anon_sym_cp12552);
      END_STATE();
    case 469:
      ACCEPT_TOKEN(anon_sym_cp12562);
      END_STATE();
    case 470:
      ACCEPT_TOKEN(anon_sym_cp12572);
      END_STATE();
    case 471:
      ACCEPT_TOKEN(anon_sym_cp12582);
      END_STATE();
    case 472:
      ACCEPT_TOKEN(anon_sym_custom);
      if (lookahead == 'l') ADVANCE(539);
      END_STATE();
    case 473:
      if (lookahead == 't') ADVANCE(540);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(anon_sym_define);
      END_STATE();
    case 475:
      ACCEPT_TOKEN(anon_sym_detect);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(anon_sym_enable);
      END_STATE();
    case 477:
      if (lookahead == 'n') ADVANCE(541);
      END_STATE();
    case 478:
      if (lookahead == 'n') ADVANCE(542);
      END_STATE();
    case 479:
      if (lookahead == 's') ADVANCE(543);
      END_STATE();
    case 480:
      if (lookahead == 'n') ADVANCE(544);
      END_STATE();
    case 481:
      if (lookahead == 'r') ADVANCE(545);
      END_STATE();
    case 482:
      if (lookahead == 'v') ADVANCE(546);
      END_STATE();
    case 483:
      if (lookahead == 'o') ADVANCE(547);
      END_STATE();
    case 484:
      if (lookahead == 'a') ADVANCE(548);
      END_STATE();
    case 485:
      if (lookahead == 'o') ADVANCE(549);
      END_STATE();
    case 486:
      if (lookahead == 'g') ADVANCE(550);
      END_STATE();
    case 487:
      if (lookahead == 'y') ADVANCE(551);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(anon_sym_ignore);
      END_STATE();
    case 489:
      if (lookahead == 'e') ADVANCE(552);
      END_STATE();
    case 490:
      ACCEPT_TOKEN(anon_sym_indent);
      END_STATE();
    case 491:
      if (lookahead == 'e') ADVANCE(553);
      END_STATE();
    case 492:
      if (lookahead == 'o') ADVANCE(554);
      END_STATE();
    case 493:
      ACCEPT_TOKEN(anon_sym_italic);
      END_STATE();
    case 494:
      if (lookahead == 'd') ADVANCE(555);
      END_STATE();
    case 495:
      ACCEPT_TOKEN(anon_sym_latin12);
      END_STATE();
    case 496:
      if (lookahead == 'e') ADVANCE(556);
      END_STATE();
    case 497:
      if (lookahead == 'n') ADVANCE(557);
      END_STATE();
    case 498:
      if (lookahead == '_') ADVANCE(558);
      END_STATE();
    case 499:
      if (lookahead == 'a') ADVANCE(559);
      END_STATE();
    case 500:
      if (lookahead == 'a') ADVANCE(560);
      END_STATE();
    case 501:
      if (lookahead == 'g') ADVANCE(561);
      END_STATE();
    case 502:
      if (lookahead == 'e') ADVANCE(562);
      END_STATE();
    case 503:
      if (lookahead == 'm') ADVANCE(563);
      END_STATE();
    case 504:
      if (lookahead == 'r') ADVANCE(564);
      END_STATE();
    case 505:
      if (lookahead == 'i') ADVANCE(565);
      END_STATE();
    case 506:
      if (lookahead == 'e') ADVANCE(566);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(anon_sym_option);
      END_STATE();
    case 508:
      if (lookahead == 'd') ADVANCE(567);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(anon_sym_plugin);
      END_STATE();
    case 510:
      if (lookahead == 'i') ADVANCE(568);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(anon_sym_region);
      END_STATE();
    case 512:
      if (lookahead == 'e') ADVANCE(569);
      END_STATE();
    case 513:
      if (lookahead == 'm') ADVANCE(570);
      END_STATE();
    case 514:
      if (lookahead == 'u') ADVANCE(571);
      END_STATE();
    case 515:
      if (lookahead == 't') ADVANCE(572);
      END_STATE();
    case 516:
      if (lookahead == 'e') ADVANCE(573);
      END_STATE();
    case 517:
      if (lookahead == 's') ADVANCE(574);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(anon_sym_taiwan2);
      END_STATE();
    case 519:
      if (lookahead == 'e') ADVANCE(575);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(anon_sym_ucs2be2);
      END_STATE();
    case 521:
      if (lookahead == 'n') ADVANCE(576);
      END_STATE();
    case 522:
      if (lookahead == 'u') ADVANCE(577);
      END_STATE();
    case 523:
      if (lookahead == 'a') ADVANCE(578);
      if (lookahead == 'o') ADVANCE(579);
      END_STATE();
    case 524:
      if (lookahead == 'i') ADVANCE(580);
      END_STATE();
    case 525:
      if (lookahead == 'e') ADVANCE(581);
      END_STATE();
    case 526:
      if (lookahead == 'e') ADVANCE(582);
      END_STATE();
    case 527:
      if (lookahead == 's') ADVANCE(583);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(anon_sym_arglist);
      END_STATE();
    case 529:
      if (lookahead == 't') ADVANCE(584);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(anon_sym_augroup);
      END_STATE();
    case 531:
      if (lookahead == 'u') ADVANCE(585);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(anon_sym_buffers);
      END_STATE();
    case 533:
      if (lookahead == 't') ADVANCE(586);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(anon_sym_chinese2);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(anon_sym_closure);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(anon_sym_cluster);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(anon_sym_command);
      END_STATE();
    case 538:
      if (lookahead == 'r') ADVANCE(587);
      END_STATE();
    case 539:
      if (lookahead == 'i') ADVANCE(588);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(anon_sym_default2);
      END_STATE();
    case 541:
      if (lookahead == 'g') ADVANCE(589);
      END_STATE();
    case 542:
      if (lookahead == 'm') ADVANCE(590);
      END_STATE();
    case 543:
      if (lookahead == 'i') ADVANCE(591);
      END_STATE();
    case 544:
      if (lookahead == '_') ADVANCE(592);
      END_STATE();
    case 545:
      if (lookahead == 'm') ADVANCE(593);
      END_STATE();
    case 546:
      if (lookahead == 'e') ADVANCE(594);
      END_STATE();
    case 547:
      if (lookahead == 'u') ADVANCE(595);
      END_STATE();
    case 548:
      if (lookahead == 'r') ADVANCE(596);
      END_STATE();
    case 549:
      if (lookahead == 'n') ADVANCE(597);
      END_STATE();
    case 550:
      if (lookahead == 'h') ADVANCE(598);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(anon_sym_history);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(anon_sym_include);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(anon_sym_inverse);
      END_STATE();
    case 554:
      if (lookahead == 'r') ADVANCE(599);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(anon_sym_keyword);
      END_STATE();
    case 556:
      if (lookahead == 'a') ADVANCE(600);
      END_STATE();
    case 557:
      if (lookahead == 't') ADVANCE(601);
      END_STATE();
    case 558:
      if (lookahead == 'b') ADVANCE(602);
      END_STATE();
    case 559:
      if (lookahead == 'n') ADVANCE(603);
      END_STATE();
    case 560:
      if (lookahead == 'r') ADVANCE(604);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(anon_sym_mapping);
      END_STATE();
    case 562:
      if (lookahead == 's') ADVANCE(605);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(anon_sym_minimum);
      END_STATE();
    case 564:
      if (lookahead == 'y') ADVANCE(606);
      END_STATE();
    case 565:
      if (lookahead == 'n') ADVANCE(607);
      END_STATE();
    case 566:
      if (lookahead == 'v') ADVANCE(608);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(anon_sym_packadd);
      END_STATE();
    case 568:
      if (lookahead == 'x') ADVANCE(609);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(anon_sym_reverse);
      END_STATE();
    case 570:
      if (lookahead == 'd') ADVANCE(610);
      END_STATE();
    case 571:
      if (lookahead == 't') ADVANCE(611);
      END_STATE();
    case 572:
      if (lookahead == 'h') ADVANCE(612);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(anon_sym_syntime);
      END_STATE();
    case 574:
      if (lookahead == 't') ADVANCE(613);
      END_STATE();
    case 575:
      if (lookahead == 'l') ADVANCE(614);
      END_STATE();
    case 576:
      if (lookahead == 'e') ADVANCE(615);
      END_STATE();
    case 577:
      if (lookahead == 'r') ADVANCE(616);
      END_STATE();
    case 578:
      if (lookahead == 's') ADVANCE(617);
      END_STATE();
    case 579:
      if (lookahead == 't') ADVANCE(618);
      if (lookahead == 'u') ADVANCE(619);
      END_STATE();
    case 580:
      if (lookahead == 'n') ADVANCE(620);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(anon_sym_unicode2);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(anon_sym_unplace);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(anon_sym_windows);
      END_STATE();
    case 584:
      if (lookahead == 's') ADVANCE(621);
      END_STATE();
    case 585:
      if (lookahead == 'n') ADVANCE(622);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(anon_sym_ccomment);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(anon_sym_compiler);
      END_STATE();
    case 588:
      if (lookahead == 's') ADVANCE(623);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(anon_sym_encoding);
      END_STATE();
    case 590:
      if (lookahead == 'e') ADVANCE(624);
      END_STATE();
    case 591:
      if (lookahead == 'o') ADVANCE(625);
      END_STATE();
    case 592:
      if (lookahead == 'p') ADVANCE(626);
      END_STATE();
    case 593:
      if (lookahead == 'a') ADVANCE(627);
      END_STATE();
    case 594:
      if (lookahead == 'l') ADVANCE(628);
      END_STATE();
    case 595:
      if (lookahead == 'n') ADVANCE(629);
      END_STATE();
    case 596:
      if (lookahead == 't') ADVANCE(630);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 598:
      if (lookahead == 't') ADVANCE(631);
      END_STATE();
    case 599:
      if (lookahead == 'd') ADVANCE(632);
      END_STATE();
    case 600:
      if (lookahead == 'k') ADVANCE(633);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(anon_sym_linecont);
      END_STATE();
    case 602:
      if (lookahead == 'u') ADVANCE(634);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(anon_sym_macroman2);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(anon_sym_mapclear);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(anon_sym_messages);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(anon_sym_nobinary);
      END_STATE();
    case 607:
      if (lookahead == 'e') ADVANCE(635);
      END_STATE();
    case 608:
      if (lookahead == 'e') ADVANCE(636);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(anon_sym_quickfix);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(anon_sym_shellcmd);
      END_STATE();
    case 611:
      ACCEPT_TOKEN(anon_sym_standout);
      END_STATE();
    case 612:
      if (lookahead == 'r') ADVANCE(637);
      END_STATE();
    case 613:
      if (lookahead == 'f') ADVANCE(638);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(anon_sym_toplevel);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(anon_sym_undefine);
      END_STATE();
    case 616:
      if (lookahead == 'l') ADVANCE(639);
      END_STATE();
    case 617:
      if (lookahead == 'h') ADVANCE(640);
      END_STATE();
    case 618:
      if (lookahead == 't') ADVANCE(641);
      END_STATE();
    case 619:
      if (lookahead == 'b') ADVANCE(642);
      END_STATE();
    case 620:
      if (lookahead == 'e') ADVANCE(643);
      END_STATE();
    case 621:
      ACCEPT_TOKEN(anon_sym_arguments);
      END_STATE();
    case 622:
      if (lookahead == 'd') ADVANCE(644);
      END_STATE();
    case 623:
      if (lookahead == 't') ADVANCE(645);
      END_STATE();
    case 624:
      if (lookahead == 'n') ADVANCE(646);
      END_STATE();
    case 625:
      if (lookahead == 'n') ADVANCE(647);
      END_STATE();
    case 626:
      if (lookahead == 'a') ADVANCE(648);
      END_STATE();
    case 627:
      if (lookahead == 't') ADVANCE(649);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(anon_sym_foldlevel);
      END_STATE();
    case 629:
      if (lookahead == 'd') ADVANCE(650);
      END_STATE();
    case 630:
      ACCEPT_TOKEN(anon_sym_fromstart);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(anon_sym_highlight);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(anon_sym_iskeyword);
      END_STATE();
    case 633:
      if (lookahead == 's') ADVANCE(651);
      END_STATE();
    case 634:
      if (lookahead == 'f') ADVANCE(652);
      END_STATE();
    case 635:
      ACCEPT_TOKEN(anon_sym_nocombine);
      END_STATE();
    case 636:
      if (lookahead == 'l') ADVANCE(653);
      END_STATE();
    case 637:
      if (lookahead == 'o') ADVANCE(654);
      END_STATE();
    case 638:
      if (lookahead == 'i') ADVANCE(655);
      END_STATE();
    case 639:
      ACCEPT_TOKEN(anon_sym_undercurl);
      END_STATE();
    case 640:
      if (lookahead == 'e') ADVANCE(656);
      END_STATE();
    case 641:
      if (lookahead == 'e') ADVANCE(657);
      END_STATE();
    case 642:
      if (lookahead == 'l') ADVANCE(658);
      END_STATE();
    case 643:
      ACCEPT_TOKEN(anon_sym_underline);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(anon_sym_background);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(anon_sym_customlist);
      END_STATE();
    case 646:
      if (lookahead == 't') ADVANCE(659);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(anon_sym_expression);
      END_STATE();
    case 648:
      if (lookahead == 't') ADVANCE(660);
      END_STATE();
    case 649:
      ACCEPT_TOKEN(anon_sym_fileformat);
      END_STATE();
    case 650:
      ACCEPT_TOKEN(anon_sym_foreground);
      END_STATE();
    case 651:
      ACCEPT_TOKEN(anon_sym_linebreaks);
      END_STATE();
    case 652:
      if (lookahead == 'f') ADVANCE(661);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(anon_sym_notoplevel);
      END_STATE();
    case 654:
      if (lookahead == 'u') ADVANCE(662);
      END_STATE();
    case 655:
      if (lookahead == 'l') ADVANCE(663);
      END_STATE();
    case 656:
      if (lookahead == 'd') ADVANCE(664);
      END_STATE();
    case 657:
      if (lookahead == 'd') ADVANCE(665);
      END_STATE();
    case 658:
      if (lookahead == 'e') ADVANCE(666);
      END_STATE();
    case 659:
      ACCEPT_TOKEN(anon_sym_environment);
      END_STATE();
    case 660:
      if (lookahead == 'h') ADVANCE(667);
      END_STATE();
    case 661:
      if (lookahead == 'e') ADVANCE(668);
      END_STATE();
    case 662:
      if (lookahead == 'g') ADVANCE(669);
      END_STATE();
    case 663:
      if (lookahead == 'e') ADVANCE(670);
      END_STATE();
    case 664:
      ACCEPT_TOKEN(anon_sym_underdashed);
      END_STATE();
    case 665:
      ACCEPT_TOKEN(anon_sym_underdotted);
      END_STATE();
    case 666:
      ACCEPT_TOKEN(anon_sym_underdouble);
      END_STATE();
    case 667:
      ACCEPT_TOKEN(anon_sym_file_in_path);
      END_STATE();
    case 668:
      if (lookahead == 'r') ADVANCE(671);
      END_STATE();
    case 669:
      if (lookahead == 'h') ADVANCE(672);
      END_STATE();
    case 670:
      if (lookahead == 's') ADVANCE(673);
      END_STATE();
    case 671:
      if (lookahead == 's') ADVANCE(674);
      END_STATE();
    case 672:
      ACCEPT_TOKEN(anon_sym_strikethrough);
      END_STATE();
    case 673:
      ACCEPT_TOKEN(anon_sym_tag_listfiles);
      END_STATE();
    case 674:
      ACCEPT_TOKEN(anon_sym_loaded_buffers);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 840, .external_lex_state = 2},
  [2] = {.lex_state = 840, .external_lex_state = 3},
  [3] = {.lex_state = 840, .external_lex_state = 4},
  [4] = {.lex_state = 840, .external_lex_state = 3},
  [5] = {.lex_state = 840, .external_lex_state = 4},
  [6] = {.lex_state = 840, .external_lex_state = 4},
  [7] = {.lex_state = 840, .external_lex_state = 4},
  [8] = {.lex_state = 840, .external_lex_state = 3},
  [9] = {.lex_state = 840, .external_lex_state = 3},
  [10] = {.lex_state = 840, .external_lex_state = 3},
  [11] = {.lex_state = 840, .external_lex_state = 3},
  [12] = {.lex_state = 840, .external_lex_state = 3},
  [13] = {.lex_state = 840, .external_lex_state = 4},
  [14] = {.lex_state = 840, .external_lex_state = 4},
  [15] = {.lex_state = 840, .external_lex_state = 4},
  [16] = {.lex_state = 840, .external_lex_state = 3},
  [17] = {.lex_state = 840, .external_lex_state = 3},
  [18] = {.lex_state = 840, .external_lex_state = 5},
  [19] = {.lex_state = 840, .external_lex_state = 6},
  [20] = {.lex_state = 840, .external_lex_state = 5},
  [21] = {.lex_state = 840, .external_lex_state = 5},
  [22] = {.lex_state = 840, .external_lex_state = 6},
  [23] = {.lex_state = 840, .external_lex_state = 7},
  [24] = {.lex_state = 840, .external_lex_state = 5},
  [25] = {.lex_state = 840, .external_lex_state = 6},
  [26] = {.lex_state = 840, .external_lex_state = 8},
  [27] = {.lex_state = 840, .external_lex_state = 5},
  [28] = {.lex_state = 840, .external_lex_state = 5},
  [29] = {.lex_state = 840, .external_lex_state = 8},
  [30] = {.lex_state = 105, .external_lex_state = 9},
  [31] = {.lex_state = 105, .external_lex_state = 9},
  [32] = {.lex_state = 105, .external_lex_state = 9},
  [33] = {.lex_state = 840, .external_lex_state = 2},
  [34] = {.lex_state = 840, .external_lex_state = 7},
  [35] = {.lex_state = 840, .external_lex_state = 5},
  [36] = {.lex_state = 840, .external_lex_state = 8},
  [37] = {.lex_state = 840, .external_lex_state = 2},
  [38] = {.lex_state = 840, .external_lex_state = 10},
  [39] = {.lex_state = 840, .external_lex_state = 7},
  [40] = {.lex_state = 840, .external_lex_state = 6},
  [41] = {.lex_state = 840, .external_lex_state = 10},
  [42] = {.lex_state = 840, .external_lex_state = 5},
  [43] = {.lex_state = 840, .external_lex_state = 8},
  [44] = {.lex_state = 840, .external_lex_state = 10},
  [45] = {.lex_state = 840, .external_lex_state = 5},
  [46] = {.lex_state = 840, .external_lex_state = 5},
  [47] = {.lex_state = 840, .external_lex_state = 8},
  [48] = {.lex_state = 840, .external_lex_state = 5},
  [49] = {.lex_state = 840, .external_lex_state = 5},
  [50] = {.lex_state = 840, .external_lex_state = 6},
  [51] = {.lex_state = 840, .external_lex_state = 5},
  [52] = {.lex_state = 105, .external_lex_state = 9},
  [53] = {.lex_state = 105, .external_lex_state = 2},
  [54] = {.lex_state = 105, .external_lex_state = 2},
  [55] = {.lex_state = 105, .external_lex_state = 2},
  [56] = {.lex_state = 105, .external_lex_state = 2},
  [57] = {.lex_state = 840, .external_lex_state = 9},
  [58] = {.lex_state = 840, .external_lex_state = 9},
  [59] = {.lex_state = 106, .external_lex_state = 9},
  [60] = {.lex_state = 106, .external_lex_state = 9},
  [61] = {.lex_state = 840, .external_lex_state = 9},
  [62] = {.lex_state = 840, .external_lex_state = 9},
  [63] = {.lex_state = 840, .external_lex_state = 9},
  [64] = {.lex_state = 840, .external_lex_state = 9},
  [65] = {.lex_state = 840, .external_lex_state = 9},
  [66] = {.lex_state = 840, .external_lex_state = 9},
  [67] = {.lex_state = 840, .external_lex_state = 9},
  [68] = {.lex_state = 840, .external_lex_state = 9},
  [69] = {.lex_state = 840, .external_lex_state = 9},
  [70] = {.lex_state = 840, .external_lex_state = 9},
  [71] = {.lex_state = 840, .external_lex_state = 9},
  [72] = {.lex_state = 840, .external_lex_state = 9},
  [73] = {.lex_state = 840, .external_lex_state = 9},
  [74] = {.lex_state = 840, .external_lex_state = 9},
  [75] = {.lex_state = 840, .external_lex_state = 9},
  [76] = {.lex_state = 840, .external_lex_state = 9},
  [77] = {.lex_state = 840, .external_lex_state = 9},
  [78] = {.lex_state = 840, .external_lex_state = 9},
  [79] = {.lex_state = 840, .external_lex_state = 9},
  [80] = {.lex_state = 840, .external_lex_state = 9},
  [81] = {.lex_state = 840, .external_lex_state = 9},
  [82] = {.lex_state = 840, .external_lex_state = 9},
  [83] = {.lex_state = 840, .external_lex_state = 9},
  [84] = {.lex_state = 840, .external_lex_state = 9},
  [85] = {.lex_state = 840, .external_lex_state = 9},
  [86] = {.lex_state = 840, .external_lex_state = 9},
  [87] = {.lex_state = 840, .external_lex_state = 9},
  [88] = {.lex_state = 840, .external_lex_state = 9},
  [89] = {.lex_state = 840, .external_lex_state = 9},
  [90] = {.lex_state = 840, .external_lex_state = 9},
  [91] = {.lex_state = 840, .external_lex_state = 9},
  [92] = {.lex_state = 840, .external_lex_state = 9},
  [93] = {.lex_state = 840, .external_lex_state = 9},
  [94] = {.lex_state = 840, .external_lex_state = 9},
  [95] = {.lex_state = 840, .external_lex_state = 9},
  [96] = {.lex_state = 105, .external_lex_state = 9},
  [97] = {.lex_state = 105, .external_lex_state = 9},
  [98] = {.lex_state = 105, .external_lex_state = 9},
  [99] = {.lex_state = 105, .external_lex_state = 2},
  [100] = {.lex_state = 105, .external_lex_state = 2},
  [101] = {.lex_state = 105, .external_lex_state = 9},
  [102] = {.lex_state = 105, .external_lex_state = 2},
  [103] = {.lex_state = 840, .external_lex_state = 4},
  [104] = {.lex_state = 105, .external_lex_state = 2},
  [105] = {.lex_state = 840, .external_lex_state = 4},
  [106] = {.lex_state = 840, .external_lex_state = 3},
  [107] = {.lex_state = 840, .external_lex_state = 3},
  [108] = {.lex_state = 840, .external_lex_state = 2},
  [109] = {.lex_state = 840, .external_lex_state = 5},
  [110] = {.lex_state = 840, .external_lex_state = 10},
  [111] = {.lex_state = 840, .external_lex_state = 8},
  [112] = {.lex_state = 840, .external_lex_state = 5},
  [113] = {.lex_state = 840, .external_lex_state = 10},
  [114] = {.lex_state = 840, .external_lex_state = 7},
  [115] = {.lex_state = 840, .external_lex_state = 7},
  [116] = {.lex_state = 840, .external_lex_state = 6},
  [117] = {.lex_state = 840, .external_lex_state = 6},
  [118] = {.lex_state = 840, .external_lex_state = 2},
  [119] = {.lex_state = 840, .external_lex_state = 8},
  [120] = {.lex_state = 840, .external_lex_state = 9},
  [121] = {.lex_state = 840, .external_lex_state = 9},
  [122] = {.lex_state = 61, .external_lex_state = 11},
  [123] = {.lex_state = 61, .external_lex_state = 11},
  [124] = {.lex_state = 840, .external_lex_state = 12},
  [125] = {.lex_state = 840, .external_lex_state = 13},
  [126] = {.lex_state = 32, .external_lex_state = 12},
  [127] = {.lex_state = 32, .external_lex_state = 12},
  [128] = {.lex_state = 32, .external_lex_state = 12},
  [129] = {.lex_state = 32, .external_lex_state = 12},
  [130] = {.lex_state = 32, .external_lex_state = 12},
  [131] = {.lex_state = 236, .external_lex_state = 12},
  [132] = {.lex_state = 239, .external_lex_state = 12},
  [133] = {.lex_state = 207, .external_lex_state = 13},
  [134] = {.lex_state = 236, .external_lex_state = 12},
  [135] = {.lex_state = 239, .external_lex_state = 12},
  [136] = {.lex_state = 207, .external_lex_state = 13},
  [137] = {.lex_state = 65, .external_lex_state = 11},
  [138] = {.lex_state = 3, .external_lex_state = 12},
  [139] = {.lex_state = 65, .external_lex_state = 14},
  [140] = {.lex_state = 61, .external_lex_state = 12},
  [141] = {.lex_state = 61, .external_lex_state = 12},
  [142] = {.lex_state = 83, .external_lex_state = 15},
  [143] = {.lex_state = 83, .external_lex_state = 15},
  [144] = {.lex_state = 65, .external_lex_state = 11},
  [145] = {.lex_state = 65, .external_lex_state = 11},
  [146] = {.lex_state = 65, .external_lex_state = 11},
  [147] = {.lex_state = 65, .external_lex_state = 11},
  [148] = {.lex_state = 65, .external_lex_state = 11},
  [149] = {.lex_state = 65, .external_lex_state = 11},
  [150] = {.lex_state = 65, .external_lex_state = 11},
  [151] = {.lex_state = 65, .external_lex_state = 11},
  [152] = {.lex_state = 65, .external_lex_state = 11},
  [153] = {.lex_state = 65, .external_lex_state = 11},
  [154] = {.lex_state = 65, .external_lex_state = 11},
  [155] = {.lex_state = 65, .external_lex_state = 11},
  [156] = {.lex_state = 65, .external_lex_state = 11},
  [157] = {.lex_state = 65, .external_lex_state = 11},
  [158] = {.lex_state = 65, .external_lex_state = 11},
  [159] = {.lex_state = 93, .external_lex_state = 11},
  [160] = {.lex_state = 65, .external_lex_state = 11},
  [161] = {.lex_state = 93, .external_lex_state = 11},
  [162] = {.lex_state = 65, .external_lex_state = 11},
  [163] = {.lex_state = 93, .external_lex_state = 11},
  [164] = {.lex_state = 65, .external_lex_state = 11},
  [165] = {.lex_state = 83, .external_lex_state = 15},
  [166] = {.lex_state = 65, .external_lex_state = 11},
  [167] = {.lex_state = 65, .external_lex_state = 11},
  [168] = {.lex_state = 65, .external_lex_state = 14},
  [169] = {.lex_state = 31, .external_lex_state = 11},
  [170] = {.lex_state = 65, .external_lex_state = 11},
  [171] = {.lex_state = 65, .external_lex_state = 11},
  [172] = {.lex_state = 86, .external_lex_state = 16},
  [173] = {.lex_state = 65, .external_lex_state = 14},
  [174] = {.lex_state = 65, .external_lex_state = 14},
  [175] = {.lex_state = 86, .external_lex_state = 16},
  [176] = {.lex_state = 86, .external_lex_state = 16},
  [177] = {.lex_state = 65, .external_lex_state = 14},
  [178] = {.lex_state = 31, .external_lex_state = 11},
  [179] = {.lex_state = 31, .external_lex_state = 11},
  [180] = {.lex_state = 65, .external_lex_state = 14},
  [181] = {.lex_state = 65, .external_lex_state = 14},
  [182] = {.lex_state = 65, .external_lex_state = 14},
  [183] = {.lex_state = 65, .external_lex_state = 14},
  [184] = {.lex_state = 65, .external_lex_state = 14},
  [185] = {.lex_state = 65, .external_lex_state = 11},
  [186] = {.lex_state = 65, .external_lex_state = 11},
  [187] = {.lex_state = 65, .external_lex_state = 11},
  [188] = {.lex_state = 65, .external_lex_state = 14},
  [189] = {.lex_state = 65, .external_lex_state = 11},
  [190] = {.lex_state = 65, .external_lex_state = 14},
  [191] = {.lex_state = 94, .external_lex_state = 14},
  [192] = {.lex_state = 65, .external_lex_state = 14},
  [193] = {.lex_state = 94, .external_lex_state = 14},
  [194] = {.lex_state = 65, .external_lex_state = 11},
  [195] = {.lex_state = 94, .external_lex_state = 14},
  [196] = {.lex_state = 31, .external_lex_state = 11},
  [197] = {.lex_state = 65, .external_lex_state = 11},
  [198] = {.lex_state = 65, .external_lex_state = 11},
  [199] = {.lex_state = 91, .external_lex_state = 11},
  [200] = {.lex_state = 93, .external_lex_state = 11},
  [201] = {.lex_state = 65, .external_lex_state = 11},
  [202] = {.lex_state = 65, .external_lex_state = 11},
  [203] = {.lex_state = 65, .external_lex_state = 11},
  [204] = {.lex_state = 65, .external_lex_state = 11},
  [205] = {.lex_state = 93, .external_lex_state = 11},
  [206] = {.lex_state = 65, .external_lex_state = 11},
  [207] = {.lex_state = 65, .external_lex_state = 11},
  [208] = {.lex_state = 83, .external_lex_state = 15},
  [209] = {.lex_state = 65, .external_lex_state = 11},
  [210] = {.lex_state = 65, .external_lex_state = 11},
  [211] = {.lex_state = 65, .external_lex_state = 11},
  [212] = {.lex_state = 65, .external_lex_state = 11},
  [213] = {.lex_state = 83, .external_lex_state = 15},
  [214] = {.lex_state = 65, .external_lex_state = 11},
  [215] = {.lex_state = 65, .external_lex_state = 11},
  [216] = {.lex_state = 65, .external_lex_state = 11},
  [217] = {.lex_state = 65, .external_lex_state = 11},
  [218] = {.lex_state = 65, .external_lex_state = 14},
  [219] = {.lex_state = 65, .external_lex_state = 11},
  [220] = {.lex_state = 65, .external_lex_state = 11},
  [221] = {.lex_state = 65, .external_lex_state = 11},
  [222] = {.lex_state = 65, .external_lex_state = 11},
  [223] = {.lex_state = 65, .external_lex_state = 11},
  [224] = {.lex_state = 65, .external_lex_state = 11},
  [225] = {.lex_state = 65, .external_lex_state = 11},
  [226] = {.lex_state = 65, .external_lex_state = 11},
  [227] = {.lex_state = 65, .external_lex_state = 11},
  [228] = {.lex_state = 86, .external_lex_state = 16},
  [229] = {.lex_state = 65, .external_lex_state = 11},
  [230] = {.lex_state = 65, .external_lex_state = 11},
  [231] = {.lex_state = 65, .external_lex_state = 11},
  [232] = {.lex_state = 65, .external_lex_state = 11},
  [233] = {.lex_state = 65, .external_lex_state = 11},
  [234] = {.lex_state = 65, .external_lex_state = 11},
  [235] = {.lex_state = 65, .external_lex_state = 11},
  [236] = {.lex_state = 92, .external_lex_state = 14},
  [237] = {.lex_state = 65, .external_lex_state = 11},
  [238] = {.lex_state = 65, .external_lex_state = 11},
  [239] = {.lex_state = 65, .external_lex_state = 11},
  [240] = {.lex_state = 65, .external_lex_state = 11},
  [241] = {.lex_state = 65, .external_lex_state = 11},
  [242] = {.lex_state = 65, .external_lex_state = 11},
  [243] = {.lex_state = 65, .external_lex_state = 11},
  [244] = {.lex_state = 86, .external_lex_state = 16},
  [245] = {.lex_state = 65, .external_lex_state = 11},
  [246] = {.lex_state = 65, .external_lex_state = 11},
  [247] = {.lex_state = 65, .external_lex_state = 11},
  [248] = {.lex_state = 65, .external_lex_state = 11},
  [249] = {.lex_state = 65, .external_lex_state = 11},
  [250] = {.lex_state = 65, .external_lex_state = 11},
  [251] = {.lex_state = 65, .external_lex_state = 11},
  [252] = {.lex_state = 65, .external_lex_state = 11},
  [253] = {.lex_state = 65, .external_lex_state = 11},
  [254] = {.lex_state = 65, .external_lex_state = 11},
  [255] = {.lex_state = 65, .external_lex_state = 11},
  [256] = {.lex_state = 65, .external_lex_state = 11},
  [257] = {.lex_state = 65, .external_lex_state = 11},
  [258] = {.lex_state = 65, .external_lex_state = 11},
  [259] = {.lex_state = 65, .external_lex_state = 11},
  [260] = {.lex_state = 94, .external_lex_state = 14},
  [261] = {.lex_state = 65, .external_lex_state = 11},
  [262] = {.lex_state = 65, .external_lex_state = 11},
  [263] = {.lex_state = 94, .external_lex_state = 14},
  [264] = {.lex_state = 65, .external_lex_state = 11},
  [265] = {.lex_state = 65, .external_lex_state = 11},
  [266] = {.lex_state = 65, .external_lex_state = 11},
  [267] = {.lex_state = 65, .external_lex_state = 11},
  [268] = {.lex_state = 65, .external_lex_state = 11},
  [269] = {.lex_state = 65, .external_lex_state = 11},
  [270] = {.lex_state = 65, .external_lex_state = 11},
  [271] = {.lex_state = 65, .external_lex_state = 11},
  [272] = {.lex_state = 65, .external_lex_state = 11},
  [273] = {.lex_state = 65, .external_lex_state = 11},
  [274] = {.lex_state = 81, .external_lex_state = 15},
  [275] = {.lex_state = 65, .external_lex_state = 11},
  [276] = {.lex_state = 65, .external_lex_state = 11},
  [277] = {.lex_state = 65, .external_lex_state = 11},
  [278] = {.lex_state = 65, .external_lex_state = 11},
  [279] = {.lex_state = 65, .external_lex_state = 11},
  [280] = {.lex_state = 65, .external_lex_state = 11},
  [281] = {.lex_state = 65, .external_lex_state = 11},
  [282] = {.lex_state = 65, .external_lex_state = 11},
  [283] = {.lex_state = 65, .external_lex_state = 11},
  [284] = {.lex_state = 65, .external_lex_state = 11},
  [285] = {.lex_state = 65, .external_lex_state = 11},
  [286] = {.lex_state = 65, .external_lex_state = 11},
  [287] = {.lex_state = 65, .external_lex_state = 11},
  [288] = {.lex_state = 65, .external_lex_state = 11},
  [289] = {.lex_state = 65, .external_lex_state = 11},
  [290] = {.lex_state = 65, .external_lex_state = 11},
  [291] = {.lex_state = 65, .external_lex_state = 11},
  [292] = {.lex_state = 65, .external_lex_state = 11},
  [293] = {.lex_state = 89, .external_lex_state = 11},
  [294] = {.lex_state = 65, .external_lex_state = 11},
  [295] = {.lex_state = 89, .external_lex_state = 11},
  [296] = {.lex_state = 89, .external_lex_state = 11},
  [297] = {.lex_state = 89, .external_lex_state = 11},
  [298] = {.lex_state = 65, .external_lex_state = 11},
  [299] = {.lex_state = 65, .external_lex_state = 11},
  [300] = {.lex_state = 65, .external_lex_state = 11},
  [301] = {.lex_state = 65, .external_lex_state = 11},
  [302] = {.lex_state = 65, .external_lex_state = 11},
  [303] = {.lex_state = 65, .external_lex_state = 11},
  [304] = {.lex_state = 89, .external_lex_state = 11},
  [305] = {.lex_state = 65, .external_lex_state = 11},
  [306] = {.lex_state = 65, .external_lex_state = 11},
  [307] = {.lex_state = 89, .external_lex_state = 11},
  [308] = {.lex_state = 89, .external_lex_state = 11},
  [309] = {.lex_state = 89, .external_lex_state = 11},
  [310] = {.lex_state = 89, .external_lex_state = 11},
  [311] = {.lex_state = 89, .external_lex_state = 11},
  [312] = {.lex_state = 89, .external_lex_state = 11},
  [313] = {.lex_state = 89, .external_lex_state = 11},
  [314] = {.lex_state = 89, .external_lex_state = 11},
  [315] = {.lex_state = 65, .external_lex_state = 11},
  [316] = {.lex_state = 89, .external_lex_state = 11},
  [317] = {.lex_state = 89, .external_lex_state = 11},
  [318] = {.lex_state = 89, .external_lex_state = 11},
  [319] = {.lex_state = 89, .external_lex_state = 11},
  [320] = {.lex_state = 89, .external_lex_state = 11},
  [321] = {.lex_state = 89, .external_lex_state = 11},
  [322] = {.lex_state = 89, .external_lex_state = 11},
  [323] = {.lex_state = 89, .external_lex_state = 11},
  [324] = {.lex_state = 65, .external_lex_state = 11},
  [325] = {.lex_state = 89, .external_lex_state = 11},
  [326] = {.lex_state = 89, .external_lex_state = 11},
  [327] = {.lex_state = 89, .external_lex_state = 11},
  [328] = {.lex_state = 89, .external_lex_state = 11},
  [329] = {.lex_state = 89, .external_lex_state = 11},
  [330] = {.lex_state = 89, .external_lex_state = 11},
  [331] = {.lex_state = 89, .external_lex_state = 11},
  [332] = {.lex_state = 89, .external_lex_state = 11},
  [333] = {.lex_state = 89, .external_lex_state = 11},
  [334] = {.lex_state = 89, .external_lex_state = 11},
  [335] = {.lex_state = 89, .external_lex_state = 11},
  [336] = {.lex_state = 89, .external_lex_state = 11},
  [337] = {.lex_state = 89, .external_lex_state = 11},
  [338] = {.lex_state = 65, .external_lex_state = 11},
  [339] = {.lex_state = 89, .external_lex_state = 11},
  [340] = {.lex_state = 89, .external_lex_state = 11},
  [341] = {.lex_state = 65, .external_lex_state = 11},
  [342] = {.lex_state = 89, .external_lex_state = 11},
  [343] = {.lex_state = 89, .external_lex_state = 11},
  [344] = {.lex_state = 89, .external_lex_state = 11},
  [345] = {.lex_state = 89, .external_lex_state = 11},
  [346] = {.lex_state = 89, .external_lex_state = 11},
  [347] = {.lex_state = 89, .external_lex_state = 11},
  [348] = {.lex_state = 89, .external_lex_state = 11},
  [349] = {.lex_state = 65, .external_lex_state = 11},
  [350] = {.lex_state = 65, .external_lex_state = 11},
  [351] = {.lex_state = 89, .external_lex_state = 11},
  [352] = {.lex_state = 89, .external_lex_state = 11},
  [353] = {.lex_state = 89, .external_lex_state = 11},
  [354] = {.lex_state = 89, .external_lex_state = 11},
  [355] = {.lex_state = 89, .external_lex_state = 11},
  [356] = {.lex_state = 65, .external_lex_state = 11},
  [357] = {.lex_state = 65, .external_lex_state = 11},
  [358] = {.lex_state = 89, .external_lex_state = 11},
  [359] = {.lex_state = 65, .external_lex_state = 11},
  [360] = {.lex_state = 65, .external_lex_state = 11},
  [361] = {.lex_state = 65, .external_lex_state = 11},
  [362] = {.lex_state = 65, .external_lex_state = 11},
  [363] = {.lex_state = 65, .external_lex_state = 11},
  [364] = {.lex_state = 65, .external_lex_state = 11},
  [365] = {.lex_state = 65, .external_lex_state = 11},
  [366] = {.lex_state = 65, .external_lex_state = 11},
  [367] = {.lex_state = 65, .external_lex_state = 11},
  [368] = {.lex_state = 65, .external_lex_state = 11},
  [369] = {.lex_state = 65, .external_lex_state = 11},
  [370] = {.lex_state = 65, .external_lex_state = 11},
  [371] = {.lex_state = 65, .external_lex_state = 11},
  [372] = {.lex_state = 65, .external_lex_state = 11},
  [373] = {.lex_state = 65, .external_lex_state = 11},
  [374] = {.lex_state = 65, .external_lex_state = 11},
  [375] = {.lex_state = 65, .external_lex_state = 11},
  [376] = {.lex_state = 65, .external_lex_state = 11},
  [377] = {.lex_state = 65, .external_lex_state = 11},
  [378] = {.lex_state = 65, .external_lex_state = 11},
  [379] = {.lex_state = 65, .external_lex_state = 11},
  [380] = {.lex_state = 65, .external_lex_state = 11},
  [381] = {.lex_state = 65, .external_lex_state = 11},
  [382] = {.lex_state = 65, .external_lex_state = 11},
  [383] = {.lex_state = 65, .external_lex_state = 11},
  [384] = {.lex_state = 65, .external_lex_state = 11},
  [385] = {.lex_state = 65, .external_lex_state = 11},
  [386] = {.lex_state = 65, .external_lex_state = 11},
  [387] = {.lex_state = 65, .external_lex_state = 11},
  [388] = {.lex_state = 65, .external_lex_state = 11},
  [389] = {.lex_state = 65, .external_lex_state = 11},
  [390] = {.lex_state = 65, .external_lex_state = 11},
  [391] = {.lex_state = 65, .external_lex_state = 11},
  [392] = {.lex_state = 65, .external_lex_state = 11},
  [393] = {.lex_state = 65, .external_lex_state = 11},
  [394] = {.lex_state = 65, .external_lex_state = 11},
  [395] = {.lex_state = 65, .external_lex_state = 11},
  [396] = {.lex_state = 65, .external_lex_state = 11},
  [397] = {.lex_state = 65, .external_lex_state = 11},
  [398] = {.lex_state = 65, .external_lex_state = 11},
  [399] = {.lex_state = 65, .external_lex_state = 11},
  [400] = {.lex_state = 65, .external_lex_state = 11},
  [401] = {.lex_state = 65, .external_lex_state = 11},
  [402] = {.lex_state = 65, .external_lex_state = 11},
  [403] = {.lex_state = 65, .external_lex_state = 11},
  [404] = {.lex_state = 65, .external_lex_state = 11},
  [405] = {.lex_state = 65, .external_lex_state = 11},
  [406] = {.lex_state = 65, .external_lex_state = 11},
  [407] = {.lex_state = 65, .external_lex_state = 11},
  [408] = {.lex_state = 65, .external_lex_state = 11},
  [409] = {.lex_state = 65, .external_lex_state = 11},
  [410] = {.lex_state = 65, .external_lex_state = 11},
  [411] = {.lex_state = 65, .external_lex_state = 11},
  [412] = {.lex_state = 65, .external_lex_state = 11},
  [413] = {.lex_state = 65, .external_lex_state = 11},
  [414] = {.lex_state = 65, .external_lex_state = 11},
  [415] = {.lex_state = 65, .external_lex_state = 11},
  [416] = {.lex_state = 65, .external_lex_state = 11},
  [417] = {.lex_state = 65, .external_lex_state = 11},
  [418] = {.lex_state = 65, .external_lex_state = 11},
  [419] = {.lex_state = 65, .external_lex_state = 11},
  [420] = {.lex_state = 65, .external_lex_state = 11},
  [421] = {.lex_state = 65, .external_lex_state = 11},
  [422] = {.lex_state = 65, .external_lex_state = 11},
  [423] = {.lex_state = 65, .external_lex_state = 11},
  [424] = {.lex_state = 65, .external_lex_state = 11},
  [425] = {.lex_state = 65, .external_lex_state = 11},
  [426] = {.lex_state = 65, .external_lex_state = 11},
  [427] = {.lex_state = 65, .external_lex_state = 11},
  [428] = {.lex_state = 65, .external_lex_state = 11},
  [429] = {.lex_state = 65, .external_lex_state = 11},
  [430] = {.lex_state = 65, .external_lex_state = 11},
  [431] = {.lex_state = 65, .external_lex_state = 11},
  [432] = {.lex_state = 65, .external_lex_state = 11},
  [433] = {.lex_state = 65, .external_lex_state = 11},
  [434] = {.lex_state = 65, .external_lex_state = 11},
  [435] = {.lex_state = 65, .external_lex_state = 11},
  [436] = {.lex_state = 65, .external_lex_state = 11},
  [437] = {.lex_state = 65, .external_lex_state = 11},
  [438] = {.lex_state = 65, .external_lex_state = 11},
  [439] = {.lex_state = 65, .external_lex_state = 11},
  [440] = {.lex_state = 65, .external_lex_state = 11},
  [441] = {.lex_state = 65, .external_lex_state = 11},
  [442] = {.lex_state = 65, .external_lex_state = 11},
  [443] = {.lex_state = 65, .external_lex_state = 11},
  [444] = {.lex_state = 65, .external_lex_state = 11},
  [445] = {.lex_state = 65, .external_lex_state = 11},
  [446] = {.lex_state = 65, .external_lex_state = 11},
  [447] = {.lex_state = 65, .external_lex_state = 11},
  [448] = {.lex_state = 65, .external_lex_state = 11},
  [449] = {.lex_state = 65, .external_lex_state = 11},
  [450] = {.lex_state = 65, .external_lex_state = 11},
  [451] = {.lex_state = 65, .external_lex_state = 11},
  [452] = {.lex_state = 65, .external_lex_state = 11},
  [453] = {.lex_state = 65, .external_lex_state = 11},
  [454] = {.lex_state = 65, .external_lex_state = 11},
  [455] = {.lex_state = 65, .external_lex_state = 11},
  [456] = {.lex_state = 65, .external_lex_state = 11},
  [457] = {.lex_state = 65, .external_lex_state = 11},
  [458] = {.lex_state = 65, .external_lex_state = 11},
  [459] = {.lex_state = 90, .external_lex_state = 14},
  [460] = {.lex_state = 90, .external_lex_state = 14},
  [461] = {.lex_state = 90, .external_lex_state = 14},
  [462] = {.lex_state = 90, .external_lex_state = 14},
  [463] = {.lex_state = 90, .external_lex_state = 14},
  [464] = {.lex_state = 90, .external_lex_state = 14},
  [465] = {.lex_state = 90, .external_lex_state = 14},
  [466] = {.lex_state = 90, .external_lex_state = 14},
  [467] = {.lex_state = 90, .external_lex_state = 14},
  [468] = {.lex_state = 90, .external_lex_state = 14},
  [469] = {.lex_state = 90, .external_lex_state = 14},
  [470] = {.lex_state = 90, .external_lex_state = 14},
  [471] = {.lex_state = 90, .external_lex_state = 14},
  [472] = {.lex_state = 90, .external_lex_state = 14},
  [473] = {.lex_state = 90, .external_lex_state = 14},
  [474] = {.lex_state = 90, .external_lex_state = 14},
  [475] = {.lex_state = 90, .external_lex_state = 14},
  [476] = {.lex_state = 90, .external_lex_state = 14},
  [477] = {.lex_state = 90, .external_lex_state = 14},
  [478] = {.lex_state = 90, .external_lex_state = 14},
  [479] = {.lex_state = 90, .external_lex_state = 14},
  [480] = {.lex_state = 90, .external_lex_state = 14},
  [481] = {.lex_state = 85, .external_lex_state = 16},
  [482] = {.lex_state = 90, .external_lex_state = 14},
  [483] = {.lex_state = 90, .external_lex_state = 14},
  [484] = {.lex_state = 90, .external_lex_state = 14},
  [485] = {.lex_state = 90, .external_lex_state = 14},
  [486] = {.lex_state = 90, .external_lex_state = 14},
  [487] = {.lex_state = 90, .external_lex_state = 14},
  [488] = {.lex_state = 90, .external_lex_state = 14},
  [489] = {.lex_state = 90, .external_lex_state = 14},
  [490] = {.lex_state = 90, .external_lex_state = 14},
  [491] = {.lex_state = 90, .external_lex_state = 14},
  [492] = {.lex_state = 90, .external_lex_state = 14},
  [493] = {.lex_state = 90, .external_lex_state = 14},
  [494] = {.lex_state = 90, .external_lex_state = 14},
  [495] = {.lex_state = 90, .external_lex_state = 14},
  [496] = {.lex_state = 90, .external_lex_state = 14},
  [497] = {.lex_state = 90, .external_lex_state = 14},
  [498] = {.lex_state = 90, .external_lex_state = 14},
  [499] = {.lex_state = 90, .external_lex_state = 14},
  [500] = {.lex_state = 90, .external_lex_state = 14},
  [501] = {.lex_state = 90, .external_lex_state = 14},
  [502] = {.lex_state = 90, .external_lex_state = 14},
  [503] = {.lex_state = 90, .external_lex_state = 14},
  [504] = {.lex_state = 90, .external_lex_state = 14},
  [505] = {.lex_state = 90, .external_lex_state = 14},
  [506] = {.lex_state = 90, .external_lex_state = 14},
  [507] = {.lex_state = 90, .external_lex_state = 14},
  [508] = {.lex_state = 90, .external_lex_state = 14},
  [509] = {.lex_state = 109, .external_lex_state = 12},
  [510] = {.lex_state = 87, .external_lex_state = 12},
  [511] = {.lex_state = 87, .external_lex_state = 12},
  [512] = {.lex_state = 87, .external_lex_state = 12},
  [513] = {.lex_state = 87, .external_lex_state = 12},
  [514] = {.lex_state = 84, .external_lex_state = 12},
  [515] = {.lex_state = 84, .external_lex_state = 12},
  [516] = {.lex_state = 84, .external_lex_state = 12},
  [517] = {.lex_state = 87, .external_lex_state = 12},
  [518] = {.lex_state = 218, .external_lex_state = 12},
  [519] = {.lex_state = 84, .external_lex_state = 12},
  [520] = {.lex_state = 68, .external_lex_state = 12},
  [521] = {.lex_state = 68, .external_lex_state = 12},
  [522] = {.lex_state = 218, .external_lex_state = 13},
  [523] = {.lex_state = 68, .external_lex_state = 12},
  [524] = {.lex_state = 84, .external_lex_state = 12},
  [525] = {.lex_state = 84, .external_lex_state = 12},
  [526] = {.lex_state = 84, .external_lex_state = 12},
  [527] = {.lex_state = 84, .external_lex_state = 12},
  [528] = {.lex_state = 84, .external_lex_state = 12},
  [529] = {.lex_state = 75, .external_lex_state = 15},
  [530] = {.lex_state = 84, .external_lex_state = 12},
  [531] = {.lex_state = 84, .external_lex_state = 12},
  [532] = {.lex_state = 84, .external_lex_state = 12},
  [533] = {.lex_state = 84, .external_lex_state = 12},
  [534] = {.lex_state = 84, .external_lex_state = 12},
  [535] = {.lex_state = 84, .external_lex_state = 12},
  [536] = {.lex_state = 84, .external_lex_state = 12},
  [537] = {.lex_state = 84, .external_lex_state = 12},
  [538] = {.lex_state = 84, .external_lex_state = 12},
  [539] = {.lex_state = 84, .external_lex_state = 12},
  [540] = {.lex_state = 84, .external_lex_state = 12},
  [541] = {.lex_state = 84, .external_lex_state = 12},
  [542] = {.lex_state = 68, .external_lex_state = 12},
  [543] = {.lex_state = 69, .external_lex_state = 12},
  [544] = {.lex_state = 80, .external_lex_state = 16},
  [545] = {.lex_state = 68, .external_lex_state = 12},
  [546] = {.lex_state = 71, .external_lex_state = 12},
  [547] = {.lex_state = 220, .external_lex_state = 12},
  [548] = {.lex_state = 71, .external_lex_state = 12},
  [549] = {.lex_state = 74, .external_lex_state = 15},
  [550] = {.lex_state = 221, .external_lex_state = 12},
  [551] = {.lex_state = 71, .external_lex_state = 12},
  [552] = {.lex_state = 74, .external_lex_state = 15},
  [553] = {.lex_state = 76, .external_lex_state = 12},
  [554] = {.lex_state = 76, .external_lex_state = 12},
  [555] = {.lex_state = 76, .external_lex_state = 12},
  [556] = {.lex_state = 71, .external_lex_state = 12},
  [557] = {.lex_state = 71, .external_lex_state = 12},
  [558] = {.lex_state = 71, .external_lex_state = 12},
  [559] = {.lex_state = 79, .external_lex_state = 16},
  [560] = {.lex_state = 71, .external_lex_state = 12},
  [561] = {.lex_state = 71, .external_lex_state = 12},
  [562] = {.lex_state = 71, .external_lex_state = 12},
  [563] = {.lex_state = 71, .external_lex_state = 12},
  [564] = {.lex_state = 79, .external_lex_state = 16},
  [565] = {.lex_state = 71, .external_lex_state = 12},
  [566] = {.lex_state = 71, .external_lex_state = 12},
  [567] = {.lex_state = 71, .external_lex_state = 12},
  [568] = {.lex_state = 71, .external_lex_state = 12},
  [569] = {.lex_state = 71, .external_lex_state = 12},
  [570] = {.lex_state = 71, .external_lex_state = 12},
  [571] = {.lex_state = 71, .external_lex_state = 12},
  [572] = {.lex_state = 71, .external_lex_state = 12},
  [573] = {.lex_state = 228, .external_lex_state = 12},
  [574] = {.lex_state = 71, .external_lex_state = 12},
  [575] = {.lex_state = 71, .external_lex_state = 12},
  [576] = {.lex_state = 228, .external_lex_state = 12},
  [577] = {.lex_state = 71, .external_lex_state = 12},
  [578] = {.lex_state = 71, .external_lex_state = 12},
  [579] = {.lex_state = 71, .external_lex_state = 12},
  [580] = {.lex_state = 68, .external_lex_state = 13},
  [581] = {.lex_state = 71, .external_lex_state = 12},
  [582] = {.lex_state = 68, .external_lex_state = 13},
  [583] = {.lex_state = 71, .external_lex_state = 12},
  [584] = {.lex_state = 71, .external_lex_state = 12},
  [585] = {.lex_state = 68, .external_lex_state = 13},
  [586] = {.lex_state = 71, .external_lex_state = 12},
  [587] = {.lex_state = 71, .external_lex_state = 12},
  [588] = {.lex_state = 71, .external_lex_state = 12},
  [589] = {.lex_state = 71, .external_lex_state = 12},
  [590] = {.lex_state = 71, .external_lex_state = 12},
  [591] = {.lex_state = 71, .external_lex_state = 12},
  [592] = {.lex_state = 71, .external_lex_state = 12},
  [593] = {.lex_state = 71, .external_lex_state = 12},
  [594] = {.lex_state = 71, .external_lex_state = 12},
  [595] = {.lex_state = 71, .external_lex_state = 12},
  [596] = {.lex_state = 71, .external_lex_state = 12},
  [597] = {.lex_state = 71, .external_lex_state = 12},
  [598] = {.lex_state = 71, .external_lex_state = 12},
  [599] = {.lex_state = 71, .external_lex_state = 12},
  [600] = {.lex_state = 71, .external_lex_state = 12},
  [601] = {.lex_state = 71, .external_lex_state = 12},
  [602] = {.lex_state = 71, .external_lex_state = 12},
  [603] = {.lex_state = 71, .external_lex_state = 12},
  [604] = {.lex_state = 71, .external_lex_state = 12},
  [605] = {.lex_state = 71, .external_lex_state = 12},
  [606] = {.lex_state = 220, .external_lex_state = 13},
  [607] = {.lex_state = 71, .external_lex_state = 12},
  [608] = {.lex_state = 71, .external_lex_state = 12},
  [609] = {.lex_state = 840, .external_lex_state = 12},
  [610] = {.lex_state = 228, .external_lex_state = 13},
  [611] = {.lex_state = 840, .external_lex_state = 12},
  [612] = {.lex_state = 220, .external_lex_state = 13},
  [613] = {.lex_state = 840, .external_lex_state = 12},
  [614] = {.lex_state = 77, .external_lex_state = 12},
  [615] = {.lex_state = 228, .external_lex_state = 13},
  [616] = {.lex_state = 76, .external_lex_state = 12},
  [617] = {.lex_state = 76, .external_lex_state = 12},
  [618] = {.lex_state = 221, .external_lex_state = 12},
  [619] = {.lex_state = 840, .external_lex_state = 12},
  [620] = {.lex_state = 71, .external_lex_state = 12},
  [621] = {.lex_state = 71, .external_lex_state = 12},
  [622] = {.lex_state = 840, .external_lex_state = 12},
  [623] = {.lex_state = 71, .external_lex_state = 12},
  [624] = {.lex_state = 71, .external_lex_state = 12},
  [625] = {.lex_state = 840, .external_lex_state = 12},
  [626] = {.lex_state = 840, .external_lex_state = 12},
  [627] = {.lex_state = 840, .external_lex_state = 12},
  [628] = {.lex_state = 840, .external_lex_state = 12},
  [629] = {.lex_state = 68, .external_lex_state = 13},
  [630] = {.lex_state = 71, .external_lex_state = 12},
  [631] = {.lex_state = 69, .external_lex_state = 13},
  [632] = {.lex_state = 840, .external_lex_state = 12},
  [633] = {.lex_state = 68, .external_lex_state = 13},
  [634] = {.lex_state = 840, .external_lex_state = 12},
  [635] = {.lex_state = 71, .external_lex_state = 12},
  [636] = {.lex_state = 840, .external_lex_state = 12},
  [637] = {.lex_state = 220, .external_lex_state = 12},
  [638] = {.lex_state = 71, .external_lex_state = 12},
  [639] = {.lex_state = 71, .external_lex_state = 12},
  [640] = {.lex_state = 71, .external_lex_state = 12},
  [641] = {.lex_state = 73, .external_lex_state = 12},
  [642] = {.lex_state = 73, .external_lex_state = 12},
  [643] = {.lex_state = 73, .external_lex_state = 12},
  [644] = {.lex_state = 73, .external_lex_state = 12},
  [645] = {.lex_state = 71, .external_lex_state = 12},
  [646] = {.lex_state = 840, .external_lex_state = 12},
  [647] = {.lex_state = 71, .external_lex_state = 12},
  [648] = {.lex_state = 73, .external_lex_state = 12},
  [649] = {.lex_state = 71, .external_lex_state = 12},
  [650] = {.lex_state = 73, .external_lex_state = 12},
  [651] = {.lex_state = 840, .external_lex_state = 12},
  [652] = {.lex_state = 73, .external_lex_state = 12},
  [653] = {.lex_state = 73, .external_lex_state = 12},
  [654] = {.lex_state = 73, .external_lex_state = 12},
  [655] = {.lex_state = 71, .external_lex_state = 12},
  [656] = {.lex_state = 71, .external_lex_state = 12},
  [657] = {.lex_state = 73, .external_lex_state = 12},
  [658] = {.lex_state = 71, .external_lex_state = 12},
  [659] = {.lex_state = 71, .external_lex_state = 12},
  [660] = {.lex_state = 71, .external_lex_state = 13},
  [661] = {.lex_state = 73, .external_lex_state = 12},
  [662] = {.lex_state = 840, .external_lex_state = 12},
  [663] = {.lex_state = 71, .external_lex_state = 12},
  [664] = {.lex_state = 73, .external_lex_state = 12},
  [665] = {.lex_state = 71, .external_lex_state = 12},
  [666] = {.lex_state = 73, .external_lex_state = 12},
  [667] = {.lex_state = 71, .external_lex_state = 13},
  [668] = {.lex_state = 71, .external_lex_state = 12},
  [669] = {.lex_state = 71, .external_lex_state = 13},
  [670] = {.lex_state = 73, .external_lex_state = 12},
  [671] = {.lex_state = 73, .external_lex_state = 12},
  [672] = {.lex_state = 71, .external_lex_state = 12},
  [673] = {.lex_state = 73, .external_lex_state = 12},
  [674] = {.lex_state = 71, .external_lex_state = 12},
  [675] = {.lex_state = 73, .external_lex_state = 12},
  [676] = {.lex_state = 73, .external_lex_state = 12},
  [677] = {.lex_state = 73, .external_lex_state = 12},
  [678] = {.lex_state = 71, .external_lex_state = 12},
  [679] = {.lex_state = 73, .external_lex_state = 12},
  [680] = {.lex_state = 71, .external_lex_state = 12},
  [681] = {.lex_state = 73, .external_lex_state = 12},
  [682] = {.lex_state = 73, .external_lex_state = 12},
  [683] = {.lex_state = 73, .external_lex_state = 12},
  [684] = {.lex_state = 73, .external_lex_state = 12},
  [685] = {.lex_state = 71, .external_lex_state = 13},
  [686] = {.lex_state = 71, .external_lex_state = 13},
  [687] = {.lex_state = 73, .external_lex_state = 12},
  [688] = {.lex_state = 73, .external_lex_state = 12},
  [689] = {.lex_state = 73, .external_lex_state = 12},
  [690] = {.lex_state = 73, .external_lex_state = 12},
  [691] = {.lex_state = 73, .external_lex_state = 12},
  [692] = {.lex_state = 71, .external_lex_state = 13},
  [693] = {.lex_state = 73, .external_lex_state = 12},
  [694] = {.lex_state = 73, .external_lex_state = 12},
  [695] = {.lex_state = 73, .external_lex_state = 12},
  [696] = {.lex_state = 73, .external_lex_state = 12},
  [697] = {.lex_state = 73, .external_lex_state = 12},
  [698] = {.lex_state = 73, .external_lex_state = 12},
  [699] = {.lex_state = 73, .external_lex_state = 12},
  [700] = {.lex_state = 71, .external_lex_state = 12},
  [701] = {.lex_state = 73, .external_lex_state = 12},
  [702] = {.lex_state = 73, .external_lex_state = 12},
  [703] = {.lex_state = 73, .external_lex_state = 12},
  [704] = {.lex_state = 73, .external_lex_state = 12},
  [705] = {.lex_state = 73, .external_lex_state = 12},
  [706] = {.lex_state = 73, .external_lex_state = 12},
  [707] = {.lex_state = 71, .external_lex_state = 13},
  [708] = {.lex_state = 73, .external_lex_state = 12},
  [709] = {.lex_state = 73, .external_lex_state = 12},
  [710] = {.lex_state = 73, .external_lex_state = 12},
  [711] = {.lex_state = 73, .external_lex_state = 12},
  [712] = {.lex_state = 73, .external_lex_state = 12},
  [713] = {.lex_state = 73, .external_lex_state = 12},
  [714] = {.lex_state = 73, .external_lex_state = 12},
  [715] = {.lex_state = 73, .external_lex_state = 12},
  [716] = {.lex_state = 73, .external_lex_state = 12},
  [717] = {.lex_state = 73, .external_lex_state = 12},
  [718] = {.lex_state = 73, .external_lex_state = 12},
  [719] = {.lex_state = 73, .external_lex_state = 12},
  [720] = {.lex_state = 73, .external_lex_state = 12},
  [721] = {.lex_state = 73, .external_lex_state = 12},
  [722] = {.lex_state = 73, .external_lex_state = 12},
  [723] = {.lex_state = 73, .external_lex_state = 12},
  [724] = {.lex_state = 73, .external_lex_state = 12},
  [725] = {.lex_state = 73, .external_lex_state = 12},
  [726] = {.lex_state = 71, .external_lex_state = 13},
  [727] = {.lex_state = 71, .external_lex_state = 13},
  [728] = {.lex_state = 71, .external_lex_state = 13},
  [729] = {.lex_state = 71, .external_lex_state = 13},
  [730] = {.lex_state = 73, .external_lex_state = 12},
  [731] = {.lex_state = 71, .external_lex_state = 13},
  [732] = {.lex_state = 71, .external_lex_state = 13},
  [733] = {.lex_state = 71, .external_lex_state = 13},
  [734] = {.lex_state = 71, .external_lex_state = 13},
  [735] = {.lex_state = 71, .external_lex_state = 13},
  [736] = {.lex_state = 71, .external_lex_state = 13},
  [737] = {.lex_state = 71, .external_lex_state = 13},
  [738] = {.lex_state = 71, .external_lex_state = 13},
  [739] = {.lex_state = 71, .external_lex_state = 13},
  [740] = {.lex_state = 71, .external_lex_state = 13},
  [741] = {.lex_state = 71, .external_lex_state = 13},
  [742] = {.lex_state = 71, .external_lex_state = 13},
  [743] = {.lex_state = 71, .external_lex_state = 12},
  [744] = {.lex_state = 71, .external_lex_state = 13},
  [745] = {.lex_state = 840, .external_lex_state = 13},
  [746] = {.lex_state = 71, .external_lex_state = 13},
  [747] = {.lex_state = 71, .external_lex_state = 13},
  [748] = {.lex_state = 71, .external_lex_state = 13},
  [749] = {.lex_state = 71, .external_lex_state = 13},
  [750] = {.lex_state = 71, .external_lex_state = 13},
  [751] = {.lex_state = 71, .external_lex_state = 13},
  [752] = {.lex_state = 71, .external_lex_state = 13},
  [753] = {.lex_state = 71, .external_lex_state = 13},
  [754] = {.lex_state = 71, .external_lex_state = 13},
  [755] = {.lex_state = 71, .external_lex_state = 12},
  [756] = {.lex_state = 71, .external_lex_state = 13},
  [757] = {.lex_state = 71, .external_lex_state = 13},
  [758] = {.lex_state = 71, .external_lex_state = 13},
  [759] = {.lex_state = 71, .external_lex_state = 13},
  [760] = {.lex_state = 71, .external_lex_state = 13},
  [761] = {.lex_state = 71, .external_lex_state = 13},
  [762] = {.lex_state = 840, .external_lex_state = 12},
  [763] = {.lex_state = 71, .external_lex_state = 13},
  [764] = {.lex_state = 71, .external_lex_state = 13},
  [765] = {.lex_state = 71, .external_lex_state = 13},
  [766] = {.lex_state = 71, .external_lex_state = 13},
  [767] = {.lex_state = 840, .external_lex_state = 12},
  [768] = {.lex_state = 840, .external_lex_state = 12},
  [769] = {.lex_state = 840, .external_lex_state = 12},
  [770] = {.lex_state = 71, .external_lex_state = 13},
  [771] = {.lex_state = 840, .external_lex_state = 12},
  [772] = {.lex_state = 840, .external_lex_state = 12},
  [773] = {.lex_state = 840, .external_lex_state = 12},
  [774] = {.lex_state = 840, .external_lex_state = 12},
  [775] = {.lex_state = 71, .external_lex_state = 12},
  [776] = {.lex_state = 840, .external_lex_state = 12},
  [777] = {.lex_state = 71, .external_lex_state = 12},
  [778] = {.lex_state = 71, .external_lex_state = 12},
  [779] = {.lex_state = 71, .external_lex_state = 13},
  [780] = {.lex_state = 71, .external_lex_state = 12},
  [781] = {.lex_state = 71, .external_lex_state = 12},
  [782] = {.lex_state = 71, .external_lex_state = 13},
  [783] = {.lex_state = 71, .external_lex_state = 12},
  [784] = {.lex_state = 71, .external_lex_state = 13},
  [785] = {.lex_state = 71, .external_lex_state = 12},
  [786] = {.lex_state = 840, .external_lex_state = 13},
  [787] = {.lex_state = 71, .external_lex_state = 12},
  [788] = {.lex_state = 71, .external_lex_state = 12},
  [789] = {.lex_state = 840, .external_lex_state = 12},
  [790] = {.lex_state = 71, .external_lex_state = 13},
  [791] = {.lex_state = 71, .external_lex_state = 13},
  [792] = {.lex_state = 71, .external_lex_state = 12},
  [793] = {.lex_state = 71, .external_lex_state = 13},
  [794] = {.lex_state = 71, .external_lex_state = 12},
  [795] = {.lex_state = 71, .external_lex_state = 12},
  [796] = {.lex_state = 71, .external_lex_state = 12},
  [797] = {.lex_state = 71, .external_lex_state = 13},
  [798] = {.lex_state = 71, .external_lex_state = 13},
  [799] = {.lex_state = 71, .external_lex_state = 13},
  [800] = {.lex_state = 71, .external_lex_state = 13},
  [801] = {.lex_state = 71, .external_lex_state = 13},
  [802] = {.lex_state = 71, .external_lex_state = 13},
  [803] = {.lex_state = 71, .external_lex_state = 13},
  [804] = {.lex_state = 71, .external_lex_state = 12},
  [805] = {.lex_state = 71, .external_lex_state = 13},
  [806] = {.lex_state = 71, .external_lex_state = 13},
  [807] = {.lex_state = 71, .external_lex_state = 13},
  [808] = {.lex_state = 71, .external_lex_state = 13},
  [809] = {.lex_state = 71, .external_lex_state = 13},
  [810] = {.lex_state = 71, .external_lex_state = 13},
  [811] = {.lex_state = 840, .external_lex_state = 12},
  [812] = {.lex_state = 840, .external_lex_state = 13},
  [813] = {.lex_state = 840, .external_lex_state = 12},
  [814] = {.lex_state = 840, .external_lex_state = 12},
  [815] = {.lex_state = 228, .external_lex_state = 12},
  [816] = {.lex_state = 71, .external_lex_state = 12},
  [817] = {.lex_state = 71, .external_lex_state = 13},
  [818] = {.lex_state = 71, .external_lex_state = 13},
  [819] = {.lex_state = 71, .external_lex_state = 13},
  [820] = {.lex_state = 71, .external_lex_state = 13},
  [821] = {.lex_state = 840, .external_lex_state = 12},
  [822] = {.lex_state = 840, .external_lex_state = 12},
  [823] = {.lex_state = 840, .external_lex_state = 12},
  [824] = {.lex_state = 840, .external_lex_state = 12},
  [825] = {.lex_state = 71, .external_lex_state = 12},
  [826] = {.lex_state = 840, .external_lex_state = 12},
  [827] = {.lex_state = 840, .external_lex_state = 12},
  [828] = {.lex_state = 71, .external_lex_state = 12},
  [829] = {.lex_state = 71, .external_lex_state = 12},
  [830] = {.lex_state = 71, .external_lex_state = 12},
  [831] = {.lex_state = 71, .external_lex_state = 12},
  [832] = {.lex_state = 71, .external_lex_state = 12},
  [833] = {.lex_state = 71, .external_lex_state = 12},
  [834] = {.lex_state = 71, .external_lex_state = 12},
  [835] = {.lex_state = 71, .external_lex_state = 12},
  [836] = {.lex_state = 71, .external_lex_state = 12},
  [837] = {.lex_state = 71, .external_lex_state = 12},
  [838] = {.lex_state = 71, .external_lex_state = 12},
  [839] = {.lex_state = 840, .external_lex_state = 12},
  [840] = {.lex_state = 840, .external_lex_state = 12},
  [841] = {.lex_state = 71, .external_lex_state = 12},
  [842] = {.lex_state = 71, .external_lex_state = 12},
  [843] = {.lex_state = 71, .external_lex_state = 12},
  [844] = {.lex_state = 71, .external_lex_state = 12},
  [845] = {.lex_state = 71, .external_lex_state = 12},
  [846] = {.lex_state = 222, .external_lex_state = 12},
  [847] = {.lex_state = 71, .external_lex_state = 12},
  [848] = {.lex_state = 71, .external_lex_state = 12},
  [849] = {.lex_state = 84, .external_lex_state = 13},
  [850] = {.lex_state = 71, .external_lex_state = 12},
  [851] = {.lex_state = 71, .external_lex_state = 12},
  [852] = {.lex_state = 71, .external_lex_state = 12},
  [853] = {.lex_state = 71, .external_lex_state = 12},
  [854] = {.lex_state = 71, .external_lex_state = 12},
  [855] = {.lex_state = 71, .external_lex_state = 12},
  [856] = {.lex_state = 71, .external_lex_state = 12},
  [857] = {.lex_state = 71, .external_lex_state = 12},
  [858] = {.lex_state = 71, .external_lex_state = 12},
  [859] = {.lex_state = 71, .external_lex_state = 12},
  [860] = {.lex_state = 840, .external_lex_state = 12},
  [861] = {.lex_state = 71, .external_lex_state = 12},
  [862] = {.lex_state = 71, .external_lex_state = 12},
  [863] = {.lex_state = 71, .external_lex_state = 12},
  [864] = {.lex_state = 71, .external_lex_state = 12},
  [865] = {.lex_state = 71, .external_lex_state = 12},
  [866] = {.lex_state = 71, .external_lex_state = 12},
  [867] = {.lex_state = 840, .external_lex_state = 12},
  [868] = {.lex_state = 71, .external_lex_state = 12},
  [869] = {.lex_state = 71, .external_lex_state = 12},
  [870] = {.lex_state = 71, .external_lex_state = 12},
  [871] = {.lex_state = 71, .external_lex_state = 12},
  [872] = {.lex_state = 840, .external_lex_state = 12},
  [873] = {.lex_state = 71, .external_lex_state = 12},
  [874] = {.lex_state = 71, .external_lex_state = 12},
  [875] = {.lex_state = 71, .external_lex_state = 12},
  [876] = {.lex_state = 71, .external_lex_state = 12},
  [877] = {.lex_state = 71, .external_lex_state = 12},
  [878] = {.lex_state = 71, .external_lex_state = 12},
  [879] = {.lex_state = 71, .external_lex_state = 12},
  [880] = {.lex_state = 71, .external_lex_state = 12},
  [881] = {.lex_state = 840, .external_lex_state = 12},
  [882] = {.lex_state = 71, .external_lex_state = 12},
  [883] = {.lex_state = 71, .external_lex_state = 12},
  [884] = {.lex_state = 71, .external_lex_state = 12},
  [885] = {.lex_state = 71, .external_lex_state = 12},
  [886] = {.lex_state = 71, .external_lex_state = 12},
  [887] = {.lex_state = 71, .external_lex_state = 12},
  [888] = {.lex_state = 71, .external_lex_state = 12},
  [889] = {.lex_state = 71, .external_lex_state = 12},
  [890] = {.lex_state = 71, .external_lex_state = 12},
  [891] = {.lex_state = 71, .external_lex_state = 12},
  [892] = {.lex_state = 71, .external_lex_state = 12},
  [893] = {.lex_state = 71, .external_lex_state = 12},
  [894] = {.lex_state = 71, .external_lex_state = 12},
  [895] = {.lex_state = 71, .external_lex_state = 12},
  [896] = {.lex_state = 71, .external_lex_state = 12},
  [897] = {.lex_state = 71, .external_lex_state = 12},
  [898] = {.lex_state = 71, .external_lex_state = 12},
  [899] = {.lex_state = 71, .external_lex_state = 12},
  [900] = {.lex_state = 71, .external_lex_state = 12},
  [901] = {.lex_state = 71, .external_lex_state = 12},
  [902] = {.lex_state = 71, .external_lex_state = 12},
  [903] = {.lex_state = 71, .external_lex_state = 12},
  [904] = {.lex_state = 71, .external_lex_state = 12},
  [905] = {.lex_state = 840, .external_lex_state = 12},
  [906] = {.lex_state = 840, .external_lex_state = 12},
  [907] = {.lex_state = 840, .external_lex_state = 12},
  [908] = {.lex_state = 840, .external_lex_state = 12},
  [909] = {.lex_state = 71, .external_lex_state = 12},
  [910] = {.lex_state = 840, .external_lex_state = 12},
  [911] = {.lex_state = 71, .external_lex_state = 12},
  [912] = {.lex_state = 840, .external_lex_state = 12},
  [913] = {.lex_state = 71, .external_lex_state = 12},
  [914] = {.lex_state = 71, .external_lex_state = 12},
  [915] = {.lex_state = 71, .external_lex_state = 12},
  [916] = {.lex_state = 228, .external_lex_state = 13},
  [917] = {.lex_state = 222, .external_lex_state = 12},
  [918] = {.lex_state = 71, .external_lex_state = 12},
  [919] = {.lex_state = 840, .external_lex_state = 12},
  [920] = {.lex_state = 117, .external_lex_state = 12},
  [921] = {.lex_state = 840, .external_lex_state = 12},
  [922] = {.lex_state = 840, .external_lex_state = 12},
  [923] = {.lex_state = 840, .external_lex_state = 12},
  [924] = {.lex_state = 71, .external_lex_state = 12},
  [925] = {.lex_state = 71, .external_lex_state = 12},
  [926] = {.lex_state = 71, .external_lex_state = 12},
  [927] = {.lex_state = 222, .external_lex_state = 12},
  [928] = {.lex_state = 71, .external_lex_state = 12},
  [929] = {.lex_state = 840, .external_lex_state = 12},
  [930] = {.lex_state = 840, .external_lex_state = 12},
  [931] = {.lex_state = 71, .external_lex_state = 12},
  [932] = {.lex_state = 71, .external_lex_state = 12},
  [933] = {.lex_state = 71, .external_lex_state = 12},
  [934] = {.lex_state = 840, .external_lex_state = 12},
  [935] = {.lex_state = 71, .external_lex_state = 12},
  [936] = {.lex_state = 840, .external_lex_state = 13},
  [937] = {.lex_state = 840, .external_lex_state = 12},
  [938] = {.lex_state = 840, .external_lex_state = 13},
  [939] = {.lex_state = 71, .external_lex_state = 12},
  [940] = {.lex_state = 222, .external_lex_state = 13},
  [941] = {.lex_state = 840, .external_lex_state = 13},
  [942] = {.lex_state = 71, .external_lex_state = 12},
  [943] = {.lex_state = 105, .external_lex_state = 12},
  [944] = {.lex_state = 105, .external_lex_state = 12},
  [945] = {.lex_state = 840, .external_lex_state = 13},
  [946] = {.lex_state = 222, .external_lex_state = 13},
  [947] = {.lex_state = 71, .external_lex_state = 12},
  [948] = {.lex_state = 117, .external_lex_state = 12},
  [949] = {.lex_state = 117, .external_lex_state = 12},
  [950] = {.lex_state = 222, .external_lex_state = 13},
  [951] = {.lex_state = 840, .external_lex_state = 13},
  [952] = {.lex_state = 840, .external_lex_state = 13},
  [953] = {.lex_state = 840, .external_lex_state = 13},
  [954] = {.lex_state = 840, .external_lex_state = 13},
  [955] = {.lex_state = 105, .external_lex_state = 12},
  [956] = {.lex_state = 840, .external_lex_state = 13},
  [957] = {.lex_state = 71, .external_lex_state = 12},
  [958] = {.lex_state = 105, .external_lex_state = 12},
  [959] = {.lex_state = 62, .external_lex_state = 11},
  [960] = {.lex_state = 117, .external_lex_state = 12},
  [961] = {.lex_state = 334, .external_lex_state = 12},
  [962] = {.lex_state = 105, .external_lex_state = 13},
  [963] = {.lex_state = 62, .external_lex_state = 11},
  [964] = {.lex_state = 840, .external_lex_state = 13},
  [965] = {.lex_state = 840, .external_lex_state = 13},
  [966] = {.lex_state = 334, .external_lex_state = 12},
  [967] = {.lex_state = 105, .external_lex_state = 13},
  [968] = {.lex_state = 840, .external_lex_state = 12},
  [969] = {.lex_state = 334, .external_lex_state = 12},
  [970] = {.lex_state = 62, .external_lex_state = 11},
  [971] = {.lex_state = 840, .external_lex_state = 13},
  [972] = {.lex_state = 105, .external_lex_state = 13},
  [973] = {.lex_state = 105, .external_lex_state = 13},
  [974] = {.lex_state = 62, .external_lex_state = 11},
  [975] = {.lex_state = 62, .external_lex_state = 11},
  [976] = {.lex_state = 840, .external_lex_state = 12},
  [977] = {.lex_state = 105, .external_lex_state = 12},
  [978] = {.lex_state = 840, .external_lex_state = 13},
  [979] = {.lex_state = 840, .external_lex_state = 12},
  [980] = {.lex_state = 105, .external_lex_state = 12},
  [981] = {.lex_state = 840, .external_lex_state = 13},
  [982] = {.lex_state = 117, .external_lex_state = 12},
  [983] = {.lex_state = 105, .external_lex_state = 13},
  [984] = {.lex_state = 105, .external_lex_state = 12},
  [985] = {.lex_state = 105, .external_lex_state = 13},
  [986] = {.lex_state = 840, .external_lex_state = 12},
  [987] = {.lex_state = 840, .external_lex_state = 13},
  [988] = {.lex_state = 105, .external_lex_state = 13},
  [989] = {.lex_state = 840, .external_lex_state = 13},
  [990] = {.lex_state = 840, .external_lex_state = 12},
  [991] = {.lex_state = 335, .external_lex_state = 12},
  [992] = {.lex_state = 840, .external_lex_state = 13},
  [993] = {.lex_state = 105, .external_lex_state = 12},
  [994] = {.lex_state = 840, .external_lex_state = 12},
  [995] = {.lex_state = 840, .external_lex_state = 13},
  [996] = {.lex_state = 840, .external_lex_state = 13},
  [997] = {.lex_state = 105, .external_lex_state = 12},
  [998] = {.lex_state = 840, .external_lex_state = 13},
  [999] = {.lex_state = 335, .external_lex_state = 12},
  [1000] = {.lex_state = 105, .external_lex_state = 12},
  [1001] = {.lex_state = 840, .external_lex_state = 13},
  [1002] = {.lex_state = 105, .external_lex_state = 12},
  [1003] = {.lex_state = 335, .external_lex_state = 12},
  [1004] = {.lex_state = 105, .external_lex_state = 17},
  [1005] = {.lex_state = 62, .external_lex_state = 11},
  [1006] = {.lex_state = 105, .external_lex_state = 13},
  [1007] = {.lex_state = 105, .external_lex_state = 12},
  [1008] = {.lex_state = 105, .external_lex_state = 12},
  [1009] = {.lex_state = 229, .external_lex_state = 12},
  [1010] = {.lex_state = 229, .external_lex_state = 12},
  [1011] = {.lex_state = 62, .external_lex_state = 11},
  [1012] = {.lex_state = 105, .external_lex_state = 17},
  [1013] = {.lex_state = 105, .external_lex_state = 13},
  [1014] = {.lex_state = 105, .external_lex_state = 13},
  [1015] = {.lex_state = 105, .external_lex_state = 12},
  [1016] = {.lex_state = 105, .external_lex_state = 12},
  [1017] = {.lex_state = 105, .external_lex_state = 13},
  [1018] = {.lex_state = 105, .external_lex_state = 13},
  [1019] = {.lex_state = 62, .external_lex_state = 11},
  [1020] = {.lex_state = 105, .external_lex_state = 17},
  [1021] = {.lex_state = 105, .external_lex_state = 13},
  [1022] = {.lex_state = 105, .external_lex_state = 13},
  [1023] = {.lex_state = 105, .external_lex_state = 17},
  [1024] = {.lex_state = 105, .external_lex_state = 13},
  [1025] = {.lex_state = 62, .external_lex_state = 11},
  [1026] = {.lex_state = 51, .external_lex_state = 13},
  [1027] = {.lex_state = 105, .external_lex_state = 17},
  [1028] = {.lex_state = 105, .external_lex_state = 13},
  [1029] = {.lex_state = 65, .external_lex_state = 18},
  [1030] = {.lex_state = 36, .external_lex_state = 13},
  [1031] = {.lex_state = 53, .external_lex_state = 13},
  [1032] = {.lex_state = 36, .external_lex_state = 13},
  [1033] = {.lex_state = 241, .external_lex_state = 12},
  [1034] = {.lex_state = 241, .external_lex_state = 12},
  [1035] = {.lex_state = 34, .external_lex_state = 13},
  [1036] = {.lex_state = 34, .external_lex_state = 13},
  [1037] = {.lex_state = 105, .external_lex_state = 12},
  [1038] = {.lex_state = 105, .external_lex_state = 12},
  [1039] = {.lex_state = 229, .external_lex_state = 13},
  [1040] = {.lex_state = 105, .external_lex_state = 12},
  [1041] = {.lex_state = 37, .external_lex_state = 12},
  [1042] = {.lex_state = 52, .external_lex_state = 12},
  [1043] = {.lex_state = 37, .external_lex_state = 12},
  [1044] = {.lex_state = 35, .external_lex_state = 12},
  [1045] = {.lex_state = 50, .external_lex_state = 12},
  [1046] = {.lex_state = 35, .external_lex_state = 12},
  [1047] = {.lex_state = 229, .external_lex_state = 13},
  [1048] = {.lex_state = 53, .external_lex_state = 13},
  [1049] = {.lex_state = 51, .external_lex_state = 13},
  [1050] = {.lex_state = 105, .external_lex_state = 12},
  [1051] = {.lex_state = 34, .external_lex_state = 13},
  [1052] = {.lex_state = 34, .external_lex_state = 13},
  [1053] = {.lex_state = 51, .external_lex_state = 13},
  [1054] = {.lex_state = 244, .external_lex_state = 13},
  [1055] = {.lex_state = 105, .external_lex_state = 17},
  [1056] = {.lex_state = 36, .external_lex_state = 13},
  [1057] = {.lex_state = 4, .external_lex_state = 12},
  [1058] = {.lex_state = 105, .external_lex_state = 17},
  [1059] = {.lex_state = 65, .external_lex_state = 19},
  [1060] = {.lex_state = 105, .external_lex_state = 12},
  [1061] = {.lex_state = 105, .external_lex_state = 12},
  [1062] = {.lex_state = 105, .external_lex_state = 12},
  [1063] = {.lex_state = 105, .external_lex_state = 17},
  [1064] = {.lex_state = 105, .external_lex_state = 13},
  [1065] = {.lex_state = 105, .external_lex_state = 12},
  [1066] = {.lex_state = 36, .external_lex_state = 13},
  [1067] = {.lex_state = 36, .external_lex_state = 13},
  [1068] = {.lex_state = 37, .external_lex_state = 12},
  [1069] = {.lex_state = 53, .external_lex_state = 13},
  [1070] = {.lex_state = 52, .external_lex_state = 12},
  [1071] = {.lex_state = 37, .external_lex_state = 12},
  [1072] = {.lex_state = 37, .external_lex_state = 12},
  [1073] = {.lex_state = 52, .external_lex_state = 12},
  [1074] = {.lex_state = 105, .external_lex_state = 13},
  [1075] = {.lex_state = 840, .external_lex_state = 12},
  [1076] = {.lex_state = 35, .external_lex_state = 12},
  [1077] = {.lex_state = 29, .external_lex_state = 12},
  [1078] = {.lex_state = 50, .external_lex_state = 12},
  [1079] = {.lex_state = 35, .external_lex_state = 12},
  [1080] = {.lex_state = 35, .external_lex_state = 12},
  [1081] = {.lex_state = 50, .external_lex_state = 12},
  [1082] = {.lex_state = 34, .external_lex_state = 13},
  [1083] = {.lex_state = 244, .external_lex_state = 13},
  [1084] = {.lex_state = 229, .external_lex_state = 17},
  [1085] = {.lex_state = 229, .external_lex_state = 17},
  [1086] = {.lex_state = 105, .external_lex_state = 12},
  [1087] = {.lex_state = 41, .external_lex_state = 12},
  [1088] = {.lex_state = 840, .external_lex_state = 13},
  [1089] = {.lex_state = 840, .external_lex_state = 12},
  [1090] = {.lex_state = 38, .external_lex_state = 13},
  [1091] = {.lex_state = 55, .external_lex_state = 13},
  [1092] = {.lex_state = 38, .external_lex_state = 13},
  [1093] = {.lex_state = 105, .external_lex_state = 13},
  [1094] = {.lex_state = 42, .external_lex_state = 12},
  [1095] = {.lex_state = 5, .external_lex_state = 13},
  [1096] = {.lex_state = 105, .external_lex_state = 17},
  [1097] = {.lex_state = 105, .external_lex_state = 13},
  [1098] = {.lex_state = 840, .external_lex_state = 12},
  [1099] = {.lex_state = 105, .external_lex_state = 13},
  [1100] = {.lex_state = 65, .external_lex_state = 11},
  [1101] = {.lex_state = 6, .external_lex_state = 12},
  [1102] = {.lex_state = 105, .external_lex_state = 13},
  [1103] = {.lex_state = 40, .external_lex_state = 13},
  [1104] = {.lex_state = 65, .external_lex_state = 11},
  [1105] = {.lex_state = 840, .external_lex_state = 12},
  [1106] = {.lex_state = 128, .external_lex_state = 13},
  [1107] = {.lex_state = 291, .external_lex_state = 13},
  [1108] = {.lex_state = 128, .external_lex_state = 13},
  [1109] = {.lex_state = 131, .external_lex_state = 12},
  [1110] = {.lex_state = 242, .external_lex_state = 12},
  [1111] = {.lex_state = 131, .external_lex_state = 12},
  [1112] = {.lex_state = 41, .external_lex_state = 12},
  [1113] = {.lex_state = 57, .external_lex_state = 12},
  [1114] = {.lex_state = 241, .external_lex_state = 12},
  [1115] = {.lex_state = 39, .external_lex_state = 12},
  [1116] = {.lex_state = 54, .external_lex_state = 12},
  [1117] = {.lex_state = 30, .external_lex_state = 13},
  [1118] = {.lex_state = 39, .external_lex_state = 12},
  [1119] = {.lex_state = 105, .external_lex_state = 13},
  [1120] = {.lex_state = 40, .external_lex_state = 13},
  [1121] = {.lex_state = 59, .external_lex_state = 13},
  [1122] = {.lex_state = 105, .external_lex_state = 13},
  [1123] = {.lex_state = 39, .external_lex_state = 12},
  [1124] = {.lex_state = 38, .external_lex_state = 13},
  [1125] = {.lex_state = 55, .external_lex_state = 13},
  [1126] = {.lex_state = 43, .external_lex_state = 13},
  [1127] = {.lex_state = 128, .external_lex_state = 13},
  [1128] = {.lex_state = 840, .external_lex_state = 12},
  [1129] = {.lex_state = 291, .external_lex_state = 13},
  [1130] = {.lex_state = 128, .external_lex_state = 13},
  [1131] = {.lex_state = 128, .external_lex_state = 13},
  [1132] = {.lex_state = 291, .external_lex_state = 13},
  [1133] = {.lex_state = 244, .external_lex_state = 13},
  [1134] = {.lex_state = 105, .external_lex_state = 17},
  [1135] = {.lex_state = 103, .external_lex_state = 12},
  [1136] = {.lex_state = 105, .external_lex_state = 17},
  [1137] = {.lex_state = 105, .external_lex_state = 17},
  [1138] = {.lex_state = 105, .external_lex_state = 17},
  [1139] = {.lex_state = 103, .external_lex_state = 12},
  [1140] = {.lex_state = 840, .external_lex_state = 12},
  [1141] = {.lex_state = 40, .external_lex_state = 13},
  [1142] = {.lex_state = 105, .external_lex_state = 17},
  [1143] = {.lex_state = 59, .external_lex_state = 13},
  [1144] = {.lex_state = 131, .external_lex_state = 12},
  [1145] = {.lex_state = 294, .external_lex_state = 12},
  [1146] = {.lex_state = 242, .external_lex_state = 12},
  [1147] = {.lex_state = 840, .external_lex_state = 13},
  [1148] = {.lex_state = 131, .external_lex_state = 12},
  [1149] = {.lex_state = 242, .external_lex_state = 12},
  [1150] = {.lex_state = 40, .external_lex_state = 13},
  [1151] = {.lex_state = 40, .external_lex_state = 13},
  [1152] = {.lex_state = 41, .external_lex_state = 12},
  [1153] = {.lex_state = 59, .external_lex_state = 13},
  [1154] = {.lex_state = 57, .external_lex_state = 12},
  [1155] = {.lex_state = 41, .external_lex_state = 12},
  [1156] = {.lex_state = 41, .external_lex_state = 12},
  [1157] = {.lex_state = 57, .external_lex_state = 12},
  [1158] = {.lex_state = 7, .external_lex_state = 13},
  [1159] = {.lex_state = 105, .external_lex_state = 17},
  [1160] = {.lex_state = 103, .external_lex_state = 12},
  [1161] = {.lex_state = 38, .external_lex_state = 13},
  [1162] = {.lex_state = 54, .external_lex_state = 12},
  [1163] = {.lex_state = 39, .external_lex_state = 12},
  [1164] = {.lex_state = 39, .external_lex_state = 12},
  [1165] = {.lex_state = 54, .external_lex_state = 12},
  [1166] = {.lex_state = 294, .external_lex_state = 12},
  [1167] = {.lex_state = 294, .external_lex_state = 12},
  [1168] = {.lex_state = 840, .external_lex_state = 13},
  [1169] = {.lex_state = 840, .external_lex_state = 13},
  [1170] = {.lex_state = 55, .external_lex_state = 13},
  [1171] = {.lex_state = 294, .external_lex_state = 12},
  [1172] = {.lex_state = 38, .external_lex_state = 13},
  [1173] = {.lex_state = 131, .external_lex_state = 12},
  [1174] = {.lex_state = 292, .external_lex_state = 13},
  [1175] = {.lex_state = 155, .external_lex_state = 12},
  [1176] = {.lex_state = 155, .external_lex_state = 12},
  [1177] = {.lex_state = 155, .external_lex_state = 12},
  [1178] = {.lex_state = 95, .external_lex_state = 12},
  [1179] = {.lex_state = 840, .external_lex_state = 12},
  [1180] = {.lex_state = 155, .external_lex_state = 12},
  [1181] = {.lex_state = 155, .external_lex_state = 12},
  [1182] = {.lex_state = 840, .external_lex_state = 13},
  [1183] = {.lex_state = 137, .external_lex_state = 12},
  [1184] = {.lex_state = 840, .external_lex_state = 20},
  [1185] = {.lex_state = 840, .external_lex_state = 12},
  [1186] = {.lex_state = 840, .external_lex_state = 12},
  [1187] = {.lex_state = 104, .external_lex_state = 13},
  [1188] = {.lex_state = 129, .external_lex_state = 13},
  [1189] = {.lex_state = 137, .external_lex_state = 12},
  [1190] = {.lex_state = 286, .external_lex_state = 12},
  [1191] = {.lex_state = 137, .external_lex_state = 12},
  [1192] = {.lex_state = 137, .external_lex_state = 12},
  [1193] = {.lex_state = 286, .external_lex_state = 12},
  [1194] = {.lex_state = 840, .external_lex_state = 12},
  [1195] = {.lex_state = 840, .external_lex_state = 12},
  [1196] = {.lex_state = 840, .external_lex_state = 12},
  [1197] = {.lex_state = 840, .external_lex_state = 12},
  [1198] = {.lex_state = 840, .external_lex_state = 12},
  [1199] = {.lex_state = 840, .external_lex_state = 12},
  [1200] = {.lex_state = 840, .external_lex_state = 12},
  [1201] = {.lex_state = 147, .external_lex_state = 12},
  [1202] = {.lex_state = 139, .external_lex_state = 12},
  [1203] = {.lex_state = 243, .external_lex_state = 12},
  [1204] = {.lex_state = 147, .external_lex_state = 12},
  [1205] = {.lex_state = 147, .external_lex_state = 12},
  [1206] = {.lex_state = 132, .external_lex_state = 12},
  [1207] = {.lex_state = 147, .external_lex_state = 12},
  [1208] = {.lex_state = 147, .external_lex_state = 12},
  [1209] = {.lex_state = 145, .external_lex_state = 12},
  [1210] = {.lex_state = 137, .external_lex_state = 12},
  [1211] = {.lex_state = 145, .external_lex_state = 12},
  [1212] = {.lex_state = 145, .external_lex_state = 12},
  [1213] = {.lex_state = 145, .external_lex_state = 12},
  [1214] = {.lex_state = 145, .external_lex_state = 12},
  [1215] = {.lex_state = 155, .external_lex_state = 12},
  [1216] = {.lex_state = 104, .external_lex_state = 13},
  [1217] = {.lex_state = 104, .external_lex_state = 13},
  [1218] = {.lex_state = 840, .external_lex_state = 12},
  [1219] = {.lex_state = 129, .external_lex_state = 13},
  [1220] = {.lex_state = 840, .external_lex_state = 12},
  [1221] = {.lex_state = 840, .external_lex_state = 12},
  [1222] = {.lex_state = 840, .external_lex_state = 12},
  [1223] = {.lex_state = 840, .external_lex_state = 12},
  [1224] = {.lex_state = 840, .external_lex_state = 12},
  [1225] = {.lex_state = 840, .external_lex_state = 12},
  [1226] = {.lex_state = 840, .external_lex_state = 12},
  [1227] = {.lex_state = 223, .external_lex_state = 12},
  [1228] = {.lex_state = 155, .external_lex_state = 12},
  [1229] = {.lex_state = 155, .external_lex_state = 12},
  [1230] = {.lex_state = 840, .external_lex_state = 12},
  [1231] = {.lex_state = 286, .external_lex_state = 12},
  [1232] = {.lex_state = 286, .external_lex_state = 12},
  [1233] = {.lex_state = 840, .external_lex_state = 13},
  [1234] = {.lex_state = 132, .external_lex_state = 12},
  [1235] = {.lex_state = 840, .external_lex_state = 21},
  [1236] = {.lex_state = 292, .external_lex_state = 13},
  [1237] = {.lex_state = 129, .external_lex_state = 22},
  [1238] = {.lex_state = 840, .external_lex_state = 13},
  [1239] = {.lex_state = 149, .external_lex_state = 12},
  [1240] = {.lex_state = 130, .external_lex_state = 12},
  [1241] = {.lex_state = 296, .external_lex_state = 12},
  [1242] = {.lex_state = 96, .external_lex_state = 13},
  [1243] = {.lex_state = 149, .external_lex_state = 12},
  [1244] = {.lex_state = 149, .external_lex_state = 12},
  [1245] = {.lex_state = 130, .external_lex_state = 12},
  [1246] = {.lex_state = 7, .external_lex_state = 12},
  [1247] = {.lex_state = 149, .external_lex_state = 12},
  [1248] = {.lex_state = 149, .external_lex_state = 12},
  [1249] = {.lex_state = 223, .external_lex_state = 13},
  [1250] = {.lex_state = 155, .external_lex_state = 13},
  [1251] = {.lex_state = 138, .external_lex_state = 13},
  [1252] = {.lex_state = 155, .external_lex_state = 13},
  [1253] = {.lex_state = 155, .external_lex_state = 13},
  [1254] = {.lex_state = 155, .external_lex_state = 13},
  [1255] = {.lex_state = 840, .external_lex_state = 21},
  [1256] = {.lex_state = 840, .external_lex_state = 21},
  [1257] = {.lex_state = 840, .external_lex_state = 21},
  [1258] = {.lex_state = 155, .external_lex_state = 13},
  [1259] = {.lex_state = 840, .external_lex_state = 23},
  [1260] = {.lex_state = 155, .external_lex_state = 13},
  [1261] = {.lex_state = 43, .external_lex_state = 12},
  [1262] = {.lex_state = 56, .external_lex_state = 24},
  [1263] = {.lex_state = 293, .external_lex_state = 12},
  [1264] = {.lex_state = 152, .external_lex_state = 13},
  [1265] = {.lex_state = 152, .external_lex_state = 13},
  [1266] = {.lex_state = 152, .external_lex_state = 13},
  [1267] = {.lex_state = 286, .external_lex_state = 12},
  [1268] = {.lex_state = 152, .external_lex_state = 13},
  [1269] = {.lex_state = 152, .external_lex_state = 13},
  [1270] = {.lex_state = 150, .external_lex_state = 13},
  [1271] = {.lex_state = 127, .external_lex_state = 12},
  [1272] = {.lex_state = 277, .external_lex_state = 12},
  [1273] = {.lex_state = 150, .external_lex_state = 13},
  [1274] = {.lex_state = 150, .external_lex_state = 13},
  [1275] = {.lex_state = 127, .external_lex_state = 12},
  [1276] = {.lex_state = 150, .external_lex_state = 13},
  [1277] = {.lex_state = 150, .external_lex_state = 13},
  [1278] = {.lex_state = 143, .external_lex_state = 13},
  [1279] = {.lex_state = 173, .external_lex_state = 12},
  [1280] = {.lex_state = 126, .external_lex_state = 12},
  [1281] = {.lex_state = 132, .external_lex_state = 12},
  [1282] = {.lex_state = 43, .external_lex_state = 12},
  [1283] = {.lex_state = 243, .external_lex_state = 12},
  [1284] = {.lex_state = 51, .external_lex_state = 13},
  [1285] = {.lex_state = 51, .external_lex_state = 13},
  [1286] = {.lex_state = 132, .external_lex_state = 12},
  [1287] = {.lex_state = 132, .external_lex_state = 12},
  [1288] = {.lex_state = 243, .external_lex_state = 12},
  [1289] = {.lex_state = 840, .external_lex_state = 21},
  [1290] = {.lex_state = 138, .external_lex_state = 13},
  [1291] = {.lex_state = 52, .external_lex_state = 12},
  [1292] = {.lex_state = 52, .external_lex_state = 12},
  [1293] = {.lex_state = 138, .external_lex_state = 13},
  [1294] = {.lex_state = 53, .external_lex_state = 13},
  [1295] = {.lex_state = 53, .external_lex_state = 13},
  [1296] = {.lex_state = 138, .external_lex_state = 13},
  [1297] = {.lex_state = 840, .external_lex_state = 21},
  [1298] = {.lex_state = 50, .external_lex_state = 12},
  [1299] = {.lex_state = 50, .external_lex_state = 12},
  [1300] = {.lex_state = 293, .external_lex_state = 12},
  [1301] = {.lex_state = 45, .external_lex_state = 12},
  [1302] = {.lex_state = 155, .external_lex_state = 12},
  [1303] = {.lex_state = 138, .external_lex_state = 13},
  [1304] = {.lex_state = 840, .external_lex_state = 13},
  [1305] = {.lex_state = 840, .external_lex_state = 13},
  [1306] = {.lex_state = 840, .external_lex_state = 12},
  [1307] = {.lex_state = 45, .external_lex_state = 12},
  [1308] = {.lex_state = 43, .external_lex_state = 12},
  [1309] = {.lex_state = 43, .external_lex_state = 12},
  [1310] = {.lex_state = 840, .external_lex_state = 13},
  [1311] = {.lex_state = 129, .external_lex_state = 13},
  [1312] = {.lex_state = 129, .external_lex_state = 13},
  [1313] = {.lex_state = 840, .external_lex_state = 13},
  [1314] = {.lex_state = 129, .external_lex_state = 13},
  [1315] = {.lex_state = 292, .external_lex_state = 13},
  [1316] = {.lex_state = 129, .external_lex_state = 22},
  [1317] = {.lex_state = 292, .external_lex_state = 22},
  [1318] = {.lex_state = 840, .external_lex_state = 13},
  [1319] = {.lex_state = 840, .external_lex_state = 13},
  [1320] = {.lex_state = 840, .external_lex_state = 13},
  [1321] = {.lex_state = 840, .external_lex_state = 13},
  [1322] = {.lex_state = 840, .external_lex_state = 13},
  [1323] = {.lex_state = 840, .external_lex_state = 13},
  [1324] = {.lex_state = 840, .external_lex_state = 13},
  [1325] = {.lex_state = 840, .external_lex_state = 13},
  [1326] = {.lex_state = 840, .external_lex_state = 13},
  [1327] = {.lex_state = 840, .external_lex_state = 13},
  [1328] = {.lex_state = 840, .external_lex_state = 13},
  [1329] = {.lex_state = 286, .external_lex_state = 12},
  [1330] = {.lex_state = 155, .external_lex_state = 13},
  [1331] = {.lex_state = 155, .external_lex_state = 13},
  [1332] = {.lex_state = 126, .external_lex_state = 12},
  [1333] = {.lex_state = 214, .external_lex_state = 12},
  [1334] = {.lex_state = 47, .external_lex_state = 25},
  [1335] = {.lex_state = 250, .external_lex_state = 12},
  [1336] = {.lex_state = 296, .external_lex_state = 12},
  [1337] = {.lex_state = 47, .external_lex_state = 25},
  [1338] = {.lex_state = 155, .external_lex_state = 12},
  [1339] = {.lex_state = 47, .external_lex_state = 25},
  [1340] = {.lex_state = 840, .external_lex_state = 26},
  [1341] = {.lex_state = 49, .external_lex_state = 12},
  [1342] = {.lex_state = 49, .external_lex_state = 12},
  [1343] = {.lex_state = 49, .external_lex_state = 12},
  [1344] = {.lex_state = 129, .external_lex_state = 22},
  [1345] = {.lex_state = 292, .external_lex_state = 22},
  [1346] = {.lex_state = 210, .external_lex_state = 15},
  [1347] = {.lex_state = 56, .external_lex_state = 27},
  [1348] = {.lex_state = 210, .external_lex_state = 15},
  [1349] = {.lex_state = 840, .external_lex_state = 26},
  [1350] = {.lex_state = 130, .external_lex_state = 12},
  [1351] = {.lex_state = 210, .external_lex_state = 15},
  [1352] = {.lex_state = 155, .external_lex_state = 12},
  [1353] = {.lex_state = 153, .external_lex_state = 13},
  [1354] = {.lex_state = 153, .external_lex_state = 13},
  [1355] = {.lex_state = 153, .external_lex_state = 13},
  [1356] = {.lex_state = 101, .external_lex_state = 12},
  [1357] = {.lex_state = 153, .external_lex_state = 13},
  [1358] = {.lex_state = 26, .external_lex_state = 12},
  [1359] = {.lex_state = 130, .external_lex_state = 12},
  [1360] = {.lex_state = 246, .external_lex_state = 12},
  [1361] = {.lex_state = 840, .external_lex_state = 26},
  [1362] = {.lex_state = 155, .external_lex_state = 12},
  [1363] = {.lex_state = 296, .external_lex_state = 12},
  [1364] = {.lex_state = 153, .external_lex_state = 13},
  [1365] = {.lex_state = 101, .external_lex_state = 12},
  [1366] = {.lex_state = 8, .external_lex_state = 12},
  [1367] = {.lex_state = 225, .external_lex_state = 12},
  [1368] = {.lex_state = 225, .external_lex_state = 12},
  [1369] = {.lex_state = 47, .external_lex_state = 25},
  [1370] = {.lex_state = 214, .external_lex_state = 12},
  [1371] = {.lex_state = 214, .external_lex_state = 12},
  [1372] = {.lex_state = 129, .external_lex_state = 22},
  [1373] = {.lex_state = 840, .external_lex_state = 13},
  [1374] = {.lex_state = 250, .external_lex_state = 12},
  [1375] = {.lex_state = 103, .external_lex_state = 12},
  [1376] = {.lex_state = 840, .external_lex_state = 26},
  [1377] = {.lex_state = 155, .external_lex_state = 13},
  [1378] = {.lex_state = 250, .external_lex_state = 12},
  [1379] = {.lex_state = 129, .external_lex_state = 22},
  [1380] = {.lex_state = 127, .external_lex_state = 12},
  [1381] = {.lex_state = 840, .external_lex_state = 26},
  [1382] = {.lex_state = 277, .external_lex_state = 12},
  [1383] = {.lex_state = 101, .external_lex_state = 12},
  [1384] = {.lex_state = 292, .external_lex_state = 22},
  [1385] = {.lex_state = 127, .external_lex_state = 12},
  [1386] = {.lex_state = 127, .external_lex_state = 12},
  [1387] = {.lex_state = 277, .external_lex_state = 12},
  [1388] = {.lex_state = 840, .external_lex_state = 12},
  [1389] = {.lex_state = 250, .external_lex_state = 12},
  [1390] = {.lex_state = 8, .external_lex_state = 12},
  [1391] = {.lex_state = 126, .external_lex_state = 12},
  [1392] = {.lex_state = 840, .external_lex_state = 26},
  [1393] = {.lex_state = 173, .external_lex_state = 12},
  [1394] = {.lex_state = 126, .external_lex_state = 12},
  [1395] = {.lex_state = 126, .external_lex_state = 12},
  [1396] = {.lex_state = 173, .external_lex_state = 12},
  [1397] = {.lex_state = 840, .external_lex_state = 12},
  [1398] = {.lex_state = 840, .external_lex_state = 12},
  [1399] = {.lex_state = 8, .external_lex_state = 12},
  [1400] = {.lex_state = 47, .external_lex_state = 25},
  [1401] = {.lex_state = 130, .external_lex_state = 12},
  [1402] = {.lex_state = 840, .external_lex_state = 12},
  [1403] = {.lex_state = 840, .external_lex_state = 12},
  [1404] = {.lex_state = 225, .external_lex_state = 12},
  [1405] = {.lex_state = 295, .external_lex_state = 12},
  [1406] = {.lex_state = 8, .external_lex_state = 12},
  [1407] = {.lex_state = 295, .external_lex_state = 12},
  [1408] = {.lex_state = 210, .external_lex_state = 16},
  [1409] = {.lex_state = 48, .external_lex_state = 28},
  [1410] = {.lex_state = 48, .external_lex_state = 28},
  [1411] = {.lex_state = 12, .external_lex_state = 12},
  [1412] = {.lex_state = 9, .external_lex_state = 12},
  [1413] = {.lex_state = 106, .external_lex_state = 29},
  [1414] = {.lex_state = 137, .external_lex_state = 12},
  [1415] = {.lex_state = 55, .external_lex_state = 13},
  [1416] = {.lex_state = 295, .external_lex_state = 12},
  [1417] = {.lex_state = 55, .external_lex_state = 13},
  [1418] = {.lex_state = 106, .external_lex_state = 29},
  [1419] = {.lex_state = 106, .external_lex_state = 29},
  [1420] = {.lex_state = 12, .external_lex_state = 12},
  [1421] = {.lex_state = 138, .external_lex_state = 12},
  [1422] = {.lex_state = 138, .external_lex_state = 12},
  [1423] = {.lex_state = 138, .external_lex_state = 12},
  [1424] = {.lex_state = 291, .external_lex_state = 13},
  [1425] = {.lex_state = 138, .external_lex_state = 12},
  [1426] = {.lex_state = 295, .external_lex_state = 12},
  [1427] = {.lex_state = 291, .external_lex_state = 13},
  [1428] = {.lex_state = 138, .external_lex_state = 12},
  [1429] = {.lex_state = 135, .external_lex_state = 12},
  [1430] = {.lex_state = 106, .external_lex_state = 29},
  [1431] = {.lex_state = 242, .external_lex_state = 12},
  [1432] = {.lex_state = 242, .external_lex_state = 12},
  [1433] = {.lex_state = 135, .external_lex_state = 12},
  [1434] = {.lex_state = 295, .external_lex_state = 12},
  [1435] = {.lex_state = 65, .external_lex_state = 15},
  [1436] = {.lex_state = 295, .external_lex_state = 12},
  [1437] = {.lex_state = 295, .external_lex_state = 12},
  [1438] = {.lex_state = 295, .external_lex_state = 12},
  [1439] = {.lex_state = 108, .external_lex_state = 12},
  [1440] = {.lex_state = 10, .external_lex_state = 13},
  [1441] = {.lex_state = 57, .external_lex_state = 12},
  [1442] = {.lex_state = 57, .external_lex_state = 12},
  [1443] = {.lex_state = 135, .external_lex_state = 12},
  [1444] = {.lex_state = 102, .external_lex_state = 13},
  [1445] = {.lex_state = 104, .external_lex_state = 13},
  [1446] = {.lex_state = 210, .external_lex_state = 16},
  [1447] = {.lex_state = 138, .external_lex_state = 12},
  [1448] = {.lex_state = 295, .external_lex_state = 12},
  [1449] = {.lex_state = 12, .external_lex_state = 12},
  [1450] = {.lex_state = 295, .external_lex_state = 12},
  [1451] = {.lex_state = 54, .external_lex_state = 12},
  [1452] = {.lex_state = 54, .external_lex_state = 12},
  [1453] = {.lex_state = 135, .external_lex_state = 12},
  [1454] = {.lex_state = 138, .external_lex_state = 12},
  [1455] = {.lex_state = 295, .external_lex_state = 12},
  [1456] = {.lex_state = 138, .external_lex_state = 12},
  [1457] = {.lex_state = 138, .external_lex_state = 12},
  [1458] = {.lex_state = 65, .external_lex_state = 15},
  [1459] = {.lex_state = 155, .external_lex_state = 13},
  [1460] = {.lex_state = 225, .external_lex_state = 13},
  [1461] = {.lex_state = 214, .external_lex_state = 13},
  [1462] = {.lex_state = 214, .external_lex_state = 13},
  [1463] = {.lex_state = 214, .external_lex_state = 13},
  [1464] = {.lex_state = 146, .external_lex_state = 12},
  [1465] = {.lex_state = 138, .external_lex_state = 12},
  [1466] = {.lex_state = 26, .external_lex_state = 12},
  [1467] = {.lex_state = 225, .external_lex_state = 13},
  [1468] = {.lex_state = 146, .external_lex_state = 12},
  [1469] = {.lex_state = 106, .external_lex_state = 29},
  [1470] = {.lex_state = 106, .external_lex_state = 29},
  [1471] = {.lex_state = 146, .external_lex_state = 12},
  [1472] = {.lex_state = 26, .external_lex_state = 12},
  [1473] = {.lex_state = 26, .external_lex_state = 13},
  [1474] = {.lex_state = 295, .external_lex_state = 12},
  [1475] = {.lex_state = 295, .external_lex_state = 12},
  [1476] = {.lex_state = 295, .external_lex_state = 12},
  [1477] = {.lex_state = 295, .external_lex_state = 12},
  [1478] = {.lex_state = 295, .external_lex_state = 12},
  [1479] = {.lex_state = 142, .external_lex_state = 12},
  [1480] = {.lex_state = 210, .external_lex_state = 16},
  [1481] = {.lex_state = 295, .external_lex_state = 12},
  [1482] = {.lex_state = 155, .external_lex_state = 12},
  [1483] = {.lex_state = 225, .external_lex_state = 13},
  [1484] = {.lex_state = 10, .external_lex_state = 13},
  [1485] = {.lex_state = 295, .external_lex_state = 12},
  [1486] = {.lex_state = 295, .external_lex_state = 12},
  [1487] = {.lex_state = 102, .external_lex_state = 13},
  [1488] = {.lex_state = 146, .external_lex_state = 12},
  [1489] = {.lex_state = 108, .external_lex_state = 12},
  [1490] = {.lex_state = 295, .external_lex_state = 12},
  [1491] = {.lex_state = 155, .external_lex_state = 12},
  [1492] = {.lex_state = 146, .external_lex_state = 12},
  [1493] = {.lex_state = 155, .external_lex_state = 12},
  [1494] = {.lex_state = 682, .external_lex_state = 13},
  [1495] = {.lex_state = 9, .external_lex_state = 12},
  [1496] = {.lex_state = 295, .external_lex_state = 12},
  [1497] = {.lex_state = 295, .external_lex_state = 12},
  [1498] = {.lex_state = 295, .external_lex_state = 12},
  [1499] = {.lex_state = 165, .external_lex_state = 12},
  [1500] = {.lex_state = 165, .external_lex_state = 12},
  [1501] = {.lex_state = 9, .external_lex_state = 12},
  [1502] = {.lex_state = 65, .external_lex_state = 15},
  [1503] = {.lex_state = 48, .external_lex_state = 28},
  [1504] = {.lex_state = 48, .external_lex_state = 28},
  [1505] = {.lex_state = 138, .external_lex_state = 12},
  [1506] = {.lex_state = 59, .external_lex_state = 13},
  [1507] = {.lex_state = 59, .external_lex_state = 13},
  [1508] = {.lex_state = 48, .external_lex_state = 28},
  [1509] = {.lex_state = 295, .external_lex_state = 12},
  [1510] = {.lex_state = 56, .external_lex_state = 24},
  [1511] = {.lex_state = 295, .external_lex_state = 12},
  [1512] = {.lex_state = 295, .external_lex_state = 12},
  [1513] = {.lex_state = 155, .external_lex_state = 13},
  [1514] = {.lex_state = 8, .external_lex_state = 12},
  [1515] = {.lex_state = 840, .external_lex_state = 21},
  [1516] = {.lex_state = 155, .external_lex_state = 13},
  [1517] = {.lex_state = 135, .external_lex_state = 12},
  [1518] = {.lex_state = 155, .external_lex_state = 12},
  [1519] = {.lex_state = 155, .external_lex_state = 12},
  [1520] = {.lex_state = 142, .external_lex_state = 12},
  [1521] = {.lex_state = 295, .external_lex_state = 12},
  [1522] = {.lex_state = 101, .external_lex_state = 12},
  [1523] = {.lex_state = 295, .external_lex_state = 12},
  [1524] = {.lex_state = 295, .external_lex_state = 12},
  [1525] = {.lex_state = 138, .external_lex_state = 12},
  [1526] = {.lex_state = 295, .external_lex_state = 12},
  [1527] = {.lex_state = 295, .external_lex_state = 12},
  [1528] = {.lex_state = 295, .external_lex_state = 12},
  [1529] = {.lex_state = 295, .external_lex_state = 12},
  [1530] = {.lex_state = 295, .external_lex_state = 12},
  [1531] = {.lex_state = 295, .external_lex_state = 12},
  [1532] = {.lex_state = 295, .external_lex_state = 12},
  [1533] = {.lex_state = 295, .external_lex_state = 12},
  [1534] = {.lex_state = 295, .external_lex_state = 12},
  [1535] = {.lex_state = 295, .external_lex_state = 12},
  [1536] = {.lex_state = 102, .external_lex_state = 13},
  [1537] = {.lex_state = 295, .external_lex_state = 12},
  [1538] = {.lex_state = 295, .external_lex_state = 12},
  [1539] = {.lex_state = 295, .external_lex_state = 12},
  [1540] = {.lex_state = 295, .external_lex_state = 12},
  [1541] = {.lex_state = 295, .external_lex_state = 12},
  [1542] = {.lex_state = 295, .external_lex_state = 12},
  [1543] = {.lex_state = 295, .external_lex_state = 12},
  [1544] = {.lex_state = 295, .external_lex_state = 12},
  [1545] = {.lex_state = 295, .external_lex_state = 12},
  [1546] = {.lex_state = 295, .external_lex_state = 12},
  [1547] = {.lex_state = 295, .external_lex_state = 12},
  [1548] = {.lex_state = 10, .external_lex_state = 13},
  [1549] = {.lex_state = 12, .external_lex_state = 12},
  [1550] = {.lex_state = 11, .external_lex_state = 13},
  [1551] = {.lex_state = 49, .external_lex_state = 12},
  [1552] = {.lex_state = 10, .external_lex_state = 13},
  [1553] = {.lex_state = 44, .external_lex_state = 12},
  [1554] = {.lex_state = 102, .external_lex_state = 13},
  [1555] = {.lex_state = 136, .external_lex_state = 13},
  [1556] = {.lex_state = 136, .external_lex_state = 13},
  [1557] = {.lex_state = 295, .external_lex_state = 12},
  [1558] = {.lex_state = 103, .external_lex_state = 12},
  [1559] = {.lex_state = 295, .external_lex_state = 12},
  [1560] = {.lex_state = 65, .external_lex_state = 16},
  [1561] = {.lex_state = 14, .external_lex_state = 12},
  [1562] = {.lex_state = 103, .external_lex_state = 12},
  [1563] = {.lex_state = 251, .external_lex_state = 12},
  [1564] = {.lex_state = 840, .external_lex_state = 12},
  [1565] = {.lex_state = 9, .external_lex_state = 12},
  [1566] = {.lex_state = 135, .external_lex_state = 12},
  [1567] = {.lex_state = 295, .external_lex_state = 12},
  [1568] = {.lex_state = 56, .external_lex_state = 27},
  [1569] = {.lex_state = 44, .external_lex_state = 12},
  [1570] = {.lex_state = 9, .external_lex_state = 12},
  [1571] = {.lex_state = 65, .external_lex_state = 30},
  [1572] = {.lex_state = 151, .external_lex_state = 13},
  [1573] = {.lex_state = 32, .external_lex_state = 12},
  [1574] = {.lex_state = 151, .external_lex_state = 13},
  [1575] = {.lex_state = 151, .external_lex_state = 13},
  [1576] = {.lex_state = 295, .external_lex_state = 12},
  [1577] = {.lex_state = 295, .external_lex_state = 12},
  [1578] = {.lex_state = 151, .external_lex_state = 13},
  [1579] = {.lex_state = 151, .external_lex_state = 13},
  [1580] = {.lex_state = 108, .external_lex_state = 12},
  [1581] = {.lex_state = 44, .external_lex_state = 12},
  [1582] = {.lex_state = 65, .external_lex_state = 16},
  [1583] = {.lex_state = 65, .external_lex_state = 16},
  [1584] = {.lex_state = 295, .external_lex_state = 12},
  [1585] = {.lex_state = 295, .external_lex_state = 12},
  [1586] = {.lex_state = 295, .external_lex_state = 12},
  [1587] = {.lex_state = 840, .external_lex_state = 12},
  [1588] = {.lex_state = 105, .external_lex_state = 12},
  [1589] = {.lex_state = 251, .external_lex_state = 12},
  [1590] = {.lex_state = 295, .external_lex_state = 12},
  [1591] = {.lex_state = 840, .external_lex_state = 12},
  [1592] = {.lex_state = 840, .external_lex_state = 12},
  [1593] = {.lex_state = 11, .external_lex_state = 13},
  [1594] = {.lex_state = 840, .external_lex_state = 12},
  [1595] = {.lex_state = 840, .external_lex_state = 12},
  [1596] = {.lex_state = 295, .external_lex_state = 12},
  [1597] = {.lex_state = 210, .external_lex_state = 15},
  [1598] = {.lex_state = 136, .external_lex_state = 13},
  [1599] = {.lex_state = 840, .external_lex_state = 26},
  [1600] = {.lex_state = 295, .external_lex_state = 12},
  [1601] = {.lex_state = 210, .external_lex_state = 15},
  [1602] = {.lex_state = 840, .external_lex_state = 12},
  [1603] = {.lex_state = 840, .external_lex_state = 12},
  [1604] = {.lex_state = 840, .external_lex_state = 12},
  [1605] = {.lex_state = 16, .external_lex_state = 12},
  [1606] = {.lex_state = 840, .external_lex_state = 12},
  [1607] = {.lex_state = 295, .external_lex_state = 12},
  [1608] = {.lex_state = 105, .external_lex_state = 12},
  [1609] = {.lex_state = 295, .external_lex_state = 12},
  [1610] = {.lex_state = 295, .external_lex_state = 12},
  [1611] = {.lex_state = 65, .external_lex_state = 30},
  [1612] = {.lex_state = 225, .external_lex_state = 12},
  [1613] = {.lex_state = 103, .external_lex_state = 12},
  [1614] = {.lex_state = 225, .external_lex_state = 12},
  [1615] = {.lex_state = 214, .external_lex_state = 12},
  [1616] = {.lex_state = 214, .external_lex_state = 12},
  [1617] = {.lex_state = 136, .external_lex_state = 13},
  [1618] = {.lex_state = 32, .external_lex_state = 12},
  [1619] = {.lex_state = 12, .external_lex_state = 13},
  [1620] = {.lex_state = 10, .external_lex_state = 13},
  [1621] = {.lex_state = 136, .external_lex_state = 13},
  [1622] = {.lex_state = 108, .external_lex_state = 12},
  [1623] = {.lex_state = 12, .external_lex_state = 13},
  [1624] = {.lex_state = 12, .external_lex_state = 13},
  [1625] = {.lex_state = 840, .external_lex_state = 12},
  [1626] = {.lex_state = 840, .external_lex_state = 12},
  [1627] = {.lex_state = 251, .external_lex_state = 12},
  [1628] = {.lex_state = 251, .external_lex_state = 12},
  [1629] = {.lex_state = 11, .external_lex_state = 13},
  [1630] = {.lex_state = 138, .external_lex_state = 13},
  [1631] = {.lex_state = 295, .external_lex_state = 12},
  [1632] = {.lex_state = 295, .external_lex_state = 12},
  [1633] = {.lex_state = 840, .external_lex_state = 13},
  [1634] = {.lex_state = 840, .external_lex_state = 21},
  [1635] = {.lex_state = 58, .external_lex_state = 25},
  [1636] = {.lex_state = 295, .external_lex_state = 12},
  [1637] = {.lex_state = 155, .external_lex_state = 12},
  [1638] = {.lex_state = 26, .external_lex_state = 12},
  [1639] = {.lex_state = 295, .external_lex_state = 12},
  [1640] = {.lex_state = 11, .external_lex_state = 13},
  [1641] = {.lex_state = 349, .external_lex_state = 12},
  [1642] = {.lex_state = 295, .external_lex_state = 12},
  [1643] = {.lex_state = 210, .external_lex_state = 16},
  [1644] = {.lex_state = 295, .external_lex_state = 12},
  [1645] = {.lex_state = 140, .external_lex_state = 12},
  [1646] = {.lex_state = 46, .external_lex_state = 13},
  [1647] = {.lex_state = 295, .external_lex_state = 12},
  [1648] = {.lex_state = 225, .external_lex_state = 13},
  [1649] = {.lex_state = 46, .external_lex_state = 13},
  [1650] = {.lex_state = 225, .external_lex_state = 13},
  [1651] = {.lex_state = 210, .external_lex_state = 16},
  [1652] = {.lex_state = 243, .external_lex_state = 12},
  [1653] = {.lex_state = 243, .external_lex_state = 12},
  [1654] = {.lex_state = 295, .external_lex_state = 12},
  [1655] = {.lex_state = 46, .external_lex_state = 13},
  [1656] = {.lex_state = 250, .external_lex_state = 12},
  [1657] = {.lex_state = 295, .external_lex_state = 12},
  [1658] = {.lex_state = 140, .external_lex_state = 12},
  [1659] = {.lex_state = 111, .external_lex_state = 12},
  [1660] = {.lex_state = 140, .external_lex_state = 12},
  [1661] = {.lex_state = 295, .external_lex_state = 12},
  [1662] = {.lex_state = 294, .external_lex_state = 12},
  [1663] = {.lex_state = 137, .external_lex_state = 12},
  [1664] = {.lex_state = 224, .external_lex_state = 12},
  [1665] = {.lex_state = 295, .external_lex_state = 12},
  [1666] = {.lex_state = 295, .external_lex_state = 12},
  [1667] = {.lex_state = 295, .external_lex_state = 12},
  [1668] = {.lex_state = 295, .external_lex_state = 12},
  [1669] = {.lex_state = 292, .external_lex_state = 13},
  [1670] = {.lex_state = 840, .external_lex_state = 13},
  [1671] = {.lex_state = 292, .external_lex_state = 13},
  [1672] = {.lex_state = 295, .external_lex_state = 12},
  [1673] = {.lex_state = 214, .external_lex_state = 13},
  [1674] = {.lex_state = 137, .external_lex_state = 12},
  [1675] = {.lex_state = 214, .external_lex_state = 13},
  [1676] = {.lex_state = 16, .external_lex_state = 12},
  [1677] = {.lex_state = 104, .external_lex_state = 13},
  [1678] = {.lex_state = 105, .external_lex_state = 13},
  [1679] = {.lex_state = 137, .external_lex_state = 12},
  [1680] = {.lex_state = 349, .external_lex_state = 12},
  [1681] = {.lex_state = 26, .external_lex_state = 12},
  [1682] = {.lex_state = 14, .external_lex_state = 13},
  [1683] = {.lex_state = 140, .external_lex_state = 12},
  [1684] = {.lex_state = 49, .external_lex_state = 13},
  [1685] = {.lex_state = 26, .external_lex_state = 12},
  [1686] = {.lex_state = 295, .external_lex_state = 12},
  [1687] = {.lex_state = 12, .external_lex_state = 13},
  [1688] = {.lex_state = 26, .external_lex_state = 12},
  [1689] = {.lex_state = 111, .external_lex_state = 12},
  [1690] = {.lex_state = 26, .external_lex_state = 12},
  [1691] = {.lex_state = 101, .external_lex_state = 12},
  [1692] = {.lex_state = 11, .external_lex_state = 13},
  [1693] = {.lex_state = 101, .external_lex_state = 12},
  [1694] = {.lex_state = 295, .external_lex_state = 12},
  [1695] = {.lex_state = 136, .external_lex_state = 13},
  [1696] = {.lex_state = 17, .external_lex_state = 13},
  [1697] = {.lex_state = 840, .external_lex_state = 13},
  [1698] = {.lex_state = 105, .external_lex_state = 13},
  [1699] = {.lex_state = 295, .external_lex_state = 12},
  [1700] = {.lex_state = 104, .external_lex_state = 13},
  [1701] = {.lex_state = 104, .external_lex_state = 13},
  [1702] = {.lex_state = 111, .external_lex_state = 12},
  [1703] = {.lex_state = 212, .external_lex_state = 15},
  [1704] = {.lex_state = 135, .external_lex_state = 12},
  [1705] = {.lex_state = 12, .external_lex_state = 12},
  [1706] = {.lex_state = 11, .external_lex_state = 12},
  [1707] = {.lex_state = 136, .external_lex_state = 12},
  [1708] = {.lex_state = 296, .external_lex_state = 12},
  [1709] = {.lex_state = 173, .external_lex_state = 12},
  [1710] = {.lex_state = 296, .external_lex_state = 12},
  [1711] = {.lex_state = 173, .external_lex_state = 12},
  [1712] = {.lex_state = 144, .external_lex_state = 13},
  [1713] = {.lex_state = 252, .external_lex_state = 25},
  [1714] = {.lex_state = 252, .external_lex_state = 25},
  [1715] = {.lex_state = 142, .external_lex_state = 12},
  [1716] = {.lex_state = 148, .external_lex_state = 12},
  [1717] = {.lex_state = 247, .external_lex_state = 12},
  [1718] = {.lex_state = 247, .external_lex_state = 12},
  [1719] = {.lex_state = 11, .external_lex_state = 12},
  [1720] = {.lex_state = 12, .external_lex_state = 12},
  [1721] = {.lex_state = 247, .external_lex_state = 12},
  [1722] = {.lex_state = 11, .external_lex_state = 12},
  [1723] = {.lex_state = 97, .external_lex_state = 25},
  [1724] = {.lex_state = 136, .external_lex_state = 12},
  [1725] = {.lex_state = 140, .external_lex_state = 12},
  [1726] = {.lex_state = 237, .external_lex_state = 12},
  [1727] = {.lex_state = 136, .external_lex_state = 12},
  [1728] = {.lex_state = 237, .external_lex_state = 12},
  [1729] = {.lex_state = 140, .external_lex_state = 12},
  [1730] = {.lex_state = 138, .external_lex_state = 12},
  [1731] = {.lex_state = 136, .external_lex_state = 12},
  [1732] = {.lex_state = 840, .external_lex_state = 12},
  [1733] = {.lex_state = 32, .external_lex_state = 13},
  [1734] = {.lex_state = 97, .external_lex_state = 25},
  [1735] = {.lex_state = 138, .external_lex_state = 13},
  [1736] = {.lex_state = 105, .external_lex_state = 12},
  [1737] = {.lex_state = 252, .external_lex_state = 25},
  [1738] = {.lex_state = 252, .external_lex_state = 25},
  [1739] = {.lex_state = 140, .external_lex_state = 12},
  [1740] = {.lex_state = 252, .external_lex_state = 25},
  [1741] = {.lex_state = 292, .external_lex_state = 22},
  [1742] = {.lex_state = 12, .external_lex_state = 12},
  [1743] = {.lex_state = 237, .external_lex_state = 12},
  [1744] = {.lex_state = 277, .external_lex_state = 12},
  [1745] = {.lex_state = 237, .external_lex_state = 12},
  [1746] = {.lex_state = 136, .external_lex_state = 12},
  [1747] = {.lex_state = 102, .external_lex_state = 13},
  [1748] = {.lex_state = 840, .external_lex_state = 12},
  [1749] = {.lex_state = 136, .external_lex_state = 12},
  [1750] = {.lex_state = 31, .external_lex_state = 12},
  [1751] = {.lex_state = 138, .external_lex_state = 13},
  [1752] = {.lex_state = 12, .external_lex_state = 12},
  [1753] = {.lex_state = 102, .external_lex_state = 13},
  [1754] = {.lex_state = 33, .external_lex_state = 12},
  [1755] = {.lex_state = 840, .external_lex_state = 12},
  [1756] = {.lex_state = 140, .external_lex_state = 12},
  [1757] = {.lex_state = 97, .external_lex_state = 25},
  [1758] = {.lex_state = 60, .external_lex_state = 28},
  [1759] = {.lex_state = 277, .external_lex_state = 12},
  [1760] = {.lex_state = 292, .external_lex_state = 22},
  [1761] = {.lex_state = 97, .external_lex_state = 25},
  [1762] = {.lex_state = 32, .external_lex_state = 12},
  [1763] = {.lex_state = 251, .external_lex_state = 12},
  [1764] = {.lex_state = 148, .external_lex_state = 12},
  [1765] = {.lex_state = 65, .external_lex_state = 15},
  [1766] = {.lex_state = 148, .external_lex_state = 12},
  [1767] = {.lex_state = 17, .external_lex_state = 13},
  [1768] = {.lex_state = 136, .external_lex_state = 12},
  [1769] = {.lex_state = 26, .external_lex_state = 12},
  [1770] = {.lex_state = 136, .external_lex_state = 12},
  [1771] = {.lex_state = 144, .external_lex_state = 13},
  [1772] = {.lex_state = 32, .external_lex_state = 12},
  [1773] = {.lex_state = 144, .external_lex_state = 13},
  [1774] = {.lex_state = 32, .external_lex_state = 13},
  [1775] = {.lex_state = 237, .external_lex_state = 12},
  [1776] = {.lex_state = 136, .external_lex_state = 12},
  [1777] = {.lex_state = 138, .external_lex_state = 13},
  [1778] = {.lex_state = 840, .external_lex_state = 12},
  [1779] = {.lex_state = 136, .external_lex_state = 12},
  [1780] = {.lex_state = 65, .external_lex_state = 30},
  [1781] = {.lex_state = 224, .external_lex_state = 13},
  [1782] = {.lex_state = 148, .external_lex_state = 12},
  [1783] = {.lex_state = 105, .external_lex_state = 12},
  [1784] = {.lex_state = 31, .external_lex_state = 12},
  [1785] = {.lex_state = 31, .external_lex_state = 13},
  [1786] = {.lex_state = 136, .external_lex_state = 12},
  [1787] = {.lex_state = 135, .external_lex_state = 12},
  [1788] = {.lex_state = 31, .external_lex_state = 13},
  [1789] = {.lex_state = 148, .external_lex_state = 12},
  [1790] = {.lex_state = 144, .external_lex_state = 13},
  [1791] = {.lex_state = 136, .external_lex_state = 12},
  [1792] = {.lex_state = 31, .external_lex_state = 13},
  [1793] = {.lex_state = 98, .external_lex_state = 28},
  [1794] = {.lex_state = 840, .external_lex_state = 12},
  [1795] = {.lex_state = 840, .external_lex_state = 12},
  [1796] = {.lex_state = 26, .external_lex_state = 12},
  [1797] = {.lex_state = 65, .external_lex_state = 16},
  [1798] = {.lex_state = 213, .external_lex_state = 12},
  [1799] = {.lex_state = 840, .external_lex_state = 12},
  [1800] = {.lex_state = 840, .external_lex_state = 12},
  [1801] = {.lex_state = 31, .external_lex_state = 12},
  [1802] = {.lex_state = 240, .external_lex_state = 12},
  [1803] = {.lex_state = 248, .external_lex_state = 12},
  [1804] = {.lex_state = 11, .external_lex_state = 12},
  [1805] = {.lex_state = 240, .external_lex_state = 12},
  [1806] = {.lex_state = 840, .external_lex_state = 12},
  [1807] = {.lex_state = 840, .external_lex_state = 12},
  [1808] = {.lex_state = 840, .external_lex_state = 12},
  [1809] = {.lex_state = 249, .external_lex_state = 25},
  [1810] = {.lex_state = 249, .external_lex_state = 25},
  [1811] = {.lex_state = 231, .external_lex_state = 12},
  [1812] = {.lex_state = 840, .external_lex_state = 13},
  [1813] = {.lex_state = 840, .external_lex_state = 21},
  [1814] = {.lex_state = 140, .external_lex_state = 12},
  [1815] = {.lex_state = 840, .external_lex_state = 12},
  [1816] = {.lex_state = 144, .external_lex_state = 13},
  [1817] = {.lex_state = 294, .external_lex_state = 12},
  [1818] = {.lex_state = 840, .external_lex_state = 21},
  [1819] = {.lex_state = 12, .external_lex_state = 13},
  [1820] = {.lex_state = 136, .external_lex_state = 12},
  [1821] = {.lex_state = 98, .external_lex_state = 28},
  [1822] = {.lex_state = 294, .external_lex_state = 12},
  [1823] = {.lex_state = 840, .external_lex_state = 21},
  [1824] = {.lex_state = 25, .external_lex_state = 13},
  [1825] = {.lex_state = 25, .external_lex_state = 13},
  [1826] = {.lex_state = 105, .external_lex_state = 13},
  [1827] = {.lex_state = 840, .external_lex_state = 12},
  [1828] = {.lex_state = 840, .external_lex_state = 12},
  [1829] = {.lex_state = 840, .external_lex_state = 12},
  [1830] = {.lex_state = 840, .external_lex_state = 21},
  [1831] = {.lex_state = 140, .external_lex_state = 12},
  [1832] = {.lex_state = 840, .external_lex_state = 12},
  [1833] = {.lex_state = 12, .external_lex_state = 13},
  [1834] = {.lex_state = 840, .external_lex_state = 12},
  [1835] = {.lex_state = 32, .external_lex_state = 13},
  [1836] = {.lex_state = 12, .external_lex_state = 13},
  [1837] = {.lex_state = 33, .external_lex_state = 12},
  [1838] = {.lex_state = 11, .external_lex_state = 12},
  [1839] = {.lex_state = 683, .external_lex_state = 13},
  [1840] = {.lex_state = 105, .external_lex_state = 12},
  [1841] = {.lex_state = 26, .external_lex_state = 13},
  [1842] = {.lex_state = 12, .external_lex_state = 13},
  [1843] = {.lex_state = 33, .external_lex_state = 12},
  [1844] = {.lex_state = 240, .external_lex_state = 12},
  [1845] = {.lex_state = 300, .external_lex_state = 28},
  [1846] = {.lex_state = 26, .external_lex_state = 12},
  [1847] = {.lex_state = 144, .external_lex_state = 13},
  [1848] = {.lex_state = 32, .external_lex_state = 12},
  [1849] = {.lex_state = 31, .external_lex_state = 13},
  [1850] = {.lex_state = 32, .external_lex_state = 13},
  [1851] = {.lex_state = 32, .external_lex_state = 13},
  [1852] = {.lex_state = 26, .external_lex_state = 12},
  [1853] = {.lex_state = 31, .external_lex_state = 12},
  [1854] = {.lex_state = 33, .external_lex_state = 12},
  [1855] = {.lex_state = 25, .external_lex_state = 13},
  [1856] = {.lex_state = 144, .external_lex_state = 13},
  [1857] = {.lex_state = 26, .external_lex_state = 12},
  [1858] = {.lex_state = 249, .external_lex_state = 25},
  [1859] = {.lex_state = 249, .external_lex_state = 25},
  [1860] = {.lex_state = 26, .external_lex_state = 13},
  [1861] = {.lex_state = 840, .external_lex_state = 13},
  [1862] = {.lex_state = 212, .external_lex_state = 16},
  [1863] = {.lex_state = 25, .external_lex_state = 13},
  [1864] = {.lex_state = 25, .external_lex_state = 13},
  [1865] = {.lex_state = 840, .external_lex_state = 13},
  [1866] = {.lex_state = 26, .external_lex_state = 13},
  [1867] = {.lex_state = 105, .external_lex_state = 13},
  [1868] = {.lex_state = 683, .external_lex_state = 13},
  [1869] = {.lex_state = 300, .external_lex_state = 28},
  [1870] = {.lex_state = 26, .external_lex_state = 13},
  [1871] = {.lex_state = 26, .external_lex_state = 13},
  [1872] = {.lex_state = 26, .external_lex_state = 13},
  [1873] = {.lex_state = 26, .external_lex_state = 13},
  [1874] = {.lex_state = 136, .external_lex_state = 13},
  [1875] = {.lex_state = 840, .external_lex_state = 12},
  [1876] = {.lex_state = 26, .external_lex_state = 13},
  [1877] = {.lex_state = 136, .external_lex_state = 13},
  [1878] = {.lex_state = 300, .external_lex_state = 28},
  [1879] = {.lex_state = 32, .external_lex_state = 12},
  [1880] = {.lex_state = 240, .external_lex_state = 12},
  [1881] = {.lex_state = 33, .external_lex_state = 13},
  [1882] = {.lex_state = 240, .external_lex_state = 12},
  [1883] = {.lex_state = 31, .external_lex_state = 12},
  [1884] = {.lex_state = 31, .external_lex_state = 13},
  [1885] = {.lex_state = 98, .external_lex_state = 28},
  [1886] = {.lex_state = 840, .external_lex_state = 12},
  [1887] = {.lex_state = 98, .external_lex_state = 28},
  [1888] = {.lex_state = 144, .external_lex_state = 13},
  [1889] = {.lex_state = 32, .external_lex_state = 12},
  [1890] = {.lex_state = 33, .external_lex_state = 12},
  [1891] = {.lex_state = 300, .external_lex_state = 28},
  [1892] = {.lex_state = 300, .external_lex_state = 28},
  [1893] = {.lex_state = 248, .external_lex_state = 12},
  [1894] = {.lex_state = 105, .external_lex_state = 12},
  [1895] = {.lex_state = 840, .external_lex_state = 13},
  [1896] = {.lex_state = 840, .external_lex_state = 21},
  [1897] = {.lex_state = 683, .external_lex_state = 13},
  [1898] = {.lex_state = 144, .external_lex_state = 13},
  [1899] = {.lex_state = 208, .external_lex_state = 13},
  [1900] = {.lex_state = 840, .external_lex_state = 13},
  [1901] = {.lex_state = 840, .external_lex_state = 12},
  [1902] = {.lex_state = 840, .external_lex_state = 13},
  [1903] = {.lex_state = 32, .external_lex_state = 12},
  [1904] = {.lex_state = 31, .external_lex_state = 12},
  [1905] = {.lex_state = 299, .external_lex_state = 28},
  [1906] = {.lex_state = 299, .external_lex_state = 28},
  [1907] = {.lex_state = 840, .external_lex_state = 12},
  [1908] = {.lex_state = 32, .external_lex_state = 13},
  [1909] = {.lex_state = 840, .external_lex_state = 13},
  [1910] = {.lex_state = 238, .external_lex_state = 12},
  [1911] = {.lex_state = 31, .external_lex_state = 13},
  [1912] = {.lex_state = 253, .external_lex_state = 25},
  [1913] = {.lex_state = 253, .external_lex_state = 25},
  [1914] = {.lex_state = 138, .external_lex_state = 12},
  [1915] = {.lex_state = 840, .external_lex_state = 12},
  [1916] = {.lex_state = 253, .external_lex_state = 25},
  [1917] = {.lex_state = 253, .external_lex_state = 25},
  [1918] = {.lex_state = 31, .external_lex_state = 12},
  [1919] = {.lex_state = 56, .external_lex_state = 24},
  [1920] = {.lex_state = 840, .external_lex_state = 12},
  [1921] = {.lex_state = 237, .external_lex_state = 12},
  [1922] = {.lex_state = 689, .external_lex_state = 13},
  [1923] = {.lex_state = 144, .external_lex_state = 13},
  [1924] = {.lex_state = 237, .external_lex_state = 12},
  [1925] = {.lex_state = 138, .external_lex_state = 12},
  [1926] = {.lex_state = 208, .external_lex_state = 13},
  [1927] = {.lex_state = 208, .external_lex_state = 13},
  [1928] = {.lex_state = 46, .external_lex_state = 12},
  [1929] = {.lex_state = 253, .external_lex_state = 25},
  [1930] = {.lex_state = 253, .external_lex_state = 25},
  [1931] = {.lex_state = 840, .external_lex_state = 13},
  [1932] = {.lex_state = 840, .external_lex_state = 12},
  [1933] = {.lex_state = 144, .external_lex_state = 12},
  [1934] = {.lex_state = 237, .external_lex_state = 12},
  [1935] = {.lex_state = 237, .external_lex_state = 12},
  [1936] = {.lex_state = 144, .external_lex_state = 12},
  [1937] = {.lex_state = 246, .external_lex_state = 12},
  [1938] = {.lex_state = 840, .external_lex_state = 12},
  [1939] = {.lex_state = 253, .external_lex_state = 25},
  [1940] = {.lex_state = 138, .external_lex_state = 12},
  [1941] = {.lex_state = 231, .external_lex_state = 13},
  [1942] = {.lex_state = 32, .external_lex_state = 12},
  [1943] = {.lex_state = 253, .external_lex_state = 25},
  [1944] = {.lex_state = 144, .external_lex_state = 12},
  [1945] = {.lex_state = 208, .external_lex_state = 13},
  [1946] = {.lex_state = 247, .external_lex_state = 12},
  [1947] = {.lex_state = 840, .external_lex_state = 13},
  [1948] = {.lex_state = 238, .external_lex_state = 12},
  [1949] = {.lex_state = 122, .external_lex_state = 12},
  [1950] = {.lex_state = 253, .external_lex_state = 25},
  [1951] = {.lex_state = 141, .external_lex_state = 12},
  [1952] = {.lex_state = 213, .external_lex_state = 13},
  [1953] = {.lex_state = 32, .external_lex_state = 13},
  [1954] = {.lex_state = 840, .external_lex_state = 13},
  [1955] = {.lex_state = 208, .external_lex_state = 13},
  [1956] = {.lex_state = 144, .external_lex_state = 12},
  [1957] = {.lex_state = 32, .external_lex_state = 12},
  [1958] = {.lex_state = 122, .external_lex_state = 12},
  [1959] = {.lex_state = 840, .external_lex_state = 12},
  [1960] = {.lex_state = 247, .external_lex_state = 12},
  [1961] = {.lex_state = 840, .external_lex_state = 13},
  [1962] = {.lex_state = 65, .external_lex_state = 15},
  [1963] = {.lex_state = 141, .external_lex_state = 12},
  [1964] = {.lex_state = 144, .external_lex_state = 12},
  [1965] = {.lex_state = 840, .external_lex_state = 12},
  [1966] = {.lex_state = 840, .external_lex_state = 13},
  [1967] = {.lex_state = 840, .external_lex_state = 13},
  [1968] = {.lex_state = 122, .external_lex_state = 12},
  [1969] = {.lex_state = 840, .external_lex_state = 13},
  [1970] = {.lex_state = 840, .external_lex_state = 13},
  [1971] = {.lex_state = 840, .external_lex_state = 13},
  [1972] = {.lex_state = 840, .external_lex_state = 12},
  [1973] = {.lex_state = 840, .external_lex_state = 13},
  [1974] = {.lex_state = 840, .external_lex_state = 13},
  [1975] = {.lex_state = 253, .external_lex_state = 25},
  [1976] = {.lex_state = 840, .external_lex_state = 12},
  [1977] = {.lex_state = 31, .external_lex_state = 13},
  [1978] = {.lex_state = 253, .external_lex_state = 25},
  [1979] = {.lex_state = 144, .external_lex_state = 12},
  [1980] = {.lex_state = 299, .external_lex_state = 28},
  [1981] = {.lex_state = 31, .external_lex_state = 12},
  [1982] = {.lex_state = 299, .external_lex_state = 28},
  [1983] = {.lex_state = 26, .external_lex_state = 13},
  [1984] = {.lex_state = 253, .external_lex_state = 25},
  [1985] = {.lex_state = 840, .external_lex_state = 13},
  [1986] = {.lex_state = 840, .external_lex_state = 13},
  [1987] = {.lex_state = 840, .external_lex_state = 13},
  [1988] = {.lex_state = 689, .external_lex_state = 13},
  [1989] = {.lex_state = 253, .external_lex_state = 25},
  [1990] = {.lex_state = 840, .external_lex_state = 13},
  [1991] = {.lex_state = 117, .external_lex_state = 13},
  [1992] = {.lex_state = 0, .external_lex_state = 31},
  [1993] = {.lex_state = 840, .external_lex_state = 12},
  [1994] = {.lex_state = 840, .external_lex_state = 12},
  [1995] = {.lex_state = 156, .external_lex_state = 12},
  [1996] = {.lex_state = 33, .external_lex_state = 12},
  [1997] = {.lex_state = 840, .external_lex_state = 12},
  [1998] = {.lex_state = 33, .external_lex_state = 12},
  [1999] = {.lex_state = 32, .external_lex_state = 13},
  [2000] = {.lex_state = 117, .external_lex_state = 13},
  [2001] = {.lex_state = 32, .external_lex_state = 13},
  [2002] = {.lex_state = 32, .external_lex_state = 12},
  [2003] = {.lex_state = 230, .external_lex_state = 12},
  [2004] = {.lex_state = 840, .external_lex_state = 13},
  [2005] = {.lex_state = 144, .external_lex_state = 12},
  [2006] = {.lex_state = 240, .external_lex_state = 12},
  [2007] = {.lex_state = 156, .external_lex_state = 12},
  [2008] = {.lex_state = 31, .external_lex_state = 12},
  [2009] = {.lex_state = 840, .external_lex_state = 13},
  [2010] = {.lex_state = 840, .external_lex_state = 12},
  [2011] = {.lex_state = 144, .external_lex_state = 12},
  [2012] = {.lex_state = 688, .external_lex_state = 28},
  [2013] = {.lex_state = 688, .external_lex_state = 28},
  [2014] = {.lex_state = 840, .external_lex_state = 12},
  [2015] = {.lex_state = 840, .external_lex_state = 12},
  [2016] = {.lex_state = 840, .external_lex_state = 12},
  [2017] = {.lex_state = 136, .external_lex_state = 12},
  [2018] = {.lex_state = 840, .external_lex_state = 12},
  [2019] = {.lex_state = 840, .external_lex_state = 12},
  [2020] = {.lex_state = 0, .external_lex_state = 32},
  [2021] = {.lex_state = 0, .external_lex_state = 31},
  [2022] = {.lex_state = 31, .external_lex_state = 13},
  [2023] = {.lex_state = 249, .external_lex_state = 25},
  [2024] = {.lex_state = 840, .external_lex_state = 13},
  [2025] = {.lex_state = 144, .external_lex_state = 12},
  [2026] = {.lex_state = 840, .external_lex_state = 12},
  [2027] = {.lex_state = 688, .external_lex_state = 28},
  [2028] = {.lex_state = 240, .external_lex_state = 12},
  [2029] = {.lex_state = 33, .external_lex_state = 12},
  [2030] = {.lex_state = 840, .external_lex_state = 12},
  [2031] = {.lex_state = 840, .external_lex_state = 12},
  [2032] = {.lex_state = 136, .external_lex_state = 12},
  [2033] = {.lex_state = 688, .external_lex_state = 28},
  [2034] = {.lex_state = 31, .external_lex_state = 13},
  [2035] = {.lex_state = 688, .external_lex_state = 28},
  [2036] = {.lex_state = 840, .external_lex_state = 12},
  [2037] = {.lex_state = 33, .external_lex_state = 12},
  [2038] = {.lex_state = 33, .external_lex_state = 12},
  [2039] = {.lex_state = 688, .external_lex_state = 28},
  [2040] = {.lex_state = 33, .external_lex_state = 12},
  [2041] = {.lex_state = 12, .external_lex_state = 12},
  [2042] = {.lex_state = 0, .external_lex_state = 31},
  [2043] = {.lex_state = 240, .external_lex_state = 12},
  [2044] = {.lex_state = 840, .external_lex_state = 12},
  [2045] = {.lex_state = 840, .external_lex_state = 12},
  [2046] = {.lex_state = 840, .external_lex_state = 12},
  [2047] = {.lex_state = 840, .external_lex_state = 12},
  [2048] = {.lex_state = 840, .external_lex_state = 12},
  [2049] = {.lex_state = 688, .external_lex_state = 28},
  [2050] = {.lex_state = 0, .external_lex_state = 32},
  [2051] = {.lex_state = 0, .external_lex_state = 31},
  [2052] = {.lex_state = 840, .external_lex_state = 12},
  [2053] = {.lex_state = 688, .external_lex_state = 28},
  [2054] = {.lex_state = 31, .external_lex_state = 13},
  [2055] = {.lex_state = 688, .external_lex_state = 28},
  [2056] = {.lex_state = 24, .external_lex_state = 12},
  [2057] = {.lex_state = 688, .external_lex_state = 28},
  [2058] = {.lex_state = 840, .external_lex_state = 12},
  [2059] = {.lex_state = 144, .external_lex_state = 12},
  [2060] = {.lex_state = 840, .external_lex_state = 12},
  [2061] = {.lex_state = 840, .external_lex_state = 12},
  [2062] = {.lex_state = 109, .external_lex_state = 13},
  [2063] = {.lex_state = 12, .external_lex_state = 12},
  [2064] = {.lex_state = 144, .external_lex_state = 12},
  [2065] = {.lex_state = 144, .external_lex_state = 12},
  [2066] = {.lex_state = 144, .external_lex_state = 12},
  [2067] = {.lex_state = 688, .external_lex_state = 28},
  [2068] = {.lex_state = 688, .external_lex_state = 28},
  [2069] = {.lex_state = 840, .external_lex_state = 12},
  [2070] = {.lex_state = 26, .external_lex_state = 13},
  [2071] = {.lex_state = 688, .external_lex_state = 28},
  [2072] = {.lex_state = 12, .external_lex_state = 12},
  [2073] = {.lex_state = 56, .external_lex_state = 27},
  [2074] = {.lex_state = 682, .external_lex_state = 13},
  [2075] = {.lex_state = 26, .external_lex_state = 13},
  [2076] = {.lex_state = 840, .external_lex_state = 13},
  [2077] = {.lex_state = 12, .external_lex_state = 12},
  [2078] = {.lex_state = 33, .external_lex_state = 12},
  [2079] = {.lex_state = 46, .external_lex_state = 12},
  [2080] = {.lex_state = 840, .external_lex_state = 12},
  [2081] = {.lex_state = 32, .external_lex_state = 13},
  [2082] = {.lex_state = 12, .external_lex_state = 12},
  [2083] = {.lex_state = 0, .external_lex_state = 32},
  [2084] = {.lex_state = 32, .external_lex_state = 12},
  [2085] = {.lex_state = 31, .external_lex_state = 13},
  [2086] = {.lex_state = 249, .external_lex_state = 25},
  [2087] = {.lex_state = 31, .external_lex_state = 12},
  [2088] = {.lex_state = 65, .external_lex_state = 16},
  [2089] = {.lex_state = 26, .external_lex_state = 13},
  [2090] = {.lex_state = 33, .external_lex_state = 12},
  [2091] = {.lex_state = 26, .external_lex_state = 13},
  [2092] = {.lex_state = 26, .external_lex_state = 13},
  [2093] = {.lex_state = 33, .external_lex_state = 12},
  [2094] = {.lex_state = 840, .external_lex_state = 13},
  [2095] = {.lex_state = 683, .external_lex_state = 13},
  [2096] = {.lex_state = 33, .external_lex_state = 12},
  [2097] = {.lex_state = 33, .external_lex_state = 12},
  [2098] = {.lex_state = 240, .external_lex_state = 12},
  [2099] = {.lex_state = 32, .external_lex_state = 13},
  [2100] = {.lex_state = 840, .external_lex_state = 13},
  [2101] = {.lex_state = 840, .external_lex_state = 13},
  [2102] = {.lex_state = 156, .external_lex_state = 12},
  [2103] = {.lex_state = 33, .external_lex_state = 12},
  [2104] = {.lex_state = 144, .external_lex_state = 12},
  [2105] = {.lex_state = 26, .external_lex_state = 13},
  [2106] = {.lex_state = 840, .external_lex_state = 12},
  [2107] = {.lex_state = 26, .external_lex_state = 13},
  [2108] = {.lex_state = 144, .external_lex_state = 12},
  [2109] = {.lex_state = 840, .external_lex_state = 13},
  [2110] = {.lex_state = 144, .external_lex_state = 12},
  [2111] = {.lex_state = 32, .external_lex_state = 12},
  [2112] = {.lex_state = 683, .external_lex_state = 13},
  [2113] = {.lex_state = 31, .external_lex_state = 12},
  [2114] = {.lex_state = 24, .external_lex_state = 12},
  [2115] = {.lex_state = 840, .external_lex_state = 12},
  [2116] = {.lex_state = 26, .external_lex_state = 13},
  [2117] = {.lex_state = 117, .external_lex_state = 13},
  [2118] = {.lex_state = 26, .external_lex_state = 13},
  [2119] = {.lex_state = 33, .external_lex_state = 12},
  [2120] = {.lex_state = 0, .external_lex_state = 32},
  [2121] = {.lex_state = 117, .external_lex_state = 12},
  [2122] = {.lex_state = 840, .external_lex_state = 13},
  [2123] = {.lex_state = 65, .external_lex_state = 12},
  [2124] = {.lex_state = 840, .external_lex_state = 12},
  [2125] = {.lex_state = 117, .external_lex_state = 12},
  [2126] = {.lex_state = 840, .external_lex_state = 12},
  [2127] = {.lex_state = 33, .external_lex_state = 12},
  [2128] = {.lex_state = 19, .external_lex_state = 12},
  [2129] = {.lex_state = 208, .external_lex_state = 13},
  [2130] = {.lex_state = 253, .external_lex_state = 25},
  [2131] = {.lex_state = 0, .external_lex_state = 31},
  [2132] = {.lex_state = 0, .external_lex_state = 32},
  [2133] = {.lex_state = 26, .external_lex_state = 33},
  [2134] = {.lex_state = 156, .external_lex_state = 12},
  [2135] = {.lex_state = 122, .external_lex_state = 12},
  [2136] = {.lex_state = 840, .external_lex_state = 13},
  [2137] = {.lex_state = 467, .external_lex_state = 12},
  [2138] = {.lex_state = 208, .external_lex_state = 13},
  [2139] = {.lex_state = 208, .external_lex_state = 13},
  [2140] = {.lex_state = 26, .external_lex_state = 33},
  [2141] = {.lex_state = 158, .external_lex_state = 13},
  [2142] = {.lex_state = 840, .external_lex_state = 12},
  [2143] = {.lex_state = 230, .external_lex_state = 13},
  [2144] = {.lex_state = 840, .external_lex_state = 12},
  [2145] = {.lex_state = 32, .external_lex_state = 12},
  [2146] = {.lex_state = 840, .external_lex_state = 13},
  [2147] = {.lex_state = 12, .external_lex_state = 12},
  [2148] = {.lex_state = 840, .external_lex_state = 12},
  [2149] = {.lex_state = 12, .external_lex_state = 12},
  [2150] = {.lex_state = 144, .external_lex_state = 12},
  [2151] = {.lex_state = 31, .external_lex_state = 12},
  [2152] = {.lex_state = 158, .external_lex_state = 13},
  [2153] = {.lex_state = 12, .external_lex_state = 12},
  [2154] = {.lex_state = 840, .external_lex_state = 13},
  [2155] = {.lex_state = 840, .external_lex_state = 12},
  [2156] = {.lex_state = 253, .external_lex_state = 25},
  [2157] = {.lex_state = 840, .external_lex_state = 12},
  [2158] = {.lex_state = 156, .external_lex_state = 12},
  [2159] = {.lex_state = 144, .external_lex_state = 12},
  [2160] = {.lex_state = 840, .external_lex_state = 12},
  [2161] = {.lex_state = 26, .external_lex_state = 12},
  [2162] = {.lex_state = 840, .external_lex_state = 13},
  [2163] = {.lex_state = 156, .external_lex_state = 12},
  [2164] = {.lex_state = 840, .external_lex_state = 13},
  [2165] = {.lex_state = 156, .external_lex_state = 12},
  [2166] = {.lex_state = 840, .external_lex_state = 13},
  [2167] = {.lex_state = 33, .external_lex_state = 12},
  [2168] = {.lex_state = 840, .external_lex_state = 13},
  [2169] = {.lex_state = 158, .external_lex_state = 13},
  [2170] = {.lex_state = 840, .external_lex_state = 13},
  [2171] = {.lex_state = 840, .external_lex_state = 13},
  [2172] = {.lex_state = 65, .external_lex_state = 12},
  [2173] = {.lex_state = 208, .external_lex_state = 13},
  [2174] = {.lex_state = 840, .external_lex_state = 12},
  [2175] = {.lex_state = 840, .external_lex_state = 13},
  [2176] = {.lex_state = 299, .external_lex_state = 28},
  [2177] = {.lex_state = 122, .external_lex_state = 12},
  [2178] = {.lex_state = 0, .external_lex_state = 34},
  [2179] = {.lex_state = 840, .external_lex_state = 13},
  [2180] = {.lex_state = 840, .external_lex_state = 13},
  [2181] = {.lex_state = 840, .external_lex_state = 13},
  [2182] = {.lex_state = 840, .external_lex_state = 13},
  [2183] = {.lex_state = 248, .external_lex_state = 12},
  [2184] = {.lex_state = 840, .external_lex_state = 13},
  [2185] = {.lex_state = 840, .external_lex_state = 13},
  [2186] = {.lex_state = 840, .external_lex_state = 13},
  [2187] = {.lex_state = 12, .external_lex_state = 12},
  [2188] = {.lex_state = 65, .external_lex_state = 12},
  [2189] = {.lex_state = 232, .external_lex_state = 12},
  [2190] = {.lex_state = 840, .external_lex_state = 13},
  [2191] = {.lex_state = 20, .external_lex_state = 12},
  [2192] = {.lex_state = 840, .external_lex_state = 13},
  [2193] = {.lex_state = 840, .external_lex_state = 13},
  [2194] = {.lex_state = 840, .external_lex_state = 13},
  [2195] = {.lex_state = 840, .external_lex_state = 13},
  [2196] = {.lex_state = 299, .external_lex_state = 28},
  [2197] = {.lex_state = 156, .external_lex_state = 12},
  [2198] = {.lex_state = 144, .external_lex_state = 12},
  [2199] = {.lex_state = 253, .external_lex_state = 25},
  [2200] = {.lex_state = 26, .external_lex_state = 33},
  [2201] = {.lex_state = 26, .external_lex_state = 12},
  [2202] = {.lex_state = 840, .external_lex_state = 12},
  [2203] = {.lex_state = 26, .external_lex_state = 33},
  [2204] = {.lex_state = 840, .external_lex_state = 12},
  [2205] = {.lex_state = 840, .external_lex_state = 13},
  [2206] = {.lex_state = 840, .external_lex_state = 12},
  [2207] = {.lex_state = 467, .external_lex_state = 12},
  [2208] = {.lex_state = 467, .external_lex_state = 12},
  [2209] = {.lex_state = 0, .external_lex_state = 34},
  [2210] = {.lex_state = 840, .external_lex_state = 13},
  [2211] = {.lex_state = 26, .external_lex_state = 33},
  [2212] = {.lex_state = 12, .external_lex_state = 12},
  [2213] = {.lex_state = 21, .external_lex_state = 13},
  [2214] = {.lex_state = 33, .external_lex_state = 12},
  [2215] = {.lex_state = 3048, .external_lex_state = 12},
  [2216] = {.lex_state = 33, .external_lex_state = 12},
  [2217] = {.lex_state = 840, .external_lex_state = 12},
  [2218] = {.lex_state = 165, .external_lex_state = 30},
  [2219] = {.lex_state = 26, .external_lex_state = 12},
  [2220] = {.lex_state = 157, .external_lex_state = 12},
  [2221] = {.lex_state = 3, .external_lex_state = 13},
  [2222] = {.lex_state = 298, .external_lex_state = 12},
  [2223] = {.lex_state = 26, .external_lex_state = 12},
  [2224] = {.lex_state = 690, .external_lex_state = 12},
  [2225] = {.lex_state = 298, .external_lex_state = 12},
  [2226] = {.lex_state = 688, .external_lex_state = 28},
  [2227] = {.lex_state = 125, .external_lex_state = 12},
  [2228] = {.lex_state = 26, .external_lex_state = 12},
  [2229] = {.lex_state = 26, .external_lex_state = 12},
  [2230] = {.lex_state = 690, .external_lex_state = 12},
  [2231] = {.lex_state = 33, .external_lex_state = 12},
  [2232] = {.lex_state = 33, .external_lex_state = 12},
  [2233] = {.lex_state = 12, .external_lex_state = 12},
  [2234] = {.lex_state = 33, .external_lex_state = 12},
  [2235] = {.lex_state = 165, .external_lex_state = 30},
  [2236] = {.lex_state = 298, .external_lex_state = 12},
  [2237] = {.lex_state = 33, .external_lex_state = 12},
  [2238] = {.lex_state = 12, .external_lex_state = 12},
  [2239] = {.lex_state = 298, .external_lex_state = 12},
  [2240] = {.lex_state = 840, .external_lex_state = 12},
  [2241] = {.lex_state = 165, .external_lex_state = 30},
  [2242] = {.lex_state = 12, .external_lex_state = 12},
  [2243] = {.lex_state = 245, .external_lex_state = 12},
  [2244] = {.lex_state = 2, .external_lex_state = 13},
  [2245] = {.lex_state = 33, .external_lex_state = 12},
  [2246] = {.lex_state = 298, .external_lex_state = 12},
  [2247] = {.lex_state = 157, .external_lex_state = 12},
  [2248] = {.lex_state = 840, .external_lex_state = 12},
  [2249] = {.lex_state = 298, .external_lex_state = 12},
  [2250] = {.lex_state = 33, .external_lex_state = 12},
  [2251] = {.lex_state = 298, .external_lex_state = 12},
  [2252] = {.lex_state = 840, .external_lex_state = 12},
  [2253] = {.lex_state = 298, .external_lex_state = 12},
  [2254] = {.lex_state = 3, .external_lex_state = 13},
  [2255] = {.lex_state = 298, .external_lex_state = 12},
  [2256] = {.lex_state = 157, .external_lex_state = 12},
  [2257] = {.lex_state = 298, .external_lex_state = 12},
  [2258] = {.lex_state = 65, .external_lex_state = 13},
  [2259] = {.lex_state = 298, .external_lex_state = 12},
  [2260] = {.lex_state = 65, .external_lex_state = 13},
  [2261] = {.lex_state = 298, .external_lex_state = 12},
  [2262] = {.lex_state = 840, .external_lex_state = 13},
  [2263] = {.lex_state = 298, .external_lex_state = 12},
  [2264] = {.lex_state = 298, .external_lex_state = 12},
  [2265] = {.lex_state = 33, .external_lex_state = 12},
  [2266] = {.lex_state = 298, .external_lex_state = 12},
  [2267] = {.lex_state = 65, .external_lex_state = 12},
  [2268] = {.lex_state = 298, .external_lex_state = 12},
  [2269] = {.lex_state = 840, .external_lex_state = 13},
  [2270] = {.lex_state = 298, .external_lex_state = 12},
  [2271] = {.lex_state = 840, .external_lex_state = 12},
  [2272] = {.lex_state = 298, .external_lex_state = 12},
  [2273] = {.lex_state = 26, .external_lex_state = 12},
  [2274] = {.lex_state = 298, .external_lex_state = 12},
  [2275] = {.lex_state = 298, .external_lex_state = 12},
  [2276] = {.lex_state = 298, .external_lex_state = 12},
  [2277] = {.lex_state = 298, .external_lex_state = 12},
  [2278] = {.lex_state = 298, .external_lex_state = 12},
  [2279] = {.lex_state = 840, .external_lex_state = 12},
  [2280] = {.lex_state = 298, .external_lex_state = 12},
  [2281] = {.lex_state = 840, .external_lex_state = 12},
  [2282] = {.lex_state = 298, .external_lex_state = 12},
  [2283] = {.lex_state = 690, .external_lex_state = 12},
  [2284] = {.lex_state = 688, .external_lex_state = 28},
  [2285] = {.lex_state = 158, .external_lex_state = 13},
  [2286] = {.lex_state = 840, .external_lex_state = 12},
  [2287] = {.lex_state = 689, .external_lex_state = 13},
  [2288] = {.lex_state = 840, .external_lex_state = 13},
  [2289] = {.lex_state = 26, .external_lex_state = 13},
  [2290] = {.lex_state = 840, .external_lex_state = 13},
  [2291] = {.lex_state = 840, .external_lex_state = 12},
  [2292] = {.lex_state = 840, .external_lex_state = 12},
  [2293] = {.lex_state = 840, .external_lex_state = 22},
  [2294] = {.lex_state = 840, .external_lex_state = 13},
  [2295] = {.lex_state = 298, .external_lex_state = 12},
  [2296] = {.lex_state = 840, .external_lex_state = 13},
  [2297] = {.lex_state = 26, .external_lex_state = 12},
  [2298] = {.lex_state = 840, .external_lex_state = 12},
  [2299] = {.lex_state = 840, .external_lex_state = 12},
  [2300] = {.lex_state = 32, .external_lex_state = 13},
  [2301] = {.lex_state = 31, .external_lex_state = 13},
  [2302] = {.lex_state = 840, .external_lex_state = 13},
  [2303] = {.lex_state = 840, .external_lex_state = 13},
  [2304] = {.lex_state = 298, .external_lex_state = 12},
  [2305] = {.lex_state = 3, .external_lex_state = 13},
  [2306] = {.lex_state = 32, .external_lex_state = 12},
  [2307] = {.lex_state = 65, .external_lex_state = 12},
  [2308] = {.lex_state = 840, .external_lex_state = 12},
  [2309] = {.lex_state = 840, .external_lex_state = 12},
  [2310] = {.lex_state = 840, .external_lex_state = 22},
  [2311] = {.lex_state = 245, .external_lex_state = 12},
  [2312] = {.lex_state = 33, .external_lex_state = 12},
  [2313] = {.lex_state = 158, .external_lex_state = 13},
  [2314] = {.lex_state = 33, .external_lex_state = 12},
  [2315] = {.lex_state = 840, .external_lex_state = 12},
  [2316] = {.lex_state = 165, .external_lex_state = 30},
  [2317] = {.lex_state = 157, .external_lex_state = 12},
  [2318] = {.lex_state = 26, .external_lex_state = 12},
  [2319] = {.lex_state = 3048, .external_lex_state = 12},
  [2320] = {.lex_state = 26, .external_lex_state = 13},
  [2321] = {.lex_state = 298, .external_lex_state = 12},
  [2322] = {.lex_state = 125, .external_lex_state = 12},
  [2323] = {.lex_state = 840, .external_lex_state = 12},
  [2324] = {.lex_state = 125, .external_lex_state = 12},
  [2325] = {.lex_state = 298, .external_lex_state = 12},
  [2326] = {.lex_state = 840, .external_lex_state = 12},
  [2327] = {.lex_state = 26, .external_lex_state = 12},
  [2328] = {.lex_state = 690, .external_lex_state = 12},
  [2329] = {.lex_state = 33, .external_lex_state = 12},
  [2330] = {.lex_state = 840, .external_lex_state = 13},
  [2331] = {.lex_state = 125, .external_lex_state = 12},
  [2332] = {.lex_state = 840, .external_lex_state = 13},
  [2333] = {.lex_state = 840, .external_lex_state = 12},
  [2334] = {.lex_state = 688, .external_lex_state = 28},
  [2335] = {.lex_state = 33, .external_lex_state = 12},
  [2336] = {.lex_state = 65, .external_lex_state = 12},
  [2337] = {.lex_state = 33, .external_lex_state = 12},
  [2338] = {.lex_state = 117, .external_lex_state = 13},
  [2339] = {.lex_state = 165, .external_lex_state = 30},
  [2340] = {.lex_state = 157, .external_lex_state = 12},
  [2341] = {.lex_state = 840, .external_lex_state = 12},
  [2342] = {.lex_state = 33, .external_lex_state = 12},
  [2343] = {.lex_state = 298, .external_lex_state = 12},
  [2344] = {.lex_state = 158, .external_lex_state = 13},
  [2345] = {.lex_state = 3, .external_lex_state = 13},
  [2346] = {.lex_state = 840, .external_lex_state = 12},
  [2347] = {.lex_state = 232, .external_lex_state = 13},
  [2348] = {.lex_state = 165, .external_lex_state = 30},
  [2349] = {.lex_state = 298, .external_lex_state = 12},
  [2350] = {.lex_state = 840, .external_lex_state = 13},
  [2351] = {.lex_state = 840, .external_lex_state = 13},
  [2352] = {.lex_state = 298, .external_lex_state = 12},
  [2353] = {.lex_state = 840, .external_lex_state = 12},
  [2354] = {.lex_state = 32, .external_lex_state = 12},
  [2355] = {.lex_state = 3, .external_lex_state = 13},
  [2356] = {.lex_state = 65, .external_lex_state = 13},
  [2357] = {.lex_state = 26, .external_lex_state = 12},
  [2358] = {.lex_state = 254, .external_lex_state = 12},
  [2359] = {.lex_state = 690, .external_lex_state = 12},
  [2360] = {.lex_state = 840, .external_lex_state = 12},
  [2361] = {.lex_state = 117, .external_lex_state = 13},
  [2362] = {.lex_state = 33, .external_lex_state = 12},
  [2363] = {.lex_state = 158, .external_lex_state = 13},
  [2364] = {.lex_state = 298, .external_lex_state = 12},
  [2365] = {.lex_state = 33, .external_lex_state = 12},
  [2366] = {.lex_state = 158, .external_lex_state = 13},
  [2367] = {.lex_state = 840, .external_lex_state = 12},
  [2368] = {.lex_state = 255, .external_lex_state = 12},
  [2369] = {.lex_state = 840, .external_lex_state = 12},
  [2370] = {.lex_state = 840, .external_lex_state = 12},
  [2371] = {.lex_state = 840, .external_lex_state = 12},
  [2372] = {.lex_state = 0, .external_lex_state = 13},
  [2373] = {.lex_state = 840, .external_lex_state = 12},
  [2374] = {.lex_state = 3, .external_lex_state = 13},
  [2375] = {.lex_state = 3, .external_lex_state = 13},
  [2376] = {.lex_state = 65, .external_lex_state = 13},
  [2377] = {.lex_state = 840, .external_lex_state = 12},
  [2378] = {.lex_state = 840, .external_lex_state = 12},
  [2379] = {.lex_state = 840, .external_lex_state = 12},
  [2380] = {.lex_state = 840, .external_lex_state = 12},
  [2381] = {.lex_state = 840, .external_lex_state = 12},
  [2382] = {.lex_state = 840, .external_lex_state = 12},
  [2383] = {.lex_state = 32, .external_lex_state = 12},
  [2384] = {.lex_state = 840, .external_lex_state = 12},
  [2385] = {.lex_state = 218, .external_lex_state = 12},
  [2386] = {.lex_state = 109, .external_lex_state = 12},
  [2387] = {.lex_state = 840, .external_lex_state = 12},
  [2388] = {.lex_state = 3052, .external_lex_state = 13},
  [2389] = {.lex_state = 32, .external_lex_state = 12},
  [2390] = {.lex_state = 840, .external_lex_state = 12},
  [2391] = {.lex_state = 840, .external_lex_state = 12},
  [2392] = {.lex_state = 840, .external_lex_state = 12},
  [2393] = {.lex_state = 840, .external_lex_state = 12},
  [2394] = {.lex_state = 840, .external_lex_state = 12},
  [2395] = {.lex_state = 840, .external_lex_state = 12},
  [2396] = {.lex_state = 840, .external_lex_state = 12},
  [2397] = {.lex_state = 840, .external_lex_state = 12},
  [2398] = {.lex_state = 840, .external_lex_state = 12},
  [2399] = {.lex_state = 840, .external_lex_state = 12},
  [2400] = {.lex_state = 840, .external_lex_state = 12},
  [2401] = {.lex_state = 840, .external_lex_state = 12},
  [2402] = {.lex_state = 65, .external_lex_state = 12},
  [2403] = {.lex_state = 840, .external_lex_state = 12},
  [2404] = {.lex_state = 840, .external_lex_state = 12},
  [2405] = {.lex_state = 840, .external_lex_state = 12},
  [2406] = {.lex_state = 840, .external_lex_state = 12},
  [2407] = {.lex_state = 840, .external_lex_state = 12},
  [2408] = {.lex_state = 65, .external_lex_state = 12},
  [2409] = {.lex_state = 840, .external_lex_state = 12},
  [2410] = {.lex_state = 840, .external_lex_state = 12},
  [2411] = {.lex_state = 49, .external_lex_state = 12},
  [2412] = {.lex_state = 840, .external_lex_state = 12},
  [2413] = {.lex_state = 840, .external_lex_state = 12},
  [2414] = {.lex_state = 840, .external_lex_state = 12},
  [2415] = {.lex_state = 840, .external_lex_state = 12},
  [2416] = {.lex_state = 840, .external_lex_state = 12},
  [2417] = {.lex_state = 840, .external_lex_state = 12},
  [2418] = {.lex_state = 840, .external_lex_state = 12},
  [2419] = {.lex_state = 467, .external_lex_state = 12},
  [2420] = {.lex_state = 282, .external_lex_state = 12},
  [2421] = {.lex_state = 840, .external_lex_state = 12},
  [2422] = {.lex_state = 840, .external_lex_state = 12},
  [2423] = {.lex_state = 840, .external_lex_state = 12},
  [2424] = {.lex_state = 26, .external_lex_state = 12},
  [2425] = {.lex_state = 26, .external_lex_state = 12},
  [2426] = {.lex_state = 840, .external_lex_state = 12},
  [2427] = {.lex_state = 840, .external_lex_state = 12},
  [2428] = {.lex_state = 297, .external_lex_state = 12},
  [2429] = {.lex_state = 840, .external_lex_state = 12},
  [2430] = {.lex_state = 840, .external_lex_state = 12},
  [2431] = {.lex_state = 27, .external_lex_state = 35},
  [2432] = {.lex_state = 840, .external_lex_state = 12},
  [2433] = {.lex_state = 840, .external_lex_state = 12},
  [2434] = {.lex_state = 840, .external_lex_state = 12},
  [2435] = {.lex_state = 840, .external_lex_state = 12},
  [2436] = {.lex_state = 840, .external_lex_state = 12},
  [2437] = {.lex_state = 840, .external_lex_state = 12},
  [2438] = {.lex_state = 840, .external_lex_state = 12},
  [2439] = {.lex_state = 840, .external_lex_state = 12},
  [2440] = {.lex_state = 840, .external_lex_state = 12},
  [2441] = {.lex_state = 840, .external_lex_state = 12},
  [2442] = {.lex_state = 840, .external_lex_state = 12},
  [2443] = {.lex_state = 840, .external_lex_state = 12},
  [2444] = {.lex_state = 840, .external_lex_state = 12},
  [2445] = {.lex_state = 840, .external_lex_state = 12},
  [2446] = {.lex_state = 0, .external_lex_state = 13},
  [2447] = {.lex_state = 840, .external_lex_state = 12},
  [2448] = {.lex_state = 840, .external_lex_state = 12},
  [2449] = {.lex_state = 840, .external_lex_state = 12},
  [2450] = {.lex_state = 840, .external_lex_state = 12},
  [2451] = {.lex_state = 840, .external_lex_state = 12},
  [2452] = {.lex_state = 840, .external_lex_state = 12},
  [2453] = {.lex_state = 840, .external_lex_state = 12},
  [2454] = {.lex_state = 840, .external_lex_state = 12},
  [2455] = {.lex_state = 840, .external_lex_state = 12},
  [2456] = {.lex_state = 840, .external_lex_state = 12},
  [2457] = {.lex_state = 840, .external_lex_state = 12},
  [2458] = {.lex_state = 840, .external_lex_state = 12},
  [2459] = {.lex_state = 840, .external_lex_state = 12},
  [2460] = {.lex_state = 840, .external_lex_state = 12},
  [2461] = {.lex_state = 840, .external_lex_state = 12},
  [2462] = {.lex_state = 840, .external_lex_state = 12},
  [2463] = {.lex_state = 840, .external_lex_state = 12},
  [2464] = {.lex_state = 840, .external_lex_state = 12},
  [2465] = {.lex_state = 840, .external_lex_state = 13},
  [2466] = {.lex_state = 27, .external_lex_state = 35},
  [2467] = {.lex_state = 840, .external_lex_state = 12},
  [2468] = {.lex_state = 840, .external_lex_state = 12},
  [2469] = {.lex_state = 840, .external_lex_state = 12},
  [2470] = {.lex_state = 27, .external_lex_state = 35},
  [2471] = {.lex_state = 840, .external_lex_state = 12},
  [2472] = {.lex_state = 840, .external_lex_state = 12},
  [2473] = {.lex_state = 840, .external_lex_state = 12},
  [2474] = {.lex_state = 840, .external_lex_state = 12},
  [2475] = {.lex_state = 840, .external_lex_state = 12},
  [2476] = {.lex_state = 840, .external_lex_state = 22},
  [2477] = {.lex_state = 840, .external_lex_state = 12},
  [2478] = {.lex_state = 255, .external_lex_state = 12},
  [2479] = {.lex_state = 840, .external_lex_state = 22},
  [2480] = {.lex_state = 840, .external_lex_state = 12},
  [2481] = {.lex_state = 840, .external_lex_state = 12},
  [2482] = {.lex_state = 840, .external_lex_state = 12},
  [2483] = {.lex_state = 24, .external_lex_state = 12},
  [2484] = {.lex_state = 840, .external_lex_state = 17},
  [2485] = {.lex_state = 32, .external_lex_state = 12},
  [2486] = {.lex_state = 840, .external_lex_state = 12},
  [2487] = {.lex_state = 840, .external_lex_state = 12},
  [2488] = {.lex_state = 840, .external_lex_state = 12},
  [2489] = {.lex_state = 840, .external_lex_state = 12},
  [2490] = {.lex_state = 24, .external_lex_state = 12},
  [2491] = {.lex_state = 255, .external_lex_state = 12},
  [2492] = {.lex_state = 255, .external_lex_state = 12},
  [2493] = {.lex_state = 255, .external_lex_state = 12},
  [2494] = {.lex_state = 255, .external_lex_state = 12},
  [2495] = {.lex_state = 840, .external_lex_state = 12},
  [2496] = {.lex_state = 282, .external_lex_state = 12},
  [2497] = {.lex_state = 165, .external_lex_state = 12},
  [2498] = {.lex_state = 27, .external_lex_state = 35},
  [2499] = {.lex_state = 840, .external_lex_state = 22},
  [2500] = {.lex_state = 840, .external_lex_state = 13},
  [2501] = {.lex_state = 840, .external_lex_state = 13},
  [2502] = {.lex_state = 840, .external_lex_state = 13},
  [2503] = {.lex_state = 840, .external_lex_state = 13},
  [2504] = {.lex_state = 840, .external_lex_state = 12},
  [2505] = {.lex_state = 840, .external_lex_state = 12},
  [2506] = {.lex_state = 32, .external_lex_state = 12},
  [2507] = {.lex_state = 840, .external_lex_state = 12},
  [2508] = {.lex_state = 840, .external_lex_state = 12},
  [2509] = {.lex_state = 165, .external_lex_state = 12},
  [2510] = {.lex_state = 165, .external_lex_state = 12},
  [2511] = {.lex_state = 840, .external_lex_state = 12},
  [2512] = {.lex_state = 26, .external_lex_state = 36},
  [2513] = {.lex_state = 840, .external_lex_state = 12},
  [2514] = {.lex_state = 840, .external_lex_state = 12},
  [2515] = {.lex_state = 840, .external_lex_state = 12},
  [2516] = {.lex_state = 255, .external_lex_state = 12},
  [2517] = {.lex_state = 157, .external_lex_state = 12},
  [2518] = {.lex_state = 24, .external_lex_state = 12},
  [2519] = {.lex_state = 840, .external_lex_state = 12},
  [2520] = {.lex_state = 840, .external_lex_state = 12},
  [2521] = {.lex_state = 840, .external_lex_state = 12},
  [2522] = {.lex_state = 165, .external_lex_state = 12},
  [2523] = {.lex_state = 840, .external_lex_state = 12},
  [2524] = {.lex_state = 255, .external_lex_state = 12},
  [2525] = {.lex_state = 840, .external_lex_state = 12},
  [2526] = {.lex_state = 27, .external_lex_state = 35},
  [2527] = {.lex_state = 467, .external_lex_state = 12},
  [2528] = {.lex_state = 840, .external_lex_state = 12},
  [2529] = {.lex_state = 840, .external_lex_state = 12},
  [2530] = {.lex_state = 840, .external_lex_state = 12},
  [2531] = {.lex_state = 0, .external_lex_state = 13},
  [2532] = {.lex_state = 297, .external_lex_state = 12},
  [2533] = {.lex_state = 24, .external_lex_state = 12},
  [2534] = {.lex_state = 0, .external_lex_state = 13},
  [2535] = {.lex_state = 840, .external_lex_state = 12},
  [2536] = {.lex_state = 840, .external_lex_state = 12},
  [2537] = {.lex_state = 157, .external_lex_state = 12},
  [2538] = {.lex_state = 840, .external_lex_state = 12},
  [2539] = {.lex_state = 840, .external_lex_state = 17},
  [2540] = {.lex_state = 840, .external_lex_state = 12},
  [2541] = {.lex_state = 27, .external_lex_state = 35},
  [2542] = {.lex_state = 27, .external_lex_state = 35},
  [2543] = {.lex_state = 840, .external_lex_state = 12},
  [2544] = {.lex_state = 840, .external_lex_state = 12},
  [2545] = {.lex_state = 840, .external_lex_state = 12},
  [2546] = {.lex_state = 840, .external_lex_state = 12},
  [2547] = {.lex_state = 298, .external_lex_state = 12},
  [2548] = {.lex_state = 840, .external_lex_state = 12},
  [2549] = {.lex_state = 840, .external_lex_state = 12},
  [2550] = {.lex_state = 49, .external_lex_state = 12},
  [2551] = {.lex_state = 840, .external_lex_state = 12},
  [2552] = {.lex_state = 157, .external_lex_state = 12},
  [2553] = {.lex_state = 840, .external_lex_state = 12},
  [2554] = {.lex_state = 0, .external_lex_state = 13},
  [2555] = {.lex_state = 840, .external_lex_state = 12},
  [2556] = {.lex_state = 27, .external_lex_state = 35},
  [2557] = {.lex_state = 27, .external_lex_state = 35},
  [2558] = {.lex_state = 840, .external_lex_state = 12},
  [2559] = {.lex_state = 840, .external_lex_state = 12},
  [2560] = {.lex_state = 0, .external_lex_state = 13},
  [2561] = {.lex_state = 27, .external_lex_state = 35},
  [2562] = {.lex_state = 840, .external_lex_state = 12},
  [2563] = {.lex_state = 840, .external_lex_state = 12},
  [2564] = {.lex_state = 27, .external_lex_state = 35},
  [2565] = {.lex_state = 27, .external_lex_state = 35},
  [2566] = {.lex_state = 840, .external_lex_state = 12},
  [2567] = {.lex_state = 840, .external_lex_state = 12},
  [2568] = {.lex_state = 840, .external_lex_state = 12},
  [2569] = {.lex_state = 840, .external_lex_state = 12},
  [2570] = {.lex_state = 27, .external_lex_state = 35},
  [2571] = {.lex_state = 27, .external_lex_state = 35},
  [2572] = {.lex_state = 27, .external_lex_state = 35},
  [2573] = {.lex_state = 840, .external_lex_state = 12},
  [2574] = {.lex_state = 32, .external_lex_state = 12},
  [2575] = {.lex_state = 840, .external_lex_state = 12},
  [2576] = {.lex_state = 840, .external_lex_state = 12},
  [2577] = {.lex_state = 165, .external_lex_state = 12},
  [2578] = {.lex_state = 840, .external_lex_state = 12},
  [2579] = {.lex_state = 840, .external_lex_state = 12},
  [2580] = {.lex_state = 125, .external_lex_state = 13},
  [2581] = {.lex_state = 297, .external_lex_state = 12},
  [2582] = {.lex_state = 840, .external_lex_state = 12},
  [2583] = {.lex_state = 840, .external_lex_state = 12},
  [2584] = {.lex_state = 157, .external_lex_state = 12},
  [2585] = {.lex_state = 840, .external_lex_state = 12},
  [2586] = {.lex_state = 840, .external_lex_state = 12},
  [2587] = {.lex_state = 165, .external_lex_state = 12},
  [2588] = {.lex_state = 165, .external_lex_state = 12},
  [2589] = {.lex_state = 157, .external_lex_state = 12},
  [2590] = {.lex_state = 840, .external_lex_state = 12},
  [2591] = {.lex_state = 157, .external_lex_state = 12},
  [2592] = {.lex_state = 840, .external_lex_state = 12},
  [2593] = {.lex_state = 840, .external_lex_state = 13},
  [2594] = {.lex_state = 840, .external_lex_state = 12},
  [2595] = {.lex_state = 840, .external_lex_state = 12},
  [2596] = {.lex_state = 65, .external_lex_state = 12},
  [2597] = {.lex_state = 24, .external_lex_state = 12},
  [2598] = {.lex_state = 840, .external_lex_state = 12},
  [2599] = {.lex_state = 840, .external_lex_state = 12},
  [2600] = {.lex_state = 840, .external_lex_state = 12},
  [2601] = {.lex_state = 840, .external_lex_state = 12},
  [2602] = {.lex_state = 840, .external_lex_state = 12},
  [2603] = {.lex_state = 165, .external_lex_state = 12},
  [2604] = {.lex_state = 840, .external_lex_state = 12},
  [2605] = {.lex_state = 840, .external_lex_state = 12},
  [2606] = {.lex_state = 840, .external_lex_state = 12},
  [2607] = {.lex_state = 840, .external_lex_state = 12},
  [2608] = {.lex_state = 840, .external_lex_state = 12},
  [2609] = {.lex_state = 840, .external_lex_state = 12},
  [2610] = {.lex_state = 297, .external_lex_state = 12},
  [2611] = {.lex_state = 26, .external_lex_state = 33},
  [2612] = {.lex_state = 840, .external_lex_state = 12},
  [2613] = {.lex_state = 840, .external_lex_state = 12},
  [2614] = {.lex_state = 840, .external_lex_state = 12},
  [2615] = {.lex_state = 840, .external_lex_state = 12},
  [2616] = {.lex_state = 157, .external_lex_state = 12},
  [2617] = {.lex_state = 840, .external_lex_state = 12},
  [2618] = {.lex_state = 27, .external_lex_state = 35},
  [2619] = {.lex_state = 840, .external_lex_state = 12},
  [2620] = {.lex_state = 27, .external_lex_state = 35},
  [2621] = {.lex_state = 157, .external_lex_state = 12},
  [2622] = {.lex_state = 840, .external_lex_state = 12},
  [2623] = {.lex_state = 840, .external_lex_state = 12},
  [2624] = {.lex_state = 840, .external_lex_state = 12},
  [2625] = {.lex_state = 840, .external_lex_state = 13},
  [2626] = {.lex_state = 840, .external_lex_state = 12},
  [2627] = {.lex_state = 840, .external_lex_state = 12},
  [2628] = {.lex_state = 840, .external_lex_state = 17},
  [2629] = {.lex_state = 840, .external_lex_state = 12},
  [2630] = {.lex_state = 840, .external_lex_state = 12},
  [2631] = {.lex_state = 165, .external_lex_state = 12},
  [2632] = {.lex_state = 840, .external_lex_state = 12},
  [2633] = {.lex_state = 3052, .external_lex_state = 13},
  [2634] = {.lex_state = 125, .external_lex_state = 13},
  [2635] = {.lex_state = 297, .external_lex_state = 12},
  [2636] = {.lex_state = 840, .external_lex_state = 12},
  [2637] = {.lex_state = 840, .external_lex_state = 12},
  [2638] = {.lex_state = 157, .external_lex_state = 12},
  [2639] = {.lex_state = 840, .external_lex_state = 12},
  [2640] = {.lex_state = 840, .external_lex_state = 12},
  [2641] = {.lex_state = 840, .external_lex_state = 12},
  [2642] = {.lex_state = 840, .external_lex_state = 12},
  [2643] = {.lex_state = 157, .external_lex_state = 12},
  [2644] = {.lex_state = 840, .external_lex_state = 12},
  [2645] = {.lex_state = 27, .external_lex_state = 35},
  [2646] = {.lex_state = 840, .external_lex_state = 12},
  [2647] = {.lex_state = 27, .external_lex_state = 35},
  [2648] = {.lex_state = 840, .external_lex_state = 12},
  [2649] = {.lex_state = 125, .external_lex_state = 13},
  [2650] = {.lex_state = 840, .external_lex_state = 12},
  [2651] = {.lex_state = 840, .external_lex_state = 12},
  [2652] = {.lex_state = 840, .external_lex_state = 12},
  [2653] = {.lex_state = 840, .external_lex_state = 12},
  [2654] = {.lex_state = 27, .external_lex_state = 35},
  [2655] = {.lex_state = 165, .external_lex_state = 12},
  [2656] = {.lex_state = 840, .external_lex_state = 12},
  [2657] = {.lex_state = 0, .external_lex_state = 13},
  [2658] = {.lex_state = 840, .external_lex_state = 12},
  [2659] = {.lex_state = 840, .external_lex_state = 12},
  [2660] = {.lex_state = 840, .external_lex_state = 12},
  [2661] = {.lex_state = 840, .external_lex_state = 12},
  [2662] = {.lex_state = 840, .external_lex_state = 12},
  [2663] = {.lex_state = 840, .external_lex_state = 12},
  [2664] = {.lex_state = 840, .external_lex_state = 12},
  [2665] = {.lex_state = 840, .external_lex_state = 12},
  [2666] = {.lex_state = 840, .external_lex_state = 12},
  [2667] = {.lex_state = 840, .external_lex_state = 12},
  [2668] = {.lex_state = 840, .external_lex_state = 12},
  [2669] = {.lex_state = 840, .external_lex_state = 12},
  [2670] = {.lex_state = 840, .external_lex_state = 12},
  [2671] = {.lex_state = 840, .external_lex_state = 12},
  [2672] = {.lex_state = 840, .external_lex_state = 12},
  [2673] = {.lex_state = 840, .external_lex_state = 12},
  [2674] = {.lex_state = 840, .external_lex_state = 12},
  [2675] = {.lex_state = 840, .external_lex_state = 12},
  [2676] = {.lex_state = 840, .external_lex_state = 12},
  [2677] = {.lex_state = 840, .external_lex_state = 12},
  [2678] = {.lex_state = 840, .external_lex_state = 12},
  [2679] = {.lex_state = 840, .external_lex_state = 12},
  [2680] = {.lex_state = 840, .external_lex_state = 12},
  [2681] = {.lex_state = 840, .external_lex_state = 12},
  [2682] = {.lex_state = 840, .external_lex_state = 12},
  [2683] = {.lex_state = 840, .external_lex_state = 12},
  [2684] = {.lex_state = 840, .external_lex_state = 12},
  [2685] = {.lex_state = 840, .external_lex_state = 12},
  [2686] = {.lex_state = 840, .external_lex_state = 12},
  [2687] = {.lex_state = 840, .external_lex_state = 12},
  [2688] = {.lex_state = 0, .external_lex_state = 13},
  [2689] = {.lex_state = 840, .external_lex_state = 12},
  [2690] = {.lex_state = 840, .external_lex_state = 12},
  [2691] = {.lex_state = 26, .external_lex_state = 36},
  [2692] = {.lex_state = 840, .external_lex_state = 12},
  [2693] = {.lex_state = 0, .external_lex_state = 13},
  [2694] = {.lex_state = 840, .external_lex_state = 12},
  [2695] = {.lex_state = 840, .external_lex_state = 12},
  [2696] = {.lex_state = 27, .external_lex_state = 35},
  [2697] = {.lex_state = 840, .external_lex_state = 12},
  [2698] = {.lex_state = 840, .external_lex_state = 12},
  [2699] = {.lex_state = 840, .external_lex_state = 12},
  [2700] = {.lex_state = 840, .external_lex_state = 12},
  [2701] = {.lex_state = 840, .external_lex_state = 12},
  [2702] = {.lex_state = 125, .external_lex_state = 13},
  [2703] = {.lex_state = 840, .external_lex_state = 12},
  [2704] = {.lex_state = 840, .external_lex_state = 12},
  [2705] = {.lex_state = 840, .external_lex_state = 12},
  [2706] = {.lex_state = 840, .external_lex_state = 12},
  [2707] = {.lex_state = 840, .external_lex_state = 12},
  [2708] = {.lex_state = 840, .external_lex_state = 12},
  [2709] = {.lex_state = 840, .external_lex_state = 12},
  [2710] = {.lex_state = 840, .external_lex_state = 12},
  [2711] = {.lex_state = 840, .external_lex_state = 12},
  [2712] = {.lex_state = 840, .external_lex_state = 12},
  [2713] = {.lex_state = 691, .external_lex_state = 13},
  [2714] = {.lex_state = 24, .external_lex_state = 12},
  [2715] = {.lex_state = 840, .external_lex_state = 12},
  [2716] = {.lex_state = 840, .external_lex_state = 12},
  [2717] = {.lex_state = 840, .external_lex_state = 12},
  [2718] = {.lex_state = 0, .external_lex_state = 13},
  [2719] = {.lex_state = 840, .external_lex_state = 12},
  [2720] = {.lex_state = 840, .external_lex_state = 12},
  [2721] = {.lex_state = 840, .external_lex_state = 12},
  [2722] = {.lex_state = 840, .external_lex_state = 12},
  [2723] = {.lex_state = 840, .external_lex_state = 12},
  [2724] = {.lex_state = 840, .external_lex_state = 12},
  [2725] = {.lex_state = 840, .external_lex_state = 13},
  [2726] = {.lex_state = 840, .external_lex_state = 12},
  [2727] = {.lex_state = 840, .external_lex_state = 12},
  [2728] = {.lex_state = 840, .external_lex_state = 12},
  [2729] = {.lex_state = 840, .external_lex_state = 12},
  [2730] = {.lex_state = 3, .external_lex_state = 13},
  [2731] = {.lex_state = 26, .external_lex_state = 12},
  [2732] = {.lex_state = 840, .external_lex_state = 12},
  [2733] = {.lex_state = 840, .external_lex_state = 12},
  [2734] = {.lex_state = 840, .external_lex_state = 17},
  [2735] = {.lex_state = 840, .external_lex_state = 17},
  [2736] = {.lex_state = 840, .external_lex_state = 12},
  [2737] = {.lex_state = 840, .external_lex_state = 12},
  [2738] = {.lex_state = 840, .external_lex_state = 17},
  [2739] = {.lex_state = 840, .external_lex_state = 12},
  [2740] = {.lex_state = 840, .external_lex_state = 12},
  [2741] = {.lex_state = 840, .external_lex_state = 12},
  [2742] = {.lex_state = 840, .external_lex_state = 12},
  [2743] = {.lex_state = 26, .external_lex_state = 12},
  [2744] = {.lex_state = 840, .external_lex_state = 12},
  [2745] = {.lex_state = 840, .external_lex_state = 12},
  [2746] = {.lex_state = 840, .external_lex_state = 12},
  [2747] = {.lex_state = 0, .external_lex_state = 13},
  [2748] = {.lex_state = 0, .external_lex_state = 13},
  [2749] = {.lex_state = 0, .external_lex_state = 13},
  [2750] = {.lex_state = 0, .external_lex_state = 13},
  [2751] = {.lex_state = 0, .external_lex_state = 13},
  [2752] = {.lex_state = 0, .external_lex_state = 13},
  [2753] = {.lex_state = 125, .external_lex_state = 12},
  [2754] = {.lex_state = 0, .external_lex_state = 13},
  [2755] = {.lex_state = 125, .external_lex_state = 12},
  [2756] = {.lex_state = 0, .external_lex_state = 13},
  [2757] = {.lex_state = 0, .external_lex_state = 13},
  [2758] = {.lex_state = 0, .external_lex_state = 13},
  [2759] = {.lex_state = 0, .external_lex_state = 13},
  [2760] = {.lex_state = 0, .external_lex_state = 13},
  [2761] = {.lex_state = 0, .external_lex_state = 13},
  [2762] = {.lex_state = 0, .external_lex_state = 13},
  [2763] = {.lex_state = 0, .external_lex_state = 13},
  [2764] = {.lex_state = 0, .external_lex_state = 13},
  [2765] = {.lex_state = 0, .external_lex_state = 13},
  [2766] = {.lex_state = 0, .external_lex_state = 13},
  [2767] = {.lex_state = 0, .external_lex_state = 13},
  [2768] = {.lex_state = 0, .external_lex_state = 13},
  [2769] = {.lex_state = 125, .external_lex_state = 12},
  [2770] = {.lex_state = 0, .external_lex_state = 13},
  [2771] = {.lex_state = 0, .external_lex_state = 13},
  [2772] = {.lex_state = 0, .external_lex_state = 13},
  [2773] = {.lex_state = 0, .external_lex_state = 13},
  [2774] = {.lex_state = 0, .external_lex_state = 13},
  [2775] = {.lex_state = 0, .external_lex_state = 13},
  [2776] = {.lex_state = 0, .external_lex_state = 13},
  [2777] = {.lex_state = 71, .external_lex_state = 12},
  [2778] = {.lex_state = 0, .external_lex_state = 13},
  [2779] = {.lex_state = 0, .external_lex_state = 17},
  [2780] = {.lex_state = 0, .external_lex_state = 13},
  [2781] = {.lex_state = 0, .external_lex_state = 13},
  [2782] = {.lex_state = 0, .external_lex_state = 13},
  [2783] = {.lex_state = 0, .external_lex_state = 13},
  [2784] = {.lex_state = 0, .external_lex_state = 13},
  [2785] = {.lex_state = 0, .external_lex_state = 13},
  [2786] = {.lex_state = 0, .external_lex_state = 13},
  [2787] = {.lex_state = 0, .external_lex_state = 13},
  [2788] = {.lex_state = 125, .external_lex_state = 12},
  [2789] = {.lex_state = 0, .external_lex_state = 13},
  [2790] = {.lex_state = 507, .external_lex_state = 12},
  [2791] = {.lex_state = 0, .external_lex_state = 13},
  [2792] = {.lex_state = 0, .external_lex_state = 13},
  [2793] = {.lex_state = 0, .external_lex_state = 13},
  [2794] = {.lex_state = 0, .external_lex_state = 13},
  [2795] = {.lex_state = 0, .external_lex_state = 13},
  [2796] = {.lex_state = 0, .external_lex_state = 13},
  [2797] = {.lex_state = 0, .external_lex_state = 13},
  [2798] = {.lex_state = 0, .external_lex_state = 13},
  [2799] = {.lex_state = 0, .external_lex_state = 13},
  [2800] = {.lex_state = 0, .external_lex_state = 13},
  [2801] = {.lex_state = 0, .external_lex_state = 13},
  [2802] = {.lex_state = 0, .external_lex_state = 13},
  [2803] = {.lex_state = 0, .external_lex_state = 13},
  [2804] = {.lex_state = 0, .external_lex_state = 13},
  [2805] = {.lex_state = 0, .external_lex_state = 13},
  [2806] = {.lex_state = 840, .external_lex_state = 12},
  [2807] = {.lex_state = 0, .external_lex_state = 13},
  [2808] = {.lex_state = 71, .external_lex_state = 12},
  [2809] = {.lex_state = 0, .external_lex_state = 13},
  [2810] = {.lex_state = 0, .external_lex_state = 13},
  [2811] = {.lex_state = 0, .external_lex_state = 13},
  [2812] = {.lex_state = 0, .external_lex_state = 13},
  [2813] = {.lex_state = 692, .external_lex_state = 12},
  [2814] = {.lex_state = 840, .external_lex_state = 12},
  [2815] = {.lex_state = 0, .external_lex_state = 37},
  [2816] = {.lex_state = 0, .external_lex_state = 17},
  [2817] = {.lex_state = 71, .external_lex_state = 12},
  [2818] = {.lex_state = 0, .external_lex_state = 13},
  [2819] = {.lex_state = 0, .external_lex_state = 17},
  [2820] = {.lex_state = 0, .external_lex_state = 13},
  [2821] = {.lex_state = 0, .external_lex_state = 13},
  [2822] = {.lex_state = 0, .external_lex_state = 13},
  [2823] = {.lex_state = 834, .external_lex_state = 12},
  [2824] = {.lex_state = 0, .external_lex_state = 13},
  [2825] = {.lex_state = 0, .external_lex_state = 13},
  [2826] = {.lex_state = 0, .external_lex_state = 13},
  [2827] = {.lex_state = 0, .external_lex_state = 36},
  [2828] = {.lex_state = 0, .external_lex_state = 13},
  [2829] = {.lex_state = 0, .external_lex_state = 13},
  [2830] = {.lex_state = 0, .external_lex_state = 13},
  [2831] = {.lex_state = 0, .external_lex_state = 13},
  [2832] = {.lex_state = 0, .external_lex_state = 13},
  [2833] = {.lex_state = 0, .external_lex_state = 13},
  [2834] = {.lex_state = 0, .external_lex_state = 13},
  [2835] = {.lex_state = 840, .external_lex_state = 22},
  [2836] = {.lex_state = 0, .external_lex_state = 13},
  [2837] = {.lex_state = 27, .external_lex_state = 35},
  [2838] = {.lex_state = 692, .external_lex_state = 12},
  [2839] = {.lex_state = 0, .external_lex_state = 13},
  [2840] = {.lex_state = 0, .external_lex_state = 13},
  [2841] = {.lex_state = 0, .external_lex_state = 13},
  [2842] = {.lex_state = 0, .external_lex_state = 13},
  [2843] = {.lex_state = 0, .external_lex_state = 13},
  [2844] = {.lex_state = 0, .external_lex_state = 13},
  [2845] = {.lex_state = 0, .external_lex_state = 13},
  [2846] = {.lex_state = 0, .external_lex_state = 13},
  [2847] = {.lex_state = 0, .external_lex_state = 13},
  [2848] = {.lex_state = 71, .external_lex_state = 12},
  [2849] = {.lex_state = 0, .external_lex_state = 13},
  [2850] = {.lex_state = 0, .external_lex_state = 13},
  [2851] = {.lex_state = 0, .external_lex_state = 13},
  [2852] = {.lex_state = 0, .external_lex_state = 13},
  [2853] = {.lex_state = 0, .external_lex_state = 13},
  [2854] = {.lex_state = 0, .external_lex_state = 13},
  [2855] = {.lex_state = 0, .external_lex_state = 13},
  [2856] = {.lex_state = 0, .external_lex_state = 13},
  [2857] = {.lex_state = 0, .external_lex_state = 13},
  [2858] = {.lex_state = 0, .external_lex_state = 13},
  [2859] = {.lex_state = 0, .external_lex_state = 13},
  [2860] = {.lex_state = 125, .external_lex_state = 12},
  [2861] = {.lex_state = 0, .external_lex_state = 13},
  [2862] = {.lex_state = 0, .external_lex_state = 13},
  [2863] = {.lex_state = 824, .external_lex_state = 12},
  [2864] = {.lex_state = 0, .external_lex_state = 13},
  [2865] = {.lex_state = 0, .external_lex_state = 13},
  [2866] = {.lex_state = 0, .external_lex_state = 13},
  [2867] = {.lex_state = 0, .external_lex_state = 13},
  [2868] = {.lex_state = 0, .external_lex_state = 13},
  [2869] = {.lex_state = 0, .external_lex_state = 13},
  [2870] = {.lex_state = 0, .external_lex_state = 13},
  [2871] = {.lex_state = 0, .external_lex_state = 13},
  [2872] = {.lex_state = 0, .external_lex_state = 13},
  [2873] = {.lex_state = 0, .external_lex_state = 13},
  [2874] = {.lex_state = 0, .external_lex_state = 13},
  [2875] = {.lex_state = 0, .external_lex_state = 37},
  [2876] = {.lex_state = 0, .external_lex_state = 13},
  [2877] = {.lex_state = 0, .external_lex_state = 13},
  [2878] = {.lex_state = 0, .external_lex_state = 13},
  [2879] = {.lex_state = 0, .external_lex_state = 13},
  [2880] = {.lex_state = 0, .external_lex_state = 13},
  [2881] = {.lex_state = 0, .external_lex_state = 13},
  [2882] = {.lex_state = 0, .external_lex_state = 13},
  [2883] = {.lex_state = 840, .external_lex_state = 12},
  [2884] = {.lex_state = 0, .external_lex_state = 13},
  [2885] = {.lex_state = 0, .external_lex_state = 13},
  [2886] = {.lex_state = 0, .external_lex_state = 13},
  [2887] = {.lex_state = 0, .external_lex_state = 13},
  [2888] = {.lex_state = 0, .external_lex_state = 13},
  [2889] = {.lex_state = 0, .external_lex_state = 13},
  [2890] = {.lex_state = 0, .external_lex_state = 13},
  [2891] = {.lex_state = 0, .external_lex_state = 13},
  [2892] = {.lex_state = 0, .external_lex_state = 13},
  [2893] = {.lex_state = 0, .external_lex_state = 13},
  [2894] = {.lex_state = 0, .external_lex_state = 13},
  [2895] = {.lex_state = 0, .external_lex_state = 13},
  [2896] = {.lex_state = 0, .external_lex_state = 13},
  [2897] = {.lex_state = 0, .external_lex_state = 13},
  [2898] = {.lex_state = 0, .external_lex_state = 13},
  [2899] = {.lex_state = 824, .external_lex_state = 12},
  [2900] = {.lex_state = 0, .external_lex_state = 13},
  [2901] = {.lex_state = 0, .external_lex_state = 13},
  [2902] = {.lex_state = 0, .external_lex_state = 13},
  [2903] = {.lex_state = 0, .external_lex_state = 13},
  [2904] = {.lex_state = 0, .external_lex_state = 13},
  [2905] = {.lex_state = 0, .external_lex_state = 13},
  [2906] = {.lex_state = 0, .external_lex_state = 13},
  [2907] = {.lex_state = 0, .external_lex_state = 13},
  [2908] = {.lex_state = 0, .external_lex_state = 13},
  [2909] = {.lex_state = 0, .external_lex_state = 13},
  [2910] = {.lex_state = 0, .external_lex_state = 13},
  [2911] = {.lex_state = 0, .external_lex_state = 13},
  [2912] = {.lex_state = 0, .external_lex_state = 13},
  [2913] = {.lex_state = 0, .external_lex_state = 13},
  [2914] = {.lex_state = 0, .external_lex_state = 13},
  [2915] = {.lex_state = 0, .external_lex_state = 13},
  [2916] = {.lex_state = 0, .external_lex_state = 13},
  [2917] = {.lex_state = 0, .external_lex_state = 13},
  [2918] = {.lex_state = 0, .external_lex_state = 13},
  [2919] = {.lex_state = 0, .external_lex_state = 13},
  [2920] = {.lex_state = 0, .external_lex_state = 17},
  [2921] = {.lex_state = 507, .external_lex_state = 12},
  [2922] = {.lex_state = 0, .external_lex_state = 13},
  [2923] = {.lex_state = 0, .external_lex_state = 13},
  [2924] = {.lex_state = 0, .external_lex_state = 13},
  [2925] = {.lex_state = 0, .external_lex_state = 36},
  [2926] = {.lex_state = 0, .external_lex_state = 13},
  [2927] = {.lex_state = 0, .external_lex_state = 13},
  [2928] = {.lex_state = 0, .external_lex_state = 13},
  [2929] = {.lex_state = 0, .external_lex_state = 13},
  [2930] = {.lex_state = 0, .external_lex_state = 13},
  [2931] = {.lex_state = 0, .external_lex_state = 37},
  [2932] = {.lex_state = 0, .external_lex_state = 13},
  [2933] = {.lex_state = 0, .external_lex_state = 37},
  [2934] = {.lex_state = 0, .external_lex_state = 13},
  [2935] = {.lex_state = 0, .external_lex_state = 13},
  [2936] = {.lex_state = 0, .external_lex_state = 13},
  [2937] = {.lex_state = 0, .external_lex_state = 13},
  [2938] = {.lex_state = 0, .external_lex_state = 13},
  [2939] = {.lex_state = 834, .external_lex_state = 12},
  [2940] = {.lex_state = 0, .external_lex_state = 13},
  [2941] = {.lex_state = 0, .external_lex_state = 13},
  [2942] = {.lex_state = 0, .external_lex_state = 13},
  [2943] = {.lex_state = 0, .external_lex_state = 13},
  [2944] = {.lex_state = 0, .external_lex_state = 13},
  [2945] = {.lex_state = 0, .external_lex_state = 13},
  [2946] = {.lex_state = 0, .external_lex_state = 13},
  [2947] = {.lex_state = 125, .external_lex_state = 12},
  [2948] = {.lex_state = 0, .external_lex_state = 13},
  [2949] = {.lex_state = 0, .external_lex_state = 13},
  [2950] = {.lex_state = 0, .external_lex_state = 13},
  [2951] = {.lex_state = 0, .external_lex_state = 13},
  [2952] = {.lex_state = 0, .external_lex_state = 13},
  [2953] = {.lex_state = 0, .external_lex_state = 13},
  [2954] = {.lex_state = 0, .external_lex_state = 13},
  [2955] = {.lex_state = 0, .external_lex_state = 13},
  [2956] = {.lex_state = 0, .external_lex_state = 13},
  [2957] = {.lex_state = 0, .external_lex_state = 13},
  [2958] = {.lex_state = 0, .external_lex_state = 13},
  [2959] = {.lex_state = 0, .external_lex_state = 13},
  [2960] = {.lex_state = 0, .external_lex_state = 13},
  [2961] = {.lex_state = 0, .external_lex_state = 13},
  [2962] = {.lex_state = 0, .external_lex_state = 13},
  [2963] = {.lex_state = 0, .external_lex_state = 13},
  [2964] = {.lex_state = 0, .external_lex_state = 13},
  [2965] = {.lex_state = 0, .external_lex_state = 13},
  [2966] = {.lex_state = 840, .external_lex_state = 12},
  [2967] = {.lex_state = 0, .external_lex_state = 13},
  [2968] = {.lex_state = 0, .external_lex_state = 13},
  [2969] = {.lex_state = 0, .external_lex_state = 13},
  [2970] = {.lex_state = 0, .external_lex_state = 13},
  [2971] = {.lex_state = 0, .external_lex_state = 13},
  [2972] = {.lex_state = 0, .external_lex_state = 13},
  [2973] = {.lex_state = 157, .external_lex_state = 12},
  [2974] = {.lex_state = 0, .external_lex_state = 13},
  [2975] = {.lex_state = 0, .external_lex_state = 13},
  [2976] = {.lex_state = 0, .external_lex_state = 13},
  [2977] = {.lex_state = 0, .external_lex_state = 13},
  [2978] = {.lex_state = 0, .external_lex_state = 13},
  [2979] = {.lex_state = 0, .external_lex_state = 13},
  [2980] = {.lex_state = 0, .external_lex_state = 13},
  [2981] = {.lex_state = 840, .external_lex_state = 12},
  [2982] = {.lex_state = 0, .external_lex_state = 13},
  [2983] = {.lex_state = 0, .external_lex_state = 13},
  [2984] = {.lex_state = 840, .external_lex_state = 12},
  [2985] = {.lex_state = 0, .external_lex_state = 38},
  [2986] = {.lex_state = 693, .external_lex_state = 12},
  [2987] = {.lex_state = 125, .external_lex_state = 12},
  [2988] = {.lex_state = 31, .external_lex_state = 12},
  [2989] = {.lex_state = 694, .external_lex_state = 12},
  [2990] = {.lex_state = 693, .external_lex_state = 12},
  [2991] = {.lex_state = 840, .external_lex_state = 12},
  [2992] = {.lex_state = 693, .external_lex_state = 12},
  [2993] = {.lex_state = 65, .external_lex_state = 12},
  [2994] = {.lex_state = 840, .external_lex_state = 12},
  [2995] = {.lex_state = 840, .external_lex_state = 12},
  [2996] = {.lex_state = 0, .external_lex_state = 17},
  [2997] = {.lex_state = 0, .external_lex_state = 39},
  [2998] = {.lex_state = 0, .external_lex_state = 22},
  [2999] = {.lex_state = 3052, .external_lex_state = 12},
  [3000] = {.lex_state = 840, .external_lex_state = 12},
  [3001] = {.lex_state = 840, .external_lex_state = 12},
  [3002] = {.lex_state = 840, .external_lex_state = 12},
  [3003] = {.lex_state = 31, .external_lex_state = 12},
  [3004] = {.lex_state = 25, .external_lex_state = 12},
  [3005] = {.lex_state = 31, .external_lex_state = 12},
  [3006] = {.lex_state = 31, .external_lex_state = 12},
  [3007] = {.lex_state = 840, .external_lex_state = 12},
  [3008] = {.lex_state = 838, .external_lex_state = 12},
  [3009] = {.lex_state = 840, .external_lex_state = 12},
  [3010] = {.lex_state = 840, .external_lex_state = 12},
  [3011] = {.lex_state = 125, .external_lex_state = 12},
  [3012] = {.lex_state = 0, .external_lex_state = 38},
  [3013] = {.lex_state = 25, .external_lex_state = 12},
  [3014] = {.lex_state = 31, .external_lex_state = 12},
  [3015] = {.lex_state = 25, .external_lex_state = 12},
  [3016] = {.lex_state = 693, .external_lex_state = 12},
  [3017] = {.lex_state = 25, .external_lex_state = 12},
  [3018] = {.lex_state = 695, .external_lex_state = 12},
  [3019] = {.lex_state = 0, .external_lex_state = 38},
  [3020] = {.lex_state = 0, .external_lex_state = 22},
  [3021] = {.lex_state = 31, .external_lex_state = 12},
  [3022] = {.lex_state = 158, .external_lex_state = 12},
  [3023] = {.lex_state = 840, .external_lex_state = 12},
  [3024] = {.lex_state = 31, .external_lex_state = 12},
  [3025] = {.lex_state = 31, .external_lex_state = 12},
  [3026] = {.lex_state = 125, .external_lex_state = 12},
  [3027] = {.lex_state = 840, .external_lex_state = 12},
  [3028] = {.lex_state = 0, .external_lex_state = 22},
  [3029] = {.lex_state = 0, .external_lex_state = 39},
  [3030] = {.lex_state = 22, .external_lex_state = 12},
  [3031] = {.lex_state = 0, .external_lex_state = 12},
  [3032] = {.lex_state = 838, .external_lex_state = 12},
  [3033] = {.lex_state = 840, .external_lex_state = 12},
  [3034] = {.lex_state = 840, .external_lex_state = 12},
  [3035] = {.lex_state = 0, .external_lex_state = 39},
  [3036] = {.lex_state = 694, .external_lex_state = 12},
  [3037] = {.lex_state = 22, .external_lex_state = 12},
  [3038] = {.lex_state = 31, .external_lex_state = 12},
  [3039] = {.lex_state = 693, .external_lex_state = 12},
  [3040] = {.lex_state = 31, .external_lex_state = 12},
  [3041] = {.lex_state = 840, .external_lex_state = 12},
  [3042] = {.lex_state = 125, .external_lex_state = 12},
  [3043] = {.lex_state = 125, .external_lex_state = 12},
  [3044] = {.lex_state = 32, .external_lex_state = 12},
  [3045] = {.lex_state = 0, .external_lex_state = 17},
  [3046] = {.lex_state = 840, .external_lex_state = 12},
  [3047] = {.lex_state = 694, .external_lex_state = 12},
  [3048] = {.lex_state = 693, .external_lex_state = 12},
  [3049] = {.lex_state = 693, .external_lex_state = 12},
  [3050] = {.lex_state = 840, .external_lex_state = 12},
  [3051] = {.lex_state = 125, .external_lex_state = 12},
  [3052] = {.lex_state = 31, .external_lex_state = 12},
  [3053] = {.lex_state = 31, .external_lex_state = 12},
  [3054] = {.lex_state = 840, .external_lex_state = 12},
  [3055] = {.lex_state = 31, .external_lex_state = 12},
  [3056] = {.lex_state = 840, .external_lex_state = 12},
  [3057] = {.lex_state = 31, .external_lex_state = 12},
  [3058] = {.lex_state = 840, .external_lex_state = 12},
  [3059] = {.lex_state = 81, .external_lex_state = 12},
  [3060] = {.lex_state = 840, .external_lex_state = 12},
  [3061] = {.lex_state = 31, .external_lex_state = 12},
  [3062] = {.lex_state = 31, .external_lex_state = 12},
  [3063] = {.lex_state = 31, .external_lex_state = 12},
  [3064] = {.lex_state = 693, .external_lex_state = 12},
  [3065] = {.lex_state = 22, .external_lex_state = 12},
  [3066] = {.lex_state = 31, .external_lex_state = 12},
  [3067] = {.lex_state = 125, .external_lex_state = 12},
  [3068] = {.lex_state = 31, .external_lex_state = 12},
  [3069] = {.lex_state = 31, .external_lex_state = 12},
  [3070] = {.lex_state = 694, .external_lex_state = 12},
  [3071] = {.lex_state = 693, .external_lex_state = 12},
  [3072] = {.lex_state = 693, .external_lex_state = 12},
  [3073] = {.lex_state = 31, .external_lex_state = 12},
  [3074] = {.lex_state = 695, .external_lex_state = 12},
  [3075] = {.lex_state = 0, .external_lex_state = 12},
  [3076] = {.lex_state = 125, .external_lex_state = 12},
  [3077] = {.lex_state = 840, .external_lex_state = 12},
  [3078] = {.lex_state = 840, .external_lex_state = 12},
  [3079] = {.lex_state = 31, .external_lex_state = 12},
  [3080] = {.lex_state = 31, .external_lex_state = 12},
  [3081] = {.lex_state = 22, .external_lex_state = 12},
  [3082] = {.lex_state = 125, .external_lex_state = 12},
  [3083] = {.lex_state = 838, .external_lex_state = 12},
  [3084] = {.lex_state = 694, .external_lex_state = 12},
  [3085] = {.lex_state = 693, .external_lex_state = 12},
  [3086] = {.lex_state = 693, .external_lex_state = 12},
  [3087] = {.lex_state = 840, .external_lex_state = 12},
  [3088] = {.lex_state = 125, .external_lex_state = 12},
  [3089] = {.lex_state = 0, .external_lex_state = 39},
  [3090] = {.lex_state = 31, .external_lex_state = 12},
  [3091] = {.lex_state = 32, .external_lex_state = 12},
  [3092] = {.lex_state = 31, .external_lex_state = 12},
  [3093] = {.lex_state = 31, .external_lex_state = 12},
  [3094] = {.lex_state = 693, .external_lex_state = 12},
  [3095] = {.lex_state = 693, .external_lex_state = 12},
  [3096] = {.lex_state = 694, .external_lex_state = 12},
  [3097] = {.lex_state = 125, .external_lex_state = 12},
  [3098] = {.lex_state = 125, .external_lex_state = 12},
  [3099] = {.lex_state = 840, .external_lex_state = 12},
  [3100] = {.lex_state = 31, .external_lex_state = 12},
  [3101] = {.lex_state = 31, .external_lex_state = 12},
  [3102] = {.lex_state = 693, .external_lex_state = 12},
  [3103] = {.lex_state = 693, .external_lex_state = 12},
  [3104] = {.lex_state = 840, .external_lex_state = 12},
  [3105] = {.lex_state = 81, .external_lex_state = 12},
  [3106] = {.lex_state = 0, .external_lex_state = 22},
  [3107] = {.lex_state = 840, .external_lex_state = 12},
  [3108] = {.lex_state = 22, .external_lex_state = 12},
  [3109] = {.lex_state = 693, .external_lex_state = 12},
  [3110] = {.lex_state = 693, .external_lex_state = 12},
  [3111] = {.lex_state = 0, .external_lex_state = 22},
  [3112] = {.lex_state = 836, .external_lex_state = 12},
  [3113] = {.lex_state = 32, .external_lex_state = 12},
  [3114] = {.lex_state = 840, .external_lex_state = 12},
  [3115] = {.lex_state = 31, .external_lex_state = 12},
  [3116] = {.lex_state = 693, .external_lex_state = 12},
  [3117] = {.lex_state = 693, .external_lex_state = 12},
  [3118] = {.lex_state = 0, .external_lex_state = 22},
  [3119] = {.lex_state = 3052, .external_lex_state = 12},
  [3120] = {.lex_state = 31, .external_lex_state = 12},
  [3121] = {.lex_state = 840, .external_lex_state = 12},
  [3122] = {.lex_state = 840, .external_lex_state = 12},
  [3123] = {.lex_state = 693, .external_lex_state = 12},
  [3124] = {.lex_state = 31, .external_lex_state = 12},
  [3125] = {.lex_state = 840, .external_lex_state = 12},
  [3126] = {.lex_state = 838, .external_lex_state = 12},
  [3127] = {.lex_state = 840, .external_lex_state = 12},
  [3128] = {.lex_state = 0, .external_lex_state = 12},
  [3129] = {.lex_state = 693, .external_lex_state = 12},
  [3130] = {.lex_state = 693, .external_lex_state = 12},
  [3131] = {.lex_state = 840, .external_lex_state = 12},
  [3132] = {.lex_state = 32, .external_lex_state = 12},
  [3133] = {.lex_state = 840, .external_lex_state = 12},
  [3134] = {.lex_state = 0, .external_lex_state = 22},
  [3135] = {.lex_state = 693, .external_lex_state = 12},
  [3136] = {.lex_state = 840, .external_lex_state = 12},
  [3137] = {.lex_state = 22, .external_lex_state = 12},
  [3138] = {.lex_state = 0, .external_lex_state = 22},
  [3139] = {.lex_state = 840, .external_lex_state = 12},
  [3140] = {.lex_state = 0, .external_lex_state = 22},
  [3141] = {.lex_state = 693, .external_lex_state = 12},
  [3142] = {.lex_state = 125, .external_lex_state = 12},
  [3143] = {.lex_state = 125, .external_lex_state = 12},
  [3144] = {.lex_state = 3052, .external_lex_state = 12},
  [3145] = {.lex_state = 840, .external_lex_state = 12},
  [3146] = {.lex_state = 31, .external_lex_state = 12},
  [3147] = {.lex_state = 840, .external_lex_state = 12},
  [3148] = {.lex_state = 31, .external_lex_state = 12},
  [3149] = {.lex_state = 0, .external_lex_state = 39},
  [3150] = {.lex_state = 693, .external_lex_state = 12},
  [3151] = {.lex_state = 840, .external_lex_state = 12},
  [3152] = {.lex_state = 0, .external_lex_state = 38},
  [3153] = {.lex_state = 81, .external_lex_state = 12},
  [3154] = {.lex_state = 840, .external_lex_state = 12},
  [3155] = {.lex_state = 95, .external_lex_state = 12},
  [3156] = {.lex_state = 158, .external_lex_state = 12},
  [3157] = {.lex_state = 693, .external_lex_state = 12},
  [3158] = {.lex_state = 31, .external_lex_state = 12},
  [3159] = {.lex_state = 31, .external_lex_state = 12},
  [3160] = {.lex_state = 31, .external_lex_state = 12},
  [3161] = {.lex_state = 838, .external_lex_state = 12},
  [3162] = {.lex_state = 31, .external_lex_state = 12},
  [3163] = {.lex_state = 694, .external_lex_state = 12},
  [3164] = {.lex_state = 125, .external_lex_state = 12},
  [3165] = {.lex_state = 125, .external_lex_state = 12},
  [3166] = {.lex_state = 125, .external_lex_state = 12},
  [3167] = {.lex_state = 840, .external_lex_state = 12},
  [3168] = {.lex_state = 31, .external_lex_state = 12},
  [3169] = {.lex_state = 693, .external_lex_state = 12},
  [3170] = {.lex_state = 840, .external_lex_state = 12},
  [3171] = {.lex_state = 32, .external_lex_state = 12},
  [3172] = {.lex_state = 693, .external_lex_state = 12},
  [3173] = {.lex_state = 840, .external_lex_state = 12},
  [3174] = {.lex_state = 693, .external_lex_state = 12},
  [3175] = {.lex_state = 0, .external_lex_state = 17},
  [3176] = {.lex_state = 0, .external_lex_state = 22},
  [3177] = {.lex_state = 31, .external_lex_state = 12},
  [3178] = {.lex_state = 840, .external_lex_state = 12},
  [3179] = {.lex_state = 125, .external_lex_state = 12},
  [3180] = {.lex_state = 31, .external_lex_state = 12},
  [3181] = {.lex_state = 31, .external_lex_state = 12},
  [3182] = {.lex_state = 31, .external_lex_state = 12},
  [3183] = {.lex_state = 31, .external_lex_state = 12},
  [3184] = {.lex_state = 693, .external_lex_state = 12},
  [3185] = {.lex_state = 31, .external_lex_state = 12},
  [3186] = {.lex_state = 31, .external_lex_state = 12},
  [3187] = {.lex_state = 840, .external_lex_state = 12},
  [3188] = {.lex_state = 31, .external_lex_state = 12},
  [3189] = {.lex_state = 840, .external_lex_state = 12},
  [3190] = {.lex_state = 31, .external_lex_state = 12},
  [3191] = {.lex_state = 31, .external_lex_state = 12},
  [3192] = {.lex_state = 31, .external_lex_state = 12},
  [3193] = {.lex_state = 31, .external_lex_state = 12},
  [3194] = {.lex_state = 31, .external_lex_state = 12},
  [3195] = {.lex_state = 31, .external_lex_state = 12},
  [3196] = {.lex_state = 31, .external_lex_state = 12},
  [3197] = {.lex_state = 31, .external_lex_state = 12},
  [3198] = {.lex_state = 125, .external_lex_state = 12},
  [3199] = {.lex_state = 840, .external_lex_state = 12},
  [3200] = {.lex_state = 25, .external_lex_state = 12},
  [3201] = {.lex_state = 840, .external_lex_state = 12},
  [3202] = {.lex_state = 31, .external_lex_state = 12},
  [3203] = {.lex_state = 31, .external_lex_state = 12},
  [3204] = {.lex_state = 125, .external_lex_state = 12},
  [3205] = {.lex_state = 31, .external_lex_state = 12},
  [3206] = {.lex_state = 840, .external_lex_state = 12},
  [3207] = {.lex_state = 31, .external_lex_state = 12},
  [3208] = {.lex_state = 31, .external_lex_state = 12},
  [3209] = {.lex_state = 31, .external_lex_state = 12},
  [3210] = {.lex_state = 31, .external_lex_state = 12},
  [3211] = {.lex_state = 31, .external_lex_state = 12},
  [3212] = {.lex_state = 31, .external_lex_state = 12},
  [3213] = {.lex_state = 31, .external_lex_state = 12},
  [3214] = {.lex_state = 31, .external_lex_state = 12},
  [3215] = {.lex_state = 31, .external_lex_state = 12},
  [3216] = {.lex_state = 31, .external_lex_state = 12},
  [3217] = {.lex_state = 31, .external_lex_state = 12},
  [3218] = {.lex_state = 125, .external_lex_state = 12},
  [3219] = {.lex_state = 125, .external_lex_state = 12},
  [3220] = {.lex_state = 0, .external_lex_state = 12},
  [3221] = {.lex_state = 31, .external_lex_state = 12},
  [3222] = {.lex_state = 840, .external_lex_state = 12},
  [3223] = {.lex_state = 836, .external_lex_state = 12},
  [3224] = {.lex_state = 31, .external_lex_state = 12},
  [3225] = {.lex_state = 31, .external_lex_state = 12},
  [3226] = {.lex_state = 31, .external_lex_state = 12},
  [3227] = {.lex_state = 0, .external_lex_state = 12},
  [3228] = {.lex_state = 125, .external_lex_state = 12},
  [3229] = {.lex_state = 840, .external_lex_state = 12},
  [3230] = {.lex_state = 125, .external_lex_state = 12},
  [3231] = {.lex_state = 32, .external_lex_state = 12},
  [3232] = {.lex_state = 25, .external_lex_state = 12},
  [3233] = {.lex_state = 158, .external_lex_state = 12},
  [3234] = {.lex_state = 0, .external_lex_state = 22},
  [3235] = {.lex_state = 840, .external_lex_state = 12},
  [3236] = {.lex_state = 125, .external_lex_state = 12},
  [3237] = {.lex_state = 31, .external_lex_state = 12},
  [3238] = {.lex_state = 31, .external_lex_state = 12},
  [3239] = {.lex_state = 31, .external_lex_state = 12},
  [3240] = {.lex_state = 31, .external_lex_state = 12},
  [3241] = {.lex_state = 81, .external_lex_state = 12},
  [3242] = {.lex_state = 840, .external_lex_state = 12},
  [3243] = {.lex_state = 3052, .external_lex_state = 12},
  [3244] = {.lex_state = 31, .external_lex_state = 12},
  [3245] = {.lex_state = 31, .external_lex_state = 12},
  [3246] = {.lex_state = 31, .external_lex_state = 12},
  [3247] = {.lex_state = 31, .external_lex_state = 12},
  [3248] = {.lex_state = 840, .external_lex_state = 12},
  [3249] = {.lex_state = 838, .external_lex_state = 12},
  [3250] = {.lex_state = 106, .external_lex_state = 12},
  [3251] = {.lex_state = 838, .external_lex_state = 12},
  [3252] = {.lex_state = 32, .external_lex_state = 12},
  [3253] = {.lex_state = 81, .external_lex_state = 12},
  [3254] = {.lex_state = 840, .external_lex_state = 12},
  [3255] = {.lex_state = 838, .external_lex_state = 12},
  [3256] = {.lex_state = 125, .external_lex_state = 12},
  [3257] = {.lex_state = 31, .external_lex_state = 12},
  [3258] = {.lex_state = 31, .external_lex_state = 12},
  [3259] = {.lex_state = 31, .external_lex_state = 12},
  [3260] = {.lex_state = 693, .external_lex_state = 12},
  [3261] = {.lex_state = 840, .external_lex_state = 12},
  [3262] = {.lex_state = 840, .external_lex_state = 12},
  [3263] = {.lex_state = 31, .external_lex_state = 12},
  [3264] = {.lex_state = 840, .external_lex_state = 12},
  [3265] = {.lex_state = 31, .external_lex_state = 12},
  [3266] = {.lex_state = 31, .external_lex_state = 12},
  [3267] = {.lex_state = 0, .external_lex_state = 40},
  [3268] = {.lex_state = 840, .external_lex_state = 12},
  [3269] = {.lex_state = 125, .external_lex_state = 12},
  [3270] = {.lex_state = 840, .external_lex_state = 12},
  [3271] = {.lex_state = 125, .external_lex_state = 12},
  [3272] = {.lex_state = 81, .external_lex_state = 12},
  [3273] = {.lex_state = 840, .external_lex_state = 12},
  [3274] = {.lex_state = 31, .external_lex_state = 12},
  [3275] = {.lex_state = 31, .external_lex_state = 12},
  [3276] = {.lex_state = 31, .external_lex_state = 12},
  [3277] = {.lex_state = 125, .external_lex_state = 12},
  [3278] = {.lex_state = 840, .external_lex_state = 12},
  [3279] = {.lex_state = 31, .external_lex_state = 12},
  [3280] = {.lex_state = 125, .external_lex_state = 12},
  [3281] = {.lex_state = 25, .external_lex_state = 12},
  [3282] = {.lex_state = 31, .external_lex_state = 12},
  [3283] = {.lex_state = 31, .external_lex_state = 12},
  [3284] = {.lex_state = 0, .external_lex_state = 22},
  [3285] = {.lex_state = 695, .external_lex_state = 12},
  [3286] = {.lex_state = 31, .external_lex_state = 12},
  [3287] = {.lex_state = 840, .external_lex_state = 12},
  [3288] = {.lex_state = 695, .external_lex_state = 12},
  [3289] = {.lex_state = 0, .external_lex_state = 38},
  [3290] = {.lex_state = 81, .external_lex_state = 12},
  [3291] = {.lex_state = 31, .external_lex_state = 12},
  [3292] = {.lex_state = 31, .external_lex_state = 12},
  [3293] = {.lex_state = 840, .external_lex_state = 12},
  [3294] = {.lex_state = 125, .external_lex_state = 12},
  [3295] = {.lex_state = 0, .external_lex_state = 17},
  [3296] = {.lex_state = 31, .external_lex_state = 12},
  [3297] = {.lex_state = 840, .external_lex_state = 12},
  [3298] = {.lex_state = 31, .external_lex_state = 12},
  [3299] = {.lex_state = 81, .external_lex_state = 12},
  [3300] = {.lex_state = 31, .external_lex_state = 12},
  [3301] = {.lex_state = 693, .external_lex_state = 12},
  [3302] = {.lex_state = 81, .external_lex_state = 12},
  [3303] = {.lex_state = 840, .external_lex_state = 12},
  [3304] = {.lex_state = 840, .external_lex_state = 12},
  [3305] = {.lex_state = 31, .external_lex_state = 12},
  [3306] = {.lex_state = 31, .external_lex_state = 12},
  [3307] = {.lex_state = 0, .external_lex_state = 22},
  [3308] = {.lex_state = 31, .external_lex_state = 12},
  [3309] = {.lex_state = 840, .external_lex_state = 12},
  [3310] = {.lex_state = 0, .external_lex_state = 22},
  [3311] = {.lex_state = 0, .external_lex_state = 40},
  [3312] = {.lex_state = 0, .external_lex_state = 22},
  [3313] = {.lex_state = 81, .external_lex_state = 12},
  [3314] = {.lex_state = 693, .external_lex_state = 12},
  [3315] = {.lex_state = 125, .external_lex_state = 12},
  [3316] = {.lex_state = 840, .external_lex_state = 12},
  [3317] = {.lex_state = 95, .external_lex_state = 12},
  [3318] = {.lex_state = 0, .external_lex_state = 38},
  [3319] = {.lex_state = 0, .external_lex_state = 39},
  [3320] = {.lex_state = 693, .external_lex_state = 12},
  [3321] = {.lex_state = 31, .external_lex_state = 12},
  [3322] = {.lex_state = 0, .external_lex_state = 22},
  [3323] = {.lex_state = 22, .external_lex_state = 12},
  [3324] = {.lex_state = 840, .external_lex_state = 12},
  [3325] = {.lex_state = 31, .external_lex_state = 12},
  [3326] = {.lex_state = 31, .external_lex_state = 12},
  [3327] = {.lex_state = 31, .external_lex_state = 12},
  [3328] = {.lex_state = 0, .external_lex_state = 38},
  [3329] = {.lex_state = 0, .external_lex_state = 38},
  [3330] = {.lex_state = 125, .external_lex_state = 12},
  [3331] = {.lex_state = 0, .external_lex_state = 17},
  [3332] = {.lex_state = 81, .external_lex_state = 12},
  [3333] = {.lex_state = 32, .external_lex_state = 12},
  [3334] = {.lex_state = 0, .external_lex_state = 39},
  [3335] = {.lex_state = 32, .external_lex_state = 12},
  [3336] = {.lex_state = 0, .external_lex_state = 17},
  [3337] = {.lex_state = 0, .external_lex_state = 39},
  [3338] = {.lex_state = 31, .external_lex_state = 12},
  [3339] = {.lex_state = 31, .external_lex_state = 12},
  [3340] = {.lex_state = 0, .external_lex_state = 17},
  [3341] = {.lex_state = 840, .external_lex_state = 12},
  [3342] = {.lex_state = 840, .external_lex_state = 12},
  [3343] = {.lex_state = 838, .external_lex_state = 12},
  [3344] = {.lex_state = 125, .external_lex_state = 12},
  [3345] = {.lex_state = 694, .external_lex_state = 12},
  [3346] = {.lex_state = 125, .external_lex_state = 12},
  [3347] = {.lex_state = 840, .external_lex_state = 12},
  [3348] = {.lex_state = 158, .external_lex_state = 12},
  [3349] = {.lex_state = 31, .external_lex_state = 12},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_keyword] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_dos] = ACTIONS(1),
    [anon_sym_unix] = ACTIONS(1),
    [anon_sym_mac] = ACTIONS(1),
    [anon_sym_latin12] = ACTIONS(1),
    [anon_sym_iso2] = ACTIONS(1),
    [anon_sym_koi82] = ACTIONS(1),
    [anon_sym_macroman2] = ACTIONS(1),
    [anon_sym_cp4372] = ACTIONS(1),
    [anon_sym_cp7372] = ACTIONS(1),
    [anon_sym_cp7752] = ACTIONS(1),
    [anon_sym_cp8502] = ACTIONS(1),
    [anon_sym_cp8522] = ACTIONS(1),
    [anon_sym_cp8552] = ACTIONS(1),
    [anon_sym_cp8572] = ACTIONS(1),
    [anon_sym_cp8602] = ACTIONS(1),
    [anon_sym_cp8612] = ACTIONS(1),
    [anon_sym_cp8622] = ACTIONS(1),
    [anon_sym_cp8632] = ACTIONS(1),
    [anon_sym_cp8652] = ACTIONS(1),
    [anon_sym_cp8662] = ACTIONS(1),
    [anon_sym_cp8692] = ACTIONS(1),
    [anon_sym_cp8742] = ACTIONS(1),
    [anon_sym_cp12502] = ACTIONS(1),
    [anon_sym_cp12512] = ACTIONS(1),
    [anon_sym_cp12532] = ACTIONS(1),
    [anon_sym_cp12542] = ACTIONS(1),
    [anon_sym_cp12552] = ACTIONS(1),
    [anon_sym_cp12562] = ACTIONS(1),
    [anon_sym_cp12572] = ACTIONS(1),
    [anon_sym_cp12582] = ACTIONS(1),
    [anon_sym_cp9322] = ACTIONS(1),
    [anon_sym_sjis2] = ACTIONS(1),
    [anon_sym_cp9492] = ACTIONS(1),
    [anon_sym_cp9362] = ACTIONS(1),
    [anon_sym_cp9502] = ACTIONS(1),
    [anon_sym_big52] = ACTIONS(1),
    [anon_sym_ansi2] = ACTIONS(1),
    [anon_sym_japan2] = ACTIONS(1),
    [anon_sym_korea2] = ACTIONS(1),
    [anon_sym_prc2] = ACTIONS(1),
    [anon_sym_chinese2] = ACTIONS(1),
    [anon_sym_taiwan2] = ACTIONS(1),
    [anon_sym_utf82] = ACTIONS(1),
    [anon_sym_unicode2] = ACTIONS(1),
    [anon_sym_ucs2be2] = ACTIONS(1),
    [anon_sym_default2] = ACTIONS(1),
    [aux_sym_wincmd_statement_token1] = ACTIONS(1),
    [anon_sym_on] = ACTIONS(1),
    [anon_sym_off] = ACTIONS(1),
    [anon_sym_detect] = ACTIONS(1),
    [anon_sym_plugin] = ACTIONS(1),
    [anon_sym_indent] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_trim] = ACTIONS(1),
    [anon_sym_LF] = ACTIONS(1),
    [aux_sym__bang_filter_command_argument_token1] = ACTIONS(1),
    [anon_sym_BSLASH] = ACTIONS(1),
    [aux_sym__bang_filter_command_argument_token3] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_LBRACE2] = ACTIONS(1),
    [anon_sym_eval] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_vi] = ACTIONS(1),
    [anon_sym_vim] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_EQ2] = ACTIONS(1),
    [anon_sym_COLON2] = ACTIONS(1),
    [anon_sym_dict] = ACTIONS(1),
    [anon_sym_range] = ACTIONS(1),
    [anon_sym_abort] = ACTIONS(1),
    [anon_sym_closure] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_SLASH2] = ACTIONS(1),
    [anon_sym_QMARK2] = ACTIONS(1),
    [anon_sym_DOT2] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_LT2] = ACTIONS(1),
    [anon_sym_BSLASH2] = ACTIONS(1),
    [anon_sym_BSLASH_PIPE] = ACTIONS(1),
    [aux_sym__map_rhs_token1] = ACTIONS(1),
    [anon_sym_define] = ACTIONS(1),
    [anon_sym_undefine] = ACTIONS(1),
    [anon_sym_list] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_place] = ACTIONS(1),
    [anon_sym_STAR2] = ACTIONS(1),
    [anon_sym_unplace] = ACTIONS(1),
    [anon_sym_jump] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_GT2] = ACTIONS(1),
    [anon_sym_BANG2] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_LPAREN2] = ACTIONS(1),
    [aux_sym_filename_token1] = ACTIONS(1),
    [aux_sym_filename_token2] = ACTIONS(1),
    [aux_sym_filename_token3] = ACTIONS(1),
    [aux_sym_filename_token4] = ACTIONS(1),
    [aux_sym_filename_token5] = ACTIONS(1),
    [aux_sym_filename_token6] = ACTIONS(1),
    [aux_sym_filename_token7] = ACTIONS(1),
    [aux_sym_filename_token8] = ACTIONS(1),
    [anon_sym_keep] = ACTIONS(1),
    [anon_sym_drop] = ACTIONS(1),
    [anon_sym_ff] = ACTIONS(1),
    [anon_sym_fileformat] = ACTIONS(1),
    [anon_sym_enc] = ACTIONS(1),
    [anon_sym_encoding] = ACTIONS(1),
    [anon_sym_bin] = ACTIONS(1),
    [anon_sym_binary] = ACTIONS(1),
    [anon_sym_nobin] = ACTIONS(1),
    [anon_sym_nobinary] = ACTIONS(1),
    [anon_sym_bad] = ACTIONS(1),
    [anon_sym_edit] = ACTIONS(1),
    [anon_sym_arglist] = ACTIONS(1),
    [anon_sym_augroup] = ACTIONS(1),
    [anon_sym_buffer2] = ACTIONS(1),
    [anon_sym_behave] = ACTIONS(1),
    [anon_sym_color] = ACTIONS(1),
    [anon_sym_command] = ACTIONS(1),
    [anon_sym_compiler] = ACTIONS(1),
    [anon_sym_dir] = ACTIONS(1),
    [anon_sym_environment] = ACTIONS(1),
    [anon_sym_even] = ACTIONS(1),
    [anon_sym_expression] = ACTIONS(1),
    [anon_sym_file2] = ACTIONS(1),
    [anon_sym_file_in_path] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_help] = ACTIONS(1),
    [anon_sym_highlight] = ACTIONS(1),
    [anon_sym_history] = ACTIONS(1),
    [anon_sym_local] = ACTIONS(1),
    [anon_sym_lua] = ACTIONS(1),
    [anon_sym_mapclear] = ACTIONS(1),
    [anon_sym_mapping] = ACTIONS(1),
    [anon_sym_menu] = ACTIONS(1),
    [anon_sym_messages] = ACTIONS(1),
    [anon_sym_option] = ACTIONS(1),
    [anon_sym_packadd] = ACTIONS(1),
    [anon_sym_shellcmd] = ACTIONS(1),
    [anon_sym_sign] = ACTIONS(1),
    [anon_sym_syntime] = ACTIONS(1),
    [anon_sym_tag] = ACTIONS(1),
    [anon_sym_tag_listfiles] = ACTIONS(1),
    [anon_sym_var] = ACTIONS(1),
    [anon_sym_custom] = ACTIONS(1),
    [anon_sym_COMMA2] = ACTIONS(1),
    [anon_sym_customlist] = ACTIONS(1),
    [anon_sym_lines] = ACTIONS(1),
    [anon_sym_arguments] = ACTIONS(1),
    [anon_sym_buffers] = ACTIONS(1),
    [anon_sym_loaded_buffers] = ACTIONS(1),
    [anon_sym_windows] = ACTIONS(1),
    [anon_sym_tabs] = ACTIONS(1),
    [anon_sym_quickfix] = ACTIONS(1),
    [anon_sym_other] = ACTIONS(1),
    [aux_sym__command_attribute_nargs_value_token1] = ACTIONS(1),
    [aux_sym__command_attribute_nargs_value_token2] = ACTIONS(1),
    [anon_sym_PERCENT2] = ACTIONS(1),
    [anon_sym_bold] = ACTIONS(1),
    [anon_sym_underline] = ACTIONS(1),
    [anon_sym_undercurl] = ACTIONS(1),
    [anon_sym_underdouble] = ACTIONS(1),
    [anon_sym_underdotted] = ACTIONS(1),
    [anon_sym_underdashed] = ACTIONS(1),
    [anon_sym_strikethrough] = ACTIONS(1),
    [anon_sym_reverse] = ACTIONS(1),
    [anon_sym_inverse] = ACTIONS(1),
    [anon_sym_italic] = ACTIONS(1),
    [anon_sym_standout] = ACTIONS(1),
    [anon_sym_nocombine] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE2] = ACTIONS(1),
    [anon_sym_bg] = ACTIONS(1),
    [anon_sym_background] = ACTIONS(1),
    [anon_sym_fg] = ACTIONS(1),
    [anon_sym_foreground] = ACTIONS(1),
    [anon_sym_enable] = ACTIONS(1),
    [anon_sym_reset] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_match] = ACTIONS(1),
    [anon_sym_ignore] = ACTIONS(1),
    [anon_sym_spell] = ACTIONS(1),
    [anon_sym_toplevel] = ACTIONS(1),
    [anon_sym_notoplevel] = ACTIONS(1),
    [anon_sym_foldlevel] = ACTIONS(1),
    [anon_sym_minimum] = ACTIONS(1),
    [anon_sym_iskeyword] = ACTIONS(1),
    [anon_sym_ms] = ACTIONS(1),
    [anon_sym_me] = ACTIONS(1),
    [anon_sym_hs] = ACTIONS(1),
    [anon_sym_he] = ACTIONS(1),
    [anon_sym_rs] = ACTIONS(1),
    [anon_sym_re] = ACTIONS(1),
    [anon_sym_lc] = ACTIONS(1),
    [aux_sym__syn_pattern_offset_token2] = ACTIONS(1),
    [anon_sym_keyword] = ACTIONS(1),
    [anon_sym_region] = ACTIONS(1),
    [anon_sym_cluster] = ACTIONS(1),
    [anon_sym_include] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_sync] = ACTIONS(1),
    [anon_sym_linebreaks] = ACTIONS(1),
    [anon_sym_fromstart] = ACTIONS(1),
    [anon_sym_ccomment] = ACTIONS(1),
    [anon_sym_linecont] = ACTIONS(1),
    [sym__no] = ACTIONS(1),
    [sym__inv] = ACTIONS(1),
    [sym__newline_or_pipe] = ACTIONS(1),
    [sym__line_continuation] = ACTIONS(3),
    [sym__script_heredoc_marker] = ACTIONS(1),
    [sym__let_heredoc_marker] = ACTIONS(1),
    [sym__heredoc_end] = ACTIONS(1),
    [sym__separator_first] = ACTIONS(1),
    [sym__separator] = ACTIONS(1),
    [sym__scope_dict] = ACTIONS(1),
    [sym_scope] = ACTIONS(1),
    [sym_string_literal] = ACTIONS(1),
    [sym_comment] = ACTIONS(1),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__bang_filter] = ACTIONS(1),
    [sym__function] = ACTIONS(1),
    [sym__endfunction] = ACTIONS(1),
    [sym__for] = ACTIONS(1),
    [sym__endfor] = ACTIONS(1),
    [sym__while] = ACTIONS(1),
    [sym__endwhile] = ACTIONS(1),
    [sym__if] = ACTIONS(1),
    [sym__elseif] = ACTIONS(1),
    [sym__else] = ACTIONS(1),
    [sym__endif] = ACTIONS(1),
    [sym__try] = ACTIONS(1),
    [sym__catch] = ACTIONS(1),
    [sym__cnext] = ACTIONS(1),
    [sym__cprevious] = ACTIONS(1),
    [sym__cNext] = ACTIONS(1),
    [sym__finally] = ACTIONS(1),
    [sym__endtry] = ACTIONS(1),
    [sym__const] = ACTIONS(1),
    [sym__normal] = ACTIONS(1),
    [sym__return] = ACTIONS(1),
    [sym__perl] = ACTIONS(1),
    [sym__lua] = ACTIONS(1),
    [sym__ruby] = ACTIONS(1),
    [sym__python] = ACTIONS(1),
    [sym__throw] = ACTIONS(1),
    [sym__execute] = ACTIONS(1),
    [sym__autocmd] = ACTIONS(1),
    [sym__silent] = ACTIONS(1),
    [sym__echo] = ACTIONS(1),
    [sym__echon] = ACTIONS(1),
    [sym__echohl] = ACTIONS(1),
    [sym__echomsg] = ACTIONS(1),
    [sym__echoerr] = ACTIONS(1),
    [sym__map] = ACTIONS(1),
    [sym__nmap] = ACTIONS(1),
    [sym__vmap] = ACTIONS(1),
    [sym__xmap] = ACTIONS(1),
    [sym__smap] = ACTIONS(1),
    [sym__omap] = ACTIONS(1),
    [sym__imap] = ACTIONS(1),
    [sym__lmap] = ACTIONS(1),
    [sym__cmap] = ACTIONS(1),
    [sym__tmap] = ACTIONS(1),
    [sym__noremap] = ACTIONS(1),
    [sym__nnoremap] = ACTIONS(1),
    [sym__vnoremap] = ACTIONS(1),
    [sym__xnoremap] = ACTIONS(1),
    [sym__snoremap] = ACTIONS(1),
    [sym__onoremap] = ACTIONS(1),
    [sym__inoremap] = ACTIONS(1),
    [sym__lnoremap] = ACTIONS(1),
    [sym__cnoremap] = ACTIONS(1),
    [sym__tnoremap] = ACTIONS(1),
    [sym__augroup] = ACTIONS(1),
    [sym__highlight] = ACTIONS(1),
    [sym__default] = ACTIONS(1),
    [sym__syntax] = ACTIONS(1),
    [sym__set] = ACTIONS(1),
    [sym__setlocal] = ACTIONS(1),
    [sym__setfiletype] = ACTIONS(1),
    [sym__browse] = ACTIONS(1),
    [sym__options] = ACTIONS(1),
    [sym__startinsert] = ACTIONS(1),
    [sym__stopinsert] = ACTIONS(1),
    [sym__scriptencoding] = ACTIONS(1),
    [sym__source] = ACTIONS(1),
    [sym__global] = ACTIONS(1),
    [sym__colorscheme] = ACTIONS(1),
    [sym__command] = ACTIONS(1),
    [sym__comclear] = ACTIONS(1),
    [sym__delcommand] = ACTIONS(1),
    [sym__runtime] = ACTIONS(1),
    [sym__wincmd] = ACTIONS(1),
    [sym__sign] = ACTIONS(1),
    [sym__filetype] = ACTIONS(1),
    [sym__let] = ACTIONS(1),
    [sym__unlet] = ACTIONS(1),
    [sym__call] = ACTIONS(1),
    [sym__break] = ACTIONS(1),
    [sym__continue] = ACTIONS(1),
    [sym__tab] = ACTIONS(1),
    [sym__vertical] = ACTIONS(1),
    [sym__leftabove] = ACTIONS(1),
    [sym__aboveleft] = ACTIONS(1),
    [sym__rightbelow] = ACTIONS(1),
    [sym__belowright] = ACTIONS(1),
    [sym__topleft] = ACTIONS(1),
    [sym__botright] = ACTIONS(1),
    [sym__edit] = ACTIONS(1),
    [sym__enew] = ACTIONS(1),
    [sym__find] = ACTIONS(1),
    [sym__ex] = ACTIONS(1),
    [sym__visual] = ACTIONS(1),
    [sym__view] = ACTIONS(1),
    [sym__eval] = ACTIONS(1),
    [sym__substitute] = ACTIONS(1),
    [sym_unknown_command_name] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_script_file] = STATE(3128),
    [sym__cmd_separator] = STATE(118),
    [aux_sym__separated_statements] = STATE(33),
    [sym__statement] = STATE(2554),
    [sym_unknown_builtin_statement] = STATE(2554),
    [sym_return_statement] = STATE(2554),
    [sym_break_statement] = STATE(2554),
    [sym_continue_statement] = STATE(2554),
    [sym_normal_statement] = STATE(2554),
    [sym_setfiletype_statement] = STATE(2554),
    [sym_options_statement] = STATE(2554),
    [sym_startinsert_statement] = STATE(2554),
    [sym_stopinsert_statement] = STATE(2554),
    [sym_scriptencoding_statement] = STATE(2554),
    [sym_cnext_statement] = STATE(2554),
    [sym_cprevious_statement] = STATE(2554),
    [sym_runtime_statement] = STATE(2554),
    [sym_wincmd_statement] = STATE(2554),
    [sym_source_statement] = STATE(2554),
    [sym_global_statement] = STATE(2554),
    [sym_filetype_statement] = STATE(2554),
    [sym_colorscheme_statement] = STATE(2554),
    [sym_lua_statement] = STATE(2554),
    [sym_ruby_statement] = STATE(2554),
    [sym_python_statement] = STATE(2554),
    [sym_perl_statement] = STATE(2554),
    [sym_for_loop] = STATE(2554),
    [sym_while_loop] = STATE(2554),
    [sym_if_statement] = STATE(2554),
    [sym_try_statement] = STATE(2554),
    [sym_throw_statement] = STATE(2554),
    [sym_bang_filter_statement] = STATE(2554),
    [sym_let_statement] = STATE(2554),
    [sym_const_statement] = STATE(2554),
    [sym_set_statement] = STATE(2554),
    [sym_setlocal_statement] = STATE(2554),
    [sym_unlet_statement] = STATE(2554),
    [sym_call_statement] = STATE(2554),
    [sym_echo_statement] = STATE(2554),
    [sym_echon_statement] = STATE(2554),
    [sym_echohl_statement] = STATE(2554),
    [sym_echomsg_statement] = STATE(2554),
    [sym_echoerr_statement] = STATE(2554),
    [sym_execute_statement] = STATE(2554),
    [sym_silent_statement] = STATE(2554),
    [sym_tab_statement] = STATE(2554),
    [sym_vertical_statement] = STATE(2554),
    [sym_topleft_statement] = STATE(2554),
    [sym_botright_statement] = STATE(2554),
    [sym_aboveleft_statement] = STATE(2554),
    [sym_belowright_statement] = STATE(2554),
    [sym_user_command] = STATE(2554),
    [sym_shebang] = STATE(2554),
    [sym_function_definition] = STATE(2554),
    [sym_range_statement] = STATE(2554),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2554),
    [sym_map_statement] = STATE(2554),
    [sym_sign_statement] = STATE(2554),
    [sym_eval_statement] = STATE(2554),
    [sym_substitute_statement] = STATE(2554),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2554),
    [sym_augroup_statement] = STATE(2554),
    [sym_command_statement] = STATE(2554),
    [sym_comclear_statement] = STATE(2554),
    [sym_delcommand_statement] = STATE(2554),
    [sym_highlight_statement] = STATE(2554),
    [sym_syntax_statement] = STATE(2554),
    [sym_edit_statement] = STATE(2554),
    [sym_enew_statement] = STATE(2554),
    [sym_find_statement] = STATE(2554),
    [sym_ex_statement] = STATE(2554),
    [sym_visual_statement] = STATE(2554),
    [sym_view_statement] = STATE(2554),
    [aux_sym__statement_repeat1] = STATE(94),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(35),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(35),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(2)] = {
    [sym__cmd_separator] = STATE(106),
    [aux_sym__separated_statements] = STATE(4),
    [sym__statement] = STATE(2560),
    [sym_unknown_builtin_statement] = STATE(2560),
    [sym_return_statement] = STATE(2560),
    [sym_break_statement] = STATE(2560),
    [sym_continue_statement] = STATE(2560),
    [sym_normal_statement] = STATE(2560),
    [sym_setfiletype_statement] = STATE(2560),
    [sym_options_statement] = STATE(2560),
    [sym_startinsert_statement] = STATE(2560),
    [sym_stopinsert_statement] = STATE(2560),
    [sym_scriptencoding_statement] = STATE(2560),
    [sym_cnext_statement] = STATE(2560),
    [sym_cprevious_statement] = STATE(2560),
    [sym_runtime_statement] = STATE(2560),
    [sym_wincmd_statement] = STATE(2560),
    [sym_source_statement] = STATE(2560),
    [sym_global_statement] = STATE(2560),
    [sym_filetype_statement] = STATE(2560),
    [sym_colorscheme_statement] = STATE(2560),
    [sym_lua_statement] = STATE(2560),
    [sym_ruby_statement] = STATE(2560),
    [sym_python_statement] = STATE(2560),
    [sym_perl_statement] = STATE(2560),
    [sym_for_loop] = STATE(2560),
    [sym_while_loop] = STATE(2560),
    [sym_if_statement] = STATE(2560),
    [sym_try_statement] = STATE(2560),
    [sym_catch_statement] = STATE(1992),
    [sym_finally_statement] = STATE(3319),
    [sym_throw_statement] = STATE(2560),
    [sym_bang_filter_statement] = STATE(2560),
    [sym_let_statement] = STATE(2560),
    [sym_const_statement] = STATE(2560),
    [sym_set_statement] = STATE(2560),
    [sym_setlocal_statement] = STATE(2560),
    [sym_unlet_statement] = STATE(2560),
    [sym_call_statement] = STATE(2560),
    [sym_echo_statement] = STATE(2560),
    [sym_echon_statement] = STATE(2560),
    [sym_echohl_statement] = STATE(2560),
    [sym_echomsg_statement] = STATE(2560),
    [sym_echoerr_statement] = STATE(2560),
    [sym_execute_statement] = STATE(2560),
    [sym_silent_statement] = STATE(2560),
    [sym_tab_statement] = STATE(2560),
    [sym_vertical_statement] = STATE(2560),
    [sym_topleft_statement] = STATE(2560),
    [sym_botright_statement] = STATE(2560),
    [sym_aboveleft_statement] = STATE(2560),
    [sym_belowright_statement] = STATE(2560),
    [sym_user_command] = STATE(2560),
    [sym_shebang] = STATE(2560),
    [sym_function_definition] = STATE(2560),
    [sym_range_statement] = STATE(2560),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2560),
    [sym_map_statement] = STATE(2560),
    [sym_sign_statement] = STATE(2560),
    [sym_eval_statement] = STATE(2560),
    [sym_substitute_statement] = STATE(2560),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2560),
    [sym_augroup_statement] = STATE(2560),
    [sym_command_statement] = STATE(2560),
    [sym_comclear_statement] = STATE(2560),
    [sym_delcommand_statement] = STATE(2560),
    [sym_highlight_statement] = STATE(2560),
    [sym_syntax_statement] = STATE(2560),
    [sym_edit_statement] = STATE(2560),
    [sym_enew_statement] = STATE(2560),
    [sym_find_statement] = STATE(2560),
    [sym_ex_statement] = STATE(2560),
    [sym_visual_statement] = STATE(2560),
    [sym_view_statement] = STATE(2560),
    [aux_sym__statement_repeat1] = STATE(94),
    [aux_sym_try_statement_repeat1] = STATE(1992),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(165),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(165),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__catch] = ACTIONS(167),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__finally] = ACTIONS(169),
    [sym__endtry] = ACTIONS(171),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(3)] = {
    [sym__cmd_separator] = STATE(105),
    [aux_sym__separated_statements] = STATE(15),
    [sym__statement] = STATE(2531),
    [sym_unknown_builtin_statement] = STATE(2531),
    [sym_return_statement] = STATE(2531),
    [sym_break_statement] = STATE(2531),
    [sym_continue_statement] = STATE(2531),
    [sym_normal_statement] = STATE(2531),
    [sym_setfiletype_statement] = STATE(2531),
    [sym_options_statement] = STATE(2531),
    [sym_startinsert_statement] = STATE(2531),
    [sym_stopinsert_statement] = STATE(2531),
    [sym_scriptencoding_statement] = STATE(2531),
    [sym_cnext_statement] = STATE(2531),
    [sym_cprevious_statement] = STATE(2531),
    [sym_runtime_statement] = STATE(2531),
    [sym_wincmd_statement] = STATE(2531),
    [sym_source_statement] = STATE(2531),
    [sym_global_statement] = STATE(2531),
    [sym_filetype_statement] = STATE(2531),
    [sym_colorscheme_statement] = STATE(2531),
    [sym_lua_statement] = STATE(2531),
    [sym_ruby_statement] = STATE(2531),
    [sym_python_statement] = STATE(2531),
    [sym_perl_statement] = STATE(2531),
    [sym_for_loop] = STATE(2531),
    [sym_while_loop] = STATE(2531),
    [sym_if_statement] = STATE(2531),
    [sym_elseif_statement] = STATE(2120),
    [sym_else_statement] = STATE(3318),
    [sym_try_statement] = STATE(2531),
    [sym_throw_statement] = STATE(2531),
    [sym_bang_filter_statement] = STATE(2531),
    [sym_let_statement] = STATE(2531),
    [sym_const_statement] = STATE(2531),
    [sym_set_statement] = STATE(2531),
    [sym_setlocal_statement] = STATE(2531),
    [sym_unlet_statement] = STATE(2531),
    [sym_call_statement] = STATE(2531),
    [sym_echo_statement] = STATE(2531),
    [sym_echon_statement] = STATE(2531),
    [sym_echohl_statement] = STATE(2531),
    [sym_echomsg_statement] = STATE(2531),
    [sym_echoerr_statement] = STATE(2531),
    [sym_execute_statement] = STATE(2531),
    [sym_silent_statement] = STATE(2531),
    [sym_tab_statement] = STATE(2531),
    [sym_vertical_statement] = STATE(2531),
    [sym_topleft_statement] = STATE(2531),
    [sym_botright_statement] = STATE(2531),
    [sym_aboveleft_statement] = STATE(2531),
    [sym_belowright_statement] = STATE(2531),
    [sym_user_command] = STATE(2531),
    [sym_shebang] = STATE(2531),
    [sym_function_definition] = STATE(2531),
    [sym_range_statement] = STATE(2531),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2531),
    [sym_map_statement] = STATE(2531),
    [sym_sign_statement] = STATE(2531),
    [sym_eval_statement] = STATE(2531),
    [sym_substitute_statement] = STATE(2531),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2531),
    [sym_augroup_statement] = STATE(2531),
    [sym_command_statement] = STATE(2531),
    [sym_comclear_statement] = STATE(2531),
    [sym_delcommand_statement] = STATE(2531),
    [sym_highlight_statement] = STATE(2531),
    [sym_syntax_statement] = STATE(2531),
    [sym_edit_statement] = STATE(2531),
    [sym_enew_statement] = STATE(2531),
    [sym_find_statement] = STATE(2531),
    [sym_ex_statement] = STATE(2531),
    [sym_visual_statement] = STATE(2531),
    [sym_view_statement] = STATE(2531),
    [aux_sym__statement_repeat1] = STATE(94),
    [aux_sym_if_statement_repeat1] = STATE(2120),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(173),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(173),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__elseif] = ACTIONS(175),
    [sym__else] = ACTIONS(177),
    [sym__endif] = ACTIONS(179),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(4)] = {
    [sym__cmd_separator] = STATE(106),
    [aux_sym__separated_statements] = STATE(17),
    [sym__statement] = STATE(2560),
    [sym_unknown_builtin_statement] = STATE(2560),
    [sym_return_statement] = STATE(2560),
    [sym_break_statement] = STATE(2560),
    [sym_continue_statement] = STATE(2560),
    [sym_normal_statement] = STATE(2560),
    [sym_setfiletype_statement] = STATE(2560),
    [sym_options_statement] = STATE(2560),
    [sym_startinsert_statement] = STATE(2560),
    [sym_stopinsert_statement] = STATE(2560),
    [sym_scriptencoding_statement] = STATE(2560),
    [sym_cnext_statement] = STATE(2560),
    [sym_cprevious_statement] = STATE(2560),
    [sym_runtime_statement] = STATE(2560),
    [sym_wincmd_statement] = STATE(2560),
    [sym_source_statement] = STATE(2560),
    [sym_global_statement] = STATE(2560),
    [sym_filetype_statement] = STATE(2560),
    [sym_colorscheme_statement] = STATE(2560),
    [sym_lua_statement] = STATE(2560),
    [sym_ruby_statement] = STATE(2560),
    [sym_python_statement] = STATE(2560),
    [sym_perl_statement] = STATE(2560),
    [sym_for_loop] = STATE(2560),
    [sym_while_loop] = STATE(2560),
    [sym_if_statement] = STATE(2560),
    [sym_try_statement] = STATE(2560),
    [sym_catch_statement] = STATE(2021),
    [sym_finally_statement] = STATE(3035),
    [sym_throw_statement] = STATE(2560),
    [sym_bang_filter_statement] = STATE(2560),
    [sym_let_statement] = STATE(2560),
    [sym_const_statement] = STATE(2560),
    [sym_set_statement] = STATE(2560),
    [sym_setlocal_statement] = STATE(2560),
    [sym_unlet_statement] = STATE(2560),
    [sym_call_statement] = STATE(2560),
    [sym_echo_statement] = STATE(2560),
    [sym_echon_statement] = STATE(2560),
    [sym_echohl_statement] = STATE(2560),
    [sym_echomsg_statement] = STATE(2560),
    [sym_echoerr_statement] = STATE(2560),
    [sym_execute_statement] = STATE(2560),
    [sym_silent_statement] = STATE(2560),
    [sym_tab_statement] = STATE(2560),
    [sym_vertical_statement] = STATE(2560),
    [sym_topleft_statement] = STATE(2560),
    [sym_botright_statement] = STATE(2560),
    [sym_aboveleft_statement] = STATE(2560),
    [sym_belowright_statement] = STATE(2560),
    [sym_user_command] = STATE(2560),
    [sym_shebang] = STATE(2560),
    [sym_function_definition] = STATE(2560),
    [sym_range_statement] = STATE(2560),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2560),
    [sym_map_statement] = STATE(2560),
    [sym_sign_statement] = STATE(2560),
    [sym_eval_statement] = STATE(2560),
    [sym_substitute_statement] = STATE(2560),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2560),
    [sym_augroup_statement] = STATE(2560),
    [sym_command_statement] = STATE(2560),
    [sym_comclear_statement] = STATE(2560),
    [sym_delcommand_statement] = STATE(2560),
    [sym_highlight_statement] = STATE(2560),
    [sym_syntax_statement] = STATE(2560),
    [sym_edit_statement] = STATE(2560),
    [sym_enew_statement] = STATE(2560),
    [sym_find_statement] = STATE(2560),
    [sym_ex_statement] = STATE(2560),
    [sym_visual_statement] = STATE(2560),
    [sym_view_statement] = STATE(2560),
    [aux_sym__statement_repeat1] = STATE(94),
    [aux_sym_try_statement_repeat1] = STATE(2021),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(165),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(165),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__catch] = ACTIONS(167),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__finally] = ACTIONS(169),
    [sym__endtry] = ACTIONS(181),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(5)] = {
    [sym__cmd_separator] = STATE(105),
    [aux_sym__separated_statements] = STATE(6),
    [sym__statement] = STATE(2531),
    [sym_unknown_builtin_statement] = STATE(2531),
    [sym_return_statement] = STATE(2531),
    [sym_break_statement] = STATE(2531),
    [sym_continue_statement] = STATE(2531),
    [sym_normal_statement] = STATE(2531),
    [sym_setfiletype_statement] = STATE(2531),
    [sym_options_statement] = STATE(2531),
    [sym_startinsert_statement] = STATE(2531),
    [sym_stopinsert_statement] = STATE(2531),
    [sym_scriptencoding_statement] = STATE(2531),
    [sym_cnext_statement] = STATE(2531),
    [sym_cprevious_statement] = STATE(2531),
    [sym_runtime_statement] = STATE(2531),
    [sym_wincmd_statement] = STATE(2531),
    [sym_source_statement] = STATE(2531),
    [sym_global_statement] = STATE(2531),
    [sym_filetype_statement] = STATE(2531),
    [sym_colorscheme_statement] = STATE(2531),
    [sym_lua_statement] = STATE(2531),
    [sym_ruby_statement] = STATE(2531),
    [sym_python_statement] = STATE(2531),
    [sym_perl_statement] = STATE(2531),
    [sym_for_loop] = STATE(2531),
    [sym_while_loop] = STATE(2531),
    [sym_if_statement] = STATE(2531),
    [sym_elseif_statement] = STATE(2020),
    [sym_else_statement] = STATE(3329),
    [sym_try_statement] = STATE(2531),
    [sym_throw_statement] = STATE(2531),
    [sym_bang_filter_statement] = STATE(2531),
    [sym_let_statement] = STATE(2531),
    [sym_const_statement] = STATE(2531),
    [sym_set_statement] = STATE(2531),
    [sym_setlocal_statement] = STATE(2531),
    [sym_unlet_statement] = STATE(2531),
    [sym_call_statement] = STATE(2531),
    [sym_echo_statement] = STATE(2531),
    [sym_echon_statement] = STATE(2531),
    [sym_echohl_statement] = STATE(2531),
    [sym_echomsg_statement] = STATE(2531),
    [sym_echoerr_statement] = STATE(2531),
    [sym_execute_statement] = STATE(2531),
    [sym_silent_statement] = STATE(2531),
    [sym_tab_statement] = STATE(2531),
    [sym_vertical_statement] = STATE(2531),
    [sym_topleft_statement] = STATE(2531),
    [sym_botright_statement] = STATE(2531),
    [sym_aboveleft_statement] = STATE(2531),
    [sym_belowright_statement] = STATE(2531),
    [sym_user_command] = STATE(2531),
    [sym_shebang] = STATE(2531),
    [sym_function_definition] = STATE(2531),
    [sym_range_statement] = STATE(2531),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2531),
    [sym_map_statement] = STATE(2531),
    [sym_sign_statement] = STATE(2531),
    [sym_eval_statement] = STATE(2531),
    [sym_substitute_statement] = STATE(2531),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2531),
    [sym_augroup_statement] = STATE(2531),
    [sym_command_statement] = STATE(2531),
    [sym_comclear_statement] = STATE(2531),
    [sym_delcommand_statement] = STATE(2531),
    [sym_highlight_statement] = STATE(2531),
    [sym_syntax_statement] = STATE(2531),
    [sym_edit_statement] = STATE(2531),
    [sym_enew_statement] = STATE(2531),
    [sym_find_statement] = STATE(2531),
    [sym_ex_statement] = STATE(2531),
    [sym_visual_statement] = STATE(2531),
    [sym_view_statement] = STATE(2531),
    [aux_sym__statement_repeat1] = STATE(94),
    [aux_sym_if_statement_repeat1] = STATE(2020),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(173),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(173),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__elseif] = ACTIONS(175),
    [sym__else] = ACTIONS(177),
    [sym__endif] = ACTIONS(183),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(6)] = {
    [sym__cmd_separator] = STATE(105),
    [aux_sym__separated_statements] = STATE(15),
    [sym__statement] = STATE(2531),
    [sym_unknown_builtin_statement] = STATE(2531),
    [sym_return_statement] = STATE(2531),
    [sym_break_statement] = STATE(2531),
    [sym_continue_statement] = STATE(2531),
    [sym_normal_statement] = STATE(2531),
    [sym_setfiletype_statement] = STATE(2531),
    [sym_options_statement] = STATE(2531),
    [sym_startinsert_statement] = STATE(2531),
    [sym_stopinsert_statement] = STATE(2531),
    [sym_scriptencoding_statement] = STATE(2531),
    [sym_cnext_statement] = STATE(2531),
    [sym_cprevious_statement] = STATE(2531),
    [sym_runtime_statement] = STATE(2531),
    [sym_wincmd_statement] = STATE(2531),
    [sym_source_statement] = STATE(2531),
    [sym_global_statement] = STATE(2531),
    [sym_filetype_statement] = STATE(2531),
    [sym_colorscheme_statement] = STATE(2531),
    [sym_lua_statement] = STATE(2531),
    [sym_ruby_statement] = STATE(2531),
    [sym_python_statement] = STATE(2531),
    [sym_perl_statement] = STATE(2531),
    [sym_for_loop] = STATE(2531),
    [sym_while_loop] = STATE(2531),
    [sym_if_statement] = STATE(2531),
    [sym_elseif_statement] = STATE(2083),
    [sym_else_statement] = STATE(3012),
    [sym_try_statement] = STATE(2531),
    [sym_throw_statement] = STATE(2531),
    [sym_bang_filter_statement] = STATE(2531),
    [sym_let_statement] = STATE(2531),
    [sym_const_statement] = STATE(2531),
    [sym_set_statement] = STATE(2531),
    [sym_setlocal_statement] = STATE(2531),
    [sym_unlet_statement] = STATE(2531),
    [sym_call_statement] = STATE(2531),
    [sym_echo_statement] = STATE(2531),
    [sym_echon_statement] = STATE(2531),
    [sym_echohl_statement] = STATE(2531),
    [sym_echomsg_statement] = STATE(2531),
    [sym_echoerr_statement] = STATE(2531),
    [sym_execute_statement] = STATE(2531),
    [sym_silent_statement] = STATE(2531),
    [sym_tab_statement] = STATE(2531),
    [sym_vertical_statement] = STATE(2531),
    [sym_topleft_statement] = STATE(2531),
    [sym_botright_statement] = STATE(2531),
    [sym_aboveleft_statement] = STATE(2531),
    [sym_belowright_statement] = STATE(2531),
    [sym_user_command] = STATE(2531),
    [sym_shebang] = STATE(2531),
    [sym_function_definition] = STATE(2531),
    [sym_range_statement] = STATE(2531),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2531),
    [sym_map_statement] = STATE(2531),
    [sym_sign_statement] = STATE(2531),
    [sym_eval_statement] = STATE(2531),
    [sym_substitute_statement] = STATE(2531),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2531),
    [sym_augroup_statement] = STATE(2531),
    [sym_command_statement] = STATE(2531),
    [sym_comclear_statement] = STATE(2531),
    [sym_delcommand_statement] = STATE(2531),
    [sym_highlight_statement] = STATE(2531),
    [sym_syntax_statement] = STATE(2531),
    [sym_edit_statement] = STATE(2531),
    [sym_enew_statement] = STATE(2531),
    [sym_find_statement] = STATE(2531),
    [sym_ex_statement] = STATE(2531),
    [sym_visual_statement] = STATE(2531),
    [sym_view_statement] = STATE(2531),
    [aux_sym__statement_repeat1] = STATE(94),
    [aux_sym_if_statement_repeat1] = STATE(2083),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(173),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(173),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__elseif] = ACTIONS(175),
    [sym__else] = ACTIONS(177),
    [sym__endif] = ACTIONS(185),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(7)] = {
    [sym__cmd_separator] = STATE(105),
    [aux_sym__separated_statements] = STATE(3),
    [sym__statement] = STATE(2531),
    [sym_unknown_builtin_statement] = STATE(2531),
    [sym_return_statement] = STATE(2531),
    [sym_break_statement] = STATE(2531),
    [sym_continue_statement] = STATE(2531),
    [sym_normal_statement] = STATE(2531),
    [sym_setfiletype_statement] = STATE(2531),
    [sym_options_statement] = STATE(2531),
    [sym_startinsert_statement] = STATE(2531),
    [sym_stopinsert_statement] = STATE(2531),
    [sym_scriptencoding_statement] = STATE(2531),
    [sym_cnext_statement] = STATE(2531),
    [sym_cprevious_statement] = STATE(2531),
    [sym_runtime_statement] = STATE(2531),
    [sym_wincmd_statement] = STATE(2531),
    [sym_source_statement] = STATE(2531),
    [sym_global_statement] = STATE(2531),
    [sym_filetype_statement] = STATE(2531),
    [sym_colorscheme_statement] = STATE(2531),
    [sym_lua_statement] = STATE(2531),
    [sym_ruby_statement] = STATE(2531),
    [sym_python_statement] = STATE(2531),
    [sym_perl_statement] = STATE(2531),
    [sym_for_loop] = STATE(2531),
    [sym_while_loop] = STATE(2531),
    [sym_if_statement] = STATE(2531),
    [sym_elseif_statement] = STATE(2050),
    [sym_else_statement] = STATE(3328),
    [sym_try_statement] = STATE(2531),
    [sym_throw_statement] = STATE(2531),
    [sym_bang_filter_statement] = STATE(2531),
    [sym_let_statement] = STATE(2531),
    [sym_const_statement] = STATE(2531),
    [sym_set_statement] = STATE(2531),
    [sym_setlocal_statement] = STATE(2531),
    [sym_unlet_statement] = STATE(2531),
    [sym_call_statement] = STATE(2531),
    [sym_echo_statement] = STATE(2531),
    [sym_echon_statement] = STATE(2531),
    [sym_echohl_statement] = STATE(2531),
    [sym_echomsg_statement] = STATE(2531),
    [sym_echoerr_statement] = STATE(2531),
    [sym_execute_statement] = STATE(2531),
    [sym_silent_statement] = STATE(2531),
    [sym_tab_statement] = STATE(2531),
    [sym_vertical_statement] = STATE(2531),
    [sym_topleft_statement] = STATE(2531),
    [sym_botright_statement] = STATE(2531),
    [sym_aboveleft_statement] = STATE(2531),
    [sym_belowright_statement] = STATE(2531),
    [sym_user_command] = STATE(2531),
    [sym_shebang] = STATE(2531),
    [sym_function_definition] = STATE(2531),
    [sym_range_statement] = STATE(2531),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2531),
    [sym_map_statement] = STATE(2531),
    [sym_sign_statement] = STATE(2531),
    [sym_eval_statement] = STATE(2531),
    [sym_substitute_statement] = STATE(2531),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2531),
    [sym_augroup_statement] = STATE(2531),
    [sym_command_statement] = STATE(2531),
    [sym_comclear_statement] = STATE(2531),
    [sym_delcommand_statement] = STATE(2531),
    [sym_highlight_statement] = STATE(2531),
    [sym_syntax_statement] = STATE(2531),
    [sym_edit_statement] = STATE(2531),
    [sym_enew_statement] = STATE(2531),
    [sym_find_statement] = STATE(2531),
    [sym_ex_statement] = STATE(2531),
    [sym_visual_statement] = STATE(2531),
    [sym_view_statement] = STATE(2531),
    [aux_sym__statement_repeat1] = STATE(94),
    [aux_sym_if_statement_repeat1] = STATE(2050),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(173),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(173),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__elseif] = ACTIONS(175),
    [sym__else] = ACTIONS(177),
    [sym__endif] = ACTIONS(187),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(8)] = {
    [sym__cmd_separator] = STATE(106),
    [aux_sym__separated_statements] = STATE(9),
    [sym__statement] = STATE(2560),
    [sym_unknown_builtin_statement] = STATE(2560),
    [sym_return_statement] = STATE(2560),
    [sym_break_statement] = STATE(2560),
    [sym_continue_statement] = STATE(2560),
    [sym_normal_statement] = STATE(2560),
    [sym_setfiletype_statement] = STATE(2560),
    [sym_options_statement] = STATE(2560),
    [sym_startinsert_statement] = STATE(2560),
    [sym_stopinsert_statement] = STATE(2560),
    [sym_scriptencoding_statement] = STATE(2560),
    [sym_cnext_statement] = STATE(2560),
    [sym_cprevious_statement] = STATE(2560),
    [sym_runtime_statement] = STATE(2560),
    [sym_wincmd_statement] = STATE(2560),
    [sym_source_statement] = STATE(2560),
    [sym_global_statement] = STATE(2560),
    [sym_filetype_statement] = STATE(2560),
    [sym_colorscheme_statement] = STATE(2560),
    [sym_lua_statement] = STATE(2560),
    [sym_ruby_statement] = STATE(2560),
    [sym_python_statement] = STATE(2560),
    [sym_perl_statement] = STATE(2560),
    [sym_for_loop] = STATE(2560),
    [sym_while_loop] = STATE(2560),
    [sym_if_statement] = STATE(2560),
    [sym_try_statement] = STATE(2560),
    [sym_catch_statement] = STATE(2042),
    [sym_finally_statement] = STATE(3149),
    [sym_throw_statement] = STATE(2560),
    [sym_bang_filter_statement] = STATE(2560),
    [sym_let_statement] = STATE(2560),
    [sym_const_statement] = STATE(2560),
    [sym_set_statement] = STATE(2560),
    [sym_setlocal_statement] = STATE(2560),
    [sym_unlet_statement] = STATE(2560),
    [sym_call_statement] = STATE(2560),
    [sym_echo_statement] = STATE(2560),
    [sym_echon_statement] = STATE(2560),
    [sym_echohl_statement] = STATE(2560),
    [sym_echomsg_statement] = STATE(2560),
    [sym_echoerr_statement] = STATE(2560),
    [sym_execute_statement] = STATE(2560),
    [sym_silent_statement] = STATE(2560),
    [sym_tab_statement] = STATE(2560),
    [sym_vertical_statement] = STATE(2560),
    [sym_topleft_statement] = STATE(2560),
    [sym_botright_statement] = STATE(2560),
    [sym_aboveleft_statement] = STATE(2560),
    [sym_belowright_statement] = STATE(2560),
    [sym_user_command] = STATE(2560),
    [sym_shebang] = STATE(2560),
    [sym_function_definition] = STATE(2560),
    [sym_range_statement] = STATE(2560),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2560),
    [sym_map_statement] = STATE(2560),
    [sym_sign_statement] = STATE(2560),
    [sym_eval_statement] = STATE(2560),
    [sym_substitute_statement] = STATE(2560),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2560),
    [sym_augroup_statement] = STATE(2560),
    [sym_command_statement] = STATE(2560),
    [sym_comclear_statement] = STATE(2560),
    [sym_delcommand_statement] = STATE(2560),
    [sym_highlight_statement] = STATE(2560),
    [sym_syntax_statement] = STATE(2560),
    [sym_edit_statement] = STATE(2560),
    [sym_enew_statement] = STATE(2560),
    [sym_find_statement] = STATE(2560),
    [sym_ex_statement] = STATE(2560),
    [sym_visual_statement] = STATE(2560),
    [sym_view_statement] = STATE(2560),
    [aux_sym__statement_repeat1] = STATE(94),
    [aux_sym_try_statement_repeat1] = STATE(2042),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(165),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(165),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__catch] = ACTIONS(167),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__finally] = ACTIONS(169),
    [sym__endtry] = ACTIONS(189),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(9)] = {
    [sym__cmd_separator] = STATE(106),
    [aux_sym__separated_statements] = STATE(17),
    [sym__statement] = STATE(2560),
    [sym_unknown_builtin_statement] = STATE(2560),
    [sym_return_statement] = STATE(2560),
    [sym_break_statement] = STATE(2560),
    [sym_continue_statement] = STATE(2560),
    [sym_normal_statement] = STATE(2560),
    [sym_setfiletype_statement] = STATE(2560),
    [sym_options_statement] = STATE(2560),
    [sym_startinsert_statement] = STATE(2560),
    [sym_stopinsert_statement] = STATE(2560),
    [sym_scriptencoding_statement] = STATE(2560),
    [sym_cnext_statement] = STATE(2560),
    [sym_cprevious_statement] = STATE(2560),
    [sym_runtime_statement] = STATE(2560),
    [sym_wincmd_statement] = STATE(2560),
    [sym_source_statement] = STATE(2560),
    [sym_global_statement] = STATE(2560),
    [sym_filetype_statement] = STATE(2560),
    [sym_colorscheme_statement] = STATE(2560),
    [sym_lua_statement] = STATE(2560),
    [sym_ruby_statement] = STATE(2560),
    [sym_python_statement] = STATE(2560),
    [sym_perl_statement] = STATE(2560),
    [sym_for_loop] = STATE(2560),
    [sym_while_loop] = STATE(2560),
    [sym_if_statement] = STATE(2560),
    [sym_try_statement] = STATE(2560),
    [sym_catch_statement] = STATE(2051),
    [sym_finally_statement] = STATE(3334),
    [sym_throw_statement] = STATE(2560),
    [sym_bang_filter_statement] = STATE(2560),
    [sym_let_statement] = STATE(2560),
    [sym_const_statement] = STATE(2560),
    [sym_set_statement] = STATE(2560),
    [sym_setlocal_statement] = STATE(2560),
    [sym_unlet_statement] = STATE(2560),
    [sym_call_statement] = STATE(2560),
    [sym_echo_statement] = STATE(2560),
    [sym_echon_statement] = STATE(2560),
    [sym_echohl_statement] = STATE(2560),
    [sym_echomsg_statement] = STATE(2560),
    [sym_echoerr_statement] = STATE(2560),
    [sym_execute_statement] = STATE(2560),
    [sym_silent_statement] = STATE(2560),
    [sym_tab_statement] = STATE(2560),
    [sym_vertical_statement] = STATE(2560),
    [sym_topleft_statement] = STATE(2560),
    [sym_botright_statement] = STATE(2560),
    [sym_aboveleft_statement] = STATE(2560),
    [sym_belowright_statement] = STATE(2560),
    [sym_user_command] = STATE(2560),
    [sym_shebang] = STATE(2560),
    [sym_function_definition] = STATE(2560),
    [sym_range_statement] = STATE(2560),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2560),
    [sym_map_statement] = STATE(2560),
    [sym_sign_statement] = STATE(2560),
    [sym_eval_statement] = STATE(2560),
    [sym_substitute_statement] = STATE(2560),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2560),
    [sym_augroup_statement] = STATE(2560),
    [sym_command_statement] = STATE(2560),
    [sym_comclear_statement] = STATE(2560),
    [sym_delcommand_statement] = STATE(2560),
    [sym_highlight_statement] = STATE(2560),
    [sym_syntax_statement] = STATE(2560),
    [sym_edit_statement] = STATE(2560),
    [sym_enew_statement] = STATE(2560),
    [sym_find_statement] = STATE(2560),
    [sym_ex_statement] = STATE(2560),
    [sym_visual_statement] = STATE(2560),
    [sym_view_statement] = STATE(2560),
    [aux_sym__statement_repeat1] = STATE(94),
    [aux_sym_try_statement_repeat1] = STATE(2051),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(165),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(165),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__catch] = ACTIONS(167),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__finally] = ACTIONS(169),
    [sym__endtry] = ACTIONS(191),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(10)] = {
    [sym__cmd_separator] = STATE(106),
    [aux_sym__separated_statements] = STATE(11),
    [sym__statement] = STATE(2560),
    [sym_unknown_builtin_statement] = STATE(2560),
    [sym_return_statement] = STATE(2560),
    [sym_break_statement] = STATE(2560),
    [sym_continue_statement] = STATE(2560),
    [sym_normal_statement] = STATE(2560),
    [sym_setfiletype_statement] = STATE(2560),
    [sym_options_statement] = STATE(2560),
    [sym_startinsert_statement] = STATE(2560),
    [sym_stopinsert_statement] = STATE(2560),
    [sym_scriptencoding_statement] = STATE(2560),
    [sym_cnext_statement] = STATE(2560),
    [sym_cprevious_statement] = STATE(2560),
    [sym_runtime_statement] = STATE(2560),
    [sym_wincmd_statement] = STATE(2560),
    [sym_source_statement] = STATE(2560),
    [sym_global_statement] = STATE(2560),
    [sym_filetype_statement] = STATE(2560),
    [sym_colorscheme_statement] = STATE(2560),
    [sym_lua_statement] = STATE(2560),
    [sym_ruby_statement] = STATE(2560),
    [sym_python_statement] = STATE(2560),
    [sym_perl_statement] = STATE(2560),
    [sym_for_loop] = STATE(2560),
    [sym_while_loop] = STATE(2560),
    [sym_if_statement] = STATE(2560),
    [sym_try_statement] = STATE(2560),
    [sym_throw_statement] = STATE(2560),
    [sym_bang_filter_statement] = STATE(2560),
    [sym_let_statement] = STATE(2560),
    [sym_const_statement] = STATE(2560),
    [sym_set_statement] = STATE(2560),
    [sym_setlocal_statement] = STATE(2560),
    [sym_unlet_statement] = STATE(2560),
    [sym_call_statement] = STATE(2560),
    [sym_echo_statement] = STATE(2560),
    [sym_echon_statement] = STATE(2560),
    [sym_echohl_statement] = STATE(2560),
    [sym_echomsg_statement] = STATE(2560),
    [sym_echoerr_statement] = STATE(2560),
    [sym_execute_statement] = STATE(2560),
    [sym_silent_statement] = STATE(2560),
    [sym_tab_statement] = STATE(2560),
    [sym_vertical_statement] = STATE(2560),
    [sym_topleft_statement] = STATE(2560),
    [sym_botright_statement] = STATE(2560),
    [sym_aboveleft_statement] = STATE(2560),
    [sym_belowright_statement] = STATE(2560),
    [sym_user_command] = STATE(2560),
    [sym_shebang] = STATE(2560),
    [sym_function_definition] = STATE(2560),
    [sym_range_statement] = STATE(2560),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2560),
    [sym_map_statement] = STATE(2560),
    [sym_sign_statement] = STATE(2560),
    [sym_eval_statement] = STATE(2560),
    [sym_substitute_statement] = STATE(2560),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2560),
    [sym_augroup_statement] = STATE(2560),
    [sym_command_statement] = STATE(2560),
    [sym_comclear_statement] = STATE(2560),
    [sym_delcommand_statement] = STATE(2560),
    [sym_highlight_statement] = STATE(2560),
    [sym_syntax_statement] = STATE(2560),
    [sym_edit_statement] = STATE(2560),
    [sym_enew_statement] = STATE(2560),
    [sym_find_statement] = STATE(2560),
    [sym_ex_statement] = STATE(2560),
    [sym_visual_statement] = STATE(2560),
    [sym_view_statement] = STATE(2560),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(165),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(165),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__catch] = ACTIONS(193),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__finally] = ACTIONS(193),
    [sym__endtry] = ACTIONS(193),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(11)] = {
    [sym__cmd_separator] = STATE(106),
    [aux_sym__separated_statements] = STATE(17),
    [sym__statement] = STATE(2560),
    [sym_unknown_builtin_statement] = STATE(2560),
    [sym_return_statement] = STATE(2560),
    [sym_break_statement] = STATE(2560),
    [sym_continue_statement] = STATE(2560),
    [sym_normal_statement] = STATE(2560),
    [sym_setfiletype_statement] = STATE(2560),
    [sym_options_statement] = STATE(2560),
    [sym_startinsert_statement] = STATE(2560),
    [sym_stopinsert_statement] = STATE(2560),
    [sym_scriptencoding_statement] = STATE(2560),
    [sym_cnext_statement] = STATE(2560),
    [sym_cprevious_statement] = STATE(2560),
    [sym_runtime_statement] = STATE(2560),
    [sym_wincmd_statement] = STATE(2560),
    [sym_source_statement] = STATE(2560),
    [sym_global_statement] = STATE(2560),
    [sym_filetype_statement] = STATE(2560),
    [sym_colorscheme_statement] = STATE(2560),
    [sym_lua_statement] = STATE(2560),
    [sym_ruby_statement] = STATE(2560),
    [sym_python_statement] = STATE(2560),
    [sym_perl_statement] = STATE(2560),
    [sym_for_loop] = STATE(2560),
    [sym_while_loop] = STATE(2560),
    [sym_if_statement] = STATE(2560),
    [sym_try_statement] = STATE(2560),
    [sym_throw_statement] = STATE(2560),
    [sym_bang_filter_statement] = STATE(2560),
    [sym_let_statement] = STATE(2560),
    [sym_const_statement] = STATE(2560),
    [sym_set_statement] = STATE(2560),
    [sym_setlocal_statement] = STATE(2560),
    [sym_unlet_statement] = STATE(2560),
    [sym_call_statement] = STATE(2560),
    [sym_echo_statement] = STATE(2560),
    [sym_echon_statement] = STATE(2560),
    [sym_echohl_statement] = STATE(2560),
    [sym_echomsg_statement] = STATE(2560),
    [sym_echoerr_statement] = STATE(2560),
    [sym_execute_statement] = STATE(2560),
    [sym_silent_statement] = STATE(2560),
    [sym_tab_statement] = STATE(2560),
    [sym_vertical_statement] = STATE(2560),
    [sym_topleft_statement] = STATE(2560),
    [sym_botright_statement] = STATE(2560),
    [sym_aboveleft_statement] = STATE(2560),
    [sym_belowright_statement] = STATE(2560),
    [sym_user_command] = STATE(2560),
    [sym_shebang] = STATE(2560),
    [sym_function_definition] = STATE(2560),
    [sym_range_statement] = STATE(2560),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2560),
    [sym_map_statement] = STATE(2560),
    [sym_sign_statement] = STATE(2560),
    [sym_eval_statement] = STATE(2560),
    [sym_substitute_statement] = STATE(2560),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2560),
    [sym_augroup_statement] = STATE(2560),
    [sym_command_statement] = STATE(2560),
    [sym_comclear_statement] = STATE(2560),
    [sym_delcommand_statement] = STATE(2560),
    [sym_highlight_statement] = STATE(2560),
    [sym_syntax_statement] = STATE(2560),
    [sym_edit_statement] = STATE(2560),
    [sym_enew_statement] = STATE(2560),
    [sym_find_statement] = STATE(2560),
    [sym_ex_statement] = STATE(2560),
    [sym_visual_statement] = STATE(2560),
    [sym_view_statement] = STATE(2560),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(165),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(165),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__catch] = ACTIONS(195),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__finally] = ACTIONS(195),
    [sym__endtry] = ACTIONS(195),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(12)] = {
    [sym__cmd_separator] = STATE(106),
    [aux_sym__separated_statements] = STATE(16),
    [sym__statement] = STATE(2560),
    [sym_unknown_builtin_statement] = STATE(2560),
    [sym_return_statement] = STATE(2560),
    [sym_break_statement] = STATE(2560),
    [sym_continue_statement] = STATE(2560),
    [sym_normal_statement] = STATE(2560),
    [sym_setfiletype_statement] = STATE(2560),
    [sym_options_statement] = STATE(2560),
    [sym_startinsert_statement] = STATE(2560),
    [sym_stopinsert_statement] = STATE(2560),
    [sym_scriptencoding_statement] = STATE(2560),
    [sym_cnext_statement] = STATE(2560),
    [sym_cprevious_statement] = STATE(2560),
    [sym_runtime_statement] = STATE(2560),
    [sym_wincmd_statement] = STATE(2560),
    [sym_source_statement] = STATE(2560),
    [sym_global_statement] = STATE(2560),
    [sym_filetype_statement] = STATE(2560),
    [sym_colorscheme_statement] = STATE(2560),
    [sym_lua_statement] = STATE(2560),
    [sym_ruby_statement] = STATE(2560),
    [sym_python_statement] = STATE(2560),
    [sym_perl_statement] = STATE(2560),
    [sym_for_loop] = STATE(2560),
    [sym_while_loop] = STATE(2560),
    [sym_if_statement] = STATE(2560),
    [sym_try_statement] = STATE(2560),
    [sym_throw_statement] = STATE(2560),
    [sym_bang_filter_statement] = STATE(2560),
    [sym_let_statement] = STATE(2560),
    [sym_const_statement] = STATE(2560),
    [sym_set_statement] = STATE(2560),
    [sym_setlocal_statement] = STATE(2560),
    [sym_unlet_statement] = STATE(2560),
    [sym_call_statement] = STATE(2560),
    [sym_echo_statement] = STATE(2560),
    [sym_echon_statement] = STATE(2560),
    [sym_echohl_statement] = STATE(2560),
    [sym_echomsg_statement] = STATE(2560),
    [sym_echoerr_statement] = STATE(2560),
    [sym_execute_statement] = STATE(2560),
    [sym_silent_statement] = STATE(2560),
    [sym_tab_statement] = STATE(2560),
    [sym_vertical_statement] = STATE(2560),
    [sym_topleft_statement] = STATE(2560),
    [sym_botright_statement] = STATE(2560),
    [sym_aboveleft_statement] = STATE(2560),
    [sym_belowright_statement] = STATE(2560),
    [sym_user_command] = STATE(2560),
    [sym_shebang] = STATE(2560),
    [sym_function_definition] = STATE(2560),
    [sym_range_statement] = STATE(2560),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2560),
    [sym_map_statement] = STATE(2560),
    [sym_sign_statement] = STATE(2560),
    [sym_eval_statement] = STATE(2560),
    [sym_substitute_statement] = STATE(2560),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2560),
    [sym_augroup_statement] = STATE(2560),
    [sym_command_statement] = STATE(2560),
    [sym_comclear_statement] = STATE(2560),
    [sym_delcommand_statement] = STATE(2560),
    [sym_highlight_statement] = STATE(2560),
    [sym_syntax_statement] = STATE(2560),
    [sym_edit_statement] = STATE(2560),
    [sym_enew_statement] = STATE(2560),
    [sym_find_statement] = STATE(2560),
    [sym_ex_statement] = STATE(2560),
    [sym_visual_statement] = STATE(2560),
    [sym_view_statement] = STATE(2560),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(165),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(165),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__catch] = ACTIONS(197),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__finally] = ACTIONS(197),
    [sym__endtry] = ACTIONS(197),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(13)] = {
    [sym__cmd_separator] = STATE(105),
    [aux_sym__separated_statements] = STATE(14),
    [sym__statement] = STATE(2531),
    [sym_unknown_builtin_statement] = STATE(2531),
    [sym_return_statement] = STATE(2531),
    [sym_break_statement] = STATE(2531),
    [sym_continue_statement] = STATE(2531),
    [sym_normal_statement] = STATE(2531),
    [sym_setfiletype_statement] = STATE(2531),
    [sym_options_statement] = STATE(2531),
    [sym_startinsert_statement] = STATE(2531),
    [sym_stopinsert_statement] = STATE(2531),
    [sym_scriptencoding_statement] = STATE(2531),
    [sym_cnext_statement] = STATE(2531),
    [sym_cprevious_statement] = STATE(2531),
    [sym_runtime_statement] = STATE(2531),
    [sym_wincmd_statement] = STATE(2531),
    [sym_source_statement] = STATE(2531),
    [sym_global_statement] = STATE(2531),
    [sym_filetype_statement] = STATE(2531),
    [sym_colorscheme_statement] = STATE(2531),
    [sym_lua_statement] = STATE(2531),
    [sym_ruby_statement] = STATE(2531),
    [sym_python_statement] = STATE(2531),
    [sym_perl_statement] = STATE(2531),
    [sym_for_loop] = STATE(2531),
    [sym_while_loop] = STATE(2531),
    [sym_if_statement] = STATE(2531),
    [sym_try_statement] = STATE(2531),
    [sym_throw_statement] = STATE(2531),
    [sym_bang_filter_statement] = STATE(2531),
    [sym_let_statement] = STATE(2531),
    [sym_const_statement] = STATE(2531),
    [sym_set_statement] = STATE(2531),
    [sym_setlocal_statement] = STATE(2531),
    [sym_unlet_statement] = STATE(2531),
    [sym_call_statement] = STATE(2531),
    [sym_echo_statement] = STATE(2531),
    [sym_echon_statement] = STATE(2531),
    [sym_echohl_statement] = STATE(2531),
    [sym_echomsg_statement] = STATE(2531),
    [sym_echoerr_statement] = STATE(2531),
    [sym_execute_statement] = STATE(2531),
    [sym_silent_statement] = STATE(2531),
    [sym_tab_statement] = STATE(2531),
    [sym_vertical_statement] = STATE(2531),
    [sym_topleft_statement] = STATE(2531),
    [sym_botright_statement] = STATE(2531),
    [sym_aboveleft_statement] = STATE(2531),
    [sym_belowright_statement] = STATE(2531),
    [sym_user_command] = STATE(2531),
    [sym_shebang] = STATE(2531),
    [sym_function_definition] = STATE(2531),
    [sym_range_statement] = STATE(2531),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2531),
    [sym_map_statement] = STATE(2531),
    [sym_sign_statement] = STATE(2531),
    [sym_eval_statement] = STATE(2531),
    [sym_substitute_statement] = STATE(2531),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2531),
    [sym_augroup_statement] = STATE(2531),
    [sym_command_statement] = STATE(2531),
    [sym_comclear_statement] = STATE(2531),
    [sym_delcommand_statement] = STATE(2531),
    [sym_highlight_statement] = STATE(2531),
    [sym_syntax_statement] = STATE(2531),
    [sym_edit_statement] = STATE(2531),
    [sym_enew_statement] = STATE(2531),
    [sym_find_statement] = STATE(2531),
    [sym_ex_statement] = STATE(2531),
    [sym_visual_statement] = STATE(2531),
    [sym_view_statement] = STATE(2531),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(173),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(173),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__elseif] = ACTIONS(199),
    [sym__else] = ACTIONS(199),
    [sym__endif] = ACTIONS(199),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(14)] = {
    [sym__cmd_separator] = STATE(105),
    [aux_sym__separated_statements] = STATE(15),
    [sym__statement] = STATE(2531),
    [sym_unknown_builtin_statement] = STATE(2531),
    [sym_return_statement] = STATE(2531),
    [sym_break_statement] = STATE(2531),
    [sym_continue_statement] = STATE(2531),
    [sym_normal_statement] = STATE(2531),
    [sym_setfiletype_statement] = STATE(2531),
    [sym_options_statement] = STATE(2531),
    [sym_startinsert_statement] = STATE(2531),
    [sym_stopinsert_statement] = STATE(2531),
    [sym_scriptencoding_statement] = STATE(2531),
    [sym_cnext_statement] = STATE(2531),
    [sym_cprevious_statement] = STATE(2531),
    [sym_runtime_statement] = STATE(2531),
    [sym_wincmd_statement] = STATE(2531),
    [sym_source_statement] = STATE(2531),
    [sym_global_statement] = STATE(2531),
    [sym_filetype_statement] = STATE(2531),
    [sym_colorscheme_statement] = STATE(2531),
    [sym_lua_statement] = STATE(2531),
    [sym_ruby_statement] = STATE(2531),
    [sym_python_statement] = STATE(2531),
    [sym_perl_statement] = STATE(2531),
    [sym_for_loop] = STATE(2531),
    [sym_while_loop] = STATE(2531),
    [sym_if_statement] = STATE(2531),
    [sym_try_statement] = STATE(2531),
    [sym_throw_statement] = STATE(2531),
    [sym_bang_filter_statement] = STATE(2531),
    [sym_let_statement] = STATE(2531),
    [sym_const_statement] = STATE(2531),
    [sym_set_statement] = STATE(2531),
    [sym_setlocal_statement] = STATE(2531),
    [sym_unlet_statement] = STATE(2531),
    [sym_call_statement] = STATE(2531),
    [sym_echo_statement] = STATE(2531),
    [sym_echon_statement] = STATE(2531),
    [sym_echohl_statement] = STATE(2531),
    [sym_echomsg_statement] = STATE(2531),
    [sym_echoerr_statement] = STATE(2531),
    [sym_execute_statement] = STATE(2531),
    [sym_silent_statement] = STATE(2531),
    [sym_tab_statement] = STATE(2531),
    [sym_vertical_statement] = STATE(2531),
    [sym_topleft_statement] = STATE(2531),
    [sym_botright_statement] = STATE(2531),
    [sym_aboveleft_statement] = STATE(2531),
    [sym_belowright_statement] = STATE(2531),
    [sym_user_command] = STATE(2531),
    [sym_shebang] = STATE(2531),
    [sym_function_definition] = STATE(2531),
    [sym_range_statement] = STATE(2531),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2531),
    [sym_map_statement] = STATE(2531),
    [sym_sign_statement] = STATE(2531),
    [sym_eval_statement] = STATE(2531),
    [sym_substitute_statement] = STATE(2531),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2531),
    [sym_augroup_statement] = STATE(2531),
    [sym_command_statement] = STATE(2531),
    [sym_comclear_statement] = STATE(2531),
    [sym_delcommand_statement] = STATE(2531),
    [sym_highlight_statement] = STATE(2531),
    [sym_syntax_statement] = STATE(2531),
    [sym_edit_statement] = STATE(2531),
    [sym_enew_statement] = STATE(2531),
    [sym_find_statement] = STATE(2531),
    [sym_ex_statement] = STATE(2531),
    [sym_visual_statement] = STATE(2531),
    [sym_view_statement] = STATE(2531),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(173),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(173),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__elseif] = ACTIONS(201),
    [sym__else] = ACTIONS(201),
    [sym__endif] = ACTIONS(201),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(15)] = {
    [sym__cmd_separator] = STATE(105),
    [aux_sym__separated_statements] = STATE(15),
    [sym__statement] = STATE(2531),
    [sym_unknown_builtin_statement] = STATE(2531),
    [sym_return_statement] = STATE(2531),
    [sym_break_statement] = STATE(2531),
    [sym_continue_statement] = STATE(2531),
    [sym_normal_statement] = STATE(2531),
    [sym_setfiletype_statement] = STATE(2531),
    [sym_options_statement] = STATE(2531),
    [sym_startinsert_statement] = STATE(2531),
    [sym_stopinsert_statement] = STATE(2531),
    [sym_scriptencoding_statement] = STATE(2531),
    [sym_cnext_statement] = STATE(2531),
    [sym_cprevious_statement] = STATE(2531),
    [sym_runtime_statement] = STATE(2531),
    [sym_wincmd_statement] = STATE(2531),
    [sym_source_statement] = STATE(2531),
    [sym_global_statement] = STATE(2531),
    [sym_filetype_statement] = STATE(2531),
    [sym_colorscheme_statement] = STATE(2531),
    [sym_lua_statement] = STATE(2531),
    [sym_ruby_statement] = STATE(2531),
    [sym_python_statement] = STATE(2531),
    [sym_perl_statement] = STATE(2531),
    [sym_for_loop] = STATE(2531),
    [sym_while_loop] = STATE(2531),
    [sym_if_statement] = STATE(2531),
    [sym_try_statement] = STATE(2531),
    [sym_throw_statement] = STATE(2531),
    [sym_bang_filter_statement] = STATE(2531),
    [sym_let_statement] = STATE(2531),
    [sym_const_statement] = STATE(2531),
    [sym_set_statement] = STATE(2531),
    [sym_setlocal_statement] = STATE(2531),
    [sym_unlet_statement] = STATE(2531),
    [sym_call_statement] = STATE(2531),
    [sym_echo_statement] = STATE(2531),
    [sym_echon_statement] = STATE(2531),
    [sym_echohl_statement] = STATE(2531),
    [sym_echomsg_statement] = STATE(2531),
    [sym_echoerr_statement] = STATE(2531),
    [sym_execute_statement] = STATE(2531),
    [sym_silent_statement] = STATE(2531),
    [sym_tab_statement] = STATE(2531),
    [sym_vertical_statement] = STATE(2531),
    [sym_topleft_statement] = STATE(2531),
    [sym_botright_statement] = STATE(2531),
    [sym_aboveleft_statement] = STATE(2531),
    [sym_belowright_statement] = STATE(2531),
    [sym_user_command] = STATE(2531),
    [sym_shebang] = STATE(2531),
    [sym_function_definition] = STATE(2531),
    [sym_range_statement] = STATE(2531),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2531),
    [sym_map_statement] = STATE(2531),
    [sym_sign_statement] = STATE(2531),
    [sym_eval_statement] = STATE(2531),
    [sym_substitute_statement] = STATE(2531),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2531),
    [sym_augroup_statement] = STATE(2531),
    [sym_command_statement] = STATE(2531),
    [sym_comclear_statement] = STATE(2531),
    [sym_delcommand_statement] = STATE(2531),
    [sym_highlight_statement] = STATE(2531),
    [sym_syntax_statement] = STATE(2531),
    [sym_edit_statement] = STATE(2531),
    [sym_enew_statement] = STATE(2531),
    [sym_find_statement] = STATE(2531),
    [sym_ex_statement] = STATE(2531),
    [sym_visual_statement] = STATE(2531),
    [sym_view_statement] = STATE(2531),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(203),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_QMARK] = ACTIONS(209),
    [anon_sym_POUND_BANG] = ACTIONS(212),
    [sym_mark] = ACTIONS(215),
    [anon_sym_PERCENT] = ACTIONS(218),
    [anon_sym_SLASH] = ACTIONS(221),
    [anon_sym_DOT2] = ACTIONS(224),
    [anon_sym_PLUS] = ACTIONS(227),
    [anon_sym_DOLLAR] = ACTIONS(230),
    [anon_sym_BSLASH_SLASH] = ACTIONS(233),
    [anon_sym_BSLASH_QMARK] = ACTIONS(233),
    [anon_sym_BSLASH_AMP] = ACTIONS(233),
    [sym_integer_literal] = ACTIONS(236),
    [sym_register] = ACTIONS(239),
    [sym_command_name] = ACTIONS(242),
    [sym__newline_or_pipe] = ACTIONS(245),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(245),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(248),
    [sym__for] = ACTIONS(251),
    [sym__while] = ACTIONS(254),
    [sym__if] = ACTIONS(257),
    [sym__elseif] = ACTIONS(260),
    [sym__else] = ACTIONS(260),
    [sym__endif] = ACTIONS(260),
    [sym__try] = ACTIONS(262),
    [sym__cnext] = ACTIONS(265),
    [sym__cprevious] = ACTIONS(268),
    [sym__cNext] = ACTIONS(268),
    [sym__const] = ACTIONS(271),
    [sym__normal] = ACTIONS(274),
    [sym__return] = ACTIONS(277),
    [sym__perl] = ACTIONS(280),
    [sym__lua] = ACTIONS(206),
    [sym__ruby] = ACTIONS(283),
    [sym__python] = ACTIONS(286),
    [sym__throw] = ACTIONS(289),
    [sym__execute] = ACTIONS(292),
    [sym__autocmd] = ACTIONS(295),
    [sym__silent] = ACTIONS(298),
    [sym__echo] = ACTIONS(301),
    [sym__echon] = ACTIONS(304),
    [sym__echohl] = ACTIONS(307),
    [sym__echomsg] = ACTIONS(310),
    [sym__echoerr] = ACTIONS(313),
    [sym__map] = ACTIONS(316),
    [sym__nmap] = ACTIONS(316),
    [sym__vmap] = ACTIONS(316),
    [sym__xmap] = ACTIONS(316),
    [sym__smap] = ACTIONS(316),
    [sym__omap] = ACTIONS(316),
    [sym__imap] = ACTIONS(316),
    [sym__lmap] = ACTIONS(316),
    [sym__cmap] = ACTIONS(316),
    [sym__tmap] = ACTIONS(316),
    [sym__noremap] = ACTIONS(316),
    [sym__nnoremap] = ACTIONS(316),
    [sym__vnoremap] = ACTIONS(316),
    [sym__xnoremap] = ACTIONS(316),
    [sym__snoremap] = ACTIONS(316),
    [sym__onoremap] = ACTIONS(316),
    [sym__inoremap] = ACTIONS(316),
    [sym__lnoremap] = ACTIONS(316),
    [sym__cnoremap] = ACTIONS(316),
    [sym__tnoremap] = ACTIONS(316),
    [sym__augroup] = ACTIONS(319),
    [sym__highlight] = ACTIONS(322),
    [sym__syntax] = ACTIONS(325),
    [sym__set] = ACTIONS(328),
    [sym__setlocal] = ACTIONS(331),
    [sym__setfiletype] = ACTIONS(334),
    [sym__browse] = ACTIONS(337),
    [sym__options] = ACTIONS(340),
    [sym__startinsert] = ACTIONS(343),
    [sym__stopinsert] = ACTIONS(346),
    [sym__scriptencoding] = ACTIONS(349),
    [sym__source] = ACTIONS(352),
    [sym__global] = ACTIONS(355),
    [sym__colorscheme] = ACTIONS(358),
    [sym__command] = ACTIONS(361),
    [sym__comclear] = ACTIONS(364),
    [sym__delcommand] = ACTIONS(367),
    [sym__runtime] = ACTIONS(370),
    [sym__wincmd] = ACTIONS(373),
    [sym__sign] = ACTIONS(376),
    [sym__filetype] = ACTIONS(379),
    [sym__let] = ACTIONS(382),
    [sym__unlet] = ACTIONS(385),
    [sym__call] = ACTIONS(388),
    [sym__break] = ACTIONS(391),
    [sym__continue] = ACTIONS(394),
    [sym__tab] = ACTIONS(397),
    [sym__vertical] = ACTIONS(400),
    [sym__leftabove] = ACTIONS(403),
    [sym__aboveleft] = ACTIONS(403),
    [sym__rightbelow] = ACTIONS(406),
    [sym__belowright] = ACTIONS(406),
    [sym__topleft] = ACTIONS(409),
    [sym__botright] = ACTIONS(412),
    [sym__edit] = ACTIONS(415),
    [sym__enew] = ACTIONS(418),
    [sym__find] = ACTIONS(421),
    [sym__ex] = ACTIONS(424),
    [sym__visual] = ACTIONS(427),
    [sym__view] = ACTIONS(430),
    [sym__eval] = ACTIONS(433),
    [sym__substitute] = ACTIONS(436),
    [sym_unknown_command_name] = ACTIONS(439),
  },
  [STATE(16)] = {
    [sym__cmd_separator] = STATE(106),
    [aux_sym__separated_statements] = STATE(17),
    [sym__statement] = STATE(2560),
    [sym_unknown_builtin_statement] = STATE(2560),
    [sym_return_statement] = STATE(2560),
    [sym_break_statement] = STATE(2560),
    [sym_continue_statement] = STATE(2560),
    [sym_normal_statement] = STATE(2560),
    [sym_setfiletype_statement] = STATE(2560),
    [sym_options_statement] = STATE(2560),
    [sym_startinsert_statement] = STATE(2560),
    [sym_stopinsert_statement] = STATE(2560),
    [sym_scriptencoding_statement] = STATE(2560),
    [sym_cnext_statement] = STATE(2560),
    [sym_cprevious_statement] = STATE(2560),
    [sym_runtime_statement] = STATE(2560),
    [sym_wincmd_statement] = STATE(2560),
    [sym_source_statement] = STATE(2560),
    [sym_global_statement] = STATE(2560),
    [sym_filetype_statement] = STATE(2560),
    [sym_colorscheme_statement] = STATE(2560),
    [sym_lua_statement] = STATE(2560),
    [sym_ruby_statement] = STATE(2560),
    [sym_python_statement] = STATE(2560),
    [sym_perl_statement] = STATE(2560),
    [sym_for_loop] = STATE(2560),
    [sym_while_loop] = STATE(2560),
    [sym_if_statement] = STATE(2560),
    [sym_try_statement] = STATE(2560),
    [sym_throw_statement] = STATE(2560),
    [sym_bang_filter_statement] = STATE(2560),
    [sym_let_statement] = STATE(2560),
    [sym_const_statement] = STATE(2560),
    [sym_set_statement] = STATE(2560),
    [sym_setlocal_statement] = STATE(2560),
    [sym_unlet_statement] = STATE(2560),
    [sym_call_statement] = STATE(2560),
    [sym_echo_statement] = STATE(2560),
    [sym_echon_statement] = STATE(2560),
    [sym_echohl_statement] = STATE(2560),
    [sym_echomsg_statement] = STATE(2560),
    [sym_echoerr_statement] = STATE(2560),
    [sym_execute_statement] = STATE(2560),
    [sym_silent_statement] = STATE(2560),
    [sym_tab_statement] = STATE(2560),
    [sym_vertical_statement] = STATE(2560),
    [sym_topleft_statement] = STATE(2560),
    [sym_botright_statement] = STATE(2560),
    [sym_aboveleft_statement] = STATE(2560),
    [sym_belowright_statement] = STATE(2560),
    [sym_user_command] = STATE(2560),
    [sym_shebang] = STATE(2560),
    [sym_function_definition] = STATE(2560),
    [sym_range_statement] = STATE(2560),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2560),
    [sym_map_statement] = STATE(2560),
    [sym_sign_statement] = STATE(2560),
    [sym_eval_statement] = STATE(2560),
    [sym_substitute_statement] = STATE(2560),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2560),
    [sym_augroup_statement] = STATE(2560),
    [sym_command_statement] = STATE(2560),
    [sym_comclear_statement] = STATE(2560),
    [sym_delcommand_statement] = STATE(2560),
    [sym_highlight_statement] = STATE(2560),
    [sym_syntax_statement] = STATE(2560),
    [sym_edit_statement] = STATE(2560),
    [sym_enew_statement] = STATE(2560),
    [sym_find_statement] = STATE(2560),
    [sym_ex_statement] = STATE(2560),
    [sym_visual_statement] = STATE(2560),
    [sym_view_statement] = STATE(2560),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(165),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(165),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__catch] = ACTIONS(442),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__finally] = ACTIONS(442),
    [sym__endtry] = ACTIONS(442),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(17)] = {
    [sym__cmd_separator] = STATE(106),
    [aux_sym__separated_statements] = STATE(17),
    [sym__statement] = STATE(2560),
    [sym_unknown_builtin_statement] = STATE(2560),
    [sym_return_statement] = STATE(2560),
    [sym_break_statement] = STATE(2560),
    [sym_continue_statement] = STATE(2560),
    [sym_normal_statement] = STATE(2560),
    [sym_setfiletype_statement] = STATE(2560),
    [sym_options_statement] = STATE(2560),
    [sym_startinsert_statement] = STATE(2560),
    [sym_stopinsert_statement] = STATE(2560),
    [sym_scriptencoding_statement] = STATE(2560),
    [sym_cnext_statement] = STATE(2560),
    [sym_cprevious_statement] = STATE(2560),
    [sym_runtime_statement] = STATE(2560),
    [sym_wincmd_statement] = STATE(2560),
    [sym_source_statement] = STATE(2560),
    [sym_global_statement] = STATE(2560),
    [sym_filetype_statement] = STATE(2560),
    [sym_colorscheme_statement] = STATE(2560),
    [sym_lua_statement] = STATE(2560),
    [sym_ruby_statement] = STATE(2560),
    [sym_python_statement] = STATE(2560),
    [sym_perl_statement] = STATE(2560),
    [sym_for_loop] = STATE(2560),
    [sym_while_loop] = STATE(2560),
    [sym_if_statement] = STATE(2560),
    [sym_try_statement] = STATE(2560),
    [sym_throw_statement] = STATE(2560),
    [sym_bang_filter_statement] = STATE(2560),
    [sym_let_statement] = STATE(2560),
    [sym_const_statement] = STATE(2560),
    [sym_set_statement] = STATE(2560),
    [sym_setlocal_statement] = STATE(2560),
    [sym_unlet_statement] = STATE(2560),
    [sym_call_statement] = STATE(2560),
    [sym_echo_statement] = STATE(2560),
    [sym_echon_statement] = STATE(2560),
    [sym_echohl_statement] = STATE(2560),
    [sym_echomsg_statement] = STATE(2560),
    [sym_echoerr_statement] = STATE(2560),
    [sym_execute_statement] = STATE(2560),
    [sym_silent_statement] = STATE(2560),
    [sym_tab_statement] = STATE(2560),
    [sym_vertical_statement] = STATE(2560),
    [sym_topleft_statement] = STATE(2560),
    [sym_botright_statement] = STATE(2560),
    [sym_aboveleft_statement] = STATE(2560),
    [sym_belowright_statement] = STATE(2560),
    [sym_user_command] = STATE(2560),
    [sym_shebang] = STATE(2560),
    [sym_function_definition] = STATE(2560),
    [sym_range_statement] = STATE(2560),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2560),
    [sym_map_statement] = STATE(2560),
    [sym_sign_statement] = STATE(2560),
    [sym_eval_statement] = STATE(2560),
    [sym_substitute_statement] = STATE(2560),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2560),
    [sym_augroup_statement] = STATE(2560),
    [sym_command_statement] = STATE(2560),
    [sym_comclear_statement] = STATE(2560),
    [sym_delcommand_statement] = STATE(2560),
    [sym_highlight_statement] = STATE(2560),
    [sym_syntax_statement] = STATE(2560),
    [sym_edit_statement] = STATE(2560),
    [sym_enew_statement] = STATE(2560),
    [sym_find_statement] = STATE(2560),
    [sym_ex_statement] = STATE(2560),
    [sym_visual_statement] = STATE(2560),
    [sym_view_statement] = STATE(2560),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(203),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_QMARK] = ACTIONS(209),
    [anon_sym_POUND_BANG] = ACTIONS(212),
    [sym_mark] = ACTIONS(215),
    [anon_sym_PERCENT] = ACTIONS(218),
    [anon_sym_SLASH] = ACTIONS(221),
    [anon_sym_DOT2] = ACTIONS(224),
    [anon_sym_PLUS] = ACTIONS(227),
    [anon_sym_DOLLAR] = ACTIONS(230),
    [anon_sym_BSLASH_SLASH] = ACTIONS(233),
    [anon_sym_BSLASH_QMARK] = ACTIONS(233),
    [anon_sym_BSLASH_AMP] = ACTIONS(233),
    [sym_integer_literal] = ACTIONS(236),
    [sym_register] = ACTIONS(239),
    [sym_command_name] = ACTIONS(242),
    [sym__newline_or_pipe] = ACTIONS(444),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(444),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(248),
    [sym__for] = ACTIONS(251),
    [sym__while] = ACTIONS(254),
    [sym__if] = ACTIONS(257),
    [sym__try] = ACTIONS(262),
    [sym__catch] = ACTIONS(260),
    [sym__cnext] = ACTIONS(265),
    [sym__cprevious] = ACTIONS(268),
    [sym__cNext] = ACTIONS(268),
    [sym__finally] = ACTIONS(260),
    [sym__endtry] = ACTIONS(260),
    [sym__const] = ACTIONS(271),
    [sym__normal] = ACTIONS(274),
    [sym__return] = ACTIONS(277),
    [sym__perl] = ACTIONS(280),
    [sym__lua] = ACTIONS(206),
    [sym__ruby] = ACTIONS(283),
    [sym__python] = ACTIONS(286),
    [sym__throw] = ACTIONS(289),
    [sym__execute] = ACTIONS(292),
    [sym__autocmd] = ACTIONS(295),
    [sym__silent] = ACTIONS(298),
    [sym__echo] = ACTIONS(301),
    [sym__echon] = ACTIONS(304),
    [sym__echohl] = ACTIONS(307),
    [sym__echomsg] = ACTIONS(310),
    [sym__echoerr] = ACTIONS(313),
    [sym__map] = ACTIONS(316),
    [sym__nmap] = ACTIONS(316),
    [sym__vmap] = ACTIONS(316),
    [sym__xmap] = ACTIONS(316),
    [sym__smap] = ACTIONS(316),
    [sym__omap] = ACTIONS(316),
    [sym__imap] = ACTIONS(316),
    [sym__lmap] = ACTIONS(316),
    [sym__cmap] = ACTIONS(316),
    [sym__tmap] = ACTIONS(316),
    [sym__noremap] = ACTIONS(316),
    [sym__nnoremap] = ACTIONS(316),
    [sym__vnoremap] = ACTIONS(316),
    [sym__xnoremap] = ACTIONS(316),
    [sym__snoremap] = ACTIONS(316),
    [sym__onoremap] = ACTIONS(316),
    [sym__inoremap] = ACTIONS(316),
    [sym__lnoremap] = ACTIONS(316),
    [sym__cnoremap] = ACTIONS(316),
    [sym__tnoremap] = ACTIONS(316),
    [sym__augroup] = ACTIONS(319),
    [sym__highlight] = ACTIONS(322),
    [sym__syntax] = ACTIONS(325),
    [sym__set] = ACTIONS(328),
    [sym__setlocal] = ACTIONS(331),
    [sym__setfiletype] = ACTIONS(334),
    [sym__browse] = ACTIONS(337),
    [sym__options] = ACTIONS(340),
    [sym__startinsert] = ACTIONS(343),
    [sym__stopinsert] = ACTIONS(346),
    [sym__scriptencoding] = ACTIONS(349),
    [sym__source] = ACTIONS(352),
    [sym__global] = ACTIONS(355),
    [sym__colorscheme] = ACTIONS(358),
    [sym__command] = ACTIONS(361),
    [sym__comclear] = ACTIONS(364),
    [sym__delcommand] = ACTIONS(367),
    [sym__runtime] = ACTIONS(370),
    [sym__wincmd] = ACTIONS(373),
    [sym__sign] = ACTIONS(376),
    [sym__filetype] = ACTIONS(379),
    [sym__let] = ACTIONS(382),
    [sym__unlet] = ACTIONS(385),
    [sym__call] = ACTIONS(388),
    [sym__break] = ACTIONS(391),
    [sym__continue] = ACTIONS(394),
    [sym__tab] = ACTIONS(397),
    [sym__vertical] = ACTIONS(400),
    [sym__leftabove] = ACTIONS(403),
    [sym__aboveleft] = ACTIONS(403),
    [sym__rightbelow] = ACTIONS(406),
    [sym__belowright] = ACTIONS(406),
    [sym__topleft] = ACTIONS(409),
    [sym__botright] = ACTIONS(412),
    [sym__edit] = ACTIONS(415),
    [sym__enew] = ACTIONS(418),
    [sym__find] = ACTIONS(421),
    [sym__ex] = ACTIONS(424),
    [sym__visual] = ACTIONS(427),
    [sym__view] = ACTIONS(430),
    [sym__eval] = ACTIONS(433),
    [sym__substitute] = ACTIONS(436),
    [sym_unknown_command_name] = ACTIONS(439),
  },
  [STATE(18)] = {
    [sym__cmd_separator] = STATE(109),
    [aux_sym__separated_statements] = STATE(35),
    [sym__statement] = STATE(2372),
    [sym_unknown_builtin_statement] = STATE(2372),
    [sym_return_statement] = STATE(2372),
    [sym_break_statement] = STATE(2372),
    [sym_continue_statement] = STATE(2372),
    [sym_normal_statement] = STATE(2372),
    [sym_setfiletype_statement] = STATE(2372),
    [sym_options_statement] = STATE(2372),
    [sym_startinsert_statement] = STATE(2372),
    [sym_stopinsert_statement] = STATE(2372),
    [sym_scriptencoding_statement] = STATE(2372),
    [sym_cnext_statement] = STATE(2372),
    [sym_cprevious_statement] = STATE(2372),
    [sym_runtime_statement] = STATE(2372),
    [sym_wincmd_statement] = STATE(2372),
    [sym_source_statement] = STATE(2372),
    [sym_global_statement] = STATE(2372),
    [sym_filetype_statement] = STATE(2372),
    [sym_colorscheme_statement] = STATE(2372),
    [sym_lua_statement] = STATE(2372),
    [sym_ruby_statement] = STATE(2372),
    [sym_python_statement] = STATE(2372),
    [sym_perl_statement] = STATE(2372),
    [sym_for_loop] = STATE(2372),
    [sym_while_loop] = STATE(2372),
    [sym_if_statement] = STATE(2372),
    [sym_try_statement] = STATE(2372),
    [sym_throw_statement] = STATE(2372),
    [sym_bang_filter_statement] = STATE(2372),
    [sym_let_statement] = STATE(2372),
    [sym_const_statement] = STATE(2372),
    [sym_set_statement] = STATE(2372),
    [sym_setlocal_statement] = STATE(2372),
    [sym_unlet_statement] = STATE(2372),
    [sym_call_statement] = STATE(2372),
    [sym_echo_statement] = STATE(2372),
    [sym_echon_statement] = STATE(2372),
    [sym_echohl_statement] = STATE(2372),
    [sym_echomsg_statement] = STATE(2372),
    [sym_echoerr_statement] = STATE(2372),
    [sym_execute_statement] = STATE(2372),
    [sym_silent_statement] = STATE(2372),
    [sym_tab_statement] = STATE(2372),
    [sym_vertical_statement] = STATE(2372),
    [sym_topleft_statement] = STATE(2372),
    [sym_botright_statement] = STATE(2372),
    [sym_aboveleft_statement] = STATE(2372),
    [sym_belowright_statement] = STATE(2372),
    [sym_user_command] = STATE(2372),
    [sym_shebang] = STATE(2372),
    [sym_function_definition] = STATE(2372),
    [sym_range_statement] = STATE(2372),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2372),
    [sym_map_statement] = STATE(2372),
    [sym_sign_statement] = STATE(2372),
    [sym_eval_statement] = STATE(2372),
    [sym_substitute_statement] = STATE(2372),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2372),
    [sym_augroup_statement] = STATE(2372),
    [sym_command_statement] = STATE(2372),
    [sym_comclear_statement] = STATE(2372),
    [sym_delcommand_statement] = STATE(2372),
    [sym_highlight_statement] = STATE(2372),
    [sym_syntax_statement] = STATE(2372),
    [sym_edit_statement] = STATE(2372),
    [sym_enew_statement] = STATE(2372),
    [sym_find_statement] = STATE(2372),
    [sym_ex_statement] = STATE(2372),
    [sym_visual_statement] = STATE(2372),
    [sym_view_statement] = STATE(2372),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(447),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(447),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__endfunction] = ACTIONS(449),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(19)] = {
    [sym__cmd_separator] = STATE(116),
    [aux_sym__separated_statements] = STATE(40),
    [sym__statement] = STATE(2718),
    [sym_unknown_builtin_statement] = STATE(2718),
    [sym_return_statement] = STATE(2718),
    [sym_break_statement] = STATE(2718),
    [sym_continue_statement] = STATE(2718),
    [sym_normal_statement] = STATE(2718),
    [sym_setfiletype_statement] = STATE(2718),
    [sym_options_statement] = STATE(2718),
    [sym_startinsert_statement] = STATE(2718),
    [sym_stopinsert_statement] = STATE(2718),
    [sym_scriptencoding_statement] = STATE(2718),
    [sym_cnext_statement] = STATE(2718),
    [sym_cprevious_statement] = STATE(2718),
    [sym_runtime_statement] = STATE(2718),
    [sym_wincmd_statement] = STATE(2718),
    [sym_source_statement] = STATE(2718),
    [sym_global_statement] = STATE(2718),
    [sym_filetype_statement] = STATE(2718),
    [sym_colorscheme_statement] = STATE(2718),
    [sym_lua_statement] = STATE(2718),
    [sym_ruby_statement] = STATE(2718),
    [sym_python_statement] = STATE(2718),
    [sym_perl_statement] = STATE(2718),
    [sym_for_loop] = STATE(2718),
    [sym_while_loop] = STATE(2718),
    [sym_if_statement] = STATE(2718),
    [sym_try_statement] = STATE(2718),
    [sym_throw_statement] = STATE(2718),
    [sym_bang_filter_statement] = STATE(2718),
    [sym_let_statement] = STATE(2718),
    [sym_const_statement] = STATE(2718),
    [sym_set_statement] = STATE(2718),
    [sym_setlocal_statement] = STATE(2718),
    [sym_unlet_statement] = STATE(2718),
    [sym_call_statement] = STATE(2718),
    [sym_echo_statement] = STATE(2718),
    [sym_echon_statement] = STATE(2718),
    [sym_echohl_statement] = STATE(2718),
    [sym_echomsg_statement] = STATE(2718),
    [sym_echoerr_statement] = STATE(2718),
    [sym_execute_statement] = STATE(2718),
    [sym_silent_statement] = STATE(2718),
    [sym_tab_statement] = STATE(2718),
    [sym_vertical_statement] = STATE(2718),
    [sym_topleft_statement] = STATE(2718),
    [sym_botright_statement] = STATE(2718),
    [sym_aboveleft_statement] = STATE(2718),
    [sym_belowright_statement] = STATE(2718),
    [sym_user_command] = STATE(2718),
    [sym_shebang] = STATE(2718),
    [sym_function_definition] = STATE(2718),
    [sym_range_statement] = STATE(2718),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2718),
    [sym_map_statement] = STATE(2718),
    [sym_sign_statement] = STATE(2718),
    [sym_eval_statement] = STATE(2718),
    [sym_substitute_statement] = STATE(2718),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2718),
    [sym_augroup_statement] = STATE(2718),
    [sym_command_statement] = STATE(2718),
    [sym_comclear_statement] = STATE(2718),
    [sym_delcommand_statement] = STATE(2718),
    [sym_highlight_statement] = STATE(2718),
    [sym_syntax_statement] = STATE(2718),
    [sym_edit_statement] = STATE(2718),
    [sym_enew_statement] = STATE(2718),
    [sym_find_statement] = STATE(2718),
    [sym_ex_statement] = STATE(2718),
    [sym_visual_statement] = STATE(2718),
    [sym_view_statement] = STATE(2718),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(451),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(451),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__endfor] = ACTIONS(453),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(20)] = {
    [sym__cmd_separator] = STATE(109),
    [aux_sym__separated_statements] = STATE(35),
    [sym__statement] = STATE(2372),
    [sym_unknown_builtin_statement] = STATE(2372),
    [sym_return_statement] = STATE(2372),
    [sym_break_statement] = STATE(2372),
    [sym_continue_statement] = STATE(2372),
    [sym_normal_statement] = STATE(2372),
    [sym_setfiletype_statement] = STATE(2372),
    [sym_options_statement] = STATE(2372),
    [sym_startinsert_statement] = STATE(2372),
    [sym_stopinsert_statement] = STATE(2372),
    [sym_scriptencoding_statement] = STATE(2372),
    [sym_cnext_statement] = STATE(2372),
    [sym_cprevious_statement] = STATE(2372),
    [sym_runtime_statement] = STATE(2372),
    [sym_wincmd_statement] = STATE(2372),
    [sym_source_statement] = STATE(2372),
    [sym_global_statement] = STATE(2372),
    [sym_filetype_statement] = STATE(2372),
    [sym_colorscheme_statement] = STATE(2372),
    [sym_lua_statement] = STATE(2372),
    [sym_ruby_statement] = STATE(2372),
    [sym_python_statement] = STATE(2372),
    [sym_perl_statement] = STATE(2372),
    [sym_for_loop] = STATE(2372),
    [sym_while_loop] = STATE(2372),
    [sym_if_statement] = STATE(2372),
    [sym_try_statement] = STATE(2372),
    [sym_throw_statement] = STATE(2372),
    [sym_bang_filter_statement] = STATE(2372),
    [sym_let_statement] = STATE(2372),
    [sym_const_statement] = STATE(2372),
    [sym_set_statement] = STATE(2372),
    [sym_setlocal_statement] = STATE(2372),
    [sym_unlet_statement] = STATE(2372),
    [sym_call_statement] = STATE(2372),
    [sym_echo_statement] = STATE(2372),
    [sym_echon_statement] = STATE(2372),
    [sym_echohl_statement] = STATE(2372),
    [sym_echomsg_statement] = STATE(2372),
    [sym_echoerr_statement] = STATE(2372),
    [sym_execute_statement] = STATE(2372),
    [sym_silent_statement] = STATE(2372),
    [sym_tab_statement] = STATE(2372),
    [sym_vertical_statement] = STATE(2372),
    [sym_topleft_statement] = STATE(2372),
    [sym_botright_statement] = STATE(2372),
    [sym_aboveleft_statement] = STATE(2372),
    [sym_belowright_statement] = STATE(2372),
    [sym_user_command] = STATE(2372),
    [sym_shebang] = STATE(2372),
    [sym_function_definition] = STATE(2372),
    [sym_range_statement] = STATE(2372),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2372),
    [sym_map_statement] = STATE(2372),
    [sym_sign_statement] = STATE(2372),
    [sym_eval_statement] = STATE(2372),
    [sym_substitute_statement] = STATE(2372),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2372),
    [sym_augroup_statement] = STATE(2372),
    [sym_command_statement] = STATE(2372),
    [sym_comclear_statement] = STATE(2372),
    [sym_delcommand_statement] = STATE(2372),
    [sym_highlight_statement] = STATE(2372),
    [sym_syntax_statement] = STATE(2372),
    [sym_edit_statement] = STATE(2372),
    [sym_enew_statement] = STATE(2372),
    [sym_find_statement] = STATE(2372),
    [sym_ex_statement] = STATE(2372),
    [sym_visual_statement] = STATE(2372),
    [sym_view_statement] = STATE(2372),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(447),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(447),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__endfunction] = ACTIONS(455),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(21)] = {
    [sym__cmd_separator] = STATE(109),
    [aux_sym__separated_statements] = STATE(18),
    [sym__statement] = STATE(2372),
    [sym_unknown_builtin_statement] = STATE(2372),
    [sym_return_statement] = STATE(2372),
    [sym_break_statement] = STATE(2372),
    [sym_continue_statement] = STATE(2372),
    [sym_normal_statement] = STATE(2372),
    [sym_setfiletype_statement] = STATE(2372),
    [sym_options_statement] = STATE(2372),
    [sym_startinsert_statement] = STATE(2372),
    [sym_stopinsert_statement] = STATE(2372),
    [sym_scriptencoding_statement] = STATE(2372),
    [sym_cnext_statement] = STATE(2372),
    [sym_cprevious_statement] = STATE(2372),
    [sym_runtime_statement] = STATE(2372),
    [sym_wincmd_statement] = STATE(2372),
    [sym_source_statement] = STATE(2372),
    [sym_global_statement] = STATE(2372),
    [sym_filetype_statement] = STATE(2372),
    [sym_colorscheme_statement] = STATE(2372),
    [sym_lua_statement] = STATE(2372),
    [sym_ruby_statement] = STATE(2372),
    [sym_python_statement] = STATE(2372),
    [sym_perl_statement] = STATE(2372),
    [sym_for_loop] = STATE(2372),
    [sym_while_loop] = STATE(2372),
    [sym_if_statement] = STATE(2372),
    [sym_try_statement] = STATE(2372),
    [sym_throw_statement] = STATE(2372),
    [sym_bang_filter_statement] = STATE(2372),
    [sym_let_statement] = STATE(2372),
    [sym_const_statement] = STATE(2372),
    [sym_set_statement] = STATE(2372),
    [sym_setlocal_statement] = STATE(2372),
    [sym_unlet_statement] = STATE(2372),
    [sym_call_statement] = STATE(2372),
    [sym_echo_statement] = STATE(2372),
    [sym_echon_statement] = STATE(2372),
    [sym_echohl_statement] = STATE(2372),
    [sym_echomsg_statement] = STATE(2372),
    [sym_echoerr_statement] = STATE(2372),
    [sym_execute_statement] = STATE(2372),
    [sym_silent_statement] = STATE(2372),
    [sym_tab_statement] = STATE(2372),
    [sym_vertical_statement] = STATE(2372),
    [sym_topleft_statement] = STATE(2372),
    [sym_botright_statement] = STATE(2372),
    [sym_aboveleft_statement] = STATE(2372),
    [sym_belowright_statement] = STATE(2372),
    [sym_user_command] = STATE(2372),
    [sym_shebang] = STATE(2372),
    [sym_function_definition] = STATE(2372),
    [sym_range_statement] = STATE(2372),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2372),
    [sym_map_statement] = STATE(2372),
    [sym_sign_statement] = STATE(2372),
    [sym_eval_statement] = STATE(2372),
    [sym_substitute_statement] = STATE(2372),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2372),
    [sym_augroup_statement] = STATE(2372),
    [sym_command_statement] = STATE(2372),
    [sym_comclear_statement] = STATE(2372),
    [sym_delcommand_statement] = STATE(2372),
    [sym_highlight_statement] = STATE(2372),
    [sym_syntax_statement] = STATE(2372),
    [sym_edit_statement] = STATE(2372),
    [sym_enew_statement] = STATE(2372),
    [sym_find_statement] = STATE(2372),
    [sym_ex_statement] = STATE(2372),
    [sym_visual_statement] = STATE(2372),
    [sym_view_statement] = STATE(2372),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(447),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(447),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__endfunction] = ACTIONS(457),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(22)] = {
    [sym__cmd_separator] = STATE(116),
    [aux_sym__separated_statements] = STATE(25),
    [sym__statement] = STATE(2718),
    [sym_unknown_builtin_statement] = STATE(2718),
    [sym_return_statement] = STATE(2718),
    [sym_break_statement] = STATE(2718),
    [sym_continue_statement] = STATE(2718),
    [sym_normal_statement] = STATE(2718),
    [sym_setfiletype_statement] = STATE(2718),
    [sym_options_statement] = STATE(2718),
    [sym_startinsert_statement] = STATE(2718),
    [sym_stopinsert_statement] = STATE(2718),
    [sym_scriptencoding_statement] = STATE(2718),
    [sym_cnext_statement] = STATE(2718),
    [sym_cprevious_statement] = STATE(2718),
    [sym_runtime_statement] = STATE(2718),
    [sym_wincmd_statement] = STATE(2718),
    [sym_source_statement] = STATE(2718),
    [sym_global_statement] = STATE(2718),
    [sym_filetype_statement] = STATE(2718),
    [sym_colorscheme_statement] = STATE(2718),
    [sym_lua_statement] = STATE(2718),
    [sym_ruby_statement] = STATE(2718),
    [sym_python_statement] = STATE(2718),
    [sym_perl_statement] = STATE(2718),
    [sym_for_loop] = STATE(2718),
    [sym_while_loop] = STATE(2718),
    [sym_if_statement] = STATE(2718),
    [sym_try_statement] = STATE(2718),
    [sym_throw_statement] = STATE(2718),
    [sym_bang_filter_statement] = STATE(2718),
    [sym_let_statement] = STATE(2718),
    [sym_const_statement] = STATE(2718),
    [sym_set_statement] = STATE(2718),
    [sym_setlocal_statement] = STATE(2718),
    [sym_unlet_statement] = STATE(2718),
    [sym_call_statement] = STATE(2718),
    [sym_echo_statement] = STATE(2718),
    [sym_echon_statement] = STATE(2718),
    [sym_echohl_statement] = STATE(2718),
    [sym_echomsg_statement] = STATE(2718),
    [sym_echoerr_statement] = STATE(2718),
    [sym_execute_statement] = STATE(2718),
    [sym_silent_statement] = STATE(2718),
    [sym_tab_statement] = STATE(2718),
    [sym_vertical_statement] = STATE(2718),
    [sym_topleft_statement] = STATE(2718),
    [sym_botright_statement] = STATE(2718),
    [sym_aboveleft_statement] = STATE(2718),
    [sym_belowright_statement] = STATE(2718),
    [sym_user_command] = STATE(2718),
    [sym_shebang] = STATE(2718),
    [sym_function_definition] = STATE(2718),
    [sym_range_statement] = STATE(2718),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2718),
    [sym_map_statement] = STATE(2718),
    [sym_sign_statement] = STATE(2718),
    [sym_eval_statement] = STATE(2718),
    [sym_substitute_statement] = STATE(2718),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2718),
    [sym_augroup_statement] = STATE(2718),
    [sym_command_statement] = STATE(2718),
    [sym_comclear_statement] = STATE(2718),
    [sym_delcommand_statement] = STATE(2718),
    [sym_highlight_statement] = STATE(2718),
    [sym_syntax_statement] = STATE(2718),
    [sym_edit_statement] = STATE(2718),
    [sym_enew_statement] = STATE(2718),
    [sym_find_statement] = STATE(2718),
    [sym_ex_statement] = STATE(2718),
    [sym_visual_statement] = STATE(2718),
    [sym_view_statement] = STATE(2718),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(451),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(451),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__endfor] = ACTIONS(459),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(23)] = {
    [sym__cmd_separator] = STATE(114),
    [aux_sym__separated_statements] = STATE(39),
    [sym__statement] = STATE(2693),
    [sym_unknown_builtin_statement] = STATE(2693),
    [sym_return_statement] = STATE(2693),
    [sym_break_statement] = STATE(2693),
    [sym_continue_statement] = STATE(2693),
    [sym_normal_statement] = STATE(2693),
    [sym_setfiletype_statement] = STATE(2693),
    [sym_options_statement] = STATE(2693),
    [sym_startinsert_statement] = STATE(2693),
    [sym_stopinsert_statement] = STATE(2693),
    [sym_scriptencoding_statement] = STATE(2693),
    [sym_cnext_statement] = STATE(2693),
    [sym_cprevious_statement] = STATE(2693),
    [sym_runtime_statement] = STATE(2693),
    [sym_wincmd_statement] = STATE(2693),
    [sym_source_statement] = STATE(2693),
    [sym_global_statement] = STATE(2693),
    [sym_filetype_statement] = STATE(2693),
    [sym_colorscheme_statement] = STATE(2693),
    [sym_lua_statement] = STATE(2693),
    [sym_ruby_statement] = STATE(2693),
    [sym_python_statement] = STATE(2693),
    [sym_perl_statement] = STATE(2693),
    [sym_for_loop] = STATE(2693),
    [sym_while_loop] = STATE(2693),
    [sym_if_statement] = STATE(2693),
    [sym_try_statement] = STATE(2693),
    [sym_throw_statement] = STATE(2693),
    [sym_bang_filter_statement] = STATE(2693),
    [sym_let_statement] = STATE(2693),
    [sym_const_statement] = STATE(2693),
    [sym_set_statement] = STATE(2693),
    [sym_setlocal_statement] = STATE(2693),
    [sym_unlet_statement] = STATE(2693),
    [sym_call_statement] = STATE(2693),
    [sym_echo_statement] = STATE(2693),
    [sym_echon_statement] = STATE(2693),
    [sym_echohl_statement] = STATE(2693),
    [sym_echomsg_statement] = STATE(2693),
    [sym_echoerr_statement] = STATE(2693),
    [sym_execute_statement] = STATE(2693),
    [sym_silent_statement] = STATE(2693),
    [sym_tab_statement] = STATE(2693),
    [sym_vertical_statement] = STATE(2693),
    [sym_topleft_statement] = STATE(2693),
    [sym_botright_statement] = STATE(2693),
    [sym_aboveleft_statement] = STATE(2693),
    [sym_belowright_statement] = STATE(2693),
    [sym_user_command] = STATE(2693),
    [sym_shebang] = STATE(2693),
    [sym_function_definition] = STATE(2693),
    [sym_range_statement] = STATE(2693),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2693),
    [sym_map_statement] = STATE(2693),
    [sym_sign_statement] = STATE(2693),
    [sym_eval_statement] = STATE(2693),
    [sym_substitute_statement] = STATE(2693),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2693),
    [sym_augroup_statement] = STATE(2693),
    [sym_command_statement] = STATE(2693),
    [sym_comclear_statement] = STATE(2693),
    [sym_delcommand_statement] = STATE(2693),
    [sym_highlight_statement] = STATE(2693),
    [sym_syntax_statement] = STATE(2693),
    [sym_edit_statement] = STATE(2693),
    [sym_enew_statement] = STATE(2693),
    [sym_find_statement] = STATE(2693),
    [sym_ex_statement] = STATE(2693),
    [sym_visual_statement] = STATE(2693),
    [sym_view_statement] = STATE(2693),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(461),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(461),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__endif] = ACTIONS(463),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(24)] = {
    [sym__cmd_separator] = STATE(109),
    [aux_sym__separated_statements] = STATE(27),
    [sym__statement] = STATE(2372),
    [sym_unknown_builtin_statement] = STATE(2372),
    [sym_return_statement] = STATE(2372),
    [sym_break_statement] = STATE(2372),
    [sym_continue_statement] = STATE(2372),
    [sym_normal_statement] = STATE(2372),
    [sym_setfiletype_statement] = STATE(2372),
    [sym_options_statement] = STATE(2372),
    [sym_startinsert_statement] = STATE(2372),
    [sym_stopinsert_statement] = STATE(2372),
    [sym_scriptencoding_statement] = STATE(2372),
    [sym_cnext_statement] = STATE(2372),
    [sym_cprevious_statement] = STATE(2372),
    [sym_runtime_statement] = STATE(2372),
    [sym_wincmd_statement] = STATE(2372),
    [sym_source_statement] = STATE(2372),
    [sym_global_statement] = STATE(2372),
    [sym_filetype_statement] = STATE(2372),
    [sym_colorscheme_statement] = STATE(2372),
    [sym_lua_statement] = STATE(2372),
    [sym_ruby_statement] = STATE(2372),
    [sym_python_statement] = STATE(2372),
    [sym_perl_statement] = STATE(2372),
    [sym_for_loop] = STATE(2372),
    [sym_while_loop] = STATE(2372),
    [sym_if_statement] = STATE(2372),
    [sym_try_statement] = STATE(2372),
    [sym_throw_statement] = STATE(2372),
    [sym_bang_filter_statement] = STATE(2372),
    [sym_let_statement] = STATE(2372),
    [sym_const_statement] = STATE(2372),
    [sym_set_statement] = STATE(2372),
    [sym_setlocal_statement] = STATE(2372),
    [sym_unlet_statement] = STATE(2372),
    [sym_call_statement] = STATE(2372),
    [sym_echo_statement] = STATE(2372),
    [sym_echon_statement] = STATE(2372),
    [sym_echohl_statement] = STATE(2372),
    [sym_echomsg_statement] = STATE(2372),
    [sym_echoerr_statement] = STATE(2372),
    [sym_execute_statement] = STATE(2372),
    [sym_silent_statement] = STATE(2372),
    [sym_tab_statement] = STATE(2372),
    [sym_vertical_statement] = STATE(2372),
    [sym_topleft_statement] = STATE(2372),
    [sym_botright_statement] = STATE(2372),
    [sym_aboveleft_statement] = STATE(2372),
    [sym_belowright_statement] = STATE(2372),
    [sym_user_command] = STATE(2372),
    [sym_shebang] = STATE(2372),
    [sym_function_definition] = STATE(2372),
    [sym_range_statement] = STATE(2372),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2372),
    [sym_map_statement] = STATE(2372),
    [sym_sign_statement] = STATE(2372),
    [sym_eval_statement] = STATE(2372),
    [sym_substitute_statement] = STATE(2372),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2372),
    [sym_augroup_statement] = STATE(2372),
    [sym_command_statement] = STATE(2372),
    [sym_comclear_statement] = STATE(2372),
    [sym_delcommand_statement] = STATE(2372),
    [sym_highlight_statement] = STATE(2372),
    [sym_syntax_statement] = STATE(2372),
    [sym_edit_statement] = STATE(2372),
    [sym_enew_statement] = STATE(2372),
    [sym_find_statement] = STATE(2372),
    [sym_ex_statement] = STATE(2372),
    [sym_visual_statement] = STATE(2372),
    [sym_view_statement] = STATE(2372),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(447),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(447),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__endfunction] = ACTIONS(465),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(25)] = {
    [sym__cmd_separator] = STATE(116),
    [aux_sym__separated_statements] = STATE(40),
    [sym__statement] = STATE(2718),
    [sym_unknown_builtin_statement] = STATE(2718),
    [sym_return_statement] = STATE(2718),
    [sym_break_statement] = STATE(2718),
    [sym_continue_statement] = STATE(2718),
    [sym_normal_statement] = STATE(2718),
    [sym_setfiletype_statement] = STATE(2718),
    [sym_options_statement] = STATE(2718),
    [sym_startinsert_statement] = STATE(2718),
    [sym_stopinsert_statement] = STATE(2718),
    [sym_scriptencoding_statement] = STATE(2718),
    [sym_cnext_statement] = STATE(2718),
    [sym_cprevious_statement] = STATE(2718),
    [sym_runtime_statement] = STATE(2718),
    [sym_wincmd_statement] = STATE(2718),
    [sym_source_statement] = STATE(2718),
    [sym_global_statement] = STATE(2718),
    [sym_filetype_statement] = STATE(2718),
    [sym_colorscheme_statement] = STATE(2718),
    [sym_lua_statement] = STATE(2718),
    [sym_ruby_statement] = STATE(2718),
    [sym_python_statement] = STATE(2718),
    [sym_perl_statement] = STATE(2718),
    [sym_for_loop] = STATE(2718),
    [sym_while_loop] = STATE(2718),
    [sym_if_statement] = STATE(2718),
    [sym_try_statement] = STATE(2718),
    [sym_throw_statement] = STATE(2718),
    [sym_bang_filter_statement] = STATE(2718),
    [sym_let_statement] = STATE(2718),
    [sym_const_statement] = STATE(2718),
    [sym_set_statement] = STATE(2718),
    [sym_setlocal_statement] = STATE(2718),
    [sym_unlet_statement] = STATE(2718),
    [sym_call_statement] = STATE(2718),
    [sym_echo_statement] = STATE(2718),
    [sym_echon_statement] = STATE(2718),
    [sym_echohl_statement] = STATE(2718),
    [sym_echomsg_statement] = STATE(2718),
    [sym_echoerr_statement] = STATE(2718),
    [sym_execute_statement] = STATE(2718),
    [sym_silent_statement] = STATE(2718),
    [sym_tab_statement] = STATE(2718),
    [sym_vertical_statement] = STATE(2718),
    [sym_topleft_statement] = STATE(2718),
    [sym_botright_statement] = STATE(2718),
    [sym_aboveleft_statement] = STATE(2718),
    [sym_belowright_statement] = STATE(2718),
    [sym_user_command] = STATE(2718),
    [sym_shebang] = STATE(2718),
    [sym_function_definition] = STATE(2718),
    [sym_range_statement] = STATE(2718),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2718),
    [sym_map_statement] = STATE(2718),
    [sym_sign_statement] = STATE(2718),
    [sym_eval_statement] = STATE(2718),
    [sym_substitute_statement] = STATE(2718),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2718),
    [sym_augroup_statement] = STATE(2718),
    [sym_command_statement] = STATE(2718),
    [sym_comclear_statement] = STATE(2718),
    [sym_delcommand_statement] = STATE(2718),
    [sym_highlight_statement] = STATE(2718),
    [sym_syntax_statement] = STATE(2718),
    [sym_edit_statement] = STATE(2718),
    [sym_enew_statement] = STATE(2718),
    [sym_find_statement] = STATE(2718),
    [sym_ex_statement] = STATE(2718),
    [sym_visual_statement] = STATE(2718),
    [sym_view_statement] = STATE(2718),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(451),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(451),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__endfor] = ACTIONS(467),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(26)] = {
    [sym__cmd_separator] = STATE(119),
    [aux_sym__separated_statements] = STATE(29),
    [sym__statement] = STATE(2446),
    [sym_unknown_builtin_statement] = STATE(2446),
    [sym_return_statement] = STATE(2446),
    [sym_break_statement] = STATE(2446),
    [sym_continue_statement] = STATE(2446),
    [sym_normal_statement] = STATE(2446),
    [sym_setfiletype_statement] = STATE(2446),
    [sym_options_statement] = STATE(2446),
    [sym_startinsert_statement] = STATE(2446),
    [sym_stopinsert_statement] = STATE(2446),
    [sym_scriptencoding_statement] = STATE(2446),
    [sym_cnext_statement] = STATE(2446),
    [sym_cprevious_statement] = STATE(2446),
    [sym_runtime_statement] = STATE(2446),
    [sym_wincmd_statement] = STATE(2446),
    [sym_source_statement] = STATE(2446),
    [sym_global_statement] = STATE(2446),
    [sym_filetype_statement] = STATE(2446),
    [sym_colorscheme_statement] = STATE(2446),
    [sym_lua_statement] = STATE(2446),
    [sym_ruby_statement] = STATE(2446),
    [sym_python_statement] = STATE(2446),
    [sym_perl_statement] = STATE(2446),
    [sym_for_loop] = STATE(2446),
    [sym_while_loop] = STATE(2446),
    [sym_if_statement] = STATE(2446),
    [sym_try_statement] = STATE(2446),
    [sym_throw_statement] = STATE(2446),
    [sym_bang_filter_statement] = STATE(2446),
    [sym_let_statement] = STATE(2446),
    [sym_const_statement] = STATE(2446),
    [sym_set_statement] = STATE(2446),
    [sym_setlocal_statement] = STATE(2446),
    [sym_unlet_statement] = STATE(2446),
    [sym_call_statement] = STATE(2446),
    [sym_echo_statement] = STATE(2446),
    [sym_echon_statement] = STATE(2446),
    [sym_echohl_statement] = STATE(2446),
    [sym_echomsg_statement] = STATE(2446),
    [sym_echoerr_statement] = STATE(2446),
    [sym_execute_statement] = STATE(2446),
    [sym_silent_statement] = STATE(2446),
    [sym_tab_statement] = STATE(2446),
    [sym_vertical_statement] = STATE(2446),
    [sym_topleft_statement] = STATE(2446),
    [sym_botright_statement] = STATE(2446),
    [sym_aboveleft_statement] = STATE(2446),
    [sym_belowright_statement] = STATE(2446),
    [sym_user_command] = STATE(2446),
    [sym_shebang] = STATE(2446),
    [sym_function_definition] = STATE(2446),
    [sym_range_statement] = STATE(2446),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2446),
    [sym_map_statement] = STATE(2446),
    [sym_sign_statement] = STATE(2446),
    [sym_eval_statement] = STATE(2446),
    [sym_substitute_statement] = STATE(2446),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2446),
    [sym_augroup_statement] = STATE(2446),
    [sym_command_statement] = STATE(2446),
    [sym_comclear_statement] = STATE(2446),
    [sym_delcommand_statement] = STATE(2446),
    [sym_highlight_statement] = STATE(2446),
    [sym_syntax_statement] = STATE(2446),
    [sym_edit_statement] = STATE(2446),
    [sym_enew_statement] = STATE(2446),
    [sym_find_statement] = STATE(2446),
    [sym_ex_statement] = STATE(2446),
    [sym_visual_statement] = STATE(2446),
    [sym_view_statement] = STATE(2446),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(469),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(469),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__endwhile] = ACTIONS(471),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(27)] = {
    [sym__cmd_separator] = STATE(109),
    [aux_sym__separated_statements] = STATE(35),
    [sym__statement] = STATE(2372),
    [sym_unknown_builtin_statement] = STATE(2372),
    [sym_return_statement] = STATE(2372),
    [sym_break_statement] = STATE(2372),
    [sym_continue_statement] = STATE(2372),
    [sym_normal_statement] = STATE(2372),
    [sym_setfiletype_statement] = STATE(2372),
    [sym_options_statement] = STATE(2372),
    [sym_startinsert_statement] = STATE(2372),
    [sym_stopinsert_statement] = STATE(2372),
    [sym_scriptencoding_statement] = STATE(2372),
    [sym_cnext_statement] = STATE(2372),
    [sym_cprevious_statement] = STATE(2372),
    [sym_runtime_statement] = STATE(2372),
    [sym_wincmd_statement] = STATE(2372),
    [sym_source_statement] = STATE(2372),
    [sym_global_statement] = STATE(2372),
    [sym_filetype_statement] = STATE(2372),
    [sym_colorscheme_statement] = STATE(2372),
    [sym_lua_statement] = STATE(2372),
    [sym_ruby_statement] = STATE(2372),
    [sym_python_statement] = STATE(2372),
    [sym_perl_statement] = STATE(2372),
    [sym_for_loop] = STATE(2372),
    [sym_while_loop] = STATE(2372),
    [sym_if_statement] = STATE(2372),
    [sym_try_statement] = STATE(2372),
    [sym_throw_statement] = STATE(2372),
    [sym_bang_filter_statement] = STATE(2372),
    [sym_let_statement] = STATE(2372),
    [sym_const_statement] = STATE(2372),
    [sym_set_statement] = STATE(2372),
    [sym_setlocal_statement] = STATE(2372),
    [sym_unlet_statement] = STATE(2372),
    [sym_call_statement] = STATE(2372),
    [sym_echo_statement] = STATE(2372),
    [sym_echon_statement] = STATE(2372),
    [sym_echohl_statement] = STATE(2372),
    [sym_echomsg_statement] = STATE(2372),
    [sym_echoerr_statement] = STATE(2372),
    [sym_execute_statement] = STATE(2372),
    [sym_silent_statement] = STATE(2372),
    [sym_tab_statement] = STATE(2372),
    [sym_vertical_statement] = STATE(2372),
    [sym_topleft_statement] = STATE(2372),
    [sym_botright_statement] = STATE(2372),
    [sym_aboveleft_statement] = STATE(2372),
    [sym_belowright_statement] = STATE(2372),
    [sym_user_command] = STATE(2372),
    [sym_shebang] = STATE(2372),
    [sym_function_definition] = STATE(2372),
    [sym_range_statement] = STATE(2372),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2372),
    [sym_map_statement] = STATE(2372),
    [sym_sign_statement] = STATE(2372),
    [sym_eval_statement] = STATE(2372),
    [sym_substitute_statement] = STATE(2372),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2372),
    [sym_augroup_statement] = STATE(2372),
    [sym_command_statement] = STATE(2372),
    [sym_comclear_statement] = STATE(2372),
    [sym_delcommand_statement] = STATE(2372),
    [sym_highlight_statement] = STATE(2372),
    [sym_syntax_statement] = STATE(2372),
    [sym_edit_statement] = STATE(2372),
    [sym_enew_statement] = STATE(2372),
    [sym_find_statement] = STATE(2372),
    [sym_ex_statement] = STATE(2372),
    [sym_visual_statement] = STATE(2372),
    [sym_view_statement] = STATE(2372),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(447),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(447),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__endfunction] = ACTIONS(473),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(28)] = {
    [sym__cmd_separator] = STATE(109),
    [aux_sym__separated_statements] = STATE(20),
    [sym__statement] = STATE(2372),
    [sym_unknown_builtin_statement] = STATE(2372),
    [sym_return_statement] = STATE(2372),
    [sym_break_statement] = STATE(2372),
    [sym_continue_statement] = STATE(2372),
    [sym_normal_statement] = STATE(2372),
    [sym_setfiletype_statement] = STATE(2372),
    [sym_options_statement] = STATE(2372),
    [sym_startinsert_statement] = STATE(2372),
    [sym_stopinsert_statement] = STATE(2372),
    [sym_scriptencoding_statement] = STATE(2372),
    [sym_cnext_statement] = STATE(2372),
    [sym_cprevious_statement] = STATE(2372),
    [sym_runtime_statement] = STATE(2372),
    [sym_wincmd_statement] = STATE(2372),
    [sym_source_statement] = STATE(2372),
    [sym_global_statement] = STATE(2372),
    [sym_filetype_statement] = STATE(2372),
    [sym_colorscheme_statement] = STATE(2372),
    [sym_lua_statement] = STATE(2372),
    [sym_ruby_statement] = STATE(2372),
    [sym_python_statement] = STATE(2372),
    [sym_perl_statement] = STATE(2372),
    [sym_for_loop] = STATE(2372),
    [sym_while_loop] = STATE(2372),
    [sym_if_statement] = STATE(2372),
    [sym_try_statement] = STATE(2372),
    [sym_throw_statement] = STATE(2372),
    [sym_bang_filter_statement] = STATE(2372),
    [sym_let_statement] = STATE(2372),
    [sym_const_statement] = STATE(2372),
    [sym_set_statement] = STATE(2372),
    [sym_setlocal_statement] = STATE(2372),
    [sym_unlet_statement] = STATE(2372),
    [sym_call_statement] = STATE(2372),
    [sym_echo_statement] = STATE(2372),
    [sym_echon_statement] = STATE(2372),
    [sym_echohl_statement] = STATE(2372),
    [sym_echomsg_statement] = STATE(2372),
    [sym_echoerr_statement] = STATE(2372),
    [sym_execute_statement] = STATE(2372),
    [sym_silent_statement] = STATE(2372),
    [sym_tab_statement] = STATE(2372),
    [sym_vertical_statement] = STATE(2372),
    [sym_topleft_statement] = STATE(2372),
    [sym_botright_statement] = STATE(2372),
    [sym_aboveleft_statement] = STATE(2372),
    [sym_belowright_statement] = STATE(2372),
    [sym_user_command] = STATE(2372),
    [sym_shebang] = STATE(2372),
    [sym_function_definition] = STATE(2372),
    [sym_range_statement] = STATE(2372),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2372),
    [sym_map_statement] = STATE(2372),
    [sym_sign_statement] = STATE(2372),
    [sym_eval_statement] = STATE(2372),
    [sym_substitute_statement] = STATE(2372),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2372),
    [sym_augroup_statement] = STATE(2372),
    [sym_command_statement] = STATE(2372),
    [sym_comclear_statement] = STATE(2372),
    [sym_delcommand_statement] = STATE(2372),
    [sym_highlight_statement] = STATE(2372),
    [sym_syntax_statement] = STATE(2372),
    [sym_edit_statement] = STATE(2372),
    [sym_enew_statement] = STATE(2372),
    [sym_find_statement] = STATE(2372),
    [sym_ex_statement] = STATE(2372),
    [sym_visual_statement] = STATE(2372),
    [sym_view_statement] = STATE(2372),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(447),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(447),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__endfunction] = ACTIONS(475),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(29)] = {
    [sym__cmd_separator] = STATE(119),
    [aux_sym__separated_statements] = STATE(36),
    [sym__statement] = STATE(2446),
    [sym_unknown_builtin_statement] = STATE(2446),
    [sym_return_statement] = STATE(2446),
    [sym_break_statement] = STATE(2446),
    [sym_continue_statement] = STATE(2446),
    [sym_normal_statement] = STATE(2446),
    [sym_setfiletype_statement] = STATE(2446),
    [sym_options_statement] = STATE(2446),
    [sym_startinsert_statement] = STATE(2446),
    [sym_stopinsert_statement] = STATE(2446),
    [sym_scriptencoding_statement] = STATE(2446),
    [sym_cnext_statement] = STATE(2446),
    [sym_cprevious_statement] = STATE(2446),
    [sym_runtime_statement] = STATE(2446),
    [sym_wincmd_statement] = STATE(2446),
    [sym_source_statement] = STATE(2446),
    [sym_global_statement] = STATE(2446),
    [sym_filetype_statement] = STATE(2446),
    [sym_colorscheme_statement] = STATE(2446),
    [sym_lua_statement] = STATE(2446),
    [sym_ruby_statement] = STATE(2446),
    [sym_python_statement] = STATE(2446),
    [sym_perl_statement] = STATE(2446),
    [sym_for_loop] = STATE(2446),
    [sym_while_loop] = STATE(2446),
    [sym_if_statement] = STATE(2446),
    [sym_try_statement] = STATE(2446),
    [sym_throw_statement] = STATE(2446),
    [sym_bang_filter_statement] = STATE(2446),
    [sym_let_statement] = STATE(2446),
    [sym_const_statement] = STATE(2446),
    [sym_set_statement] = STATE(2446),
    [sym_setlocal_statement] = STATE(2446),
    [sym_unlet_statement] = STATE(2446),
    [sym_call_statement] = STATE(2446),
    [sym_echo_statement] = STATE(2446),
    [sym_echon_statement] = STATE(2446),
    [sym_echohl_statement] = STATE(2446),
    [sym_echomsg_statement] = STATE(2446),
    [sym_echoerr_statement] = STATE(2446),
    [sym_execute_statement] = STATE(2446),
    [sym_silent_statement] = STATE(2446),
    [sym_tab_statement] = STATE(2446),
    [sym_vertical_statement] = STATE(2446),
    [sym_topleft_statement] = STATE(2446),
    [sym_botright_statement] = STATE(2446),
    [sym_aboveleft_statement] = STATE(2446),
    [sym_belowright_statement] = STATE(2446),
    [sym_user_command] = STATE(2446),
    [sym_shebang] = STATE(2446),
    [sym_function_definition] = STATE(2446),
    [sym_range_statement] = STATE(2446),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2446),
    [sym_map_statement] = STATE(2446),
    [sym_sign_statement] = STATE(2446),
    [sym_eval_statement] = STATE(2446),
    [sym_substitute_statement] = STATE(2446),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2446),
    [sym_augroup_statement] = STATE(2446),
    [sym_command_statement] = STATE(2446),
    [sym_comclear_statement] = STATE(2446),
    [sym_delcommand_statement] = STATE(2446),
    [sym_highlight_statement] = STATE(2446),
    [sym_syntax_statement] = STATE(2446),
    [sym_edit_statement] = STATE(2446),
    [sym_enew_statement] = STATE(2446),
    [sym_find_statement] = STATE(2446),
    [sym_ex_statement] = STATE(2446),
    [sym_visual_statement] = STATE(2446),
    [sym_view_statement] = STATE(2446),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(469),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(469),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__endwhile] = ACTIONS(477),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(30)] = {
    [sym__statement] = STATE(2440),
    [sym_unknown_builtin_statement] = STATE(2440),
    [sym_return_statement] = STATE(2440),
    [sym_break_statement] = STATE(2440),
    [sym_continue_statement] = STATE(2440),
    [sym_normal_statement] = STATE(2440),
    [sym_setfiletype_statement] = STATE(2440),
    [sym_options_statement] = STATE(2440),
    [sym_startinsert_statement] = STATE(2440),
    [sym_stopinsert_statement] = STATE(2440),
    [sym_scriptencoding_statement] = STATE(2440),
    [sym_cnext_statement] = STATE(2440),
    [sym_cprevious_statement] = STATE(2440),
    [sym_runtime_statement] = STATE(2440),
    [sym_wincmd_statement] = STATE(2440),
    [sym_source_statement] = STATE(2440),
    [sym_global_statement] = STATE(2440),
    [sym_filetype_statement] = STATE(2440),
    [sym_colorscheme_statement] = STATE(2440),
    [sym_lua_statement] = STATE(2440),
    [sym_ruby_statement] = STATE(2440),
    [sym_python_statement] = STATE(2440),
    [sym_perl_statement] = STATE(2440),
    [sym_for_loop] = STATE(2440),
    [sym_while_loop] = STATE(2440),
    [sym_if_statement] = STATE(2440),
    [sym_try_statement] = STATE(2440),
    [sym_throw_statement] = STATE(2440),
    [sym_bang_filter_statement] = STATE(2440),
    [sym_let_statement] = STATE(2440),
    [sym_const_statement] = STATE(2440),
    [sym_set_statement] = STATE(2440),
    [sym_setlocal_statement] = STATE(2440),
    [sym_unlet_statement] = STATE(2440),
    [sym_call_statement] = STATE(2440),
    [sym_echo_statement] = STATE(2440),
    [sym_echon_statement] = STATE(2440),
    [sym_echohl_statement] = STATE(2440),
    [sym_echomsg_statement] = STATE(2440),
    [sym_echoerr_statement] = STATE(2440),
    [sym_execute_statement] = STATE(2440),
    [sym_silent_statement] = STATE(2440),
    [sym_tab_statement] = STATE(2440),
    [sym_vertical_statement] = STATE(2440),
    [sym_topleft_statement] = STATE(2440),
    [sym_botright_statement] = STATE(2440),
    [sym_aboveleft_statement] = STATE(2440),
    [sym_belowright_statement] = STATE(2440),
    [sym_user_command] = STATE(2440),
    [sym_shebang] = STATE(2440),
    [sym_function_definition] = STATE(2440),
    [sym_range_statement] = STATE(2440),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2440),
    [sym_map_statement] = STATE(2440),
    [sym_sign_statement] = STATE(2440),
    [sym_eval_statement] = STATE(2440),
    [sym_substitute_statement] = STATE(2440),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2440),
    [sym_augroup_statement] = STATE(2440),
    [sym_command_statement] = STATE(2440),
    [sym_comclear_statement] = STATE(2440),
    [sym_delcommand_statement] = STATE(2440),
    [sym_highlight_statement] = STATE(2440),
    [sym_syntax_statement] = STATE(2440),
    [sym_edit_statement] = STATE(2440),
    [sym_enew_statement] = STATE(2440),
    [sym_find_statement] = STATE(2440),
    [sym_ex_statement] = STATE(2440),
    [sym_visual_statement] = STATE(2440),
    [sym_view_statement] = STATE(2440),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [anon_sym_BSLASH_PIPE] = ACTIONS(501),
    [aux_sym__map_rhs_statement_token2] = ACTIONS(501),
    [aux_sym__map_rhs_statement_token3] = ACTIONS(501),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_au_once] = ACTIONS(507),
    [sym_au_nested] = ACTIONS(509),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(31)] = {
    [sym__statement] = STATE(2440),
    [sym_unknown_builtin_statement] = STATE(2440),
    [sym_return_statement] = STATE(2440),
    [sym_break_statement] = STATE(2440),
    [sym_continue_statement] = STATE(2440),
    [sym_normal_statement] = STATE(2440),
    [sym_setfiletype_statement] = STATE(2440),
    [sym_options_statement] = STATE(2440),
    [sym_startinsert_statement] = STATE(2440),
    [sym_stopinsert_statement] = STATE(2440),
    [sym_scriptencoding_statement] = STATE(2440),
    [sym_cnext_statement] = STATE(2440),
    [sym_cprevious_statement] = STATE(2440),
    [sym_runtime_statement] = STATE(2440),
    [sym_wincmd_statement] = STATE(2440),
    [sym_source_statement] = STATE(2440),
    [sym_global_statement] = STATE(2440),
    [sym_filetype_statement] = STATE(2440),
    [sym_colorscheme_statement] = STATE(2440),
    [sym_lua_statement] = STATE(2440),
    [sym_ruby_statement] = STATE(2440),
    [sym_python_statement] = STATE(2440),
    [sym_perl_statement] = STATE(2440),
    [sym_for_loop] = STATE(2440),
    [sym_while_loop] = STATE(2440),
    [sym_if_statement] = STATE(2440),
    [sym_try_statement] = STATE(2440),
    [sym_throw_statement] = STATE(2440),
    [sym_bang_filter_statement] = STATE(2440),
    [sym_let_statement] = STATE(2440),
    [sym_const_statement] = STATE(2440),
    [sym_set_statement] = STATE(2440),
    [sym_setlocal_statement] = STATE(2440),
    [sym_unlet_statement] = STATE(2440),
    [sym_call_statement] = STATE(2440),
    [sym_echo_statement] = STATE(2440),
    [sym_echon_statement] = STATE(2440),
    [sym_echohl_statement] = STATE(2440),
    [sym_echomsg_statement] = STATE(2440),
    [sym_echoerr_statement] = STATE(2440),
    [sym_execute_statement] = STATE(2440),
    [sym_silent_statement] = STATE(2440),
    [sym_tab_statement] = STATE(2440),
    [sym_vertical_statement] = STATE(2440),
    [sym_topleft_statement] = STATE(2440),
    [sym_botright_statement] = STATE(2440),
    [sym_aboveleft_statement] = STATE(2440),
    [sym_belowright_statement] = STATE(2440),
    [sym_user_command] = STATE(2440),
    [sym_shebang] = STATE(2440),
    [sym_function_definition] = STATE(2440),
    [sym_range_statement] = STATE(2440),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2440),
    [sym_map_statement] = STATE(2440),
    [sym_sign_statement] = STATE(2440),
    [sym_eval_statement] = STATE(2440),
    [sym_substitute_statement] = STATE(2440),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2440),
    [sym_augroup_statement] = STATE(2440),
    [sym_command_statement] = STATE(2440),
    [sym_comclear_statement] = STATE(2440),
    [sym_delcommand_statement] = STATE(2440),
    [sym_highlight_statement] = STATE(2440),
    [sym_syntax_statement] = STATE(2440),
    [sym_edit_statement] = STATE(2440),
    [sym_enew_statement] = STATE(2440),
    [sym_find_statement] = STATE(2440),
    [sym_ex_statement] = STATE(2440),
    [sym_visual_statement] = STATE(2440),
    [sym_view_statement] = STATE(2440),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [anon_sym_BSLASH_PIPE] = ACTIONS(641),
    [aux_sym__map_rhs_statement_token2] = ACTIONS(641),
    [aux_sym__map_rhs_statement_token3] = ACTIONS(641),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_au_once] = ACTIONS(507),
    [sym_au_nested] = ACTIONS(509),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(32)] = {
    [sym__statement] = STATE(2440),
    [sym_unknown_builtin_statement] = STATE(2440),
    [sym_return_statement] = STATE(2440),
    [sym_break_statement] = STATE(2440),
    [sym_continue_statement] = STATE(2440),
    [sym_normal_statement] = STATE(2440),
    [sym_setfiletype_statement] = STATE(2440),
    [sym_options_statement] = STATE(2440),
    [sym_startinsert_statement] = STATE(2440),
    [sym_stopinsert_statement] = STATE(2440),
    [sym_scriptencoding_statement] = STATE(2440),
    [sym_cnext_statement] = STATE(2440),
    [sym_cprevious_statement] = STATE(2440),
    [sym_runtime_statement] = STATE(2440),
    [sym_wincmd_statement] = STATE(2440),
    [sym_source_statement] = STATE(2440),
    [sym_global_statement] = STATE(2440),
    [sym_filetype_statement] = STATE(2440),
    [sym_colorscheme_statement] = STATE(2440),
    [sym_lua_statement] = STATE(2440),
    [sym_ruby_statement] = STATE(2440),
    [sym_python_statement] = STATE(2440),
    [sym_perl_statement] = STATE(2440),
    [sym_for_loop] = STATE(2440),
    [sym_while_loop] = STATE(2440),
    [sym_if_statement] = STATE(2440),
    [sym_try_statement] = STATE(2440),
    [sym_throw_statement] = STATE(2440),
    [sym_bang_filter_statement] = STATE(2440),
    [sym_let_statement] = STATE(2440),
    [sym_const_statement] = STATE(2440),
    [sym_set_statement] = STATE(2440),
    [sym_setlocal_statement] = STATE(2440),
    [sym_unlet_statement] = STATE(2440),
    [sym_call_statement] = STATE(2440),
    [sym_echo_statement] = STATE(2440),
    [sym_echon_statement] = STATE(2440),
    [sym_echohl_statement] = STATE(2440),
    [sym_echomsg_statement] = STATE(2440),
    [sym_echoerr_statement] = STATE(2440),
    [sym_execute_statement] = STATE(2440),
    [sym_silent_statement] = STATE(2440),
    [sym_tab_statement] = STATE(2440),
    [sym_vertical_statement] = STATE(2440),
    [sym_topleft_statement] = STATE(2440),
    [sym_botright_statement] = STATE(2440),
    [sym_aboveleft_statement] = STATE(2440),
    [sym_belowright_statement] = STATE(2440),
    [sym_user_command] = STATE(2440),
    [sym_shebang] = STATE(2440),
    [sym_function_definition] = STATE(2440),
    [sym_range_statement] = STATE(2440),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2440),
    [sym_map_statement] = STATE(2440),
    [sym_sign_statement] = STATE(2440),
    [sym_eval_statement] = STATE(2440),
    [sym_substitute_statement] = STATE(2440),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2440),
    [sym_augroup_statement] = STATE(2440),
    [sym_command_statement] = STATE(2440),
    [sym_comclear_statement] = STATE(2440),
    [sym_delcommand_statement] = STATE(2440),
    [sym_highlight_statement] = STATE(2440),
    [sym_syntax_statement] = STATE(2440),
    [sym_edit_statement] = STATE(2440),
    [sym_enew_statement] = STATE(2440),
    [sym_find_statement] = STATE(2440),
    [sym_ex_statement] = STATE(2440),
    [sym_visual_statement] = STATE(2440),
    [sym_view_statement] = STATE(2440),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [anon_sym_BSLASH_PIPE] = ACTIONS(643),
    [aux_sym__map_rhs_statement_token2] = ACTIONS(643),
    [aux_sym__map_rhs_statement_token3] = ACTIONS(643),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_au_once] = ACTIONS(507),
    [sym_au_nested] = ACTIONS(509),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(33)] = {
    [sym__cmd_separator] = STATE(118),
    [aux_sym__separated_statements] = STATE(37),
    [sym__statement] = STATE(2554),
    [sym_unknown_builtin_statement] = STATE(2554),
    [sym_return_statement] = STATE(2554),
    [sym_break_statement] = STATE(2554),
    [sym_continue_statement] = STATE(2554),
    [sym_normal_statement] = STATE(2554),
    [sym_setfiletype_statement] = STATE(2554),
    [sym_options_statement] = STATE(2554),
    [sym_startinsert_statement] = STATE(2554),
    [sym_stopinsert_statement] = STATE(2554),
    [sym_scriptencoding_statement] = STATE(2554),
    [sym_cnext_statement] = STATE(2554),
    [sym_cprevious_statement] = STATE(2554),
    [sym_runtime_statement] = STATE(2554),
    [sym_wincmd_statement] = STATE(2554),
    [sym_source_statement] = STATE(2554),
    [sym_global_statement] = STATE(2554),
    [sym_filetype_statement] = STATE(2554),
    [sym_colorscheme_statement] = STATE(2554),
    [sym_lua_statement] = STATE(2554),
    [sym_ruby_statement] = STATE(2554),
    [sym_python_statement] = STATE(2554),
    [sym_perl_statement] = STATE(2554),
    [sym_for_loop] = STATE(2554),
    [sym_while_loop] = STATE(2554),
    [sym_if_statement] = STATE(2554),
    [sym_try_statement] = STATE(2554),
    [sym_throw_statement] = STATE(2554),
    [sym_bang_filter_statement] = STATE(2554),
    [sym_let_statement] = STATE(2554),
    [sym_const_statement] = STATE(2554),
    [sym_set_statement] = STATE(2554),
    [sym_setlocal_statement] = STATE(2554),
    [sym_unlet_statement] = STATE(2554),
    [sym_call_statement] = STATE(2554),
    [sym_echo_statement] = STATE(2554),
    [sym_echon_statement] = STATE(2554),
    [sym_echohl_statement] = STATE(2554),
    [sym_echomsg_statement] = STATE(2554),
    [sym_echoerr_statement] = STATE(2554),
    [sym_execute_statement] = STATE(2554),
    [sym_silent_statement] = STATE(2554),
    [sym_tab_statement] = STATE(2554),
    [sym_vertical_statement] = STATE(2554),
    [sym_topleft_statement] = STATE(2554),
    [sym_botright_statement] = STATE(2554),
    [sym_aboveleft_statement] = STATE(2554),
    [sym_belowright_statement] = STATE(2554),
    [sym_user_command] = STATE(2554),
    [sym_shebang] = STATE(2554),
    [sym_function_definition] = STATE(2554),
    [sym_range_statement] = STATE(2554),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2554),
    [sym_map_statement] = STATE(2554),
    [sym_sign_statement] = STATE(2554),
    [sym_eval_statement] = STATE(2554),
    [sym_substitute_statement] = STATE(2554),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2554),
    [sym_augroup_statement] = STATE(2554),
    [sym_command_statement] = STATE(2554),
    [sym_comclear_statement] = STATE(2554),
    [sym_delcommand_statement] = STATE(2554),
    [sym_highlight_statement] = STATE(2554),
    [sym_syntax_statement] = STATE(2554),
    [sym_edit_statement] = STATE(2554),
    [sym_enew_statement] = STATE(2554),
    [sym_find_statement] = STATE(2554),
    [sym_ex_statement] = STATE(2554),
    [sym_visual_statement] = STATE(2554),
    [sym_view_statement] = STATE(2554),
    [aux_sym__statement_repeat1] = STATE(94),
    [ts_builtin_sym_end] = ACTIONS(645),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(35),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(35),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(34)] = {
    [sym__cmd_separator] = STATE(114),
    [aux_sym__separated_statements] = STATE(23),
    [sym__statement] = STATE(2693),
    [sym_unknown_builtin_statement] = STATE(2693),
    [sym_return_statement] = STATE(2693),
    [sym_break_statement] = STATE(2693),
    [sym_continue_statement] = STATE(2693),
    [sym_normal_statement] = STATE(2693),
    [sym_setfiletype_statement] = STATE(2693),
    [sym_options_statement] = STATE(2693),
    [sym_startinsert_statement] = STATE(2693),
    [sym_stopinsert_statement] = STATE(2693),
    [sym_scriptencoding_statement] = STATE(2693),
    [sym_cnext_statement] = STATE(2693),
    [sym_cprevious_statement] = STATE(2693),
    [sym_runtime_statement] = STATE(2693),
    [sym_wincmd_statement] = STATE(2693),
    [sym_source_statement] = STATE(2693),
    [sym_global_statement] = STATE(2693),
    [sym_filetype_statement] = STATE(2693),
    [sym_colorscheme_statement] = STATE(2693),
    [sym_lua_statement] = STATE(2693),
    [sym_ruby_statement] = STATE(2693),
    [sym_python_statement] = STATE(2693),
    [sym_perl_statement] = STATE(2693),
    [sym_for_loop] = STATE(2693),
    [sym_while_loop] = STATE(2693),
    [sym_if_statement] = STATE(2693),
    [sym_try_statement] = STATE(2693),
    [sym_throw_statement] = STATE(2693),
    [sym_bang_filter_statement] = STATE(2693),
    [sym_let_statement] = STATE(2693),
    [sym_const_statement] = STATE(2693),
    [sym_set_statement] = STATE(2693),
    [sym_setlocal_statement] = STATE(2693),
    [sym_unlet_statement] = STATE(2693),
    [sym_call_statement] = STATE(2693),
    [sym_echo_statement] = STATE(2693),
    [sym_echon_statement] = STATE(2693),
    [sym_echohl_statement] = STATE(2693),
    [sym_echomsg_statement] = STATE(2693),
    [sym_echoerr_statement] = STATE(2693),
    [sym_execute_statement] = STATE(2693),
    [sym_silent_statement] = STATE(2693),
    [sym_tab_statement] = STATE(2693),
    [sym_vertical_statement] = STATE(2693),
    [sym_topleft_statement] = STATE(2693),
    [sym_botright_statement] = STATE(2693),
    [sym_aboveleft_statement] = STATE(2693),
    [sym_belowright_statement] = STATE(2693),
    [sym_user_command] = STATE(2693),
    [sym_shebang] = STATE(2693),
    [sym_function_definition] = STATE(2693),
    [sym_range_statement] = STATE(2693),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2693),
    [sym_map_statement] = STATE(2693),
    [sym_sign_statement] = STATE(2693),
    [sym_eval_statement] = STATE(2693),
    [sym_substitute_statement] = STATE(2693),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2693),
    [sym_augroup_statement] = STATE(2693),
    [sym_command_statement] = STATE(2693),
    [sym_comclear_statement] = STATE(2693),
    [sym_delcommand_statement] = STATE(2693),
    [sym_highlight_statement] = STATE(2693),
    [sym_syntax_statement] = STATE(2693),
    [sym_edit_statement] = STATE(2693),
    [sym_enew_statement] = STATE(2693),
    [sym_find_statement] = STATE(2693),
    [sym_ex_statement] = STATE(2693),
    [sym_visual_statement] = STATE(2693),
    [sym_view_statement] = STATE(2693),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(461),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(461),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__endif] = ACTIONS(647),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(35)] = {
    [sym__cmd_separator] = STATE(109),
    [aux_sym__separated_statements] = STATE(35),
    [sym__statement] = STATE(2372),
    [sym_unknown_builtin_statement] = STATE(2372),
    [sym_return_statement] = STATE(2372),
    [sym_break_statement] = STATE(2372),
    [sym_continue_statement] = STATE(2372),
    [sym_normal_statement] = STATE(2372),
    [sym_setfiletype_statement] = STATE(2372),
    [sym_options_statement] = STATE(2372),
    [sym_startinsert_statement] = STATE(2372),
    [sym_stopinsert_statement] = STATE(2372),
    [sym_scriptencoding_statement] = STATE(2372),
    [sym_cnext_statement] = STATE(2372),
    [sym_cprevious_statement] = STATE(2372),
    [sym_runtime_statement] = STATE(2372),
    [sym_wincmd_statement] = STATE(2372),
    [sym_source_statement] = STATE(2372),
    [sym_global_statement] = STATE(2372),
    [sym_filetype_statement] = STATE(2372),
    [sym_colorscheme_statement] = STATE(2372),
    [sym_lua_statement] = STATE(2372),
    [sym_ruby_statement] = STATE(2372),
    [sym_python_statement] = STATE(2372),
    [sym_perl_statement] = STATE(2372),
    [sym_for_loop] = STATE(2372),
    [sym_while_loop] = STATE(2372),
    [sym_if_statement] = STATE(2372),
    [sym_try_statement] = STATE(2372),
    [sym_throw_statement] = STATE(2372),
    [sym_bang_filter_statement] = STATE(2372),
    [sym_let_statement] = STATE(2372),
    [sym_const_statement] = STATE(2372),
    [sym_set_statement] = STATE(2372),
    [sym_setlocal_statement] = STATE(2372),
    [sym_unlet_statement] = STATE(2372),
    [sym_call_statement] = STATE(2372),
    [sym_echo_statement] = STATE(2372),
    [sym_echon_statement] = STATE(2372),
    [sym_echohl_statement] = STATE(2372),
    [sym_echomsg_statement] = STATE(2372),
    [sym_echoerr_statement] = STATE(2372),
    [sym_execute_statement] = STATE(2372),
    [sym_silent_statement] = STATE(2372),
    [sym_tab_statement] = STATE(2372),
    [sym_vertical_statement] = STATE(2372),
    [sym_topleft_statement] = STATE(2372),
    [sym_botright_statement] = STATE(2372),
    [sym_aboveleft_statement] = STATE(2372),
    [sym_belowright_statement] = STATE(2372),
    [sym_user_command] = STATE(2372),
    [sym_shebang] = STATE(2372),
    [sym_function_definition] = STATE(2372),
    [sym_range_statement] = STATE(2372),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2372),
    [sym_map_statement] = STATE(2372),
    [sym_sign_statement] = STATE(2372),
    [sym_eval_statement] = STATE(2372),
    [sym_substitute_statement] = STATE(2372),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2372),
    [sym_augroup_statement] = STATE(2372),
    [sym_command_statement] = STATE(2372),
    [sym_comclear_statement] = STATE(2372),
    [sym_delcommand_statement] = STATE(2372),
    [sym_highlight_statement] = STATE(2372),
    [sym_syntax_statement] = STATE(2372),
    [sym_edit_statement] = STATE(2372),
    [sym_enew_statement] = STATE(2372),
    [sym_find_statement] = STATE(2372),
    [sym_ex_statement] = STATE(2372),
    [sym_visual_statement] = STATE(2372),
    [sym_view_statement] = STATE(2372),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(203),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_QMARK] = ACTIONS(209),
    [anon_sym_POUND_BANG] = ACTIONS(212),
    [sym_mark] = ACTIONS(215),
    [anon_sym_PERCENT] = ACTIONS(218),
    [anon_sym_SLASH] = ACTIONS(221),
    [anon_sym_DOT2] = ACTIONS(224),
    [anon_sym_PLUS] = ACTIONS(227),
    [anon_sym_DOLLAR] = ACTIONS(230),
    [anon_sym_BSLASH_SLASH] = ACTIONS(233),
    [anon_sym_BSLASH_QMARK] = ACTIONS(233),
    [anon_sym_BSLASH_AMP] = ACTIONS(233),
    [sym_integer_literal] = ACTIONS(236),
    [sym_register] = ACTIONS(239),
    [sym_command_name] = ACTIONS(242),
    [sym__newline_or_pipe] = ACTIONS(649),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(649),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(248),
    [sym__endfunction] = ACTIONS(260),
    [sym__for] = ACTIONS(251),
    [sym__while] = ACTIONS(254),
    [sym__if] = ACTIONS(257),
    [sym__try] = ACTIONS(262),
    [sym__cnext] = ACTIONS(265),
    [sym__cprevious] = ACTIONS(268),
    [sym__cNext] = ACTIONS(268),
    [sym__const] = ACTIONS(271),
    [sym__normal] = ACTIONS(274),
    [sym__return] = ACTIONS(277),
    [sym__perl] = ACTIONS(280),
    [sym__lua] = ACTIONS(206),
    [sym__ruby] = ACTIONS(283),
    [sym__python] = ACTIONS(286),
    [sym__throw] = ACTIONS(289),
    [sym__execute] = ACTIONS(292),
    [sym__autocmd] = ACTIONS(295),
    [sym__silent] = ACTIONS(298),
    [sym__echo] = ACTIONS(301),
    [sym__echon] = ACTIONS(304),
    [sym__echohl] = ACTIONS(307),
    [sym__echomsg] = ACTIONS(310),
    [sym__echoerr] = ACTIONS(313),
    [sym__map] = ACTIONS(316),
    [sym__nmap] = ACTIONS(316),
    [sym__vmap] = ACTIONS(316),
    [sym__xmap] = ACTIONS(316),
    [sym__smap] = ACTIONS(316),
    [sym__omap] = ACTIONS(316),
    [sym__imap] = ACTIONS(316),
    [sym__lmap] = ACTIONS(316),
    [sym__cmap] = ACTIONS(316),
    [sym__tmap] = ACTIONS(316),
    [sym__noremap] = ACTIONS(316),
    [sym__nnoremap] = ACTIONS(316),
    [sym__vnoremap] = ACTIONS(316),
    [sym__xnoremap] = ACTIONS(316),
    [sym__snoremap] = ACTIONS(316),
    [sym__onoremap] = ACTIONS(316),
    [sym__inoremap] = ACTIONS(316),
    [sym__lnoremap] = ACTIONS(316),
    [sym__cnoremap] = ACTIONS(316),
    [sym__tnoremap] = ACTIONS(316),
    [sym__augroup] = ACTIONS(319),
    [sym__highlight] = ACTIONS(322),
    [sym__syntax] = ACTIONS(325),
    [sym__set] = ACTIONS(328),
    [sym__setlocal] = ACTIONS(331),
    [sym__setfiletype] = ACTIONS(334),
    [sym__browse] = ACTIONS(337),
    [sym__options] = ACTIONS(340),
    [sym__startinsert] = ACTIONS(343),
    [sym__stopinsert] = ACTIONS(346),
    [sym__scriptencoding] = ACTIONS(349),
    [sym__source] = ACTIONS(352),
    [sym__global] = ACTIONS(355),
    [sym__colorscheme] = ACTIONS(358),
    [sym__command] = ACTIONS(361),
    [sym__comclear] = ACTIONS(364),
    [sym__delcommand] = ACTIONS(367),
    [sym__runtime] = ACTIONS(370),
    [sym__wincmd] = ACTIONS(373),
    [sym__sign] = ACTIONS(376),
    [sym__filetype] = ACTIONS(379),
    [sym__let] = ACTIONS(382),
    [sym__unlet] = ACTIONS(385),
    [sym__call] = ACTIONS(388),
    [sym__break] = ACTIONS(391),
    [sym__continue] = ACTIONS(394),
    [sym__tab] = ACTIONS(397),
    [sym__vertical] = ACTIONS(400),
    [sym__leftabove] = ACTIONS(403),
    [sym__aboveleft] = ACTIONS(403),
    [sym__rightbelow] = ACTIONS(406),
    [sym__belowright] = ACTIONS(406),
    [sym__topleft] = ACTIONS(409),
    [sym__botright] = ACTIONS(412),
    [sym__edit] = ACTIONS(415),
    [sym__enew] = ACTIONS(418),
    [sym__find] = ACTIONS(421),
    [sym__ex] = ACTIONS(424),
    [sym__visual] = ACTIONS(427),
    [sym__view] = ACTIONS(430),
    [sym__eval] = ACTIONS(433),
    [sym__substitute] = ACTIONS(436),
    [sym_unknown_command_name] = ACTIONS(439),
  },
  [STATE(36)] = {
    [sym__cmd_separator] = STATE(119),
    [aux_sym__separated_statements] = STATE(36),
    [sym__statement] = STATE(2446),
    [sym_unknown_builtin_statement] = STATE(2446),
    [sym_return_statement] = STATE(2446),
    [sym_break_statement] = STATE(2446),
    [sym_continue_statement] = STATE(2446),
    [sym_normal_statement] = STATE(2446),
    [sym_setfiletype_statement] = STATE(2446),
    [sym_options_statement] = STATE(2446),
    [sym_startinsert_statement] = STATE(2446),
    [sym_stopinsert_statement] = STATE(2446),
    [sym_scriptencoding_statement] = STATE(2446),
    [sym_cnext_statement] = STATE(2446),
    [sym_cprevious_statement] = STATE(2446),
    [sym_runtime_statement] = STATE(2446),
    [sym_wincmd_statement] = STATE(2446),
    [sym_source_statement] = STATE(2446),
    [sym_global_statement] = STATE(2446),
    [sym_filetype_statement] = STATE(2446),
    [sym_colorscheme_statement] = STATE(2446),
    [sym_lua_statement] = STATE(2446),
    [sym_ruby_statement] = STATE(2446),
    [sym_python_statement] = STATE(2446),
    [sym_perl_statement] = STATE(2446),
    [sym_for_loop] = STATE(2446),
    [sym_while_loop] = STATE(2446),
    [sym_if_statement] = STATE(2446),
    [sym_try_statement] = STATE(2446),
    [sym_throw_statement] = STATE(2446),
    [sym_bang_filter_statement] = STATE(2446),
    [sym_let_statement] = STATE(2446),
    [sym_const_statement] = STATE(2446),
    [sym_set_statement] = STATE(2446),
    [sym_setlocal_statement] = STATE(2446),
    [sym_unlet_statement] = STATE(2446),
    [sym_call_statement] = STATE(2446),
    [sym_echo_statement] = STATE(2446),
    [sym_echon_statement] = STATE(2446),
    [sym_echohl_statement] = STATE(2446),
    [sym_echomsg_statement] = STATE(2446),
    [sym_echoerr_statement] = STATE(2446),
    [sym_execute_statement] = STATE(2446),
    [sym_silent_statement] = STATE(2446),
    [sym_tab_statement] = STATE(2446),
    [sym_vertical_statement] = STATE(2446),
    [sym_topleft_statement] = STATE(2446),
    [sym_botright_statement] = STATE(2446),
    [sym_aboveleft_statement] = STATE(2446),
    [sym_belowright_statement] = STATE(2446),
    [sym_user_command] = STATE(2446),
    [sym_shebang] = STATE(2446),
    [sym_function_definition] = STATE(2446),
    [sym_range_statement] = STATE(2446),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2446),
    [sym_map_statement] = STATE(2446),
    [sym_sign_statement] = STATE(2446),
    [sym_eval_statement] = STATE(2446),
    [sym_substitute_statement] = STATE(2446),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2446),
    [sym_augroup_statement] = STATE(2446),
    [sym_command_statement] = STATE(2446),
    [sym_comclear_statement] = STATE(2446),
    [sym_delcommand_statement] = STATE(2446),
    [sym_highlight_statement] = STATE(2446),
    [sym_syntax_statement] = STATE(2446),
    [sym_edit_statement] = STATE(2446),
    [sym_enew_statement] = STATE(2446),
    [sym_find_statement] = STATE(2446),
    [sym_ex_statement] = STATE(2446),
    [sym_visual_statement] = STATE(2446),
    [sym_view_statement] = STATE(2446),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(203),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_QMARK] = ACTIONS(209),
    [anon_sym_POUND_BANG] = ACTIONS(212),
    [sym_mark] = ACTIONS(215),
    [anon_sym_PERCENT] = ACTIONS(218),
    [anon_sym_SLASH] = ACTIONS(221),
    [anon_sym_DOT2] = ACTIONS(224),
    [anon_sym_PLUS] = ACTIONS(227),
    [anon_sym_DOLLAR] = ACTIONS(230),
    [anon_sym_BSLASH_SLASH] = ACTIONS(233),
    [anon_sym_BSLASH_QMARK] = ACTIONS(233),
    [anon_sym_BSLASH_AMP] = ACTIONS(233),
    [sym_integer_literal] = ACTIONS(236),
    [sym_register] = ACTIONS(239),
    [sym_command_name] = ACTIONS(242),
    [sym__newline_or_pipe] = ACTIONS(652),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(652),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(248),
    [sym__for] = ACTIONS(251),
    [sym__while] = ACTIONS(254),
    [sym__endwhile] = ACTIONS(260),
    [sym__if] = ACTIONS(257),
    [sym__try] = ACTIONS(262),
    [sym__cnext] = ACTIONS(265),
    [sym__cprevious] = ACTIONS(268),
    [sym__cNext] = ACTIONS(268),
    [sym__const] = ACTIONS(271),
    [sym__normal] = ACTIONS(274),
    [sym__return] = ACTIONS(277),
    [sym__perl] = ACTIONS(280),
    [sym__lua] = ACTIONS(206),
    [sym__ruby] = ACTIONS(283),
    [sym__python] = ACTIONS(286),
    [sym__throw] = ACTIONS(289),
    [sym__execute] = ACTIONS(292),
    [sym__autocmd] = ACTIONS(295),
    [sym__silent] = ACTIONS(298),
    [sym__echo] = ACTIONS(301),
    [sym__echon] = ACTIONS(304),
    [sym__echohl] = ACTIONS(307),
    [sym__echomsg] = ACTIONS(310),
    [sym__echoerr] = ACTIONS(313),
    [sym__map] = ACTIONS(316),
    [sym__nmap] = ACTIONS(316),
    [sym__vmap] = ACTIONS(316),
    [sym__xmap] = ACTIONS(316),
    [sym__smap] = ACTIONS(316),
    [sym__omap] = ACTIONS(316),
    [sym__imap] = ACTIONS(316),
    [sym__lmap] = ACTIONS(316),
    [sym__cmap] = ACTIONS(316),
    [sym__tmap] = ACTIONS(316),
    [sym__noremap] = ACTIONS(316),
    [sym__nnoremap] = ACTIONS(316),
    [sym__vnoremap] = ACTIONS(316),
    [sym__xnoremap] = ACTIONS(316),
    [sym__snoremap] = ACTIONS(316),
    [sym__onoremap] = ACTIONS(316),
    [sym__inoremap] = ACTIONS(316),
    [sym__lnoremap] = ACTIONS(316),
    [sym__cnoremap] = ACTIONS(316),
    [sym__tnoremap] = ACTIONS(316),
    [sym__augroup] = ACTIONS(319),
    [sym__highlight] = ACTIONS(322),
    [sym__syntax] = ACTIONS(325),
    [sym__set] = ACTIONS(328),
    [sym__setlocal] = ACTIONS(331),
    [sym__setfiletype] = ACTIONS(334),
    [sym__browse] = ACTIONS(337),
    [sym__options] = ACTIONS(340),
    [sym__startinsert] = ACTIONS(343),
    [sym__stopinsert] = ACTIONS(346),
    [sym__scriptencoding] = ACTIONS(349),
    [sym__source] = ACTIONS(352),
    [sym__global] = ACTIONS(355),
    [sym__colorscheme] = ACTIONS(358),
    [sym__command] = ACTIONS(361),
    [sym__comclear] = ACTIONS(364),
    [sym__delcommand] = ACTIONS(367),
    [sym__runtime] = ACTIONS(370),
    [sym__wincmd] = ACTIONS(373),
    [sym__sign] = ACTIONS(376),
    [sym__filetype] = ACTIONS(379),
    [sym__let] = ACTIONS(382),
    [sym__unlet] = ACTIONS(385),
    [sym__call] = ACTIONS(388),
    [sym__break] = ACTIONS(391),
    [sym__continue] = ACTIONS(394),
    [sym__tab] = ACTIONS(397),
    [sym__vertical] = ACTIONS(400),
    [sym__leftabove] = ACTIONS(403),
    [sym__aboveleft] = ACTIONS(403),
    [sym__rightbelow] = ACTIONS(406),
    [sym__belowright] = ACTIONS(406),
    [sym__topleft] = ACTIONS(409),
    [sym__botright] = ACTIONS(412),
    [sym__edit] = ACTIONS(415),
    [sym__enew] = ACTIONS(418),
    [sym__find] = ACTIONS(421),
    [sym__ex] = ACTIONS(424),
    [sym__visual] = ACTIONS(427),
    [sym__view] = ACTIONS(430),
    [sym__eval] = ACTIONS(433),
    [sym__substitute] = ACTIONS(436),
    [sym_unknown_command_name] = ACTIONS(439),
  },
  [STATE(37)] = {
    [sym__cmd_separator] = STATE(118),
    [aux_sym__separated_statements] = STATE(37),
    [sym__statement] = STATE(2554),
    [sym_unknown_builtin_statement] = STATE(2554),
    [sym_return_statement] = STATE(2554),
    [sym_break_statement] = STATE(2554),
    [sym_continue_statement] = STATE(2554),
    [sym_normal_statement] = STATE(2554),
    [sym_setfiletype_statement] = STATE(2554),
    [sym_options_statement] = STATE(2554),
    [sym_startinsert_statement] = STATE(2554),
    [sym_stopinsert_statement] = STATE(2554),
    [sym_scriptencoding_statement] = STATE(2554),
    [sym_cnext_statement] = STATE(2554),
    [sym_cprevious_statement] = STATE(2554),
    [sym_runtime_statement] = STATE(2554),
    [sym_wincmd_statement] = STATE(2554),
    [sym_source_statement] = STATE(2554),
    [sym_global_statement] = STATE(2554),
    [sym_filetype_statement] = STATE(2554),
    [sym_colorscheme_statement] = STATE(2554),
    [sym_lua_statement] = STATE(2554),
    [sym_ruby_statement] = STATE(2554),
    [sym_python_statement] = STATE(2554),
    [sym_perl_statement] = STATE(2554),
    [sym_for_loop] = STATE(2554),
    [sym_while_loop] = STATE(2554),
    [sym_if_statement] = STATE(2554),
    [sym_try_statement] = STATE(2554),
    [sym_throw_statement] = STATE(2554),
    [sym_bang_filter_statement] = STATE(2554),
    [sym_let_statement] = STATE(2554),
    [sym_const_statement] = STATE(2554),
    [sym_set_statement] = STATE(2554),
    [sym_setlocal_statement] = STATE(2554),
    [sym_unlet_statement] = STATE(2554),
    [sym_call_statement] = STATE(2554),
    [sym_echo_statement] = STATE(2554),
    [sym_echon_statement] = STATE(2554),
    [sym_echohl_statement] = STATE(2554),
    [sym_echomsg_statement] = STATE(2554),
    [sym_echoerr_statement] = STATE(2554),
    [sym_execute_statement] = STATE(2554),
    [sym_silent_statement] = STATE(2554),
    [sym_tab_statement] = STATE(2554),
    [sym_vertical_statement] = STATE(2554),
    [sym_topleft_statement] = STATE(2554),
    [sym_botright_statement] = STATE(2554),
    [sym_aboveleft_statement] = STATE(2554),
    [sym_belowright_statement] = STATE(2554),
    [sym_user_command] = STATE(2554),
    [sym_shebang] = STATE(2554),
    [sym_function_definition] = STATE(2554),
    [sym_range_statement] = STATE(2554),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2554),
    [sym_map_statement] = STATE(2554),
    [sym_sign_statement] = STATE(2554),
    [sym_eval_statement] = STATE(2554),
    [sym_substitute_statement] = STATE(2554),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2554),
    [sym_augroup_statement] = STATE(2554),
    [sym_command_statement] = STATE(2554),
    [sym_comclear_statement] = STATE(2554),
    [sym_delcommand_statement] = STATE(2554),
    [sym_highlight_statement] = STATE(2554),
    [sym_syntax_statement] = STATE(2554),
    [sym_edit_statement] = STATE(2554),
    [sym_enew_statement] = STATE(2554),
    [sym_find_statement] = STATE(2554),
    [sym_ex_statement] = STATE(2554),
    [sym_visual_statement] = STATE(2554),
    [sym_view_statement] = STATE(2554),
    [aux_sym__statement_repeat1] = STATE(94),
    [ts_builtin_sym_end] = ACTIONS(260),
    [anon_sym_COLON] = ACTIONS(203),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_QMARK] = ACTIONS(209),
    [anon_sym_POUND_BANG] = ACTIONS(212),
    [sym_mark] = ACTIONS(215),
    [anon_sym_PERCENT] = ACTIONS(218),
    [anon_sym_SLASH] = ACTIONS(221),
    [anon_sym_DOT2] = ACTIONS(224),
    [anon_sym_PLUS] = ACTIONS(227),
    [anon_sym_DOLLAR] = ACTIONS(230),
    [anon_sym_BSLASH_SLASH] = ACTIONS(233),
    [anon_sym_BSLASH_QMARK] = ACTIONS(233),
    [anon_sym_BSLASH_AMP] = ACTIONS(233),
    [sym_integer_literal] = ACTIONS(236),
    [sym_register] = ACTIONS(239),
    [sym_command_name] = ACTIONS(242),
    [sym__newline_or_pipe] = ACTIONS(655),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(655),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(248),
    [sym__for] = ACTIONS(251),
    [sym__while] = ACTIONS(254),
    [sym__if] = ACTIONS(257),
    [sym__try] = ACTIONS(262),
    [sym__cnext] = ACTIONS(265),
    [sym__cprevious] = ACTIONS(268),
    [sym__cNext] = ACTIONS(268),
    [sym__const] = ACTIONS(271),
    [sym__normal] = ACTIONS(274),
    [sym__return] = ACTIONS(277),
    [sym__perl] = ACTIONS(280),
    [sym__lua] = ACTIONS(206),
    [sym__ruby] = ACTIONS(283),
    [sym__python] = ACTIONS(286),
    [sym__throw] = ACTIONS(289),
    [sym__execute] = ACTIONS(292),
    [sym__autocmd] = ACTIONS(295),
    [sym__silent] = ACTIONS(298),
    [sym__echo] = ACTIONS(301),
    [sym__echon] = ACTIONS(304),
    [sym__echohl] = ACTIONS(307),
    [sym__echomsg] = ACTIONS(310),
    [sym__echoerr] = ACTIONS(313),
    [sym__map] = ACTIONS(316),
    [sym__nmap] = ACTIONS(316),
    [sym__vmap] = ACTIONS(316),
    [sym__xmap] = ACTIONS(316),
    [sym__smap] = ACTIONS(316),
    [sym__omap] = ACTIONS(316),
    [sym__imap] = ACTIONS(316),
    [sym__lmap] = ACTIONS(316),
    [sym__cmap] = ACTIONS(316),
    [sym__tmap] = ACTIONS(316),
    [sym__noremap] = ACTIONS(316),
    [sym__nnoremap] = ACTIONS(316),
    [sym__vnoremap] = ACTIONS(316),
    [sym__xnoremap] = ACTIONS(316),
    [sym__snoremap] = ACTIONS(316),
    [sym__onoremap] = ACTIONS(316),
    [sym__inoremap] = ACTIONS(316),
    [sym__lnoremap] = ACTIONS(316),
    [sym__cnoremap] = ACTIONS(316),
    [sym__tnoremap] = ACTIONS(316),
    [sym__augroup] = ACTIONS(319),
    [sym__highlight] = ACTIONS(322),
    [sym__syntax] = ACTIONS(325),
    [sym__set] = ACTIONS(328),
    [sym__setlocal] = ACTIONS(331),
    [sym__setfiletype] = ACTIONS(334),
    [sym__browse] = ACTIONS(337),
    [sym__options] = ACTIONS(340),
    [sym__startinsert] = ACTIONS(343),
    [sym__stopinsert] = ACTIONS(346),
    [sym__scriptencoding] = ACTIONS(349),
    [sym__source] = ACTIONS(352),
    [sym__global] = ACTIONS(355),
    [sym__colorscheme] = ACTIONS(358),
    [sym__command] = ACTIONS(361),
    [sym__comclear] = ACTIONS(364),
    [sym__delcommand] = ACTIONS(367),
    [sym__runtime] = ACTIONS(370),
    [sym__wincmd] = ACTIONS(373),
    [sym__sign] = ACTIONS(376),
    [sym__filetype] = ACTIONS(379),
    [sym__let] = ACTIONS(382),
    [sym__unlet] = ACTIONS(385),
    [sym__call] = ACTIONS(388),
    [sym__break] = ACTIONS(391),
    [sym__continue] = ACTIONS(394),
    [sym__tab] = ACTIONS(397),
    [sym__vertical] = ACTIONS(400),
    [sym__leftabove] = ACTIONS(403),
    [sym__aboveleft] = ACTIONS(403),
    [sym__rightbelow] = ACTIONS(406),
    [sym__belowright] = ACTIONS(406),
    [sym__topleft] = ACTIONS(409),
    [sym__botright] = ACTIONS(412),
    [sym__edit] = ACTIONS(415),
    [sym__enew] = ACTIONS(418),
    [sym__find] = ACTIONS(421),
    [sym__ex] = ACTIONS(424),
    [sym__visual] = ACTIONS(427),
    [sym__view] = ACTIONS(430),
    [sym__eval] = ACTIONS(433),
    [sym__substitute] = ACTIONS(436),
    [sym_unknown_command_name] = ACTIONS(439),
  },
  [STATE(38)] = {
    [sym__cmd_separator] = STATE(113),
    [aux_sym__separated_statements] = STATE(38),
    [sym__statement] = STATE(2657),
    [sym_unknown_builtin_statement] = STATE(2657),
    [sym_return_statement] = STATE(2657),
    [sym_break_statement] = STATE(2657),
    [sym_continue_statement] = STATE(2657),
    [sym_normal_statement] = STATE(2657),
    [sym_setfiletype_statement] = STATE(2657),
    [sym_options_statement] = STATE(2657),
    [sym_startinsert_statement] = STATE(2657),
    [sym_stopinsert_statement] = STATE(2657),
    [sym_scriptencoding_statement] = STATE(2657),
    [sym_cnext_statement] = STATE(2657),
    [sym_cprevious_statement] = STATE(2657),
    [sym_runtime_statement] = STATE(2657),
    [sym_wincmd_statement] = STATE(2657),
    [sym_source_statement] = STATE(2657),
    [sym_global_statement] = STATE(2657),
    [sym_filetype_statement] = STATE(2657),
    [sym_colorscheme_statement] = STATE(2657),
    [sym_lua_statement] = STATE(2657),
    [sym_ruby_statement] = STATE(2657),
    [sym_python_statement] = STATE(2657),
    [sym_perl_statement] = STATE(2657),
    [sym_for_loop] = STATE(2657),
    [sym_while_loop] = STATE(2657),
    [sym_if_statement] = STATE(2657),
    [sym_try_statement] = STATE(2657),
    [sym_throw_statement] = STATE(2657),
    [sym_bang_filter_statement] = STATE(2657),
    [sym_let_statement] = STATE(2657),
    [sym_const_statement] = STATE(2657),
    [sym_set_statement] = STATE(2657),
    [sym_setlocal_statement] = STATE(2657),
    [sym_unlet_statement] = STATE(2657),
    [sym_call_statement] = STATE(2657),
    [sym_echo_statement] = STATE(2657),
    [sym_echon_statement] = STATE(2657),
    [sym_echohl_statement] = STATE(2657),
    [sym_echomsg_statement] = STATE(2657),
    [sym_echoerr_statement] = STATE(2657),
    [sym_execute_statement] = STATE(2657),
    [sym_silent_statement] = STATE(2657),
    [sym_tab_statement] = STATE(2657),
    [sym_vertical_statement] = STATE(2657),
    [sym_topleft_statement] = STATE(2657),
    [sym_botright_statement] = STATE(2657),
    [sym_aboveleft_statement] = STATE(2657),
    [sym_belowright_statement] = STATE(2657),
    [sym_user_command] = STATE(2657),
    [sym_shebang] = STATE(2657),
    [sym_function_definition] = STATE(2657),
    [sym_range_statement] = STATE(2657),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2657),
    [sym_map_statement] = STATE(2657),
    [sym_sign_statement] = STATE(2657),
    [sym_eval_statement] = STATE(2657),
    [sym_substitute_statement] = STATE(2657),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2657),
    [sym_augroup_statement] = STATE(2657),
    [sym_command_statement] = STATE(2657),
    [sym_comclear_statement] = STATE(2657),
    [sym_delcommand_statement] = STATE(2657),
    [sym_highlight_statement] = STATE(2657),
    [sym_syntax_statement] = STATE(2657),
    [sym_edit_statement] = STATE(2657),
    [sym_enew_statement] = STATE(2657),
    [sym_find_statement] = STATE(2657),
    [sym_ex_statement] = STATE(2657),
    [sym_visual_statement] = STATE(2657),
    [sym_view_statement] = STATE(2657),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(203),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_QMARK] = ACTIONS(209),
    [anon_sym_POUND_BANG] = ACTIONS(212),
    [sym_mark] = ACTIONS(215),
    [anon_sym_PERCENT] = ACTIONS(218),
    [anon_sym_SLASH] = ACTIONS(221),
    [anon_sym_DOT2] = ACTIONS(224),
    [anon_sym_PLUS] = ACTIONS(227),
    [anon_sym_DOLLAR] = ACTIONS(230),
    [anon_sym_BSLASH_SLASH] = ACTIONS(233),
    [anon_sym_BSLASH_QMARK] = ACTIONS(233),
    [anon_sym_BSLASH_AMP] = ACTIONS(233),
    [sym_integer_literal] = ACTIONS(236),
    [sym_register] = ACTIONS(239),
    [sym_command_name] = ACTIONS(242),
    [sym__newline_or_pipe] = ACTIONS(658),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(658),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(248),
    [sym__for] = ACTIONS(251),
    [sym__while] = ACTIONS(254),
    [sym__if] = ACTIONS(257),
    [sym__try] = ACTIONS(262),
    [sym__cnext] = ACTIONS(265),
    [sym__cprevious] = ACTIONS(268),
    [sym__cNext] = ACTIONS(268),
    [sym__endtry] = ACTIONS(260),
    [sym__const] = ACTIONS(271),
    [sym__normal] = ACTIONS(274),
    [sym__return] = ACTIONS(277),
    [sym__perl] = ACTIONS(280),
    [sym__lua] = ACTIONS(206),
    [sym__ruby] = ACTIONS(283),
    [sym__python] = ACTIONS(286),
    [sym__throw] = ACTIONS(289),
    [sym__execute] = ACTIONS(292),
    [sym__autocmd] = ACTIONS(295),
    [sym__silent] = ACTIONS(298),
    [sym__echo] = ACTIONS(301),
    [sym__echon] = ACTIONS(304),
    [sym__echohl] = ACTIONS(307),
    [sym__echomsg] = ACTIONS(310),
    [sym__echoerr] = ACTIONS(313),
    [sym__map] = ACTIONS(316),
    [sym__nmap] = ACTIONS(316),
    [sym__vmap] = ACTIONS(316),
    [sym__xmap] = ACTIONS(316),
    [sym__smap] = ACTIONS(316),
    [sym__omap] = ACTIONS(316),
    [sym__imap] = ACTIONS(316),
    [sym__lmap] = ACTIONS(316),
    [sym__cmap] = ACTIONS(316),
    [sym__tmap] = ACTIONS(316),
    [sym__noremap] = ACTIONS(316),
    [sym__nnoremap] = ACTIONS(316),
    [sym__vnoremap] = ACTIONS(316),
    [sym__xnoremap] = ACTIONS(316),
    [sym__snoremap] = ACTIONS(316),
    [sym__onoremap] = ACTIONS(316),
    [sym__inoremap] = ACTIONS(316),
    [sym__lnoremap] = ACTIONS(316),
    [sym__cnoremap] = ACTIONS(316),
    [sym__tnoremap] = ACTIONS(316),
    [sym__augroup] = ACTIONS(319),
    [sym__highlight] = ACTIONS(322),
    [sym__syntax] = ACTIONS(325),
    [sym__set] = ACTIONS(328),
    [sym__setlocal] = ACTIONS(331),
    [sym__setfiletype] = ACTIONS(334),
    [sym__browse] = ACTIONS(337),
    [sym__options] = ACTIONS(340),
    [sym__startinsert] = ACTIONS(343),
    [sym__stopinsert] = ACTIONS(346),
    [sym__scriptencoding] = ACTIONS(349),
    [sym__source] = ACTIONS(352),
    [sym__global] = ACTIONS(355),
    [sym__colorscheme] = ACTIONS(358),
    [sym__command] = ACTIONS(361),
    [sym__comclear] = ACTIONS(364),
    [sym__delcommand] = ACTIONS(367),
    [sym__runtime] = ACTIONS(370),
    [sym__wincmd] = ACTIONS(373),
    [sym__sign] = ACTIONS(376),
    [sym__filetype] = ACTIONS(379),
    [sym__let] = ACTIONS(382),
    [sym__unlet] = ACTIONS(385),
    [sym__call] = ACTIONS(388),
    [sym__break] = ACTIONS(391),
    [sym__continue] = ACTIONS(394),
    [sym__tab] = ACTIONS(397),
    [sym__vertical] = ACTIONS(400),
    [sym__leftabove] = ACTIONS(403),
    [sym__aboveleft] = ACTIONS(403),
    [sym__rightbelow] = ACTIONS(406),
    [sym__belowright] = ACTIONS(406),
    [sym__topleft] = ACTIONS(409),
    [sym__botright] = ACTIONS(412),
    [sym__edit] = ACTIONS(415),
    [sym__enew] = ACTIONS(418),
    [sym__find] = ACTIONS(421),
    [sym__ex] = ACTIONS(424),
    [sym__visual] = ACTIONS(427),
    [sym__view] = ACTIONS(430),
    [sym__eval] = ACTIONS(433),
    [sym__substitute] = ACTIONS(436),
    [sym_unknown_command_name] = ACTIONS(439),
  },
  [STATE(39)] = {
    [sym__cmd_separator] = STATE(114),
    [aux_sym__separated_statements] = STATE(39),
    [sym__statement] = STATE(2693),
    [sym_unknown_builtin_statement] = STATE(2693),
    [sym_return_statement] = STATE(2693),
    [sym_break_statement] = STATE(2693),
    [sym_continue_statement] = STATE(2693),
    [sym_normal_statement] = STATE(2693),
    [sym_setfiletype_statement] = STATE(2693),
    [sym_options_statement] = STATE(2693),
    [sym_startinsert_statement] = STATE(2693),
    [sym_stopinsert_statement] = STATE(2693),
    [sym_scriptencoding_statement] = STATE(2693),
    [sym_cnext_statement] = STATE(2693),
    [sym_cprevious_statement] = STATE(2693),
    [sym_runtime_statement] = STATE(2693),
    [sym_wincmd_statement] = STATE(2693),
    [sym_source_statement] = STATE(2693),
    [sym_global_statement] = STATE(2693),
    [sym_filetype_statement] = STATE(2693),
    [sym_colorscheme_statement] = STATE(2693),
    [sym_lua_statement] = STATE(2693),
    [sym_ruby_statement] = STATE(2693),
    [sym_python_statement] = STATE(2693),
    [sym_perl_statement] = STATE(2693),
    [sym_for_loop] = STATE(2693),
    [sym_while_loop] = STATE(2693),
    [sym_if_statement] = STATE(2693),
    [sym_try_statement] = STATE(2693),
    [sym_throw_statement] = STATE(2693),
    [sym_bang_filter_statement] = STATE(2693),
    [sym_let_statement] = STATE(2693),
    [sym_const_statement] = STATE(2693),
    [sym_set_statement] = STATE(2693),
    [sym_setlocal_statement] = STATE(2693),
    [sym_unlet_statement] = STATE(2693),
    [sym_call_statement] = STATE(2693),
    [sym_echo_statement] = STATE(2693),
    [sym_echon_statement] = STATE(2693),
    [sym_echohl_statement] = STATE(2693),
    [sym_echomsg_statement] = STATE(2693),
    [sym_echoerr_statement] = STATE(2693),
    [sym_execute_statement] = STATE(2693),
    [sym_silent_statement] = STATE(2693),
    [sym_tab_statement] = STATE(2693),
    [sym_vertical_statement] = STATE(2693),
    [sym_topleft_statement] = STATE(2693),
    [sym_botright_statement] = STATE(2693),
    [sym_aboveleft_statement] = STATE(2693),
    [sym_belowright_statement] = STATE(2693),
    [sym_user_command] = STATE(2693),
    [sym_shebang] = STATE(2693),
    [sym_function_definition] = STATE(2693),
    [sym_range_statement] = STATE(2693),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2693),
    [sym_map_statement] = STATE(2693),
    [sym_sign_statement] = STATE(2693),
    [sym_eval_statement] = STATE(2693),
    [sym_substitute_statement] = STATE(2693),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2693),
    [sym_augroup_statement] = STATE(2693),
    [sym_command_statement] = STATE(2693),
    [sym_comclear_statement] = STATE(2693),
    [sym_delcommand_statement] = STATE(2693),
    [sym_highlight_statement] = STATE(2693),
    [sym_syntax_statement] = STATE(2693),
    [sym_edit_statement] = STATE(2693),
    [sym_enew_statement] = STATE(2693),
    [sym_find_statement] = STATE(2693),
    [sym_ex_statement] = STATE(2693),
    [sym_visual_statement] = STATE(2693),
    [sym_view_statement] = STATE(2693),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(203),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_QMARK] = ACTIONS(209),
    [anon_sym_POUND_BANG] = ACTIONS(212),
    [sym_mark] = ACTIONS(215),
    [anon_sym_PERCENT] = ACTIONS(218),
    [anon_sym_SLASH] = ACTIONS(221),
    [anon_sym_DOT2] = ACTIONS(224),
    [anon_sym_PLUS] = ACTIONS(227),
    [anon_sym_DOLLAR] = ACTIONS(230),
    [anon_sym_BSLASH_SLASH] = ACTIONS(233),
    [anon_sym_BSLASH_QMARK] = ACTIONS(233),
    [anon_sym_BSLASH_AMP] = ACTIONS(233),
    [sym_integer_literal] = ACTIONS(236),
    [sym_register] = ACTIONS(239),
    [sym_command_name] = ACTIONS(242),
    [sym__newline_or_pipe] = ACTIONS(661),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(661),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(248),
    [sym__for] = ACTIONS(251),
    [sym__while] = ACTIONS(254),
    [sym__if] = ACTIONS(257),
    [sym__endif] = ACTIONS(260),
    [sym__try] = ACTIONS(262),
    [sym__cnext] = ACTIONS(265),
    [sym__cprevious] = ACTIONS(268),
    [sym__cNext] = ACTIONS(268),
    [sym__const] = ACTIONS(271),
    [sym__normal] = ACTIONS(274),
    [sym__return] = ACTIONS(277),
    [sym__perl] = ACTIONS(280),
    [sym__lua] = ACTIONS(206),
    [sym__ruby] = ACTIONS(283),
    [sym__python] = ACTIONS(286),
    [sym__throw] = ACTIONS(289),
    [sym__execute] = ACTIONS(292),
    [sym__autocmd] = ACTIONS(295),
    [sym__silent] = ACTIONS(298),
    [sym__echo] = ACTIONS(301),
    [sym__echon] = ACTIONS(304),
    [sym__echohl] = ACTIONS(307),
    [sym__echomsg] = ACTIONS(310),
    [sym__echoerr] = ACTIONS(313),
    [sym__map] = ACTIONS(316),
    [sym__nmap] = ACTIONS(316),
    [sym__vmap] = ACTIONS(316),
    [sym__xmap] = ACTIONS(316),
    [sym__smap] = ACTIONS(316),
    [sym__omap] = ACTIONS(316),
    [sym__imap] = ACTIONS(316),
    [sym__lmap] = ACTIONS(316),
    [sym__cmap] = ACTIONS(316),
    [sym__tmap] = ACTIONS(316),
    [sym__noremap] = ACTIONS(316),
    [sym__nnoremap] = ACTIONS(316),
    [sym__vnoremap] = ACTIONS(316),
    [sym__xnoremap] = ACTIONS(316),
    [sym__snoremap] = ACTIONS(316),
    [sym__onoremap] = ACTIONS(316),
    [sym__inoremap] = ACTIONS(316),
    [sym__lnoremap] = ACTIONS(316),
    [sym__cnoremap] = ACTIONS(316),
    [sym__tnoremap] = ACTIONS(316),
    [sym__augroup] = ACTIONS(319),
    [sym__highlight] = ACTIONS(322),
    [sym__syntax] = ACTIONS(325),
    [sym__set] = ACTIONS(328),
    [sym__setlocal] = ACTIONS(331),
    [sym__setfiletype] = ACTIONS(334),
    [sym__browse] = ACTIONS(337),
    [sym__options] = ACTIONS(340),
    [sym__startinsert] = ACTIONS(343),
    [sym__stopinsert] = ACTIONS(346),
    [sym__scriptencoding] = ACTIONS(349),
    [sym__source] = ACTIONS(352),
    [sym__global] = ACTIONS(355),
    [sym__colorscheme] = ACTIONS(358),
    [sym__command] = ACTIONS(361),
    [sym__comclear] = ACTIONS(364),
    [sym__delcommand] = ACTIONS(367),
    [sym__runtime] = ACTIONS(370),
    [sym__wincmd] = ACTIONS(373),
    [sym__sign] = ACTIONS(376),
    [sym__filetype] = ACTIONS(379),
    [sym__let] = ACTIONS(382),
    [sym__unlet] = ACTIONS(385),
    [sym__call] = ACTIONS(388),
    [sym__break] = ACTIONS(391),
    [sym__continue] = ACTIONS(394),
    [sym__tab] = ACTIONS(397),
    [sym__vertical] = ACTIONS(400),
    [sym__leftabove] = ACTIONS(403),
    [sym__aboveleft] = ACTIONS(403),
    [sym__rightbelow] = ACTIONS(406),
    [sym__belowright] = ACTIONS(406),
    [sym__topleft] = ACTIONS(409),
    [sym__botright] = ACTIONS(412),
    [sym__edit] = ACTIONS(415),
    [sym__enew] = ACTIONS(418),
    [sym__find] = ACTIONS(421),
    [sym__ex] = ACTIONS(424),
    [sym__visual] = ACTIONS(427),
    [sym__view] = ACTIONS(430),
    [sym__eval] = ACTIONS(433),
    [sym__substitute] = ACTIONS(436),
    [sym_unknown_command_name] = ACTIONS(439),
  },
  [STATE(40)] = {
    [sym__cmd_separator] = STATE(116),
    [aux_sym__separated_statements] = STATE(40),
    [sym__statement] = STATE(2718),
    [sym_unknown_builtin_statement] = STATE(2718),
    [sym_return_statement] = STATE(2718),
    [sym_break_statement] = STATE(2718),
    [sym_continue_statement] = STATE(2718),
    [sym_normal_statement] = STATE(2718),
    [sym_setfiletype_statement] = STATE(2718),
    [sym_options_statement] = STATE(2718),
    [sym_startinsert_statement] = STATE(2718),
    [sym_stopinsert_statement] = STATE(2718),
    [sym_scriptencoding_statement] = STATE(2718),
    [sym_cnext_statement] = STATE(2718),
    [sym_cprevious_statement] = STATE(2718),
    [sym_runtime_statement] = STATE(2718),
    [sym_wincmd_statement] = STATE(2718),
    [sym_source_statement] = STATE(2718),
    [sym_global_statement] = STATE(2718),
    [sym_filetype_statement] = STATE(2718),
    [sym_colorscheme_statement] = STATE(2718),
    [sym_lua_statement] = STATE(2718),
    [sym_ruby_statement] = STATE(2718),
    [sym_python_statement] = STATE(2718),
    [sym_perl_statement] = STATE(2718),
    [sym_for_loop] = STATE(2718),
    [sym_while_loop] = STATE(2718),
    [sym_if_statement] = STATE(2718),
    [sym_try_statement] = STATE(2718),
    [sym_throw_statement] = STATE(2718),
    [sym_bang_filter_statement] = STATE(2718),
    [sym_let_statement] = STATE(2718),
    [sym_const_statement] = STATE(2718),
    [sym_set_statement] = STATE(2718),
    [sym_setlocal_statement] = STATE(2718),
    [sym_unlet_statement] = STATE(2718),
    [sym_call_statement] = STATE(2718),
    [sym_echo_statement] = STATE(2718),
    [sym_echon_statement] = STATE(2718),
    [sym_echohl_statement] = STATE(2718),
    [sym_echomsg_statement] = STATE(2718),
    [sym_echoerr_statement] = STATE(2718),
    [sym_execute_statement] = STATE(2718),
    [sym_silent_statement] = STATE(2718),
    [sym_tab_statement] = STATE(2718),
    [sym_vertical_statement] = STATE(2718),
    [sym_topleft_statement] = STATE(2718),
    [sym_botright_statement] = STATE(2718),
    [sym_aboveleft_statement] = STATE(2718),
    [sym_belowright_statement] = STATE(2718),
    [sym_user_command] = STATE(2718),
    [sym_shebang] = STATE(2718),
    [sym_function_definition] = STATE(2718),
    [sym_range_statement] = STATE(2718),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2718),
    [sym_map_statement] = STATE(2718),
    [sym_sign_statement] = STATE(2718),
    [sym_eval_statement] = STATE(2718),
    [sym_substitute_statement] = STATE(2718),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2718),
    [sym_augroup_statement] = STATE(2718),
    [sym_command_statement] = STATE(2718),
    [sym_comclear_statement] = STATE(2718),
    [sym_delcommand_statement] = STATE(2718),
    [sym_highlight_statement] = STATE(2718),
    [sym_syntax_statement] = STATE(2718),
    [sym_edit_statement] = STATE(2718),
    [sym_enew_statement] = STATE(2718),
    [sym_find_statement] = STATE(2718),
    [sym_ex_statement] = STATE(2718),
    [sym_visual_statement] = STATE(2718),
    [sym_view_statement] = STATE(2718),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(203),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_QMARK] = ACTIONS(209),
    [anon_sym_POUND_BANG] = ACTIONS(212),
    [sym_mark] = ACTIONS(215),
    [anon_sym_PERCENT] = ACTIONS(218),
    [anon_sym_SLASH] = ACTIONS(221),
    [anon_sym_DOT2] = ACTIONS(224),
    [anon_sym_PLUS] = ACTIONS(227),
    [anon_sym_DOLLAR] = ACTIONS(230),
    [anon_sym_BSLASH_SLASH] = ACTIONS(233),
    [anon_sym_BSLASH_QMARK] = ACTIONS(233),
    [anon_sym_BSLASH_AMP] = ACTIONS(233),
    [sym_integer_literal] = ACTIONS(236),
    [sym_register] = ACTIONS(239),
    [sym_command_name] = ACTIONS(242),
    [sym__newline_or_pipe] = ACTIONS(664),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(664),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(248),
    [sym__for] = ACTIONS(251),
    [sym__endfor] = ACTIONS(260),
    [sym__while] = ACTIONS(254),
    [sym__if] = ACTIONS(257),
    [sym__try] = ACTIONS(262),
    [sym__cnext] = ACTIONS(265),
    [sym__cprevious] = ACTIONS(268),
    [sym__cNext] = ACTIONS(268),
    [sym__const] = ACTIONS(271),
    [sym__normal] = ACTIONS(274),
    [sym__return] = ACTIONS(277),
    [sym__perl] = ACTIONS(280),
    [sym__lua] = ACTIONS(206),
    [sym__ruby] = ACTIONS(283),
    [sym__python] = ACTIONS(286),
    [sym__throw] = ACTIONS(289),
    [sym__execute] = ACTIONS(292),
    [sym__autocmd] = ACTIONS(295),
    [sym__silent] = ACTIONS(298),
    [sym__echo] = ACTIONS(301),
    [sym__echon] = ACTIONS(304),
    [sym__echohl] = ACTIONS(307),
    [sym__echomsg] = ACTIONS(310),
    [sym__echoerr] = ACTIONS(313),
    [sym__map] = ACTIONS(316),
    [sym__nmap] = ACTIONS(316),
    [sym__vmap] = ACTIONS(316),
    [sym__xmap] = ACTIONS(316),
    [sym__smap] = ACTIONS(316),
    [sym__omap] = ACTIONS(316),
    [sym__imap] = ACTIONS(316),
    [sym__lmap] = ACTIONS(316),
    [sym__cmap] = ACTIONS(316),
    [sym__tmap] = ACTIONS(316),
    [sym__noremap] = ACTIONS(316),
    [sym__nnoremap] = ACTIONS(316),
    [sym__vnoremap] = ACTIONS(316),
    [sym__xnoremap] = ACTIONS(316),
    [sym__snoremap] = ACTIONS(316),
    [sym__onoremap] = ACTIONS(316),
    [sym__inoremap] = ACTIONS(316),
    [sym__lnoremap] = ACTIONS(316),
    [sym__cnoremap] = ACTIONS(316),
    [sym__tnoremap] = ACTIONS(316),
    [sym__augroup] = ACTIONS(319),
    [sym__highlight] = ACTIONS(322),
    [sym__syntax] = ACTIONS(325),
    [sym__set] = ACTIONS(328),
    [sym__setlocal] = ACTIONS(331),
    [sym__setfiletype] = ACTIONS(334),
    [sym__browse] = ACTIONS(337),
    [sym__options] = ACTIONS(340),
    [sym__startinsert] = ACTIONS(343),
    [sym__stopinsert] = ACTIONS(346),
    [sym__scriptencoding] = ACTIONS(349),
    [sym__source] = ACTIONS(352),
    [sym__global] = ACTIONS(355),
    [sym__colorscheme] = ACTIONS(358),
    [sym__command] = ACTIONS(361),
    [sym__comclear] = ACTIONS(364),
    [sym__delcommand] = ACTIONS(367),
    [sym__runtime] = ACTIONS(370),
    [sym__wincmd] = ACTIONS(373),
    [sym__sign] = ACTIONS(376),
    [sym__filetype] = ACTIONS(379),
    [sym__let] = ACTIONS(382),
    [sym__unlet] = ACTIONS(385),
    [sym__call] = ACTIONS(388),
    [sym__break] = ACTIONS(391),
    [sym__continue] = ACTIONS(394),
    [sym__tab] = ACTIONS(397),
    [sym__vertical] = ACTIONS(400),
    [sym__leftabove] = ACTIONS(403),
    [sym__aboveleft] = ACTIONS(403),
    [sym__rightbelow] = ACTIONS(406),
    [sym__belowright] = ACTIONS(406),
    [sym__topleft] = ACTIONS(409),
    [sym__botright] = ACTIONS(412),
    [sym__edit] = ACTIONS(415),
    [sym__enew] = ACTIONS(418),
    [sym__find] = ACTIONS(421),
    [sym__ex] = ACTIONS(424),
    [sym__visual] = ACTIONS(427),
    [sym__view] = ACTIONS(430),
    [sym__eval] = ACTIONS(433),
    [sym__substitute] = ACTIONS(436),
    [sym_unknown_command_name] = ACTIONS(439),
  },
  [STATE(41)] = {
    [sym__cmd_separator] = STATE(113),
    [aux_sym__separated_statements] = STATE(44),
    [sym__statement] = STATE(2657),
    [sym_unknown_builtin_statement] = STATE(2657),
    [sym_return_statement] = STATE(2657),
    [sym_break_statement] = STATE(2657),
    [sym_continue_statement] = STATE(2657),
    [sym_normal_statement] = STATE(2657),
    [sym_setfiletype_statement] = STATE(2657),
    [sym_options_statement] = STATE(2657),
    [sym_startinsert_statement] = STATE(2657),
    [sym_stopinsert_statement] = STATE(2657),
    [sym_scriptencoding_statement] = STATE(2657),
    [sym_cnext_statement] = STATE(2657),
    [sym_cprevious_statement] = STATE(2657),
    [sym_runtime_statement] = STATE(2657),
    [sym_wincmd_statement] = STATE(2657),
    [sym_source_statement] = STATE(2657),
    [sym_global_statement] = STATE(2657),
    [sym_filetype_statement] = STATE(2657),
    [sym_colorscheme_statement] = STATE(2657),
    [sym_lua_statement] = STATE(2657),
    [sym_ruby_statement] = STATE(2657),
    [sym_python_statement] = STATE(2657),
    [sym_perl_statement] = STATE(2657),
    [sym_for_loop] = STATE(2657),
    [sym_while_loop] = STATE(2657),
    [sym_if_statement] = STATE(2657),
    [sym_try_statement] = STATE(2657),
    [sym_throw_statement] = STATE(2657),
    [sym_bang_filter_statement] = STATE(2657),
    [sym_let_statement] = STATE(2657),
    [sym_const_statement] = STATE(2657),
    [sym_set_statement] = STATE(2657),
    [sym_setlocal_statement] = STATE(2657),
    [sym_unlet_statement] = STATE(2657),
    [sym_call_statement] = STATE(2657),
    [sym_echo_statement] = STATE(2657),
    [sym_echon_statement] = STATE(2657),
    [sym_echohl_statement] = STATE(2657),
    [sym_echomsg_statement] = STATE(2657),
    [sym_echoerr_statement] = STATE(2657),
    [sym_execute_statement] = STATE(2657),
    [sym_silent_statement] = STATE(2657),
    [sym_tab_statement] = STATE(2657),
    [sym_vertical_statement] = STATE(2657),
    [sym_topleft_statement] = STATE(2657),
    [sym_botright_statement] = STATE(2657),
    [sym_aboveleft_statement] = STATE(2657),
    [sym_belowright_statement] = STATE(2657),
    [sym_user_command] = STATE(2657),
    [sym_shebang] = STATE(2657),
    [sym_function_definition] = STATE(2657),
    [sym_range_statement] = STATE(2657),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2657),
    [sym_map_statement] = STATE(2657),
    [sym_sign_statement] = STATE(2657),
    [sym_eval_statement] = STATE(2657),
    [sym_substitute_statement] = STATE(2657),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2657),
    [sym_augroup_statement] = STATE(2657),
    [sym_command_statement] = STATE(2657),
    [sym_comclear_statement] = STATE(2657),
    [sym_delcommand_statement] = STATE(2657),
    [sym_highlight_statement] = STATE(2657),
    [sym_syntax_statement] = STATE(2657),
    [sym_edit_statement] = STATE(2657),
    [sym_enew_statement] = STATE(2657),
    [sym_find_statement] = STATE(2657),
    [sym_ex_statement] = STATE(2657),
    [sym_visual_statement] = STATE(2657),
    [sym_view_statement] = STATE(2657),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(667),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(667),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__endtry] = ACTIONS(669),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(42)] = {
    [sym__cmd_separator] = STATE(109),
    [aux_sym__separated_statements] = STATE(45),
    [sym__statement] = STATE(2372),
    [sym_unknown_builtin_statement] = STATE(2372),
    [sym_return_statement] = STATE(2372),
    [sym_break_statement] = STATE(2372),
    [sym_continue_statement] = STATE(2372),
    [sym_normal_statement] = STATE(2372),
    [sym_setfiletype_statement] = STATE(2372),
    [sym_options_statement] = STATE(2372),
    [sym_startinsert_statement] = STATE(2372),
    [sym_stopinsert_statement] = STATE(2372),
    [sym_scriptencoding_statement] = STATE(2372),
    [sym_cnext_statement] = STATE(2372),
    [sym_cprevious_statement] = STATE(2372),
    [sym_runtime_statement] = STATE(2372),
    [sym_wincmd_statement] = STATE(2372),
    [sym_source_statement] = STATE(2372),
    [sym_global_statement] = STATE(2372),
    [sym_filetype_statement] = STATE(2372),
    [sym_colorscheme_statement] = STATE(2372),
    [sym_lua_statement] = STATE(2372),
    [sym_ruby_statement] = STATE(2372),
    [sym_python_statement] = STATE(2372),
    [sym_perl_statement] = STATE(2372),
    [sym_for_loop] = STATE(2372),
    [sym_while_loop] = STATE(2372),
    [sym_if_statement] = STATE(2372),
    [sym_try_statement] = STATE(2372),
    [sym_throw_statement] = STATE(2372),
    [sym_bang_filter_statement] = STATE(2372),
    [sym_let_statement] = STATE(2372),
    [sym_const_statement] = STATE(2372),
    [sym_set_statement] = STATE(2372),
    [sym_setlocal_statement] = STATE(2372),
    [sym_unlet_statement] = STATE(2372),
    [sym_call_statement] = STATE(2372),
    [sym_echo_statement] = STATE(2372),
    [sym_echon_statement] = STATE(2372),
    [sym_echohl_statement] = STATE(2372),
    [sym_echomsg_statement] = STATE(2372),
    [sym_echoerr_statement] = STATE(2372),
    [sym_execute_statement] = STATE(2372),
    [sym_silent_statement] = STATE(2372),
    [sym_tab_statement] = STATE(2372),
    [sym_vertical_statement] = STATE(2372),
    [sym_topleft_statement] = STATE(2372),
    [sym_botright_statement] = STATE(2372),
    [sym_aboveleft_statement] = STATE(2372),
    [sym_belowright_statement] = STATE(2372),
    [sym_user_command] = STATE(2372),
    [sym_shebang] = STATE(2372),
    [sym_function_definition] = STATE(2372),
    [sym_range_statement] = STATE(2372),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2372),
    [sym_map_statement] = STATE(2372),
    [sym_sign_statement] = STATE(2372),
    [sym_eval_statement] = STATE(2372),
    [sym_substitute_statement] = STATE(2372),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2372),
    [sym_augroup_statement] = STATE(2372),
    [sym_command_statement] = STATE(2372),
    [sym_comclear_statement] = STATE(2372),
    [sym_delcommand_statement] = STATE(2372),
    [sym_highlight_statement] = STATE(2372),
    [sym_syntax_statement] = STATE(2372),
    [sym_edit_statement] = STATE(2372),
    [sym_enew_statement] = STATE(2372),
    [sym_find_statement] = STATE(2372),
    [sym_ex_statement] = STATE(2372),
    [sym_visual_statement] = STATE(2372),
    [sym_view_statement] = STATE(2372),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(447),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(447),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__endfunction] = ACTIONS(671),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(43)] = {
    [sym__cmd_separator] = STATE(119),
    [aux_sym__separated_statements] = STATE(47),
    [sym__statement] = STATE(2446),
    [sym_unknown_builtin_statement] = STATE(2446),
    [sym_return_statement] = STATE(2446),
    [sym_break_statement] = STATE(2446),
    [sym_continue_statement] = STATE(2446),
    [sym_normal_statement] = STATE(2446),
    [sym_setfiletype_statement] = STATE(2446),
    [sym_options_statement] = STATE(2446),
    [sym_startinsert_statement] = STATE(2446),
    [sym_stopinsert_statement] = STATE(2446),
    [sym_scriptencoding_statement] = STATE(2446),
    [sym_cnext_statement] = STATE(2446),
    [sym_cprevious_statement] = STATE(2446),
    [sym_runtime_statement] = STATE(2446),
    [sym_wincmd_statement] = STATE(2446),
    [sym_source_statement] = STATE(2446),
    [sym_global_statement] = STATE(2446),
    [sym_filetype_statement] = STATE(2446),
    [sym_colorscheme_statement] = STATE(2446),
    [sym_lua_statement] = STATE(2446),
    [sym_ruby_statement] = STATE(2446),
    [sym_python_statement] = STATE(2446),
    [sym_perl_statement] = STATE(2446),
    [sym_for_loop] = STATE(2446),
    [sym_while_loop] = STATE(2446),
    [sym_if_statement] = STATE(2446),
    [sym_try_statement] = STATE(2446),
    [sym_throw_statement] = STATE(2446),
    [sym_bang_filter_statement] = STATE(2446),
    [sym_let_statement] = STATE(2446),
    [sym_const_statement] = STATE(2446),
    [sym_set_statement] = STATE(2446),
    [sym_setlocal_statement] = STATE(2446),
    [sym_unlet_statement] = STATE(2446),
    [sym_call_statement] = STATE(2446),
    [sym_echo_statement] = STATE(2446),
    [sym_echon_statement] = STATE(2446),
    [sym_echohl_statement] = STATE(2446),
    [sym_echomsg_statement] = STATE(2446),
    [sym_echoerr_statement] = STATE(2446),
    [sym_execute_statement] = STATE(2446),
    [sym_silent_statement] = STATE(2446),
    [sym_tab_statement] = STATE(2446),
    [sym_vertical_statement] = STATE(2446),
    [sym_topleft_statement] = STATE(2446),
    [sym_botright_statement] = STATE(2446),
    [sym_aboveleft_statement] = STATE(2446),
    [sym_belowright_statement] = STATE(2446),
    [sym_user_command] = STATE(2446),
    [sym_shebang] = STATE(2446),
    [sym_function_definition] = STATE(2446),
    [sym_range_statement] = STATE(2446),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2446),
    [sym_map_statement] = STATE(2446),
    [sym_sign_statement] = STATE(2446),
    [sym_eval_statement] = STATE(2446),
    [sym_substitute_statement] = STATE(2446),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2446),
    [sym_augroup_statement] = STATE(2446),
    [sym_command_statement] = STATE(2446),
    [sym_comclear_statement] = STATE(2446),
    [sym_delcommand_statement] = STATE(2446),
    [sym_highlight_statement] = STATE(2446),
    [sym_syntax_statement] = STATE(2446),
    [sym_edit_statement] = STATE(2446),
    [sym_enew_statement] = STATE(2446),
    [sym_find_statement] = STATE(2446),
    [sym_ex_statement] = STATE(2446),
    [sym_visual_statement] = STATE(2446),
    [sym_view_statement] = STATE(2446),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(469),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(469),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__endwhile] = ACTIONS(673),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(44)] = {
    [sym__cmd_separator] = STATE(113),
    [aux_sym__separated_statements] = STATE(38),
    [sym__statement] = STATE(2657),
    [sym_unknown_builtin_statement] = STATE(2657),
    [sym_return_statement] = STATE(2657),
    [sym_break_statement] = STATE(2657),
    [sym_continue_statement] = STATE(2657),
    [sym_normal_statement] = STATE(2657),
    [sym_setfiletype_statement] = STATE(2657),
    [sym_options_statement] = STATE(2657),
    [sym_startinsert_statement] = STATE(2657),
    [sym_stopinsert_statement] = STATE(2657),
    [sym_scriptencoding_statement] = STATE(2657),
    [sym_cnext_statement] = STATE(2657),
    [sym_cprevious_statement] = STATE(2657),
    [sym_runtime_statement] = STATE(2657),
    [sym_wincmd_statement] = STATE(2657),
    [sym_source_statement] = STATE(2657),
    [sym_global_statement] = STATE(2657),
    [sym_filetype_statement] = STATE(2657),
    [sym_colorscheme_statement] = STATE(2657),
    [sym_lua_statement] = STATE(2657),
    [sym_ruby_statement] = STATE(2657),
    [sym_python_statement] = STATE(2657),
    [sym_perl_statement] = STATE(2657),
    [sym_for_loop] = STATE(2657),
    [sym_while_loop] = STATE(2657),
    [sym_if_statement] = STATE(2657),
    [sym_try_statement] = STATE(2657),
    [sym_throw_statement] = STATE(2657),
    [sym_bang_filter_statement] = STATE(2657),
    [sym_let_statement] = STATE(2657),
    [sym_const_statement] = STATE(2657),
    [sym_set_statement] = STATE(2657),
    [sym_setlocal_statement] = STATE(2657),
    [sym_unlet_statement] = STATE(2657),
    [sym_call_statement] = STATE(2657),
    [sym_echo_statement] = STATE(2657),
    [sym_echon_statement] = STATE(2657),
    [sym_echohl_statement] = STATE(2657),
    [sym_echomsg_statement] = STATE(2657),
    [sym_echoerr_statement] = STATE(2657),
    [sym_execute_statement] = STATE(2657),
    [sym_silent_statement] = STATE(2657),
    [sym_tab_statement] = STATE(2657),
    [sym_vertical_statement] = STATE(2657),
    [sym_topleft_statement] = STATE(2657),
    [sym_botright_statement] = STATE(2657),
    [sym_aboveleft_statement] = STATE(2657),
    [sym_belowright_statement] = STATE(2657),
    [sym_user_command] = STATE(2657),
    [sym_shebang] = STATE(2657),
    [sym_function_definition] = STATE(2657),
    [sym_range_statement] = STATE(2657),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2657),
    [sym_map_statement] = STATE(2657),
    [sym_sign_statement] = STATE(2657),
    [sym_eval_statement] = STATE(2657),
    [sym_substitute_statement] = STATE(2657),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2657),
    [sym_augroup_statement] = STATE(2657),
    [sym_command_statement] = STATE(2657),
    [sym_comclear_statement] = STATE(2657),
    [sym_delcommand_statement] = STATE(2657),
    [sym_highlight_statement] = STATE(2657),
    [sym_syntax_statement] = STATE(2657),
    [sym_edit_statement] = STATE(2657),
    [sym_enew_statement] = STATE(2657),
    [sym_find_statement] = STATE(2657),
    [sym_ex_statement] = STATE(2657),
    [sym_visual_statement] = STATE(2657),
    [sym_view_statement] = STATE(2657),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(667),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(667),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__endtry] = ACTIONS(675),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(45)] = {
    [sym__cmd_separator] = STATE(109),
    [aux_sym__separated_statements] = STATE(35),
    [sym__statement] = STATE(2372),
    [sym_unknown_builtin_statement] = STATE(2372),
    [sym_return_statement] = STATE(2372),
    [sym_break_statement] = STATE(2372),
    [sym_continue_statement] = STATE(2372),
    [sym_normal_statement] = STATE(2372),
    [sym_setfiletype_statement] = STATE(2372),
    [sym_options_statement] = STATE(2372),
    [sym_startinsert_statement] = STATE(2372),
    [sym_stopinsert_statement] = STATE(2372),
    [sym_scriptencoding_statement] = STATE(2372),
    [sym_cnext_statement] = STATE(2372),
    [sym_cprevious_statement] = STATE(2372),
    [sym_runtime_statement] = STATE(2372),
    [sym_wincmd_statement] = STATE(2372),
    [sym_source_statement] = STATE(2372),
    [sym_global_statement] = STATE(2372),
    [sym_filetype_statement] = STATE(2372),
    [sym_colorscheme_statement] = STATE(2372),
    [sym_lua_statement] = STATE(2372),
    [sym_ruby_statement] = STATE(2372),
    [sym_python_statement] = STATE(2372),
    [sym_perl_statement] = STATE(2372),
    [sym_for_loop] = STATE(2372),
    [sym_while_loop] = STATE(2372),
    [sym_if_statement] = STATE(2372),
    [sym_try_statement] = STATE(2372),
    [sym_throw_statement] = STATE(2372),
    [sym_bang_filter_statement] = STATE(2372),
    [sym_let_statement] = STATE(2372),
    [sym_const_statement] = STATE(2372),
    [sym_set_statement] = STATE(2372),
    [sym_setlocal_statement] = STATE(2372),
    [sym_unlet_statement] = STATE(2372),
    [sym_call_statement] = STATE(2372),
    [sym_echo_statement] = STATE(2372),
    [sym_echon_statement] = STATE(2372),
    [sym_echohl_statement] = STATE(2372),
    [sym_echomsg_statement] = STATE(2372),
    [sym_echoerr_statement] = STATE(2372),
    [sym_execute_statement] = STATE(2372),
    [sym_silent_statement] = STATE(2372),
    [sym_tab_statement] = STATE(2372),
    [sym_vertical_statement] = STATE(2372),
    [sym_topleft_statement] = STATE(2372),
    [sym_botright_statement] = STATE(2372),
    [sym_aboveleft_statement] = STATE(2372),
    [sym_belowright_statement] = STATE(2372),
    [sym_user_command] = STATE(2372),
    [sym_shebang] = STATE(2372),
    [sym_function_definition] = STATE(2372),
    [sym_range_statement] = STATE(2372),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2372),
    [sym_map_statement] = STATE(2372),
    [sym_sign_statement] = STATE(2372),
    [sym_eval_statement] = STATE(2372),
    [sym_substitute_statement] = STATE(2372),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2372),
    [sym_augroup_statement] = STATE(2372),
    [sym_command_statement] = STATE(2372),
    [sym_comclear_statement] = STATE(2372),
    [sym_delcommand_statement] = STATE(2372),
    [sym_highlight_statement] = STATE(2372),
    [sym_syntax_statement] = STATE(2372),
    [sym_edit_statement] = STATE(2372),
    [sym_enew_statement] = STATE(2372),
    [sym_find_statement] = STATE(2372),
    [sym_ex_statement] = STATE(2372),
    [sym_visual_statement] = STATE(2372),
    [sym_view_statement] = STATE(2372),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(447),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(447),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__endfunction] = ACTIONS(677),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(46)] = {
    [sym__cmd_separator] = STATE(109),
    [aux_sym__separated_statements] = STATE(48),
    [sym__statement] = STATE(2372),
    [sym_unknown_builtin_statement] = STATE(2372),
    [sym_return_statement] = STATE(2372),
    [sym_break_statement] = STATE(2372),
    [sym_continue_statement] = STATE(2372),
    [sym_normal_statement] = STATE(2372),
    [sym_setfiletype_statement] = STATE(2372),
    [sym_options_statement] = STATE(2372),
    [sym_startinsert_statement] = STATE(2372),
    [sym_stopinsert_statement] = STATE(2372),
    [sym_scriptencoding_statement] = STATE(2372),
    [sym_cnext_statement] = STATE(2372),
    [sym_cprevious_statement] = STATE(2372),
    [sym_runtime_statement] = STATE(2372),
    [sym_wincmd_statement] = STATE(2372),
    [sym_source_statement] = STATE(2372),
    [sym_global_statement] = STATE(2372),
    [sym_filetype_statement] = STATE(2372),
    [sym_colorscheme_statement] = STATE(2372),
    [sym_lua_statement] = STATE(2372),
    [sym_ruby_statement] = STATE(2372),
    [sym_python_statement] = STATE(2372),
    [sym_perl_statement] = STATE(2372),
    [sym_for_loop] = STATE(2372),
    [sym_while_loop] = STATE(2372),
    [sym_if_statement] = STATE(2372),
    [sym_try_statement] = STATE(2372),
    [sym_throw_statement] = STATE(2372),
    [sym_bang_filter_statement] = STATE(2372),
    [sym_let_statement] = STATE(2372),
    [sym_const_statement] = STATE(2372),
    [sym_set_statement] = STATE(2372),
    [sym_setlocal_statement] = STATE(2372),
    [sym_unlet_statement] = STATE(2372),
    [sym_call_statement] = STATE(2372),
    [sym_echo_statement] = STATE(2372),
    [sym_echon_statement] = STATE(2372),
    [sym_echohl_statement] = STATE(2372),
    [sym_echomsg_statement] = STATE(2372),
    [sym_echoerr_statement] = STATE(2372),
    [sym_execute_statement] = STATE(2372),
    [sym_silent_statement] = STATE(2372),
    [sym_tab_statement] = STATE(2372),
    [sym_vertical_statement] = STATE(2372),
    [sym_topleft_statement] = STATE(2372),
    [sym_botright_statement] = STATE(2372),
    [sym_aboveleft_statement] = STATE(2372),
    [sym_belowright_statement] = STATE(2372),
    [sym_user_command] = STATE(2372),
    [sym_shebang] = STATE(2372),
    [sym_function_definition] = STATE(2372),
    [sym_range_statement] = STATE(2372),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2372),
    [sym_map_statement] = STATE(2372),
    [sym_sign_statement] = STATE(2372),
    [sym_eval_statement] = STATE(2372),
    [sym_substitute_statement] = STATE(2372),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2372),
    [sym_augroup_statement] = STATE(2372),
    [sym_command_statement] = STATE(2372),
    [sym_comclear_statement] = STATE(2372),
    [sym_delcommand_statement] = STATE(2372),
    [sym_highlight_statement] = STATE(2372),
    [sym_syntax_statement] = STATE(2372),
    [sym_edit_statement] = STATE(2372),
    [sym_enew_statement] = STATE(2372),
    [sym_find_statement] = STATE(2372),
    [sym_ex_statement] = STATE(2372),
    [sym_visual_statement] = STATE(2372),
    [sym_view_statement] = STATE(2372),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(447),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(447),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__endfunction] = ACTIONS(679),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(47)] = {
    [sym__cmd_separator] = STATE(119),
    [aux_sym__separated_statements] = STATE(36),
    [sym__statement] = STATE(2446),
    [sym_unknown_builtin_statement] = STATE(2446),
    [sym_return_statement] = STATE(2446),
    [sym_break_statement] = STATE(2446),
    [sym_continue_statement] = STATE(2446),
    [sym_normal_statement] = STATE(2446),
    [sym_setfiletype_statement] = STATE(2446),
    [sym_options_statement] = STATE(2446),
    [sym_startinsert_statement] = STATE(2446),
    [sym_stopinsert_statement] = STATE(2446),
    [sym_scriptencoding_statement] = STATE(2446),
    [sym_cnext_statement] = STATE(2446),
    [sym_cprevious_statement] = STATE(2446),
    [sym_runtime_statement] = STATE(2446),
    [sym_wincmd_statement] = STATE(2446),
    [sym_source_statement] = STATE(2446),
    [sym_global_statement] = STATE(2446),
    [sym_filetype_statement] = STATE(2446),
    [sym_colorscheme_statement] = STATE(2446),
    [sym_lua_statement] = STATE(2446),
    [sym_ruby_statement] = STATE(2446),
    [sym_python_statement] = STATE(2446),
    [sym_perl_statement] = STATE(2446),
    [sym_for_loop] = STATE(2446),
    [sym_while_loop] = STATE(2446),
    [sym_if_statement] = STATE(2446),
    [sym_try_statement] = STATE(2446),
    [sym_throw_statement] = STATE(2446),
    [sym_bang_filter_statement] = STATE(2446),
    [sym_let_statement] = STATE(2446),
    [sym_const_statement] = STATE(2446),
    [sym_set_statement] = STATE(2446),
    [sym_setlocal_statement] = STATE(2446),
    [sym_unlet_statement] = STATE(2446),
    [sym_call_statement] = STATE(2446),
    [sym_echo_statement] = STATE(2446),
    [sym_echon_statement] = STATE(2446),
    [sym_echohl_statement] = STATE(2446),
    [sym_echomsg_statement] = STATE(2446),
    [sym_echoerr_statement] = STATE(2446),
    [sym_execute_statement] = STATE(2446),
    [sym_silent_statement] = STATE(2446),
    [sym_tab_statement] = STATE(2446),
    [sym_vertical_statement] = STATE(2446),
    [sym_topleft_statement] = STATE(2446),
    [sym_botright_statement] = STATE(2446),
    [sym_aboveleft_statement] = STATE(2446),
    [sym_belowright_statement] = STATE(2446),
    [sym_user_command] = STATE(2446),
    [sym_shebang] = STATE(2446),
    [sym_function_definition] = STATE(2446),
    [sym_range_statement] = STATE(2446),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2446),
    [sym_map_statement] = STATE(2446),
    [sym_sign_statement] = STATE(2446),
    [sym_eval_statement] = STATE(2446),
    [sym_substitute_statement] = STATE(2446),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2446),
    [sym_augroup_statement] = STATE(2446),
    [sym_command_statement] = STATE(2446),
    [sym_comclear_statement] = STATE(2446),
    [sym_delcommand_statement] = STATE(2446),
    [sym_highlight_statement] = STATE(2446),
    [sym_syntax_statement] = STATE(2446),
    [sym_edit_statement] = STATE(2446),
    [sym_enew_statement] = STATE(2446),
    [sym_find_statement] = STATE(2446),
    [sym_ex_statement] = STATE(2446),
    [sym_visual_statement] = STATE(2446),
    [sym_view_statement] = STATE(2446),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(469),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(469),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__endwhile] = ACTIONS(681),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(48)] = {
    [sym__cmd_separator] = STATE(109),
    [aux_sym__separated_statements] = STATE(35),
    [sym__statement] = STATE(2372),
    [sym_unknown_builtin_statement] = STATE(2372),
    [sym_return_statement] = STATE(2372),
    [sym_break_statement] = STATE(2372),
    [sym_continue_statement] = STATE(2372),
    [sym_normal_statement] = STATE(2372),
    [sym_setfiletype_statement] = STATE(2372),
    [sym_options_statement] = STATE(2372),
    [sym_startinsert_statement] = STATE(2372),
    [sym_stopinsert_statement] = STATE(2372),
    [sym_scriptencoding_statement] = STATE(2372),
    [sym_cnext_statement] = STATE(2372),
    [sym_cprevious_statement] = STATE(2372),
    [sym_runtime_statement] = STATE(2372),
    [sym_wincmd_statement] = STATE(2372),
    [sym_source_statement] = STATE(2372),
    [sym_global_statement] = STATE(2372),
    [sym_filetype_statement] = STATE(2372),
    [sym_colorscheme_statement] = STATE(2372),
    [sym_lua_statement] = STATE(2372),
    [sym_ruby_statement] = STATE(2372),
    [sym_python_statement] = STATE(2372),
    [sym_perl_statement] = STATE(2372),
    [sym_for_loop] = STATE(2372),
    [sym_while_loop] = STATE(2372),
    [sym_if_statement] = STATE(2372),
    [sym_try_statement] = STATE(2372),
    [sym_throw_statement] = STATE(2372),
    [sym_bang_filter_statement] = STATE(2372),
    [sym_let_statement] = STATE(2372),
    [sym_const_statement] = STATE(2372),
    [sym_set_statement] = STATE(2372),
    [sym_setlocal_statement] = STATE(2372),
    [sym_unlet_statement] = STATE(2372),
    [sym_call_statement] = STATE(2372),
    [sym_echo_statement] = STATE(2372),
    [sym_echon_statement] = STATE(2372),
    [sym_echohl_statement] = STATE(2372),
    [sym_echomsg_statement] = STATE(2372),
    [sym_echoerr_statement] = STATE(2372),
    [sym_execute_statement] = STATE(2372),
    [sym_silent_statement] = STATE(2372),
    [sym_tab_statement] = STATE(2372),
    [sym_vertical_statement] = STATE(2372),
    [sym_topleft_statement] = STATE(2372),
    [sym_botright_statement] = STATE(2372),
    [sym_aboveleft_statement] = STATE(2372),
    [sym_belowright_statement] = STATE(2372),
    [sym_user_command] = STATE(2372),
    [sym_shebang] = STATE(2372),
    [sym_function_definition] = STATE(2372),
    [sym_range_statement] = STATE(2372),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2372),
    [sym_map_statement] = STATE(2372),
    [sym_sign_statement] = STATE(2372),
    [sym_eval_statement] = STATE(2372),
    [sym_substitute_statement] = STATE(2372),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2372),
    [sym_augroup_statement] = STATE(2372),
    [sym_command_statement] = STATE(2372),
    [sym_comclear_statement] = STATE(2372),
    [sym_delcommand_statement] = STATE(2372),
    [sym_highlight_statement] = STATE(2372),
    [sym_syntax_statement] = STATE(2372),
    [sym_edit_statement] = STATE(2372),
    [sym_enew_statement] = STATE(2372),
    [sym_find_statement] = STATE(2372),
    [sym_ex_statement] = STATE(2372),
    [sym_visual_statement] = STATE(2372),
    [sym_view_statement] = STATE(2372),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(447),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(447),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__endfunction] = ACTIONS(683),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(49)] = {
    [sym__cmd_separator] = STATE(109),
    [aux_sym__separated_statements] = STATE(51),
    [sym__statement] = STATE(2372),
    [sym_unknown_builtin_statement] = STATE(2372),
    [sym_return_statement] = STATE(2372),
    [sym_break_statement] = STATE(2372),
    [sym_continue_statement] = STATE(2372),
    [sym_normal_statement] = STATE(2372),
    [sym_setfiletype_statement] = STATE(2372),
    [sym_options_statement] = STATE(2372),
    [sym_startinsert_statement] = STATE(2372),
    [sym_stopinsert_statement] = STATE(2372),
    [sym_scriptencoding_statement] = STATE(2372),
    [sym_cnext_statement] = STATE(2372),
    [sym_cprevious_statement] = STATE(2372),
    [sym_runtime_statement] = STATE(2372),
    [sym_wincmd_statement] = STATE(2372),
    [sym_source_statement] = STATE(2372),
    [sym_global_statement] = STATE(2372),
    [sym_filetype_statement] = STATE(2372),
    [sym_colorscheme_statement] = STATE(2372),
    [sym_lua_statement] = STATE(2372),
    [sym_ruby_statement] = STATE(2372),
    [sym_python_statement] = STATE(2372),
    [sym_perl_statement] = STATE(2372),
    [sym_for_loop] = STATE(2372),
    [sym_while_loop] = STATE(2372),
    [sym_if_statement] = STATE(2372),
    [sym_try_statement] = STATE(2372),
    [sym_throw_statement] = STATE(2372),
    [sym_bang_filter_statement] = STATE(2372),
    [sym_let_statement] = STATE(2372),
    [sym_const_statement] = STATE(2372),
    [sym_set_statement] = STATE(2372),
    [sym_setlocal_statement] = STATE(2372),
    [sym_unlet_statement] = STATE(2372),
    [sym_call_statement] = STATE(2372),
    [sym_echo_statement] = STATE(2372),
    [sym_echon_statement] = STATE(2372),
    [sym_echohl_statement] = STATE(2372),
    [sym_echomsg_statement] = STATE(2372),
    [sym_echoerr_statement] = STATE(2372),
    [sym_execute_statement] = STATE(2372),
    [sym_silent_statement] = STATE(2372),
    [sym_tab_statement] = STATE(2372),
    [sym_vertical_statement] = STATE(2372),
    [sym_topleft_statement] = STATE(2372),
    [sym_botright_statement] = STATE(2372),
    [sym_aboveleft_statement] = STATE(2372),
    [sym_belowright_statement] = STATE(2372),
    [sym_user_command] = STATE(2372),
    [sym_shebang] = STATE(2372),
    [sym_function_definition] = STATE(2372),
    [sym_range_statement] = STATE(2372),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2372),
    [sym_map_statement] = STATE(2372),
    [sym_sign_statement] = STATE(2372),
    [sym_eval_statement] = STATE(2372),
    [sym_substitute_statement] = STATE(2372),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2372),
    [sym_augroup_statement] = STATE(2372),
    [sym_command_statement] = STATE(2372),
    [sym_comclear_statement] = STATE(2372),
    [sym_delcommand_statement] = STATE(2372),
    [sym_highlight_statement] = STATE(2372),
    [sym_syntax_statement] = STATE(2372),
    [sym_edit_statement] = STATE(2372),
    [sym_enew_statement] = STATE(2372),
    [sym_find_statement] = STATE(2372),
    [sym_ex_statement] = STATE(2372),
    [sym_visual_statement] = STATE(2372),
    [sym_view_statement] = STATE(2372),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(447),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(447),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__endfunction] = ACTIONS(685),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(50)] = {
    [sym__cmd_separator] = STATE(116),
    [aux_sym__separated_statements] = STATE(19),
    [sym__statement] = STATE(2718),
    [sym_unknown_builtin_statement] = STATE(2718),
    [sym_return_statement] = STATE(2718),
    [sym_break_statement] = STATE(2718),
    [sym_continue_statement] = STATE(2718),
    [sym_normal_statement] = STATE(2718),
    [sym_setfiletype_statement] = STATE(2718),
    [sym_options_statement] = STATE(2718),
    [sym_startinsert_statement] = STATE(2718),
    [sym_stopinsert_statement] = STATE(2718),
    [sym_scriptencoding_statement] = STATE(2718),
    [sym_cnext_statement] = STATE(2718),
    [sym_cprevious_statement] = STATE(2718),
    [sym_runtime_statement] = STATE(2718),
    [sym_wincmd_statement] = STATE(2718),
    [sym_source_statement] = STATE(2718),
    [sym_global_statement] = STATE(2718),
    [sym_filetype_statement] = STATE(2718),
    [sym_colorscheme_statement] = STATE(2718),
    [sym_lua_statement] = STATE(2718),
    [sym_ruby_statement] = STATE(2718),
    [sym_python_statement] = STATE(2718),
    [sym_perl_statement] = STATE(2718),
    [sym_for_loop] = STATE(2718),
    [sym_while_loop] = STATE(2718),
    [sym_if_statement] = STATE(2718),
    [sym_try_statement] = STATE(2718),
    [sym_throw_statement] = STATE(2718),
    [sym_bang_filter_statement] = STATE(2718),
    [sym_let_statement] = STATE(2718),
    [sym_const_statement] = STATE(2718),
    [sym_set_statement] = STATE(2718),
    [sym_setlocal_statement] = STATE(2718),
    [sym_unlet_statement] = STATE(2718),
    [sym_call_statement] = STATE(2718),
    [sym_echo_statement] = STATE(2718),
    [sym_echon_statement] = STATE(2718),
    [sym_echohl_statement] = STATE(2718),
    [sym_echomsg_statement] = STATE(2718),
    [sym_echoerr_statement] = STATE(2718),
    [sym_execute_statement] = STATE(2718),
    [sym_silent_statement] = STATE(2718),
    [sym_tab_statement] = STATE(2718),
    [sym_vertical_statement] = STATE(2718),
    [sym_topleft_statement] = STATE(2718),
    [sym_botright_statement] = STATE(2718),
    [sym_aboveleft_statement] = STATE(2718),
    [sym_belowright_statement] = STATE(2718),
    [sym_user_command] = STATE(2718),
    [sym_shebang] = STATE(2718),
    [sym_function_definition] = STATE(2718),
    [sym_range_statement] = STATE(2718),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2718),
    [sym_map_statement] = STATE(2718),
    [sym_sign_statement] = STATE(2718),
    [sym_eval_statement] = STATE(2718),
    [sym_substitute_statement] = STATE(2718),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2718),
    [sym_augroup_statement] = STATE(2718),
    [sym_command_statement] = STATE(2718),
    [sym_comclear_statement] = STATE(2718),
    [sym_delcommand_statement] = STATE(2718),
    [sym_highlight_statement] = STATE(2718),
    [sym_syntax_statement] = STATE(2718),
    [sym_edit_statement] = STATE(2718),
    [sym_enew_statement] = STATE(2718),
    [sym_find_statement] = STATE(2718),
    [sym_ex_statement] = STATE(2718),
    [sym_visual_statement] = STATE(2718),
    [sym_view_statement] = STATE(2718),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(451),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(451),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__endfor] = ACTIONS(687),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(51)] = {
    [sym__cmd_separator] = STATE(109),
    [aux_sym__separated_statements] = STATE(35),
    [sym__statement] = STATE(2372),
    [sym_unknown_builtin_statement] = STATE(2372),
    [sym_return_statement] = STATE(2372),
    [sym_break_statement] = STATE(2372),
    [sym_continue_statement] = STATE(2372),
    [sym_normal_statement] = STATE(2372),
    [sym_setfiletype_statement] = STATE(2372),
    [sym_options_statement] = STATE(2372),
    [sym_startinsert_statement] = STATE(2372),
    [sym_stopinsert_statement] = STATE(2372),
    [sym_scriptencoding_statement] = STATE(2372),
    [sym_cnext_statement] = STATE(2372),
    [sym_cprevious_statement] = STATE(2372),
    [sym_runtime_statement] = STATE(2372),
    [sym_wincmd_statement] = STATE(2372),
    [sym_source_statement] = STATE(2372),
    [sym_global_statement] = STATE(2372),
    [sym_filetype_statement] = STATE(2372),
    [sym_colorscheme_statement] = STATE(2372),
    [sym_lua_statement] = STATE(2372),
    [sym_ruby_statement] = STATE(2372),
    [sym_python_statement] = STATE(2372),
    [sym_perl_statement] = STATE(2372),
    [sym_for_loop] = STATE(2372),
    [sym_while_loop] = STATE(2372),
    [sym_if_statement] = STATE(2372),
    [sym_try_statement] = STATE(2372),
    [sym_throw_statement] = STATE(2372),
    [sym_bang_filter_statement] = STATE(2372),
    [sym_let_statement] = STATE(2372),
    [sym_const_statement] = STATE(2372),
    [sym_set_statement] = STATE(2372),
    [sym_setlocal_statement] = STATE(2372),
    [sym_unlet_statement] = STATE(2372),
    [sym_call_statement] = STATE(2372),
    [sym_echo_statement] = STATE(2372),
    [sym_echon_statement] = STATE(2372),
    [sym_echohl_statement] = STATE(2372),
    [sym_echomsg_statement] = STATE(2372),
    [sym_echoerr_statement] = STATE(2372),
    [sym_execute_statement] = STATE(2372),
    [sym_silent_statement] = STATE(2372),
    [sym_tab_statement] = STATE(2372),
    [sym_vertical_statement] = STATE(2372),
    [sym_topleft_statement] = STATE(2372),
    [sym_botright_statement] = STATE(2372),
    [sym_aboveleft_statement] = STATE(2372),
    [sym_belowright_statement] = STATE(2372),
    [sym_user_command] = STATE(2372),
    [sym_shebang] = STATE(2372),
    [sym_function_definition] = STATE(2372),
    [sym_range_statement] = STATE(2372),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2372),
    [sym_map_statement] = STATE(2372),
    [sym_sign_statement] = STATE(2372),
    [sym_eval_statement] = STATE(2372),
    [sym_substitute_statement] = STATE(2372),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2372),
    [sym_augroup_statement] = STATE(2372),
    [sym_command_statement] = STATE(2372),
    [sym_comclear_statement] = STATE(2372),
    [sym_delcommand_statement] = STATE(2372),
    [sym_highlight_statement] = STATE(2372),
    [sym_syntax_statement] = STATE(2372),
    [sym_edit_statement] = STATE(2372),
    [sym_enew_statement] = STATE(2372),
    [sym_find_statement] = STATE(2372),
    [sym_ex_statement] = STATE(2372),
    [sym_visual_statement] = STATE(2372),
    [sym_view_statement] = STATE(2372),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(447),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(447),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__endfunction] = ACTIONS(689),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(52)] = {
    [sym__statement] = STATE(2440),
    [sym_unknown_builtin_statement] = STATE(2440),
    [sym_return_statement] = STATE(2440),
    [sym_break_statement] = STATE(2440),
    [sym_continue_statement] = STATE(2440),
    [sym_normal_statement] = STATE(2440),
    [sym_setfiletype_statement] = STATE(2440),
    [sym_options_statement] = STATE(2440),
    [sym_startinsert_statement] = STATE(2440),
    [sym_stopinsert_statement] = STATE(2440),
    [sym_scriptencoding_statement] = STATE(2440),
    [sym_cnext_statement] = STATE(2440),
    [sym_cprevious_statement] = STATE(2440),
    [sym_runtime_statement] = STATE(2440),
    [sym_wincmd_statement] = STATE(2440),
    [sym_source_statement] = STATE(2440),
    [sym_global_statement] = STATE(2440),
    [sym_filetype_statement] = STATE(2440),
    [sym_colorscheme_statement] = STATE(2440),
    [sym_lua_statement] = STATE(2440),
    [sym_ruby_statement] = STATE(2440),
    [sym_python_statement] = STATE(2440),
    [sym_perl_statement] = STATE(2440),
    [sym_for_loop] = STATE(2440),
    [sym_while_loop] = STATE(2440),
    [sym_if_statement] = STATE(2440),
    [sym_try_statement] = STATE(2440),
    [sym_throw_statement] = STATE(2440),
    [sym_bang_filter_statement] = STATE(2440),
    [sym_let_statement] = STATE(2440),
    [sym_const_statement] = STATE(2440),
    [sym_set_statement] = STATE(2440),
    [sym_setlocal_statement] = STATE(2440),
    [sym_unlet_statement] = STATE(2440),
    [sym_call_statement] = STATE(2440),
    [sym_echo_statement] = STATE(2440),
    [sym_echon_statement] = STATE(2440),
    [sym_echohl_statement] = STATE(2440),
    [sym_echomsg_statement] = STATE(2440),
    [sym_echoerr_statement] = STATE(2440),
    [sym_execute_statement] = STATE(2440),
    [sym_silent_statement] = STATE(2440),
    [sym_tab_statement] = STATE(2440),
    [sym_vertical_statement] = STATE(2440),
    [sym_topleft_statement] = STATE(2440),
    [sym_botright_statement] = STATE(2440),
    [sym_aboveleft_statement] = STATE(2440),
    [sym_belowright_statement] = STATE(2440),
    [sym_user_command] = STATE(2440),
    [sym_shebang] = STATE(2440),
    [sym_function_definition] = STATE(2440),
    [sym_range_statement] = STATE(2440),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2440),
    [sym_map_statement] = STATE(2440),
    [sym_sign_statement] = STATE(2440),
    [sym_eval_statement] = STATE(2440),
    [sym_substitute_statement] = STATE(2440),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2440),
    [sym_augroup_statement] = STATE(2440),
    [sym_command_statement] = STATE(2440),
    [sym_comclear_statement] = STATE(2440),
    [sym_delcommand_statement] = STATE(2440),
    [sym_highlight_statement] = STATE(2440),
    [sym_syntax_statement] = STATE(2440),
    [sym_edit_statement] = STATE(2440),
    [sym_enew_statement] = STATE(2440),
    [sym_find_statement] = STATE(2440),
    [sym_ex_statement] = STATE(2440),
    [sym_visual_statement] = STATE(2440),
    [sym_view_statement] = STATE(2440),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [anon_sym_BSLASH_PIPE] = ACTIONS(691),
    [aux_sym__map_rhs_statement_token2] = ACTIONS(691),
    [aux_sym__map_rhs_statement_token3] = ACTIONS(691),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_au_once] = ACTIONS(507),
    [sym_au_nested] = ACTIONS(509),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(53)] = {
    [sym__statement] = STATE(2859),
    [sym_unknown_builtin_statement] = STATE(2859),
    [sym_return_statement] = STATE(2859),
    [sym_break_statement] = STATE(2859),
    [sym_continue_statement] = STATE(2859),
    [sym_normal_statement] = STATE(2859),
    [sym_setfiletype_statement] = STATE(2859),
    [sym_options_statement] = STATE(2859),
    [sym_startinsert_statement] = STATE(2859),
    [sym_stopinsert_statement] = STATE(2859),
    [sym_scriptencoding_statement] = STATE(2859),
    [sym_cnext_statement] = STATE(2859),
    [sym_cprevious_statement] = STATE(2859),
    [sym_runtime_statement] = STATE(2859),
    [sym_wincmd_statement] = STATE(2859),
    [sym_source_statement] = STATE(2859),
    [sym_global_statement] = STATE(2859),
    [sym_filetype_statement] = STATE(2859),
    [sym_colorscheme_statement] = STATE(2859),
    [sym_lua_statement] = STATE(2859),
    [sym_ruby_statement] = STATE(2859),
    [sym_python_statement] = STATE(2859),
    [sym_perl_statement] = STATE(2859),
    [sym_for_loop] = STATE(2859),
    [sym_while_loop] = STATE(2859),
    [sym_if_statement] = STATE(2859),
    [sym_try_statement] = STATE(2859),
    [sym_throw_statement] = STATE(2859),
    [sym_bang_filter_statement] = STATE(2859),
    [sym_let_statement] = STATE(2859),
    [sym_const_statement] = STATE(2859),
    [sym_set_statement] = STATE(2859),
    [sym_setlocal_statement] = STATE(2859),
    [sym_unlet_statement] = STATE(2859),
    [sym_call_statement] = STATE(2859),
    [sym_echo_statement] = STATE(2859),
    [sym_echon_statement] = STATE(2859),
    [sym_echohl_statement] = STATE(2859),
    [sym_echomsg_statement] = STATE(2859),
    [sym_echoerr_statement] = STATE(2859),
    [sym_execute_statement] = STATE(2859),
    [sym_silent_statement] = STATE(2859),
    [sym_tab_statement] = STATE(2859),
    [sym_vertical_statement] = STATE(2859),
    [sym_topleft_statement] = STATE(2859),
    [sym_botright_statement] = STATE(2859),
    [sym_aboveleft_statement] = STATE(2859),
    [sym_belowright_statement] = STATE(2859),
    [sym_user_command] = STATE(2859),
    [sym_shebang] = STATE(2859),
    [sym_function_definition] = STATE(2859),
    [sym_range_statement] = STATE(2859),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2859),
    [sym_map_statement] = STATE(2859),
    [sym_sign_statement] = STATE(2859),
    [sym_eval_statement] = STATE(2859),
    [sym_substitute_statement] = STATE(2859),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2859),
    [sym_augroup_statement] = STATE(2859),
    [sym_command_statement] = STATE(2859),
    [sym_comclear_statement] = STATE(2859),
    [sym_delcommand_statement] = STATE(2859),
    [sym_highlight_statement] = STATE(2859),
    [sym_syntax_statement] = STATE(2859),
    [sym_edit_statement] = STATE(2859),
    [sym_enew_statement] = STATE(2859),
    [sym_find_statement] = STATE(2859),
    [sym_ex_statement] = STATE(2859),
    [sym_visual_statement] = STATE(2859),
    [sym_view_statement] = STATE(2859),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_au_once] = ACTIONS(693),
    [sym_au_nested] = ACTIONS(695),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(643),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(643),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(54)] = {
    [sym__statement] = STATE(2859),
    [sym_unknown_builtin_statement] = STATE(2859),
    [sym_return_statement] = STATE(2859),
    [sym_break_statement] = STATE(2859),
    [sym_continue_statement] = STATE(2859),
    [sym_normal_statement] = STATE(2859),
    [sym_setfiletype_statement] = STATE(2859),
    [sym_options_statement] = STATE(2859),
    [sym_startinsert_statement] = STATE(2859),
    [sym_stopinsert_statement] = STATE(2859),
    [sym_scriptencoding_statement] = STATE(2859),
    [sym_cnext_statement] = STATE(2859),
    [sym_cprevious_statement] = STATE(2859),
    [sym_runtime_statement] = STATE(2859),
    [sym_wincmd_statement] = STATE(2859),
    [sym_source_statement] = STATE(2859),
    [sym_global_statement] = STATE(2859),
    [sym_filetype_statement] = STATE(2859),
    [sym_colorscheme_statement] = STATE(2859),
    [sym_lua_statement] = STATE(2859),
    [sym_ruby_statement] = STATE(2859),
    [sym_python_statement] = STATE(2859),
    [sym_perl_statement] = STATE(2859),
    [sym_for_loop] = STATE(2859),
    [sym_while_loop] = STATE(2859),
    [sym_if_statement] = STATE(2859),
    [sym_try_statement] = STATE(2859),
    [sym_throw_statement] = STATE(2859),
    [sym_bang_filter_statement] = STATE(2859),
    [sym_let_statement] = STATE(2859),
    [sym_const_statement] = STATE(2859),
    [sym_set_statement] = STATE(2859),
    [sym_setlocal_statement] = STATE(2859),
    [sym_unlet_statement] = STATE(2859),
    [sym_call_statement] = STATE(2859),
    [sym_echo_statement] = STATE(2859),
    [sym_echon_statement] = STATE(2859),
    [sym_echohl_statement] = STATE(2859),
    [sym_echomsg_statement] = STATE(2859),
    [sym_echoerr_statement] = STATE(2859),
    [sym_execute_statement] = STATE(2859),
    [sym_silent_statement] = STATE(2859),
    [sym_tab_statement] = STATE(2859),
    [sym_vertical_statement] = STATE(2859),
    [sym_topleft_statement] = STATE(2859),
    [sym_botright_statement] = STATE(2859),
    [sym_aboveleft_statement] = STATE(2859),
    [sym_belowright_statement] = STATE(2859),
    [sym_user_command] = STATE(2859),
    [sym_shebang] = STATE(2859),
    [sym_function_definition] = STATE(2859),
    [sym_range_statement] = STATE(2859),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2859),
    [sym_map_statement] = STATE(2859),
    [sym_sign_statement] = STATE(2859),
    [sym_eval_statement] = STATE(2859),
    [sym_substitute_statement] = STATE(2859),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2859),
    [sym_augroup_statement] = STATE(2859),
    [sym_command_statement] = STATE(2859),
    [sym_comclear_statement] = STATE(2859),
    [sym_delcommand_statement] = STATE(2859),
    [sym_highlight_statement] = STATE(2859),
    [sym_syntax_statement] = STATE(2859),
    [sym_edit_statement] = STATE(2859),
    [sym_enew_statement] = STATE(2859),
    [sym_find_statement] = STATE(2859),
    [sym_ex_statement] = STATE(2859),
    [sym_visual_statement] = STATE(2859),
    [sym_view_statement] = STATE(2859),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_au_once] = ACTIONS(693),
    [sym_au_nested] = ACTIONS(695),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(691),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(691),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(55)] = {
    [sym__statement] = STATE(2859),
    [sym_unknown_builtin_statement] = STATE(2859),
    [sym_return_statement] = STATE(2859),
    [sym_break_statement] = STATE(2859),
    [sym_continue_statement] = STATE(2859),
    [sym_normal_statement] = STATE(2859),
    [sym_setfiletype_statement] = STATE(2859),
    [sym_options_statement] = STATE(2859),
    [sym_startinsert_statement] = STATE(2859),
    [sym_stopinsert_statement] = STATE(2859),
    [sym_scriptencoding_statement] = STATE(2859),
    [sym_cnext_statement] = STATE(2859),
    [sym_cprevious_statement] = STATE(2859),
    [sym_runtime_statement] = STATE(2859),
    [sym_wincmd_statement] = STATE(2859),
    [sym_source_statement] = STATE(2859),
    [sym_global_statement] = STATE(2859),
    [sym_filetype_statement] = STATE(2859),
    [sym_colorscheme_statement] = STATE(2859),
    [sym_lua_statement] = STATE(2859),
    [sym_ruby_statement] = STATE(2859),
    [sym_python_statement] = STATE(2859),
    [sym_perl_statement] = STATE(2859),
    [sym_for_loop] = STATE(2859),
    [sym_while_loop] = STATE(2859),
    [sym_if_statement] = STATE(2859),
    [sym_try_statement] = STATE(2859),
    [sym_throw_statement] = STATE(2859),
    [sym_bang_filter_statement] = STATE(2859),
    [sym_let_statement] = STATE(2859),
    [sym_const_statement] = STATE(2859),
    [sym_set_statement] = STATE(2859),
    [sym_setlocal_statement] = STATE(2859),
    [sym_unlet_statement] = STATE(2859),
    [sym_call_statement] = STATE(2859),
    [sym_echo_statement] = STATE(2859),
    [sym_echon_statement] = STATE(2859),
    [sym_echohl_statement] = STATE(2859),
    [sym_echomsg_statement] = STATE(2859),
    [sym_echoerr_statement] = STATE(2859),
    [sym_execute_statement] = STATE(2859),
    [sym_silent_statement] = STATE(2859),
    [sym_tab_statement] = STATE(2859),
    [sym_vertical_statement] = STATE(2859),
    [sym_topleft_statement] = STATE(2859),
    [sym_botright_statement] = STATE(2859),
    [sym_aboveleft_statement] = STATE(2859),
    [sym_belowright_statement] = STATE(2859),
    [sym_user_command] = STATE(2859),
    [sym_shebang] = STATE(2859),
    [sym_function_definition] = STATE(2859),
    [sym_range_statement] = STATE(2859),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2859),
    [sym_map_statement] = STATE(2859),
    [sym_sign_statement] = STATE(2859),
    [sym_eval_statement] = STATE(2859),
    [sym_substitute_statement] = STATE(2859),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2859),
    [sym_augroup_statement] = STATE(2859),
    [sym_command_statement] = STATE(2859),
    [sym_comclear_statement] = STATE(2859),
    [sym_delcommand_statement] = STATE(2859),
    [sym_highlight_statement] = STATE(2859),
    [sym_syntax_statement] = STATE(2859),
    [sym_edit_statement] = STATE(2859),
    [sym_enew_statement] = STATE(2859),
    [sym_find_statement] = STATE(2859),
    [sym_ex_statement] = STATE(2859),
    [sym_visual_statement] = STATE(2859),
    [sym_view_statement] = STATE(2859),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_au_once] = ACTIONS(693),
    [sym_au_nested] = ACTIONS(695),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(641),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(641),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(56)] = {
    [sym__statement] = STATE(2859),
    [sym_unknown_builtin_statement] = STATE(2859),
    [sym_return_statement] = STATE(2859),
    [sym_break_statement] = STATE(2859),
    [sym_continue_statement] = STATE(2859),
    [sym_normal_statement] = STATE(2859),
    [sym_setfiletype_statement] = STATE(2859),
    [sym_options_statement] = STATE(2859),
    [sym_startinsert_statement] = STATE(2859),
    [sym_stopinsert_statement] = STATE(2859),
    [sym_scriptencoding_statement] = STATE(2859),
    [sym_cnext_statement] = STATE(2859),
    [sym_cprevious_statement] = STATE(2859),
    [sym_runtime_statement] = STATE(2859),
    [sym_wincmd_statement] = STATE(2859),
    [sym_source_statement] = STATE(2859),
    [sym_global_statement] = STATE(2859),
    [sym_filetype_statement] = STATE(2859),
    [sym_colorscheme_statement] = STATE(2859),
    [sym_lua_statement] = STATE(2859),
    [sym_ruby_statement] = STATE(2859),
    [sym_python_statement] = STATE(2859),
    [sym_perl_statement] = STATE(2859),
    [sym_for_loop] = STATE(2859),
    [sym_while_loop] = STATE(2859),
    [sym_if_statement] = STATE(2859),
    [sym_try_statement] = STATE(2859),
    [sym_throw_statement] = STATE(2859),
    [sym_bang_filter_statement] = STATE(2859),
    [sym_let_statement] = STATE(2859),
    [sym_const_statement] = STATE(2859),
    [sym_set_statement] = STATE(2859),
    [sym_setlocal_statement] = STATE(2859),
    [sym_unlet_statement] = STATE(2859),
    [sym_call_statement] = STATE(2859),
    [sym_echo_statement] = STATE(2859),
    [sym_echon_statement] = STATE(2859),
    [sym_echohl_statement] = STATE(2859),
    [sym_echomsg_statement] = STATE(2859),
    [sym_echoerr_statement] = STATE(2859),
    [sym_execute_statement] = STATE(2859),
    [sym_silent_statement] = STATE(2859),
    [sym_tab_statement] = STATE(2859),
    [sym_vertical_statement] = STATE(2859),
    [sym_topleft_statement] = STATE(2859),
    [sym_botright_statement] = STATE(2859),
    [sym_aboveleft_statement] = STATE(2859),
    [sym_belowright_statement] = STATE(2859),
    [sym_user_command] = STATE(2859),
    [sym_shebang] = STATE(2859),
    [sym_function_definition] = STATE(2859),
    [sym_range_statement] = STATE(2859),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2859),
    [sym_map_statement] = STATE(2859),
    [sym_sign_statement] = STATE(2859),
    [sym_eval_statement] = STATE(2859),
    [sym_substitute_statement] = STATE(2859),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2859),
    [sym_augroup_statement] = STATE(2859),
    [sym_command_statement] = STATE(2859),
    [sym_comclear_statement] = STATE(2859),
    [sym_delcommand_statement] = STATE(2859),
    [sym_highlight_statement] = STATE(2859),
    [sym_syntax_statement] = STATE(2859),
    [sym_edit_statement] = STATE(2859),
    [sym_enew_statement] = STATE(2859),
    [sym_find_statement] = STATE(2859),
    [sym_ex_statement] = STATE(2859),
    [sym_visual_statement] = STATE(2859),
    [sym_view_statement] = STATE(2859),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_au_once] = ACTIONS(693),
    [sym_au_nested] = ACTIONS(695),
    [sym_command_name] = ACTIONS(33),
    [sym__newline_or_pipe] = ACTIONS(501),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(501),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(57)] = {
    [sym__statement] = STATE(2700),
    [sym_unknown_builtin_statement] = STATE(2700),
    [sym_return_statement] = STATE(2700),
    [sym_break_statement] = STATE(2700),
    [sym_continue_statement] = STATE(2700),
    [sym_normal_statement] = STATE(2700),
    [sym_setfiletype_statement] = STATE(2700),
    [sym_options_statement] = STATE(2700),
    [sym_startinsert_statement] = STATE(2700),
    [sym_stopinsert_statement] = STATE(2700),
    [sym_scriptencoding_statement] = STATE(2700),
    [sym_cnext_statement] = STATE(2700),
    [sym_cprevious_statement] = STATE(2700),
    [sym_runtime_statement] = STATE(2700),
    [sym_wincmd_statement] = STATE(2700),
    [sym_source_statement] = STATE(2700),
    [sym_global_statement] = STATE(2700),
    [sym_filetype_statement] = STATE(2700),
    [sym_colorscheme_statement] = STATE(2700),
    [sym_lua_statement] = STATE(2700),
    [sym_ruby_statement] = STATE(2700),
    [sym_python_statement] = STATE(2700),
    [sym_perl_statement] = STATE(2700),
    [sym_for_loop] = STATE(2700),
    [sym_while_loop] = STATE(2700),
    [sym_if_statement] = STATE(2700),
    [sym_try_statement] = STATE(2700),
    [sym_throw_statement] = STATE(2700),
    [sym_bang_filter_statement] = STATE(2700),
    [sym_let_statement] = STATE(2700),
    [sym_const_statement] = STATE(2700),
    [sym_set_statement] = STATE(2700),
    [sym_setlocal_statement] = STATE(2700),
    [sym_unlet_statement] = STATE(2700),
    [sym_call_statement] = STATE(2700),
    [sym_echo_statement] = STATE(2700),
    [sym_echon_statement] = STATE(2700),
    [sym_echohl_statement] = STATE(2700),
    [sym_echomsg_statement] = STATE(2700),
    [sym_echoerr_statement] = STATE(2700),
    [sym_execute_statement] = STATE(2700),
    [sym_silent_statement] = STATE(2700),
    [sym_tab_statement] = STATE(2700),
    [sym_vertical_statement] = STATE(2700),
    [sym_topleft_statement] = STATE(2700),
    [sym_botright_statement] = STATE(2700),
    [sym_aboveleft_statement] = STATE(2700),
    [sym_belowright_statement] = STATE(2700),
    [sym_user_command] = STATE(2700),
    [sym_shebang] = STATE(2700),
    [sym_function_definition] = STATE(2700),
    [sym_bang] = STATE(70),
    [sym_range_statement] = STATE(2700),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2700),
    [sym_map_statement] = STATE(2700),
    [sym_sign_statement] = STATE(2700),
    [sym_eval_statement] = STATE(2700),
    [sym_substitute_statement] = STATE(2700),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2700),
    [sym_augroup_statement] = STATE(2700),
    [sym_command_statement] = STATE(2700),
    [sym_comclear_statement] = STATE(2700),
    [sym_delcommand_statement] = STATE(2700),
    [sym_highlight_statement] = STATE(2700),
    [sym_syntax_statement] = STATE(2700),
    [sym_edit_statement] = STATE(2700),
    [sym_enew_statement] = STATE(2700),
    [sym_find_statement] = STATE(2700),
    [sym_ex_statement] = STATE(2700),
    [sym_visual_statement] = STATE(2700),
    [sym_view_statement] = STATE(2700),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_BANG] = ACTIONS(697),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(58)] = {
    [sym__statement] = STATE(2948),
    [sym_unknown_builtin_statement] = STATE(2948),
    [sym_return_statement] = STATE(2948),
    [sym_break_statement] = STATE(2948),
    [sym_continue_statement] = STATE(2948),
    [sym_normal_statement] = STATE(2948),
    [sym_setfiletype_statement] = STATE(2948),
    [sym_options_statement] = STATE(2948),
    [sym_startinsert_statement] = STATE(2948),
    [sym_stopinsert_statement] = STATE(2948),
    [sym_scriptencoding_statement] = STATE(2948),
    [sym_cnext_statement] = STATE(2948),
    [sym_cprevious_statement] = STATE(2948),
    [sym_runtime_statement] = STATE(2948),
    [sym_wincmd_statement] = STATE(2948),
    [sym_source_statement] = STATE(2948),
    [sym_global_statement] = STATE(2948),
    [sym_filetype_statement] = STATE(2948),
    [sym_colorscheme_statement] = STATE(2948),
    [sym_lua_statement] = STATE(2948),
    [sym_ruby_statement] = STATE(2948),
    [sym_python_statement] = STATE(2948),
    [sym_perl_statement] = STATE(2948),
    [sym_for_loop] = STATE(2948),
    [sym_while_loop] = STATE(2948),
    [sym_if_statement] = STATE(2948),
    [sym_try_statement] = STATE(2948),
    [sym_throw_statement] = STATE(2948),
    [sym_bang_filter_statement] = STATE(2948),
    [sym_let_statement] = STATE(2948),
    [sym_const_statement] = STATE(2948),
    [sym_set_statement] = STATE(2948),
    [sym_setlocal_statement] = STATE(2948),
    [sym_unlet_statement] = STATE(2948),
    [sym_call_statement] = STATE(2948),
    [sym_echo_statement] = STATE(2948),
    [sym_echon_statement] = STATE(2948),
    [sym_echohl_statement] = STATE(2948),
    [sym_echomsg_statement] = STATE(2948),
    [sym_echoerr_statement] = STATE(2948),
    [sym_execute_statement] = STATE(2948),
    [sym_silent_statement] = STATE(2948),
    [sym_tab_statement] = STATE(2948),
    [sym_vertical_statement] = STATE(2948),
    [sym_topleft_statement] = STATE(2948),
    [sym_botright_statement] = STATE(2948),
    [sym_aboveleft_statement] = STATE(2948),
    [sym_belowright_statement] = STATE(2948),
    [sym_user_command] = STATE(2948),
    [sym_shebang] = STATE(2948),
    [sym_function_definition] = STATE(2948),
    [sym_bang] = STATE(63),
    [sym_range_statement] = STATE(2948),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2948),
    [sym_map_statement] = STATE(2948),
    [sym_sign_statement] = STATE(2948),
    [sym_eval_statement] = STATE(2948),
    [sym_substitute_statement] = STATE(2948),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2948),
    [sym_augroup_statement] = STATE(2948),
    [sym_command_statement] = STATE(2948),
    [sym_comclear_statement] = STATE(2948),
    [sym_delcommand_statement] = STATE(2948),
    [sym_highlight_statement] = STATE(2948),
    [sym_syntax_statement] = STATE(2948),
    [sym_edit_statement] = STATE(2948),
    [sym_enew_statement] = STATE(2948),
    [sym_find_statement] = STATE(2948),
    [sym_ex_statement] = STATE(2948),
    [sym_visual_statement] = STATE(2948),
    [sym_view_statement] = STATE(2948),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_BANG] = ACTIONS(697),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(59)] = {
    [sym__statement] = STATE(2887),
    [sym_unknown_builtin_statement] = STATE(2887),
    [sym_return_statement] = STATE(2887),
    [sym_break_statement] = STATE(2887),
    [sym_continue_statement] = STATE(2887),
    [sym_normal_statement] = STATE(2887),
    [sym_setfiletype_statement] = STATE(2887),
    [sym_options_statement] = STATE(2887),
    [sym_startinsert_statement] = STATE(2887),
    [sym_stopinsert_statement] = STATE(2887),
    [sym_scriptencoding_statement] = STATE(2887),
    [sym_cnext_statement] = STATE(2887),
    [sym_cprevious_statement] = STATE(2887),
    [sym_runtime_statement] = STATE(2887),
    [sym_wincmd_statement] = STATE(2887),
    [sym_source_statement] = STATE(2887),
    [sym_global_statement] = STATE(2887),
    [sym_filetype_statement] = STATE(2887),
    [sym_colorscheme_statement] = STATE(2887),
    [sym_lua_statement] = STATE(2887),
    [sym_ruby_statement] = STATE(2887),
    [sym_python_statement] = STATE(2887),
    [sym_perl_statement] = STATE(2887),
    [sym_for_loop] = STATE(2887),
    [sym_while_loop] = STATE(2887),
    [sym_if_statement] = STATE(2887),
    [sym_try_statement] = STATE(2887),
    [sym_throw_statement] = STATE(2887),
    [sym_bang_filter_statement] = STATE(2887),
    [sym_let_statement] = STATE(2887),
    [sym_const_statement] = STATE(2887),
    [sym_set_statement] = STATE(2887),
    [sym_setlocal_statement] = STATE(2887),
    [sym_unlet_statement] = STATE(2887),
    [sym_call_statement] = STATE(2887),
    [sym_echo_statement] = STATE(2887),
    [sym_echon_statement] = STATE(2887),
    [sym_echohl_statement] = STATE(2887),
    [sym_echomsg_statement] = STATE(2887),
    [sym_echoerr_statement] = STATE(2887),
    [sym_execute_statement] = STATE(2887),
    [sym_silent_statement] = STATE(2887),
    [sym_tab_statement] = STATE(2887),
    [sym_vertical_statement] = STATE(2887),
    [sym_topleft_statement] = STATE(2887),
    [sym_botright_statement] = STATE(2887),
    [sym_aboveleft_statement] = STATE(2887),
    [sym_belowright_statement] = STATE(2887),
    [sym_user_command] = STATE(2887),
    [sym_shebang] = STATE(2887),
    [sym_function_definition] = STATE(2887),
    [sym_range_statement] = STATE(2887),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2887),
    [sym_map_statement] = STATE(2887),
    [sym_sign_statement] = STATE(2887),
    [sym_eval_statement] = STATE(2887),
    [sym_substitute_statement] = STATE(2887),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2887),
    [sym_augroup_statement] = STATE(2887),
    [sym_command_statement] = STATE(2887),
    [sym_comclear_statement] = STATE(2887),
    [sym_delcommand_statement] = STATE(2887),
    [sym_highlight_statement] = STATE(2887),
    [sym_syntax_statement] = STATE(2887),
    [sym_edit_statement] = STATE(2887),
    [sym_enew_statement] = STATE(2887),
    [sym_find_statement] = STATE(2887),
    [sym_ex_statement] = STATE(2887),
    [sym_visual_statement] = STATE(2887),
    [sym_view_statement] = STATE(2887),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_au_nested] = ACTIONS(699),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(60)] = {
    [sym__statement] = STATE(2551),
    [sym_unknown_builtin_statement] = STATE(2551),
    [sym_return_statement] = STATE(2551),
    [sym_break_statement] = STATE(2551),
    [sym_continue_statement] = STATE(2551),
    [sym_normal_statement] = STATE(2551),
    [sym_setfiletype_statement] = STATE(2551),
    [sym_options_statement] = STATE(2551),
    [sym_startinsert_statement] = STATE(2551),
    [sym_stopinsert_statement] = STATE(2551),
    [sym_scriptencoding_statement] = STATE(2551),
    [sym_cnext_statement] = STATE(2551),
    [sym_cprevious_statement] = STATE(2551),
    [sym_runtime_statement] = STATE(2551),
    [sym_wincmd_statement] = STATE(2551),
    [sym_source_statement] = STATE(2551),
    [sym_global_statement] = STATE(2551),
    [sym_filetype_statement] = STATE(2551),
    [sym_colorscheme_statement] = STATE(2551),
    [sym_lua_statement] = STATE(2551),
    [sym_ruby_statement] = STATE(2551),
    [sym_python_statement] = STATE(2551),
    [sym_perl_statement] = STATE(2551),
    [sym_for_loop] = STATE(2551),
    [sym_while_loop] = STATE(2551),
    [sym_if_statement] = STATE(2551),
    [sym_try_statement] = STATE(2551),
    [sym_throw_statement] = STATE(2551),
    [sym_bang_filter_statement] = STATE(2551),
    [sym_let_statement] = STATE(2551),
    [sym_const_statement] = STATE(2551),
    [sym_set_statement] = STATE(2551),
    [sym_setlocal_statement] = STATE(2551),
    [sym_unlet_statement] = STATE(2551),
    [sym_call_statement] = STATE(2551),
    [sym_echo_statement] = STATE(2551),
    [sym_echon_statement] = STATE(2551),
    [sym_echohl_statement] = STATE(2551),
    [sym_echomsg_statement] = STATE(2551),
    [sym_echoerr_statement] = STATE(2551),
    [sym_execute_statement] = STATE(2551),
    [sym_silent_statement] = STATE(2551),
    [sym_tab_statement] = STATE(2551),
    [sym_vertical_statement] = STATE(2551),
    [sym_topleft_statement] = STATE(2551),
    [sym_botright_statement] = STATE(2551),
    [sym_aboveleft_statement] = STATE(2551),
    [sym_belowright_statement] = STATE(2551),
    [sym_user_command] = STATE(2551),
    [sym_shebang] = STATE(2551),
    [sym_function_definition] = STATE(2551),
    [sym_range_statement] = STATE(2551),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2551),
    [sym_map_statement] = STATE(2551),
    [sym_sign_statement] = STATE(2551),
    [sym_eval_statement] = STATE(2551),
    [sym_substitute_statement] = STATE(2551),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2551),
    [sym_augroup_statement] = STATE(2551),
    [sym_command_statement] = STATE(2551),
    [sym_comclear_statement] = STATE(2551),
    [sym_delcommand_statement] = STATE(2551),
    [sym_highlight_statement] = STATE(2551),
    [sym_syntax_statement] = STATE(2551),
    [sym_edit_statement] = STATE(2551),
    [sym_enew_statement] = STATE(2551),
    [sym_find_statement] = STATE(2551),
    [sym_ex_statement] = STATE(2551),
    [sym_visual_statement] = STATE(2551),
    [sym_view_statement] = STATE(2551),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_au_nested] = ACTIONS(701),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(61)] = {
    [sym__statement] = STATE(2829),
    [sym_unknown_builtin_statement] = STATE(2829),
    [sym_return_statement] = STATE(2829),
    [sym_break_statement] = STATE(2829),
    [sym_continue_statement] = STATE(2829),
    [sym_normal_statement] = STATE(2829),
    [sym_setfiletype_statement] = STATE(2829),
    [sym_options_statement] = STATE(2829),
    [sym_startinsert_statement] = STATE(2829),
    [sym_stopinsert_statement] = STATE(2829),
    [sym_scriptencoding_statement] = STATE(2829),
    [sym_cnext_statement] = STATE(2829),
    [sym_cprevious_statement] = STATE(2829),
    [sym_runtime_statement] = STATE(2829),
    [sym_wincmd_statement] = STATE(2829),
    [sym_source_statement] = STATE(2829),
    [sym_global_statement] = STATE(2829),
    [sym_filetype_statement] = STATE(2829),
    [sym_colorscheme_statement] = STATE(2829),
    [sym_lua_statement] = STATE(2829),
    [sym_ruby_statement] = STATE(2829),
    [sym_python_statement] = STATE(2829),
    [sym_perl_statement] = STATE(2829),
    [sym_for_loop] = STATE(2829),
    [sym_while_loop] = STATE(2829),
    [sym_if_statement] = STATE(2829),
    [sym_try_statement] = STATE(2829),
    [sym_throw_statement] = STATE(2829),
    [sym_bang_filter_statement] = STATE(2829),
    [sym_let_statement] = STATE(2829),
    [sym_const_statement] = STATE(2829),
    [sym_set_statement] = STATE(2829),
    [sym_setlocal_statement] = STATE(2829),
    [sym_unlet_statement] = STATE(2829),
    [sym_call_statement] = STATE(2829),
    [sym_echo_statement] = STATE(2829),
    [sym_echon_statement] = STATE(2829),
    [sym_echohl_statement] = STATE(2829),
    [sym_echomsg_statement] = STATE(2829),
    [sym_echoerr_statement] = STATE(2829),
    [sym_execute_statement] = STATE(2829),
    [sym_silent_statement] = STATE(2829),
    [sym_tab_statement] = STATE(2829),
    [sym_vertical_statement] = STATE(2829),
    [sym_topleft_statement] = STATE(2829),
    [sym_botright_statement] = STATE(2829),
    [sym_aboveleft_statement] = STATE(2829),
    [sym_belowright_statement] = STATE(2829),
    [sym_user_command] = STATE(2829),
    [sym_shebang] = STATE(2829),
    [sym_function_definition] = STATE(2829),
    [sym_range_statement] = STATE(2829),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2829),
    [sym_map_statement] = STATE(2829),
    [sym_sign_statement] = STATE(2829),
    [sym_eval_statement] = STATE(2829),
    [sym_substitute_statement] = STATE(2829),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2829),
    [sym_augroup_statement] = STATE(2829),
    [sym_command_statement] = STATE(2829),
    [sym_comclear_statement] = STATE(2829),
    [sym_delcommand_statement] = STATE(2829),
    [sym_highlight_statement] = STATE(2829),
    [sym_syntax_statement] = STATE(2829),
    [sym_edit_statement] = STATE(2829),
    [sym_enew_statement] = STATE(2829),
    [sym_find_statement] = STATE(2829),
    [sym_ex_statement] = STATE(2829),
    [sym_visual_statement] = STATE(2829),
    [sym_view_statement] = STATE(2829),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(62)] = {
    [sym__statement] = STATE(2888),
    [sym_unknown_builtin_statement] = STATE(2888),
    [sym_return_statement] = STATE(2888),
    [sym_break_statement] = STATE(2888),
    [sym_continue_statement] = STATE(2888),
    [sym_normal_statement] = STATE(2888),
    [sym_setfiletype_statement] = STATE(2888),
    [sym_options_statement] = STATE(2888),
    [sym_startinsert_statement] = STATE(2888),
    [sym_stopinsert_statement] = STATE(2888),
    [sym_scriptencoding_statement] = STATE(2888),
    [sym_cnext_statement] = STATE(2888),
    [sym_cprevious_statement] = STATE(2888),
    [sym_runtime_statement] = STATE(2888),
    [sym_wincmd_statement] = STATE(2888),
    [sym_source_statement] = STATE(2888),
    [sym_global_statement] = STATE(2888),
    [sym_filetype_statement] = STATE(2888),
    [sym_colorscheme_statement] = STATE(2888),
    [sym_lua_statement] = STATE(2888),
    [sym_ruby_statement] = STATE(2888),
    [sym_python_statement] = STATE(2888),
    [sym_perl_statement] = STATE(2888),
    [sym_for_loop] = STATE(2888),
    [sym_while_loop] = STATE(2888),
    [sym_if_statement] = STATE(2888),
    [sym_try_statement] = STATE(2888),
    [sym_throw_statement] = STATE(2888),
    [sym_bang_filter_statement] = STATE(2888),
    [sym_let_statement] = STATE(2888),
    [sym_const_statement] = STATE(2888),
    [sym_set_statement] = STATE(2888),
    [sym_setlocal_statement] = STATE(2888),
    [sym_unlet_statement] = STATE(2888),
    [sym_call_statement] = STATE(2888),
    [sym_echo_statement] = STATE(2888),
    [sym_echon_statement] = STATE(2888),
    [sym_echohl_statement] = STATE(2888),
    [sym_echomsg_statement] = STATE(2888),
    [sym_echoerr_statement] = STATE(2888),
    [sym_execute_statement] = STATE(2888),
    [sym_silent_statement] = STATE(2888),
    [sym_tab_statement] = STATE(2888),
    [sym_vertical_statement] = STATE(2888),
    [sym_topleft_statement] = STATE(2888),
    [sym_botright_statement] = STATE(2888),
    [sym_aboveleft_statement] = STATE(2888),
    [sym_belowright_statement] = STATE(2888),
    [sym_user_command] = STATE(2888),
    [sym_shebang] = STATE(2888),
    [sym_function_definition] = STATE(2888),
    [sym_range_statement] = STATE(2888),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2888),
    [sym_map_statement] = STATE(2888),
    [sym_sign_statement] = STATE(2888),
    [sym_eval_statement] = STATE(2888),
    [sym_substitute_statement] = STATE(2888),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2888),
    [sym_augroup_statement] = STATE(2888),
    [sym_command_statement] = STATE(2888),
    [sym_comclear_statement] = STATE(2888),
    [sym_delcommand_statement] = STATE(2888),
    [sym_highlight_statement] = STATE(2888),
    [sym_syntax_statement] = STATE(2888),
    [sym_edit_statement] = STATE(2888),
    [sym_enew_statement] = STATE(2888),
    [sym_find_statement] = STATE(2888),
    [sym_ex_statement] = STATE(2888),
    [sym_visual_statement] = STATE(2888),
    [sym_view_statement] = STATE(2888),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(63)] = {
    [sym__statement] = STATE(2930),
    [sym_unknown_builtin_statement] = STATE(2930),
    [sym_return_statement] = STATE(2930),
    [sym_break_statement] = STATE(2930),
    [sym_continue_statement] = STATE(2930),
    [sym_normal_statement] = STATE(2930),
    [sym_setfiletype_statement] = STATE(2930),
    [sym_options_statement] = STATE(2930),
    [sym_startinsert_statement] = STATE(2930),
    [sym_stopinsert_statement] = STATE(2930),
    [sym_scriptencoding_statement] = STATE(2930),
    [sym_cnext_statement] = STATE(2930),
    [sym_cprevious_statement] = STATE(2930),
    [sym_runtime_statement] = STATE(2930),
    [sym_wincmd_statement] = STATE(2930),
    [sym_source_statement] = STATE(2930),
    [sym_global_statement] = STATE(2930),
    [sym_filetype_statement] = STATE(2930),
    [sym_colorscheme_statement] = STATE(2930),
    [sym_lua_statement] = STATE(2930),
    [sym_ruby_statement] = STATE(2930),
    [sym_python_statement] = STATE(2930),
    [sym_perl_statement] = STATE(2930),
    [sym_for_loop] = STATE(2930),
    [sym_while_loop] = STATE(2930),
    [sym_if_statement] = STATE(2930),
    [sym_try_statement] = STATE(2930),
    [sym_throw_statement] = STATE(2930),
    [sym_bang_filter_statement] = STATE(2930),
    [sym_let_statement] = STATE(2930),
    [sym_const_statement] = STATE(2930),
    [sym_set_statement] = STATE(2930),
    [sym_setlocal_statement] = STATE(2930),
    [sym_unlet_statement] = STATE(2930),
    [sym_call_statement] = STATE(2930),
    [sym_echo_statement] = STATE(2930),
    [sym_echon_statement] = STATE(2930),
    [sym_echohl_statement] = STATE(2930),
    [sym_echomsg_statement] = STATE(2930),
    [sym_echoerr_statement] = STATE(2930),
    [sym_execute_statement] = STATE(2930),
    [sym_silent_statement] = STATE(2930),
    [sym_tab_statement] = STATE(2930),
    [sym_vertical_statement] = STATE(2930),
    [sym_topleft_statement] = STATE(2930),
    [sym_botright_statement] = STATE(2930),
    [sym_aboveleft_statement] = STATE(2930),
    [sym_belowright_statement] = STATE(2930),
    [sym_user_command] = STATE(2930),
    [sym_shebang] = STATE(2930),
    [sym_function_definition] = STATE(2930),
    [sym_range_statement] = STATE(2930),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2930),
    [sym_map_statement] = STATE(2930),
    [sym_sign_statement] = STATE(2930),
    [sym_eval_statement] = STATE(2930),
    [sym_substitute_statement] = STATE(2930),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2930),
    [sym_augroup_statement] = STATE(2930),
    [sym_command_statement] = STATE(2930),
    [sym_comclear_statement] = STATE(2930),
    [sym_delcommand_statement] = STATE(2930),
    [sym_highlight_statement] = STATE(2930),
    [sym_syntax_statement] = STATE(2930),
    [sym_edit_statement] = STATE(2930),
    [sym_enew_statement] = STATE(2930),
    [sym_find_statement] = STATE(2930),
    [sym_ex_statement] = STATE(2930),
    [sym_visual_statement] = STATE(2930),
    [sym_view_statement] = STATE(2930),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(64)] = {
    [sym__statement] = STATE(2453),
    [sym_unknown_builtin_statement] = STATE(2453),
    [sym_return_statement] = STATE(2453),
    [sym_break_statement] = STATE(2453),
    [sym_continue_statement] = STATE(2453),
    [sym_normal_statement] = STATE(2453),
    [sym_setfiletype_statement] = STATE(2453),
    [sym_options_statement] = STATE(2453),
    [sym_startinsert_statement] = STATE(2453),
    [sym_stopinsert_statement] = STATE(2453),
    [sym_scriptencoding_statement] = STATE(2453),
    [sym_cnext_statement] = STATE(2453),
    [sym_cprevious_statement] = STATE(2453),
    [sym_runtime_statement] = STATE(2453),
    [sym_wincmd_statement] = STATE(2453),
    [sym_source_statement] = STATE(2453),
    [sym_global_statement] = STATE(2453),
    [sym_filetype_statement] = STATE(2453),
    [sym_colorscheme_statement] = STATE(2453),
    [sym_lua_statement] = STATE(2453),
    [sym_ruby_statement] = STATE(2453),
    [sym_python_statement] = STATE(2453),
    [sym_perl_statement] = STATE(2453),
    [sym_for_loop] = STATE(2453),
    [sym_while_loop] = STATE(2453),
    [sym_if_statement] = STATE(2453),
    [sym_try_statement] = STATE(2453),
    [sym_throw_statement] = STATE(2453),
    [sym_bang_filter_statement] = STATE(2453),
    [sym_let_statement] = STATE(2453),
    [sym_const_statement] = STATE(2453),
    [sym_set_statement] = STATE(2453),
    [sym_setlocal_statement] = STATE(2453),
    [sym_unlet_statement] = STATE(2453),
    [sym_call_statement] = STATE(2453),
    [sym_echo_statement] = STATE(2453),
    [sym_echon_statement] = STATE(2453),
    [sym_echohl_statement] = STATE(2453),
    [sym_echomsg_statement] = STATE(2453),
    [sym_echoerr_statement] = STATE(2453),
    [sym_execute_statement] = STATE(2453),
    [sym_silent_statement] = STATE(2453),
    [sym_tab_statement] = STATE(2453),
    [sym_vertical_statement] = STATE(2453),
    [sym_topleft_statement] = STATE(2453),
    [sym_botright_statement] = STATE(2453),
    [sym_aboveleft_statement] = STATE(2453),
    [sym_belowright_statement] = STATE(2453),
    [sym_user_command] = STATE(2453),
    [sym_shebang] = STATE(2453),
    [sym_function_definition] = STATE(2453),
    [sym_range_statement] = STATE(2453),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2453),
    [sym_map_statement] = STATE(2453),
    [sym_sign_statement] = STATE(2453),
    [sym_eval_statement] = STATE(2453),
    [sym_substitute_statement] = STATE(2453),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2453),
    [sym_augroup_statement] = STATE(2453),
    [sym_command_statement] = STATE(2453),
    [sym_comclear_statement] = STATE(2453),
    [sym_delcommand_statement] = STATE(2453),
    [sym_highlight_statement] = STATE(2453),
    [sym_syntax_statement] = STATE(2453),
    [sym_edit_statement] = STATE(2453),
    [sym_enew_statement] = STATE(2453),
    [sym_find_statement] = STATE(2453),
    [sym_ex_statement] = STATE(2453),
    [sym_visual_statement] = STATE(2453),
    [sym_view_statement] = STATE(2453),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(65)] = {
    [sym__statement] = STATE(2454),
    [sym_unknown_builtin_statement] = STATE(2454),
    [sym_return_statement] = STATE(2454),
    [sym_break_statement] = STATE(2454),
    [sym_continue_statement] = STATE(2454),
    [sym_normal_statement] = STATE(2454),
    [sym_setfiletype_statement] = STATE(2454),
    [sym_options_statement] = STATE(2454),
    [sym_startinsert_statement] = STATE(2454),
    [sym_stopinsert_statement] = STATE(2454),
    [sym_scriptencoding_statement] = STATE(2454),
    [sym_cnext_statement] = STATE(2454),
    [sym_cprevious_statement] = STATE(2454),
    [sym_runtime_statement] = STATE(2454),
    [sym_wincmd_statement] = STATE(2454),
    [sym_source_statement] = STATE(2454),
    [sym_global_statement] = STATE(2454),
    [sym_filetype_statement] = STATE(2454),
    [sym_colorscheme_statement] = STATE(2454),
    [sym_lua_statement] = STATE(2454),
    [sym_ruby_statement] = STATE(2454),
    [sym_python_statement] = STATE(2454),
    [sym_perl_statement] = STATE(2454),
    [sym_for_loop] = STATE(2454),
    [sym_while_loop] = STATE(2454),
    [sym_if_statement] = STATE(2454),
    [sym_try_statement] = STATE(2454),
    [sym_throw_statement] = STATE(2454),
    [sym_bang_filter_statement] = STATE(2454),
    [sym_let_statement] = STATE(2454),
    [sym_const_statement] = STATE(2454),
    [sym_set_statement] = STATE(2454),
    [sym_setlocal_statement] = STATE(2454),
    [sym_unlet_statement] = STATE(2454),
    [sym_call_statement] = STATE(2454),
    [sym_echo_statement] = STATE(2454),
    [sym_echon_statement] = STATE(2454),
    [sym_echohl_statement] = STATE(2454),
    [sym_echomsg_statement] = STATE(2454),
    [sym_echoerr_statement] = STATE(2454),
    [sym_execute_statement] = STATE(2454),
    [sym_silent_statement] = STATE(2454),
    [sym_tab_statement] = STATE(2454),
    [sym_vertical_statement] = STATE(2454),
    [sym_topleft_statement] = STATE(2454),
    [sym_botright_statement] = STATE(2454),
    [sym_aboveleft_statement] = STATE(2454),
    [sym_belowright_statement] = STATE(2454),
    [sym_user_command] = STATE(2454),
    [sym_shebang] = STATE(2454),
    [sym_function_definition] = STATE(2454),
    [sym_range_statement] = STATE(2454),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2454),
    [sym_map_statement] = STATE(2454),
    [sym_sign_statement] = STATE(2454),
    [sym_eval_statement] = STATE(2454),
    [sym_substitute_statement] = STATE(2454),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2454),
    [sym_augroup_statement] = STATE(2454),
    [sym_command_statement] = STATE(2454),
    [sym_comclear_statement] = STATE(2454),
    [sym_delcommand_statement] = STATE(2454),
    [sym_highlight_statement] = STATE(2454),
    [sym_syntax_statement] = STATE(2454),
    [sym_edit_statement] = STATE(2454),
    [sym_enew_statement] = STATE(2454),
    [sym_find_statement] = STATE(2454),
    [sym_ex_statement] = STATE(2454),
    [sym_visual_statement] = STATE(2454),
    [sym_view_statement] = STATE(2454),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(66)] = {
    [sym__statement] = STATE(2455),
    [sym_unknown_builtin_statement] = STATE(2455),
    [sym_return_statement] = STATE(2455),
    [sym_break_statement] = STATE(2455),
    [sym_continue_statement] = STATE(2455),
    [sym_normal_statement] = STATE(2455),
    [sym_setfiletype_statement] = STATE(2455),
    [sym_options_statement] = STATE(2455),
    [sym_startinsert_statement] = STATE(2455),
    [sym_stopinsert_statement] = STATE(2455),
    [sym_scriptencoding_statement] = STATE(2455),
    [sym_cnext_statement] = STATE(2455),
    [sym_cprevious_statement] = STATE(2455),
    [sym_runtime_statement] = STATE(2455),
    [sym_wincmd_statement] = STATE(2455),
    [sym_source_statement] = STATE(2455),
    [sym_global_statement] = STATE(2455),
    [sym_filetype_statement] = STATE(2455),
    [sym_colorscheme_statement] = STATE(2455),
    [sym_lua_statement] = STATE(2455),
    [sym_ruby_statement] = STATE(2455),
    [sym_python_statement] = STATE(2455),
    [sym_perl_statement] = STATE(2455),
    [sym_for_loop] = STATE(2455),
    [sym_while_loop] = STATE(2455),
    [sym_if_statement] = STATE(2455),
    [sym_try_statement] = STATE(2455),
    [sym_throw_statement] = STATE(2455),
    [sym_bang_filter_statement] = STATE(2455),
    [sym_let_statement] = STATE(2455),
    [sym_const_statement] = STATE(2455),
    [sym_set_statement] = STATE(2455),
    [sym_setlocal_statement] = STATE(2455),
    [sym_unlet_statement] = STATE(2455),
    [sym_call_statement] = STATE(2455),
    [sym_echo_statement] = STATE(2455),
    [sym_echon_statement] = STATE(2455),
    [sym_echohl_statement] = STATE(2455),
    [sym_echomsg_statement] = STATE(2455),
    [sym_echoerr_statement] = STATE(2455),
    [sym_execute_statement] = STATE(2455),
    [sym_silent_statement] = STATE(2455),
    [sym_tab_statement] = STATE(2455),
    [sym_vertical_statement] = STATE(2455),
    [sym_topleft_statement] = STATE(2455),
    [sym_botright_statement] = STATE(2455),
    [sym_aboveleft_statement] = STATE(2455),
    [sym_belowright_statement] = STATE(2455),
    [sym_user_command] = STATE(2455),
    [sym_shebang] = STATE(2455),
    [sym_function_definition] = STATE(2455),
    [sym_range_statement] = STATE(2455),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2455),
    [sym_map_statement] = STATE(2455),
    [sym_sign_statement] = STATE(2455),
    [sym_eval_statement] = STATE(2455),
    [sym_substitute_statement] = STATE(2455),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2455),
    [sym_augroup_statement] = STATE(2455),
    [sym_command_statement] = STATE(2455),
    [sym_comclear_statement] = STATE(2455),
    [sym_delcommand_statement] = STATE(2455),
    [sym_highlight_statement] = STATE(2455),
    [sym_syntax_statement] = STATE(2455),
    [sym_edit_statement] = STATE(2455),
    [sym_enew_statement] = STATE(2455),
    [sym_find_statement] = STATE(2455),
    [sym_ex_statement] = STATE(2455),
    [sym_visual_statement] = STATE(2455),
    [sym_view_statement] = STATE(2455),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(67)] = {
    [sym__statement] = STATE(2456),
    [sym_unknown_builtin_statement] = STATE(2456),
    [sym_return_statement] = STATE(2456),
    [sym_break_statement] = STATE(2456),
    [sym_continue_statement] = STATE(2456),
    [sym_normal_statement] = STATE(2456),
    [sym_setfiletype_statement] = STATE(2456),
    [sym_options_statement] = STATE(2456),
    [sym_startinsert_statement] = STATE(2456),
    [sym_stopinsert_statement] = STATE(2456),
    [sym_scriptencoding_statement] = STATE(2456),
    [sym_cnext_statement] = STATE(2456),
    [sym_cprevious_statement] = STATE(2456),
    [sym_runtime_statement] = STATE(2456),
    [sym_wincmd_statement] = STATE(2456),
    [sym_source_statement] = STATE(2456),
    [sym_global_statement] = STATE(2456),
    [sym_filetype_statement] = STATE(2456),
    [sym_colorscheme_statement] = STATE(2456),
    [sym_lua_statement] = STATE(2456),
    [sym_ruby_statement] = STATE(2456),
    [sym_python_statement] = STATE(2456),
    [sym_perl_statement] = STATE(2456),
    [sym_for_loop] = STATE(2456),
    [sym_while_loop] = STATE(2456),
    [sym_if_statement] = STATE(2456),
    [sym_try_statement] = STATE(2456),
    [sym_throw_statement] = STATE(2456),
    [sym_bang_filter_statement] = STATE(2456),
    [sym_let_statement] = STATE(2456),
    [sym_const_statement] = STATE(2456),
    [sym_set_statement] = STATE(2456),
    [sym_setlocal_statement] = STATE(2456),
    [sym_unlet_statement] = STATE(2456),
    [sym_call_statement] = STATE(2456),
    [sym_echo_statement] = STATE(2456),
    [sym_echon_statement] = STATE(2456),
    [sym_echohl_statement] = STATE(2456),
    [sym_echomsg_statement] = STATE(2456),
    [sym_echoerr_statement] = STATE(2456),
    [sym_execute_statement] = STATE(2456),
    [sym_silent_statement] = STATE(2456),
    [sym_tab_statement] = STATE(2456),
    [sym_vertical_statement] = STATE(2456),
    [sym_topleft_statement] = STATE(2456),
    [sym_botright_statement] = STATE(2456),
    [sym_aboveleft_statement] = STATE(2456),
    [sym_belowright_statement] = STATE(2456),
    [sym_user_command] = STATE(2456),
    [sym_shebang] = STATE(2456),
    [sym_function_definition] = STATE(2456),
    [sym_range_statement] = STATE(2456),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2456),
    [sym_map_statement] = STATE(2456),
    [sym_sign_statement] = STATE(2456),
    [sym_eval_statement] = STATE(2456),
    [sym_substitute_statement] = STATE(2456),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2456),
    [sym_augroup_statement] = STATE(2456),
    [sym_command_statement] = STATE(2456),
    [sym_comclear_statement] = STATE(2456),
    [sym_delcommand_statement] = STATE(2456),
    [sym_highlight_statement] = STATE(2456),
    [sym_syntax_statement] = STATE(2456),
    [sym_edit_statement] = STATE(2456),
    [sym_enew_statement] = STATE(2456),
    [sym_find_statement] = STATE(2456),
    [sym_ex_statement] = STATE(2456),
    [sym_visual_statement] = STATE(2456),
    [sym_view_statement] = STATE(2456),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(68)] = {
    [sym__statement] = STATE(2458),
    [sym_unknown_builtin_statement] = STATE(2458),
    [sym_return_statement] = STATE(2458),
    [sym_break_statement] = STATE(2458),
    [sym_continue_statement] = STATE(2458),
    [sym_normal_statement] = STATE(2458),
    [sym_setfiletype_statement] = STATE(2458),
    [sym_options_statement] = STATE(2458),
    [sym_startinsert_statement] = STATE(2458),
    [sym_stopinsert_statement] = STATE(2458),
    [sym_scriptencoding_statement] = STATE(2458),
    [sym_cnext_statement] = STATE(2458),
    [sym_cprevious_statement] = STATE(2458),
    [sym_runtime_statement] = STATE(2458),
    [sym_wincmd_statement] = STATE(2458),
    [sym_source_statement] = STATE(2458),
    [sym_global_statement] = STATE(2458),
    [sym_filetype_statement] = STATE(2458),
    [sym_colorscheme_statement] = STATE(2458),
    [sym_lua_statement] = STATE(2458),
    [sym_ruby_statement] = STATE(2458),
    [sym_python_statement] = STATE(2458),
    [sym_perl_statement] = STATE(2458),
    [sym_for_loop] = STATE(2458),
    [sym_while_loop] = STATE(2458),
    [sym_if_statement] = STATE(2458),
    [sym_try_statement] = STATE(2458),
    [sym_throw_statement] = STATE(2458),
    [sym_bang_filter_statement] = STATE(2458),
    [sym_let_statement] = STATE(2458),
    [sym_const_statement] = STATE(2458),
    [sym_set_statement] = STATE(2458),
    [sym_setlocal_statement] = STATE(2458),
    [sym_unlet_statement] = STATE(2458),
    [sym_call_statement] = STATE(2458),
    [sym_echo_statement] = STATE(2458),
    [sym_echon_statement] = STATE(2458),
    [sym_echohl_statement] = STATE(2458),
    [sym_echomsg_statement] = STATE(2458),
    [sym_echoerr_statement] = STATE(2458),
    [sym_execute_statement] = STATE(2458),
    [sym_silent_statement] = STATE(2458),
    [sym_tab_statement] = STATE(2458),
    [sym_vertical_statement] = STATE(2458),
    [sym_topleft_statement] = STATE(2458),
    [sym_botright_statement] = STATE(2458),
    [sym_aboveleft_statement] = STATE(2458),
    [sym_belowright_statement] = STATE(2458),
    [sym_user_command] = STATE(2458),
    [sym_shebang] = STATE(2458),
    [sym_function_definition] = STATE(2458),
    [sym_range_statement] = STATE(2458),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2458),
    [sym_map_statement] = STATE(2458),
    [sym_sign_statement] = STATE(2458),
    [sym_eval_statement] = STATE(2458),
    [sym_substitute_statement] = STATE(2458),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2458),
    [sym_augroup_statement] = STATE(2458),
    [sym_command_statement] = STATE(2458),
    [sym_comclear_statement] = STATE(2458),
    [sym_delcommand_statement] = STATE(2458),
    [sym_highlight_statement] = STATE(2458),
    [sym_syntax_statement] = STATE(2458),
    [sym_edit_statement] = STATE(2458),
    [sym_enew_statement] = STATE(2458),
    [sym_find_statement] = STATE(2458),
    [sym_ex_statement] = STATE(2458),
    [sym_visual_statement] = STATE(2458),
    [sym_view_statement] = STATE(2458),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(69)] = {
    [sym__statement] = STATE(2459),
    [sym_unknown_builtin_statement] = STATE(2459),
    [sym_return_statement] = STATE(2459),
    [sym_break_statement] = STATE(2459),
    [sym_continue_statement] = STATE(2459),
    [sym_normal_statement] = STATE(2459),
    [sym_setfiletype_statement] = STATE(2459),
    [sym_options_statement] = STATE(2459),
    [sym_startinsert_statement] = STATE(2459),
    [sym_stopinsert_statement] = STATE(2459),
    [sym_scriptencoding_statement] = STATE(2459),
    [sym_cnext_statement] = STATE(2459),
    [sym_cprevious_statement] = STATE(2459),
    [sym_runtime_statement] = STATE(2459),
    [sym_wincmd_statement] = STATE(2459),
    [sym_source_statement] = STATE(2459),
    [sym_global_statement] = STATE(2459),
    [sym_filetype_statement] = STATE(2459),
    [sym_colorscheme_statement] = STATE(2459),
    [sym_lua_statement] = STATE(2459),
    [sym_ruby_statement] = STATE(2459),
    [sym_python_statement] = STATE(2459),
    [sym_perl_statement] = STATE(2459),
    [sym_for_loop] = STATE(2459),
    [sym_while_loop] = STATE(2459),
    [sym_if_statement] = STATE(2459),
    [sym_try_statement] = STATE(2459),
    [sym_throw_statement] = STATE(2459),
    [sym_bang_filter_statement] = STATE(2459),
    [sym_let_statement] = STATE(2459),
    [sym_const_statement] = STATE(2459),
    [sym_set_statement] = STATE(2459),
    [sym_setlocal_statement] = STATE(2459),
    [sym_unlet_statement] = STATE(2459),
    [sym_call_statement] = STATE(2459),
    [sym_echo_statement] = STATE(2459),
    [sym_echon_statement] = STATE(2459),
    [sym_echohl_statement] = STATE(2459),
    [sym_echomsg_statement] = STATE(2459),
    [sym_echoerr_statement] = STATE(2459),
    [sym_execute_statement] = STATE(2459),
    [sym_silent_statement] = STATE(2459),
    [sym_tab_statement] = STATE(2459),
    [sym_vertical_statement] = STATE(2459),
    [sym_topleft_statement] = STATE(2459),
    [sym_botright_statement] = STATE(2459),
    [sym_aboveleft_statement] = STATE(2459),
    [sym_belowright_statement] = STATE(2459),
    [sym_user_command] = STATE(2459),
    [sym_shebang] = STATE(2459),
    [sym_function_definition] = STATE(2459),
    [sym_range_statement] = STATE(2459),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2459),
    [sym_map_statement] = STATE(2459),
    [sym_sign_statement] = STATE(2459),
    [sym_eval_statement] = STATE(2459),
    [sym_substitute_statement] = STATE(2459),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2459),
    [sym_augroup_statement] = STATE(2459),
    [sym_command_statement] = STATE(2459),
    [sym_comclear_statement] = STATE(2459),
    [sym_delcommand_statement] = STATE(2459),
    [sym_highlight_statement] = STATE(2459),
    [sym_syntax_statement] = STATE(2459),
    [sym_edit_statement] = STATE(2459),
    [sym_enew_statement] = STATE(2459),
    [sym_find_statement] = STATE(2459),
    [sym_ex_statement] = STATE(2459),
    [sym_visual_statement] = STATE(2459),
    [sym_view_statement] = STATE(2459),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(70)] = {
    [sym__statement] = STATE(2624),
    [sym_unknown_builtin_statement] = STATE(2624),
    [sym_return_statement] = STATE(2624),
    [sym_break_statement] = STATE(2624),
    [sym_continue_statement] = STATE(2624),
    [sym_normal_statement] = STATE(2624),
    [sym_setfiletype_statement] = STATE(2624),
    [sym_options_statement] = STATE(2624),
    [sym_startinsert_statement] = STATE(2624),
    [sym_stopinsert_statement] = STATE(2624),
    [sym_scriptencoding_statement] = STATE(2624),
    [sym_cnext_statement] = STATE(2624),
    [sym_cprevious_statement] = STATE(2624),
    [sym_runtime_statement] = STATE(2624),
    [sym_wincmd_statement] = STATE(2624),
    [sym_source_statement] = STATE(2624),
    [sym_global_statement] = STATE(2624),
    [sym_filetype_statement] = STATE(2624),
    [sym_colorscheme_statement] = STATE(2624),
    [sym_lua_statement] = STATE(2624),
    [sym_ruby_statement] = STATE(2624),
    [sym_python_statement] = STATE(2624),
    [sym_perl_statement] = STATE(2624),
    [sym_for_loop] = STATE(2624),
    [sym_while_loop] = STATE(2624),
    [sym_if_statement] = STATE(2624),
    [sym_try_statement] = STATE(2624),
    [sym_throw_statement] = STATE(2624),
    [sym_bang_filter_statement] = STATE(2624),
    [sym_let_statement] = STATE(2624),
    [sym_const_statement] = STATE(2624),
    [sym_set_statement] = STATE(2624),
    [sym_setlocal_statement] = STATE(2624),
    [sym_unlet_statement] = STATE(2624),
    [sym_call_statement] = STATE(2624),
    [sym_echo_statement] = STATE(2624),
    [sym_echon_statement] = STATE(2624),
    [sym_echohl_statement] = STATE(2624),
    [sym_echomsg_statement] = STATE(2624),
    [sym_echoerr_statement] = STATE(2624),
    [sym_execute_statement] = STATE(2624),
    [sym_silent_statement] = STATE(2624),
    [sym_tab_statement] = STATE(2624),
    [sym_vertical_statement] = STATE(2624),
    [sym_topleft_statement] = STATE(2624),
    [sym_botright_statement] = STATE(2624),
    [sym_aboveleft_statement] = STATE(2624),
    [sym_belowright_statement] = STATE(2624),
    [sym_user_command] = STATE(2624),
    [sym_shebang] = STATE(2624),
    [sym_function_definition] = STATE(2624),
    [sym_range_statement] = STATE(2624),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2624),
    [sym_map_statement] = STATE(2624),
    [sym_sign_statement] = STATE(2624),
    [sym_eval_statement] = STATE(2624),
    [sym_substitute_statement] = STATE(2624),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2624),
    [sym_augroup_statement] = STATE(2624),
    [sym_command_statement] = STATE(2624),
    [sym_comclear_statement] = STATE(2624),
    [sym_delcommand_statement] = STATE(2624),
    [sym_highlight_statement] = STATE(2624),
    [sym_syntax_statement] = STATE(2624),
    [sym_edit_statement] = STATE(2624),
    [sym_enew_statement] = STATE(2624),
    [sym_find_statement] = STATE(2624),
    [sym_ex_statement] = STATE(2624),
    [sym_visual_statement] = STATE(2624),
    [sym_view_statement] = STATE(2624),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(71)] = {
    [sym__statement] = STATE(2880),
    [sym_unknown_builtin_statement] = STATE(2880),
    [sym_return_statement] = STATE(2880),
    [sym_break_statement] = STATE(2880),
    [sym_continue_statement] = STATE(2880),
    [sym_normal_statement] = STATE(2880),
    [sym_setfiletype_statement] = STATE(2880),
    [sym_options_statement] = STATE(2880),
    [sym_startinsert_statement] = STATE(2880),
    [sym_stopinsert_statement] = STATE(2880),
    [sym_scriptencoding_statement] = STATE(2880),
    [sym_cnext_statement] = STATE(2880),
    [sym_cprevious_statement] = STATE(2880),
    [sym_runtime_statement] = STATE(2880),
    [sym_wincmd_statement] = STATE(2880),
    [sym_source_statement] = STATE(2880),
    [sym_global_statement] = STATE(2880),
    [sym_filetype_statement] = STATE(2880),
    [sym_colorscheme_statement] = STATE(2880),
    [sym_lua_statement] = STATE(2880),
    [sym_ruby_statement] = STATE(2880),
    [sym_python_statement] = STATE(2880),
    [sym_perl_statement] = STATE(2880),
    [sym_for_loop] = STATE(2880),
    [sym_while_loop] = STATE(2880),
    [sym_if_statement] = STATE(2880),
    [sym_try_statement] = STATE(2880),
    [sym_throw_statement] = STATE(2880),
    [sym_bang_filter_statement] = STATE(2880),
    [sym_let_statement] = STATE(2880),
    [sym_const_statement] = STATE(2880),
    [sym_set_statement] = STATE(2880),
    [sym_setlocal_statement] = STATE(2880),
    [sym_unlet_statement] = STATE(2880),
    [sym_call_statement] = STATE(2880),
    [sym_echo_statement] = STATE(2880),
    [sym_echon_statement] = STATE(2880),
    [sym_echohl_statement] = STATE(2880),
    [sym_echomsg_statement] = STATE(2880),
    [sym_echoerr_statement] = STATE(2880),
    [sym_execute_statement] = STATE(2880),
    [sym_silent_statement] = STATE(2880),
    [sym_tab_statement] = STATE(2880),
    [sym_vertical_statement] = STATE(2880),
    [sym_topleft_statement] = STATE(2880),
    [sym_botright_statement] = STATE(2880),
    [sym_aboveleft_statement] = STATE(2880),
    [sym_belowright_statement] = STATE(2880),
    [sym_user_command] = STATE(2880),
    [sym_shebang] = STATE(2880),
    [sym_function_definition] = STATE(2880),
    [sym_range_statement] = STATE(2880),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2880),
    [sym_map_statement] = STATE(2880),
    [sym_sign_statement] = STATE(2880),
    [sym_eval_statement] = STATE(2880),
    [sym_substitute_statement] = STATE(2880),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2880),
    [sym_augroup_statement] = STATE(2880),
    [sym_command_statement] = STATE(2880),
    [sym_comclear_statement] = STATE(2880),
    [sym_delcommand_statement] = STATE(2880),
    [sym_highlight_statement] = STATE(2880),
    [sym_syntax_statement] = STATE(2880),
    [sym_edit_statement] = STATE(2880),
    [sym_enew_statement] = STATE(2880),
    [sym_find_statement] = STATE(2880),
    [sym_ex_statement] = STATE(2880),
    [sym_visual_statement] = STATE(2880),
    [sym_view_statement] = STATE(2880),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(72)] = {
    [sym__statement] = STATE(2551),
    [sym_unknown_builtin_statement] = STATE(2551),
    [sym_return_statement] = STATE(2551),
    [sym_break_statement] = STATE(2551),
    [sym_continue_statement] = STATE(2551),
    [sym_normal_statement] = STATE(2551),
    [sym_setfiletype_statement] = STATE(2551),
    [sym_options_statement] = STATE(2551),
    [sym_startinsert_statement] = STATE(2551),
    [sym_stopinsert_statement] = STATE(2551),
    [sym_scriptencoding_statement] = STATE(2551),
    [sym_cnext_statement] = STATE(2551),
    [sym_cprevious_statement] = STATE(2551),
    [sym_runtime_statement] = STATE(2551),
    [sym_wincmd_statement] = STATE(2551),
    [sym_source_statement] = STATE(2551),
    [sym_global_statement] = STATE(2551),
    [sym_filetype_statement] = STATE(2551),
    [sym_colorscheme_statement] = STATE(2551),
    [sym_lua_statement] = STATE(2551),
    [sym_ruby_statement] = STATE(2551),
    [sym_python_statement] = STATE(2551),
    [sym_perl_statement] = STATE(2551),
    [sym_for_loop] = STATE(2551),
    [sym_while_loop] = STATE(2551),
    [sym_if_statement] = STATE(2551),
    [sym_try_statement] = STATE(2551),
    [sym_throw_statement] = STATE(2551),
    [sym_bang_filter_statement] = STATE(2551),
    [sym_let_statement] = STATE(2551),
    [sym_const_statement] = STATE(2551),
    [sym_set_statement] = STATE(2551),
    [sym_setlocal_statement] = STATE(2551),
    [sym_unlet_statement] = STATE(2551),
    [sym_call_statement] = STATE(2551),
    [sym_echo_statement] = STATE(2551),
    [sym_echon_statement] = STATE(2551),
    [sym_echohl_statement] = STATE(2551),
    [sym_echomsg_statement] = STATE(2551),
    [sym_echoerr_statement] = STATE(2551),
    [sym_execute_statement] = STATE(2551),
    [sym_silent_statement] = STATE(2551),
    [sym_tab_statement] = STATE(2551),
    [sym_vertical_statement] = STATE(2551),
    [sym_topleft_statement] = STATE(2551),
    [sym_botright_statement] = STATE(2551),
    [sym_aboveleft_statement] = STATE(2551),
    [sym_belowright_statement] = STATE(2551),
    [sym_user_command] = STATE(2551),
    [sym_shebang] = STATE(2551),
    [sym_function_definition] = STATE(2551),
    [sym_range_statement] = STATE(2551),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2551),
    [sym_map_statement] = STATE(2551),
    [sym_sign_statement] = STATE(2551),
    [sym_eval_statement] = STATE(2551),
    [sym_substitute_statement] = STATE(2551),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2551),
    [sym_augroup_statement] = STATE(2551),
    [sym_command_statement] = STATE(2551),
    [sym_comclear_statement] = STATE(2551),
    [sym_delcommand_statement] = STATE(2551),
    [sym_highlight_statement] = STATE(2551),
    [sym_syntax_statement] = STATE(2551),
    [sym_edit_statement] = STATE(2551),
    [sym_enew_statement] = STATE(2551),
    [sym_find_statement] = STATE(2551),
    [sym_ex_statement] = STATE(2551),
    [sym_visual_statement] = STATE(2551),
    [sym_view_statement] = STATE(2551),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(73)] = {
    [sym__statement] = STATE(2783),
    [sym_unknown_builtin_statement] = STATE(2783),
    [sym_return_statement] = STATE(2783),
    [sym_break_statement] = STATE(2783),
    [sym_continue_statement] = STATE(2783),
    [sym_normal_statement] = STATE(2783),
    [sym_setfiletype_statement] = STATE(2783),
    [sym_options_statement] = STATE(2783),
    [sym_startinsert_statement] = STATE(2783),
    [sym_stopinsert_statement] = STATE(2783),
    [sym_scriptencoding_statement] = STATE(2783),
    [sym_cnext_statement] = STATE(2783),
    [sym_cprevious_statement] = STATE(2783),
    [sym_runtime_statement] = STATE(2783),
    [sym_wincmd_statement] = STATE(2783),
    [sym_source_statement] = STATE(2783),
    [sym_global_statement] = STATE(2783),
    [sym_filetype_statement] = STATE(2783),
    [sym_colorscheme_statement] = STATE(2783),
    [sym_lua_statement] = STATE(2783),
    [sym_ruby_statement] = STATE(2783),
    [sym_python_statement] = STATE(2783),
    [sym_perl_statement] = STATE(2783),
    [sym_for_loop] = STATE(2783),
    [sym_while_loop] = STATE(2783),
    [sym_if_statement] = STATE(2783),
    [sym_try_statement] = STATE(2783),
    [sym_throw_statement] = STATE(2783),
    [sym_bang_filter_statement] = STATE(2783),
    [sym_let_statement] = STATE(2783),
    [sym_const_statement] = STATE(2783),
    [sym_set_statement] = STATE(2783),
    [sym_setlocal_statement] = STATE(2783),
    [sym_unlet_statement] = STATE(2783),
    [sym_call_statement] = STATE(2783),
    [sym_echo_statement] = STATE(2783),
    [sym_echon_statement] = STATE(2783),
    [sym_echohl_statement] = STATE(2783),
    [sym_echomsg_statement] = STATE(2783),
    [sym_echoerr_statement] = STATE(2783),
    [sym_execute_statement] = STATE(2783),
    [sym_silent_statement] = STATE(2783),
    [sym_tab_statement] = STATE(2783),
    [sym_vertical_statement] = STATE(2783),
    [sym_topleft_statement] = STATE(2783),
    [sym_botright_statement] = STATE(2783),
    [sym_aboveleft_statement] = STATE(2783),
    [sym_belowright_statement] = STATE(2783),
    [sym_user_command] = STATE(2783),
    [sym_shebang] = STATE(2783),
    [sym_function_definition] = STATE(2783),
    [sym_range_statement] = STATE(2783),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2783),
    [sym_map_statement] = STATE(2783),
    [sym_sign_statement] = STATE(2783),
    [sym_eval_statement] = STATE(2783),
    [sym_substitute_statement] = STATE(2783),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2783),
    [sym_augroup_statement] = STATE(2783),
    [sym_command_statement] = STATE(2783),
    [sym_comclear_statement] = STATE(2783),
    [sym_delcommand_statement] = STATE(2783),
    [sym_highlight_statement] = STATE(2783),
    [sym_syntax_statement] = STATE(2783),
    [sym_edit_statement] = STATE(2783),
    [sym_enew_statement] = STATE(2783),
    [sym_find_statement] = STATE(2783),
    [sym_ex_statement] = STATE(2783),
    [sym_visual_statement] = STATE(2783),
    [sym_view_statement] = STATE(2783),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(74)] = {
    [sym__statement] = STATE(2626),
    [sym_unknown_builtin_statement] = STATE(2626),
    [sym_return_statement] = STATE(2626),
    [sym_break_statement] = STATE(2626),
    [sym_continue_statement] = STATE(2626),
    [sym_normal_statement] = STATE(2626),
    [sym_setfiletype_statement] = STATE(2626),
    [sym_options_statement] = STATE(2626),
    [sym_startinsert_statement] = STATE(2626),
    [sym_stopinsert_statement] = STATE(2626),
    [sym_scriptencoding_statement] = STATE(2626),
    [sym_cnext_statement] = STATE(2626),
    [sym_cprevious_statement] = STATE(2626),
    [sym_runtime_statement] = STATE(2626),
    [sym_wincmd_statement] = STATE(2626),
    [sym_source_statement] = STATE(2626),
    [sym_global_statement] = STATE(2626),
    [sym_filetype_statement] = STATE(2626),
    [sym_colorscheme_statement] = STATE(2626),
    [sym_lua_statement] = STATE(2626),
    [sym_ruby_statement] = STATE(2626),
    [sym_python_statement] = STATE(2626),
    [sym_perl_statement] = STATE(2626),
    [sym_for_loop] = STATE(2626),
    [sym_while_loop] = STATE(2626),
    [sym_if_statement] = STATE(2626),
    [sym_try_statement] = STATE(2626),
    [sym_throw_statement] = STATE(2626),
    [sym_bang_filter_statement] = STATE(2626),
    [sym_let_statement] = STATE(2626),
    [sym_const_statement] = STATE(2626),
    [sym_set_statement] = STATE(2626),
    [sym_setlocal_statement] = STATE(2626),
    [sym_unlet_statement] = STATE(2626),
    [sym_call_statement] = STATE(2626),
    [sym_echo_statement] = STATE(2626),
    [sym_echon_statement] = STATE(2626),
    [sym_echohl_statement] = STATE(2626),
    [sym_echomsg_statement] = STATE(2626),
    [sym_echoerr_statement] = STATE(2626),
    [sym_execute_statement] = STATE(2626),
    [sym_silent_statement] = STATE(2626),
    [sym_tab_statement] = STATE(2626),
    [sym_vertical_statement] = STATE(2626),
    [sym_topleft_statement] = STATE(2626),
    [sym_botright_statement] = STATE(2626),
    [sym_aboveleft_statement] = STATE(2626),
    [sym_belowright_statement] = STATE(2626),
    [sym_user_command] = STATE(2626),
    [sym_shebang] = STATE(2626),
    [sym_function_definition] = STATE(2626),
    [sym_range_statement] = STATE(2626),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2626),
    [sym_map_statement] = STATE(2626),
    [sym_sign_statement] = STATE(2626),
    [sym_eval_statement] = STATE(2626),
    [sym_substitute_statement] = STATE(2626),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2626),
    [sym_augroup_statement] = STATE(2626),
    [sym_command_statement] = STATE(2626),
    [sym_comclear_statement] = STATE(2626),
    [sym_delcommand_statement] = STATE(2626),
    [sym_highlight_statement] = STATE(2626),
    [sym_syntax_statement] = STATE(2626),
    [sym_edit_statement] = STATE(2626),
    [sym_enew_statement] = STATE(2626),
    [sym_find_statement] = STATE(2626),
    [sym_ex_statement] = STATE(2626),
    [sym_visual_statement] = STATE(2626),
    [sym_view_statement] = STATE(2626),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(75)] = {
    [sym__statement] = STATE(2887),
    [sym_unknown_builtin_statement] = STATE(2887),
    [sym_return_statement] = STATE(2887),
    [sym_break_statement] = STATE(2887),
    [sym_continue_statement] = STATE(2887),
    [sym_normal_statement] = STATE(2887),
    [sym_setfiletype_statement] = STATE(2887),
    [sym_options_statement] = STATE(2887),
    [sym_startinsert_statement] = STATE(2887),
    [sym_stopinsert_statement] = STATE(2887),
    [sym_scriptencoding_statement] = STATE(2887),
    [sym_cnext_statement] = STATE(2887),
    [sym_cprevious_statement] = STATE(2887),
    [sym_runtime_statement] = STATE(2887),
    [sym_wincmd_statement] = STATE(2887),
    [sym_source_statement] = STATE(2887),
    [sym_global_statement] = STATE(2887),
    [sym_filetype_statement] = STATE(2887),
    [sym_colorscheme_statement] = STATE(2887),
    [sym_lua_statement] = STATE(2887),
    [sym_ruby_statement] = STATE(2887),
    [sym_python_statement] = STATE(2887),
    [sym_perl_statement] = STATE(2887),
    [sym_for_loop] = STATE(2887),
    [sym_while_loop] = STATE(2887),
    [sym_if_statement] = STATE(2887),
    [sym_try_statement] = STATE(2887),
    [sym_throw_statement] = STATE(2887),
    [sym_bang_filter_statement] = STATE(2887),
    [sym_let_statement] = STATE(2887),
    [sym_const_statement] = STATE(2887),
    [sym_set_statement] = STATE(2887),
    [sym_setlocal_statement] = STATE(2887),
    [sym_unlet_statement] = STATE(2887),
    [sym_call_statement] = STATE(2887),
    [sym_echo_statement] = STATE(2887),
    [sym_echon_statement] = STATE(2887),
    [sym_echohl_statement] = STATE(2887),
    [sym_echomsg_statement] = STATE(2887),
    [sym_echoerr_statement] = STATE(2887),
    [sym_execute_statement] = STATE(2887),
    [sym_silent_statement] = STATE(2887),
    [sym_tab_statement] = STATE(2887),
    [sym_vertical_statement] = STATE(2887),
    [sym_topleft_statement] = STATE(2887),
    [sym_botright_statement] = STATE(2887),
    [sym_aboveleft_statement] = STATE(2887),
    [sym_belowright_statement] = STATE(2887),
    [sym_user_command] = STATE(2887),
    [sym_shebang] = STATE(2887),
    [sym_function_definition] = STATE(2887),
    [sym_range_statement] = STATE(2887),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2887),
    [sym_map_statement] = STATE(2887),
    [sym_sign_statement] = STATE(2887),
    [sym_eval_statement] = STATE(2887),
    [sym_substitute_statement] = STATE(2887),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2887),
    [sym_augroup_statement] = STATE(2887),
    [sym_command_statement] = STATE(2887),
    [sym_comclear_statement] = STATE(2887),
    [sym_delcommand_statement] = STATE(2887),
    [sym_highlight_statement] = STATE(2887),
    [sym_syntax_statement] = STATE(2887),
    [sym_edit_statement] = STATE(2887),
    [sym_enew_statement] = STATE(2887),
    [sym_find_statement] = STATE(2887),
    [sym_ex_statement] = STATE(2887),
    [sym_visual_statement] = STATE(2887),
    [sym_view_statement] = STATE(2887),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(76)] = {
    [sym__statement] = STATE(2240),
    [sym_unknown_builtin_statement] = STATE(2240),
    [sym_return_statement] = STATE(2240),
    [sym_break_statement] = STATE(2240),
    [sym_continue_statement] = STATE(2240),
    [sym_normal_statement] = STATE(2240),
    [sym_setfiletype_statement] = STATE(2240),
    [sym_options_statement] = STATE(2240),
    [sym_startinsert_statement] = STATE(2240),
    [sym_stopinsert_statement] = STATE(2240),
    [sym_scriptencoding_statement] = STATE(2240),
    [sym_cnext_statement] = STATE(2240),
    [sym_cprevious_statement] = STATE(2240),
    [sym_runtime_statement] = STATE(2240),
    [sym_wincmd_statement] = STATE(2240),
    [sym_source_statement] = STATE(2240),
    [sym_global_statement] = STATE(2240),
    [sym_filetype_statement] = STATE(2240),
    [sym_colorscheme_statement] = STATE(2240),
    [sym_lua_statement] = STATE(2240),
    [sym_ruby_statement] = STATE(2240),
    [sym_python_statement] = STATE(2240),
    [sym_perl_statement] = STATE(2240),
    [sym_for_loop] = STATE(2240),
    [sym_while_loop] = STATE(2240),
    [sym_if_statement] = STATE(2240),
    [sym_try_statement] = STATE(2240),
    [sym_throw_statement] = STATE(2240),
    [sym_bang_filter_statement] = STATE(2240),
    [sym_let_statement] = STATE(2240),
    [sym_const_statement] = STATE(2240),
    [sym_set_statement] = STATE(2240),
    [sym_setlocal_statement] = STATE(2240),
    [sym_unlet_statement] = STATE(2240),
    [sym_call_statement] = STATE(2240),
    [sym_echo_statement] = STATE(2240),
    [sym_echon_statement] = STATE(2240),
    [sym_echohl_statement] = STATE(2240),
    [sym_echomsg_statement] = STATE(2240),
    [sym_echoerr_statement] = STATE(2240),
    [sym_execute_statement] = STATE(2240),
    [sym_silent_statement] = STATE(2240),
    [sym_tab_statement] = STATE(2240),
    [sym_vertical_statement] = STATE(2240),
    [sym_topleft_statement] = STATE(2240),
    [sym_botright_statement] = STATE(2240),
    [sym_aboveleft_statement] = STATE(2240),
    [sym_belowright_statement] = STATE(2240),
    [sym_user_command] = STATE(2240),
    [sym_shebang] = STATE(2240),
    [sym_function_definition] = STATE(2240),
    [sym_range_statement] = STATE(2240),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2240),
    [sym_map_statement] = STATE(2240),
    [sym_sign_statement] = STATE(2240),
    [sym_eval_statement] = STATE(2240),
    [sym_substitute_statement] = STATE(2240),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2240),
    [sym_augroup_statement] = STATE(2240),
    [sym_command_statement] = STATE(2240),
    [sym_comclear_statement] = STATE(2240),
    [sym_delcommand_statement] = STATE(2240),
    [sym_highlight_statement] = STATE(2240),
    [sym_syntax_statement] = STATE(2240),
    [sym_edit_statement] = STATE(2240),
    [sym_enew_statement] = STATE(2240),
    [sym_find_statement] = STATE(2240),
    [sym_ex_statement] = STATE(2240),
    [sym_visual_statement] = STATE(2240),
    [sym_view_statement] = STATE(2240),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(77)] = {
    [sym__statement] = STATE(2695),
    [sym_unknown_builtin_statement] = STATE(2695),
    [sym_return_statement] = STATE(2695),
    [sym_break_statement] = STATE(2695),
    [sym_continue_statement] = STATE(2695),
    [sym_normal_statement] = STATE(2695),
    [sym_setfiletype_statement] = STATE(2695),
    [sym_options_statement] = STATE(2695),
    [sym_startinsert_statement] = STATE(2695),
    [sym_stopinsert_statement] = STATE(2695),
    [sym_scriptencoding_statement] = STATE(2695),
    [sym_cnext_statement] = STATE(2695),
    [sym_cprevious_statement] = STATE(2695),
    [sym_runtime_statement] = STATE(2695),
    [sym_wincmd_statement] = STATE(2695),
    [sym_source_statement] = STATE(2695),
    [sym_global_statement] = STATE(2695),
    [sym_filetype_statement] = STATE(2695),
    [sym_colorscheme_statement] = STATE(2695),
    [sym_lua_statement] = STATE(2695),
    [sym_ruby_statement] = STATE(2695),
    [sym_python_statement] = STATE(2695),
    [sym_perl_statement] = STATE(2695),
    [sym_for_loop] = STATE(2695),
    [sym_while_loop] = STATE(2695),
    [sym_if_statement] = STATE(2695),
    [sym_try_statement] = STATE(2695),
    [sym_throw_statement] = STATE(2695),
    [sym_bang_filter_statement] = STATE(2695),
    [sym_let_statement] = STATE(2695),
    [sym_const_statement] = STATE(2695),
    [sym_set_statement] = STATE(2695),
    [sym_setlocal_statement] = STATE(2695),
    [sym_unlet_statement] = STATE(2695),
    [sym_call_statement] = STATE(2695),
    [sym_echo_statement] = STATE(2695),
    [sym_echon_statement] = STATE(2695),
    [sym_echohl_statement] = STATE(2695),
    [sym_echomsg_statement] = STATE(2695),
    [sym_echoerr_statement] = STATE(2695),
    [sym_execute_statement] = STATE(2695),
    [sym_silent_statement] = STATE(2695),
    [sym_tab_statement] = STATE(2695),
    [sym_vertical_statement] = STATE(2695),
    [sym_topleft_statement] = STATE(2695),
    [sym_botright_statement] = STATE(2695),
    [sym_aboveleft_statement] = STATE(2695),
    [sym_belowright_statement] = STATE(2695),
    [sym_user_command] = STATE(2695),
    [sym_shebang] = STATE(2695),
    [sym_function_definition] = STATE(2695),
    [sym_range_statement] = STATE(2695),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2695),
    [sym_map_statement] = STATE(2695),
    [sym_sign_statement] = STATE(2695),
    [sym_eval_statement] = STATE(2695),
    [sym_substitute_statement] = STATE(2695),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2695),
    [sym_augroup_statement] = STATE(2695),
    [sym_command_statement] = STATE(2695),
    [sym_comclear_statement] = STATE(2695),
    [sym_delcommand_statement] = STATE(2695),
    [sym_highlight_statement] = STATE(2695),
    [sym_syntax_statement] = STATE(2695),
    [sym_edit_statement] = STATE(2695),
    [sym_enew_statement] = STATE(2695),
    [sym_find_statement] = STATE(2695),
    [sym_ex_statement] = STATE(2695),
    [sym_visual_statement] = STATE(2695),
    [sym_view_statement] = STATE(2695),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(78)] = {
    [sym__statement] = STATE(2701),
    [sym_unknown_builtin_statement] = STATE(2701),
    [sym_return_statement] = STATE(2701),
    [sym_break_statement] = STATE(2701),
    [sym_continue_statement] = STATE(2701),
    [sym_normal_statement] = STATE(2701),
    [sym_setfiletype_statement] = STATE(2701),
    [sym_options_statement] = STATE(2701),
    [sym_startinsert_statement] = STATE(2701),
    [sym_stopinsert_statement] = STATE(2701),
    [sym_scriptencoding_statement] = STATE(2701),
    [sym_cnext_statement] = STATE(2701),
    [sym_cprevious_statement] = STATE(2701),
    [sym_runtime_statement] = STATE(2701),
    [sym_wincmd_statement] = STATE(2701),
    [sym_source_statement] = STATE(2701),
    [sym_global_statement] = STATE(2701),
    [sym_filetype_statement] = STATE(2701),
    [sym_colorscheme_statement] = STATE(2701),
    [sym_lua_statement] = STATE(2701),
    [sym_ruby_statement] = STATE(2701),
    [sym_python_statement] = STATE(2701),
    [sym_perl_statement] = STATE(2701),
    [sym_for_loop] = STATE(2701),
    [sym_while_loop] = STATE(2701),
    [sym_if_statement] = STATE(2701),
    [sym_try_statement] = STATE(2701),
    [sym_throw_statement] = STATE(2701),
    [sym_bang_filter_statement] = STATE(2701),
    [sym_let_statement] = STATE(2701),
    [sym_const_statement] = STATE(2701),
    [sym_set_statement] = STATE(2701),
    [sym_setlocal_statement] = STATE(2701),
    [sym_unlet_statement] = STATE(2701),
    [sym_call_statement] = STATE(2701),
    [sym_echo_statement] = STATE(2701),
    [sym_echon_statement] = STATE(2701),
    [sym_echohl_statement] = STATE(2701),
    [sym_echomsg_statement] = STATE(2701),
    [sym_echoerr_statement] = STATE(2701),
    [sym_execute_statement] = STATE(2701),
    [sym_silent_statement] = STATE(2701),
    [sym_tab_statement] = STATE(2701),
    [sym_vertical_statement] = STATE(2701),
    [sym_topleft_statement] = STATE(2701),
    [sym_botright_statement] = STATE(2701),
    [sym_aboveleft_statement] = STATE(2701),
    [sym_belowright_statement] = STATE(2701),
    [sym_user_command] = STATE(2701),
    [sym_shebang] = STATE(2701),
    [sym_function_definition] = STATE(2701),
    [sym_range_statement] = STATE(2701),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2701),
    [sym_map_statement] = STATE(2701),
    [sym_sign_statement] = STATE(2701),
    [sym_eval_statement] = STATE(2701),
    [sym_substitute_statement] = STATE(2701),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2701),
    [sym_augroup_statement] = STATE(2701),
    [sym_command_statement] = STATE(2701),
    [sym_comclear_statement] = STATE(2701),
    [sym_delcommand_statement] = STATE(2701),
    [sym_highlight_statement] = STATE(2701),
    [sym_syntax_statement] = STATE(2701),
    [sym_edit_statement] = STATE(2701),
    [sym_enew_statement] = STATE(2701),
    [sym_find_statement] = STATE(2701),
    [sym_ex_statement] = STATE(2701),
    [sym_visual_statement] = STATE(2701),
    [sym_view_statement] = STATE(2701),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(79)] = {
    [sym__statement] = STATE(2722),
    [sym_unknown_builtin_statement] = STATE(2722),
    [sym_return_statement] = STATE(2722),
    [sym_break_statement] = STATE(2722),
    [sym_continue_statement] = STATE(2722),
    [sym_normal_statement] = STATE(2722),
    [sym_setfiletype_statement] = STATE(2722),
    [sym_options_statement] = STATE(2722),
    [sym_startinsert_statement] = STATE(2722),
    [sym_stopinsert_statement] = STATE(2722),
    [sym_scriptencoding_statement] = STATE(2722),
    [sym_cnext_statement] = STATE(2722),
    [sym_cprevious_statement] = STATE(2722),
    [sym_runtime_statement] = STATE(2722),
    [sym_wincmd_statement] = STATE(2722),
    [sym_source_statement] = STATE(2722),
    [sym_global_statement] = STATE(2722),
    [sym_filetype_statement] = STATE(2722),
    [sym_colorscheme_statement] = STATE(2722),
    [sym_lua_statement] = STATE(2722),
    [sym_ruby_statement] = STATE(2722),
    [sym_python_statement] = STATE(2722),
    [sym_perl_statement] = STATE(2722),
    [sym_for_loop] = STATE(2722),
    [sym_while_loop] = STATE(2722),
    [sym_if_statement] = STATE(2722),
    [sym_try_statement] = STATE(2722),
    [sym_throw_statement] = STATE(2722),
    [sym_bang_filter_statement] = STATE(2722),
    [sym_let_statement] = STATE(2722),
    [sym_const_statement] = STATE(2722),
    [sym_set_statement] = STATE(2722),
    [sym_setlocal_statement] = STATE(2722),
    [sym_unlet_statement] = STATE(2722),
    [sym_call_statement] = STATE(2722),
    [sym_echo_statement] = STATE(2722),
    [sym_echon_statement] = STATE(2722),
    [sym_echohl_statement] = STATE(2722),
    [sym_echomsg_statement] = STATE(2722),
    [sym_echoerr_statement] = STATE(2722),
    [sym_execute_statement] = STATE(2722),
    [sym_silent_statement] = STATE(2722),
    [sym_tab_statement] = STATE(2722),
    [sym_vertical_statement] = STATE(2722),
    [sym_topleft_statement] = STATE(2722),
    [sym_botright_statement] = STATE(2722),
    [sym_aboveleft_statement] = STATE(2722),
    [sym_belowright_statement] = STATE(2722),
    [sym_user_command] = STATE(2722),
    [sym_shebang] = STATE(2722),
    [sym_function_definition] = STATE(2722),
    [sym_range_statement] = STATE(2722),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2722),
    [sym_map_statement] = STATE(2722),
    [sym_sign_statement] = STATE(2722),
    [sym_eval_statement] = STATE(2722),
    [sym_substitute_statement] = STATE(2722),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2722),
    [sym_augroup_statement] = STATE(2722),
    [sym_command_statement] = STATE(2722),
    [sym_comclear_statement] = STATE(2722),
    [sym_delcommand_statement] = STATE(2722),
    [sym_highlight_statement] = STATE(2722),
    [sym_syntax_statement] = STATE(2722),
    [sym_edit_statement] = STATE(2722),
    [sym_enew_statement] = STATE(2722),
    [sym_find_statement] = STATE(2722),
    [sym_ex_statement] = STATE(2722),
    [sym_visual_statement] = STATE(2722),
    [sym_view_statement] = STATE(2722),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(80)] = {
    [sym__statement] = STATE(2723),
    [sym_unknown_builtin_statement] = STATE(2723),
    [sym_return_statement] = STATE(2723),
    [sym_break_statement] = STATE(2723),
    [sym_continue_statement] = STATE(2723),
    [sym_normal_statement] = STATE(2723),
    [sym_setfiletype_statement] = STATE(2723),
    [sym_options_statement] = STATE(2723),
    [sym_startinsert_statement] = STATE(2723),
    [sym_stopinsert_statement] = STATE(2723),
    [sym_scriptencoding_statement] = STATE(2723),
    [sym_cnext_statement] = STATE(2723),
    [sym_cprevious_statement] = STATE(2723),
    [sym_runtime_statement] = STATE(2723),
    [sym_wincmd_statement] = STATE(2723),
    [sym_source_statement] = STATE(2723),
    [sym_global_statement] = STATE(2723),
    [sym_filetype_statement] = STATE(2723),
    [sym_colorscheme_statement] = STATE(2723),
    [sym_lua_statement] = STATE(2723),
    [sym_ruby_statement] = STATE(2723),
    [sym_python_statement] = STATE(2723),
    [sym_perl_statement] = STATE(2723),
    [sym_for_loop] = STATE(2723),
    [sym_while_loop] = STATE(2723),
    [sym_if_statement] = STATE(2723),
    [sym_try_statement] = STATE(2723),
    [sym_throw_statement] = STATE(2723),
    [sym_bang_filter_statement] = STATE(2723),
    [sym_let_statement] = STATE(2723),
    [sym_const_statement] = STATE(2723),
    [sym_set_statement] = STATE(2723),
    [sym_setlocal_statement] = STATE(2723),
    [sym_unlet_statement] = STATE(2723),
    [sym_call_statement] = STATE(2723),
    [sym_echo_statement] = STATE(2723),
    [sym_echon_statement] = STATE(2723),
    [sym_echohl_statement] = STATE(2723),
    [sym_echomsg_statement] = STATE(2723),
    [sym_echoerr_statement] = STATE(2723),
    [sym_execute_statement] = STATE(2723),
    [sym_silent_statement] = STATE(2723),
    [sym_tab_statement] = STATE(2723),
    [sym_vertical_statement] = STATE(2723),
    [sym_topleft_statement] = STATE(2723),
    [sym_botright_statement] = STATE(2723),
    [sym_aboveleft_statement] = STATE(2723),
    [sym_belowright_statement] = STATE(2723),
    [sym_user_command] = STATE(2723),
    [sym_shebang] = STATE(2723),
    [sym_function_definition] = STATE(2723),
    [sym_range_statement] = STATE(2723),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2723),
    [sym_map_statement] = STATE(2723),
    [sym_sign_statement] = STATE(2723),
    [sym_eval_statement] = STATE(2723),
    [sym_substitute_statement] = STATE(2723),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2723),
    [sym_augroup_statement] = STATE(2723),
    [sym_command_statement] = STATE(2723),
    [sym_comclear_statement] = STATE(2723),
    [sym_delcommand_statement] = STATE(2723),
    [sym_highlight_statement] = STATE(2723),
    [sym_syntax_statement] = STATE(2723),
    [sym_edit_statement] = STATE(2723),
    [sym_enew_statement] = STATE(2723),
    [sym_find_statement] = STATE(2723),
    [sym_ex_statement] = STATE(2723),
    [sym_visual_statement] = STATE(2723),
    [sym_view_statement] = STATE(2723),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(81)] = {
    [sym__statement] = STATE(2737),
    [sym_unknown_builtin_statement] = STATE(2737),
    [sym_return_statement] = STATE(2737),
    [sym_break_statement] = STATE(2737),
    [sym_continue_statement] = STATE(2737),
    [sym_normal_statement] = STATE(2737),
    [sym_setfiletype_statement] = STATE(2737),
    [sym_options_statement] = STATE(2737),
    [sym_startinsert_statement] = STATE(2737),
    [sym_stopinsert_statement] = STATE(2737),
    [sym_scriptencoding_statement] = STATE(2737),
    [sym_cnext_statement] = STATE(2737),
    [sym_cprevious_statement] = STATE(2737),
    [sym_runtime_statement] = STATE(2737),
    [sym_wincmd_statement] = STATE(2737),
    [sym_source_statement] = STATE(2737),
    [sym_global_statement] = STATE(2737),
    [sym_filetype_statement] = STATE(2737),
    [sym_colorscheme_statement] = STATE(2737),
    [sym_lua_statement] = STATE(2737),
    [sym_ruby_statement] = STATE(2737),
    [sym_python_statement] = STATE(2737),
    [sym_perl_statement] = STATE(2737),
    [sym_for_loop] = STATE(2737),
    [sym_while_loop] = STATE(2737),
    [sym_if_statement] = STATE(2737),
    [sym_try_statement] = STATE(2737),
    [sym_throw_statement] = STATE(2737),
    [sym_bang_filter_statement] = STATE(2737),
    [sym_let_statement] = STATE(2737),
    [sym_const_statement] = STATE(2737),
    [sym_set_statement] = STATE(2737),
    [sym_setlocal_statement] = STATE(2737),
    [sym_unlet_statement] = STATE(2737),
    [sym_call_statement] = STATE(2737),
    [sym_echo_statement] = STATE(2737),
    [sym_echon_statement] = STATE(2737),
    [sym_echohl_statement] = STATE(2737),
    [sym_echomsg_statement] = STATE(2737),
    [sym_echoerr_statement] = STATE(2737),
    [sym_execute_statement] = STATE(2737),
    [sym_silent_statement] = STATE(2737),
    [sym_tab_statement] = STATE(2737),
    [sym_vertical_statement] = STATE(2737),
    [sym_topleft_statement] = STATE(2737),
    [sym_botright_statement] = STATE(2737),
    [sym_aboveleft_statement] = STATE(2737),
    [sym_belowright_statement] = STATE(2737),
    [sym_user_command] = STATE(2737),
    [sym_shebang] = STATE(2737),
    [sym_function_definition] = STATE(2737),
    [sym_range_statement] = STATE(2737),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2737),
    [sym_map_statement] = STATE(2737),
    [sym_sign_statement] = STATE(2737),
    [sym_eval_statement] = STATE(2737),
    [sym_substitute_statement] = STATE(2737),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2737),
    [sym_augroup_statement] = STATE(2737),
    [sym_command_statement] = STATE(2737),
    [sym_comclear_statement] = STATE(2737),
    [sym_delcommand_statement] = STATE(2737),
    [sym_highlight_statement] = STATE(2737),
    [sym_syntax_statement] = STATE(2737),
    [sym_edit_statement] = STATE(2737),
    [sym_enew_statement] = STATE(2737),
    [sym_find_statement] = STATE(2737),
    [sym_ex_statement] = STATE(2737),
    [sym_visual_statement] = STATE(2737),
    [sym_view_statement] = STATE(2737),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(82)] = {
    [sym__statement] = STATE(2786),
    [sym_unknown_builtin_statement] = STATE(2786),
    [sym_return_statement] = STATE(2786),
    [sym_break_statement] = STATE(2786),
    [sym_continue_statement] = STATE(2786),
    [sym_normal_statement] = STATE(2786),
    [sym_setfiletype_statement] = STATE(2786),
    [sym_options_statement] = STATE(2786),
    [sym_startinsert_statement] = STATE(2786),
    [sym_stopinsert_statement] = STATE(2786),
    [sym_scriptencoding_statement] = STATE(2786),
    [sym_cnext_statement] = STATE(2786),
    [sym_cprevious_statement] = STATE(2786),
    [sym_runtime_statement] = STATE(2786),
    [sym_wincmd_statement] = STATE(2786),
    [sym_source_statement] = STATE(2786),
    [sym_global_statement] = STATE(2786),
    [sym_filetype_statement] = STATE(2786),
    [sym_colorscheme_statement] = STATE(2786),
    [sym_lua_statement] = STATE(2786),
    [sym_ruby_statement] = STATE(2786),
    [sym_python_statement] = STATE(2786),
    [sym_perl_statement] = STATE(2786),
    [sym_for_loop] = STATE(2786),
    [sym_while_loop] = STATE(2786),
    [sym_if_statement] = STATE(2786),
    [sym_try_statement] = STATE(2786),
    [sym_throw_statement] = STATE(2786),
    [sym_bang_filter_statement] = STATE(2786),
    [sym_let_statement] = STATE(2786),
    [sym_const_statement] = STATE(2786),
    [sym_set_statement] = STATE(2786),
    [sym_setlocal_statement] = STATE(2786),
    [sym_unlet_statement] = STATE(2786),
    [sym_call_statement] = STATE(2786),
    [sym_echo_statement] = STATE(2786),
    [sym_echon_statement] = STATE(2786),
    [sym_echohl_statement] = STATE(2786),
    [sym_echomsg_statement] = STATE(2786),
    [sym_echoerr_statement] = STATE(2786),
    [sym_execute_statement] = STATE(2786),
    [sym_silent_statement] = STATE(2786),
    [sym_tab_statement] = STATE(2786),
    [sym_vertical_statement] = STATE(2786),
    [sym_topleft_statement] = STATE(2786),
    [sym_botright_statement] = STATE(2786),
    [sym_aboveleft_statement] = STATE(2786),
    [sym_belowright_statement] = STATE(2786),
    [sym_user_command] = STATE(2786),
    [sym_shebang] = STATE(2786),
    [sym_function_definition] = STATE(2786),
    [sym_range_statement] = STATE(2786),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2786),
    [sym_map_statement] = STATE(2786),
    [sym_sign_statement] = STATE(2786),
    [sym_eval_statement] = STATE(2786),
    [sym_substitute_statement] = STATE(2786),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2786),
    [sym_augroup_statement] = STATE(2786),
    [sym_command_statement] = STATE(2786),
    [sym_comclear_statement] = STATE(2786),
    [sym_delcommand_statement] = STATE(2786),
    [sym_highlight_statement] = STATE(2786),
    [sym_syntax_statement] = STATE(2786),
    [sym_edit_statement] = STATE(2786),
    [sym_enew_statement] = STATE(2786),
    [sym_find_statement] = STATE(2786),
    [sym_ex_statement] = STATE(2786),
    [sym_visual_statement] = STATE(2786),
    [sym_view_statement] = STATE(2786),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(83)] = {
    [sym__statement] = STATE(2889),
    [sym_unknown_builtin_statement] = STATE(2889),
    [sym_return_statement] = STATE(2889),
    [sym_break_statement] = STATE(2889),
    [sym_continue_statement] = STATE(2889),
    [sym_normal_statement] = STATE(2889),
    [sym_setfiletype_statement] = STATE(2889),
    [sym_options_statement] = STATE(2889),
    [sym_startinsert_statement] = STATE(2889),
    [sym_stopinsert_statement] = STATE(2889),
    [sym_scriptencoding_statement] = STATE(2889),
    [sym_cnext_statement] = STATE(2889),
    [sym_cprevious_statement] = STATE(2889),
    [sym_runtime_statement] = STATE(2889),
    [sym_wincmd_statement] = STATE(2889),
    [sym_source_statement] = STATE(2889),
    [sym_global_statement] = STATE(2889),
    [sym_filetype_statement] = STATE(2889),
    [sym_colorscheme_statement] = STATE(2889),
    [sym_lua_statement] = STATE(2889),
    [sym_ruby_statement] = STATE(2889),
    [sym_python_statement] = STATE(2889),
    [sym_perl_statement] = STATE(2889),
    [sym_for_loop] = STATE(2889),
    [sym_while_loop] = STATE(2889),
    [sym_if_statement] = STATE(2889),
    [sym_try_statement] = STATE(2889),
    [sym_throw_statement] = STATE(2889),
    [sym_bang_filter_statement] = STATE(2889),
    [sym_let_statement] = STATE(2889),
    [sym_const_statement] = STATE(2889),
    [sym_set_statement] = STATE(2889),
    [sym_setlocal_statement] = STATE(2889),
    [sym_unlet_statement] = STATE(2889),
    [sym_call_statement] = STATE(2889),
    [sym_echo_statement] = STATE(2889),
    [sym_echon_statement] = STATE(2889),
    [sym_echohl_statement] = STATE(2889),
    [sym_echomsg_statement] = STATE(2889),
    [sym_echoerr_statement] = STATE(2889),
    [sym_execute_statement] = STATE(2889),
    [sym_silent_statement] = STATE(2889),
    [sym_tab_statement] = STATE(2889),
    [sym_vertical_statement] = STATE(2889),
    [sym_topleft_statement] = STATE(2889),
    [sym_botright_statement] = STATE(2889),
    [sym_aboveleft_statement] = STATE(2889),
    [sym_belowright_statement] = STATE(2889),
    [sym_user_command] = STATE(2889),
    [sym_shebang] = STATE(2889),
    [sym_function_definition] = STATE(2889),
    [sym_range_statement] = STATE(2889),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2889),
    [sym_map_statement] = STATE(2889),
    [sym_sign_statement] = STATE(2889),
    [sym_eval_statement] = STATE(2889),
    [sym_substitute_statement] = STATE(2889),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2889),
    [sym_augroup_statement] = STATE(2889),
    [sym_command_statement] = STATE(2889),
    [sym_comclear_statement] = STATE(2889),
    [sym_delcommand_statement] = STATE(2889),
    [sym_highlight_statement] = STATE(2889),
    [sym_syntax_statement] = STATE(2889),
    [sym_edit_statement] = STATE(2889),
    [sym_enew_statement] = STATE(2889),
    [sym_find_statement] = STATE(2889),
    [sym_ex_statement] = STATE(2889),
    [sym_visual_statement] = STATE(2889),
    [sym_view_statement] = STATE(2889),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(84)] = {
    [sym__statement] = STATE(2940),
    [sym_unknown_builtin_statement] = STATE(2940),
    [sym_return_statement] = STATE(2940),
    [sym_break_statement] = STATE(2940),
    [sym_continue_statement] = STATE(2940),
    [sym_normal_statement] = STATE(2940),
    [sym_setfiletype_statement] = STATE(2940),
    [sym_options_statement] = STATE(2940),
    [sym_startinsert_statement] = STATE(2940),
    [sym_stopinsert_statement] = STATE(2940),
    [sym_scriptencoding_statement] = STATE(2940),
    [sym_cnext_statement] = STATE(2940),
    [sym_cprevious_statement] = STATE(2940),
    [sym_runtime_statement] = STATE(2940),
    [sym_wincmd_statement] = STATE(2940),
    [sym_source_statement] = STATE(2940),
    [sym_global_statement] = STATE(2940),
    [sym_filetype_statement] = STATE(2940),
    [sym_colorscheme_statement] = STATE(2940),
    [sym_lua_statement] = STATE(2940),
    [sym_ruby_statement] = STATE(2940),
    [sym_python_statement] = STATE(2940),
    [sym_perl_statement] = STATE(2940),
    [sym_for_loop] = STATE(2940),
    [sym_while_loop] = STATE(2940),
    [sym_if_statement] = STATE(2940),
    [sym_try_statement] = STATE(2940),
    [sym_throw_statement] = STATE(2940),
    [sym_bang_filter_statement] = STATE(2940),
    [sym_let_statement] = STATE(2940),
    [sym_const_statement] = STATE(2940),
    [sym_set_statement] = STATE(2940),
    [sym_setlocal_statement] = STATE(2940),
    [sym_unlet_statement] = STATE(2940),
    [sym_call_statement] = STATE(2940),
    [sym_echo_statement] = STATE(2940),
    [sym_echon_statement] = STATE(2940),
    [sym_echohl_statement] = STATE(2940),
    [sym_echomsg_statement] = STATE(2940),
    [sym_echoerr_statement] = STATE(2940),
    [sym_execute_statement] = STATE(2940),
    [sym_silent_statement] = STATE(2940),
    [sym_tab_statement] = STATE(2940),
    [sym_vertical_statement] = STATE(2940),
    [sym_topleft_statement] = STATE(2940),
    [sym_botright_statement] = STATE(2940),
    [sym_aboveleft_statement] = STATE(2940),
    [sym_belowright_statement] = STATE(2940),
    [sym_user_command] = STATE(2940),
    [sym_shebang] = STATE(2940),
    [sym_function_definition] = STATE(2940),
    [sym_range_statement] = STATE(2940),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2940),
    [sym_map_statement] = STATE(2940),
    [sym_sign_statement] = STATE(2940),
    [sym_eval_statement] = STATE(2940),
    [sym_substitute_statement] = STATE(2940),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2940),
    [sym_augroup_statement] = STATE(2940),
    [sym_command_statement] = STATE(2940),
    [sym_comclear_statement] = STATE(2940),
    [sym_delcommand_statement] = STATE(2940),
    [sym_highlight_statement] = STATE(2940),
    [sym_syntax_statement] = STATE(2940),
    [sym_edit_statement] = STATE(2940),
    [sym_enew_statement] = STATE(2940),
    [sym_find_statement] = STATE(2940),
    [sym_ex_statement] = STATE(2940),
    [sym_visual_statement] = STATE(2940),
    [sym_view_statement] = STATE(2940),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(85)] = {
    [sym__statement] = STATE(2822),
    [sym_unknown_builtin_statement] = STATE(2822),
    [sym_return_statement] = STATE(2822),
    [sym_break_statement] = STATE(2822),
    [sym_continue_statement] = STATE(2822),
    [sym_normal_statement] = STATE(2822),
    [sym_setfiletype_statement] = STATE(2822),
    [sym_options_statement] = STATE(2822),
    [sym_startinsert_statement] = STATE(2822),
    [sym_stopinsert_statement] = STATE(2822),
    [sym_scriptencoding_statement] = STATE(2822),
    [sym_cnext_statement] = STATE(2822),
    [sym_cprevious_statement] = STATE(2822),
    [sym_runtime_statement] = STATE(2822),
    [sym_wincmd_statement] = STATE(2822),
    [sym_source_statement] = STATE(2822),
    [sym_global_statement] = STATE(2822),
    [sym_filetype_statement] = STATE(2822),
    [sym_colorscheme_statement] = STATE(2822),
    [sym_lua_statement] = STATE(2822),
    [sym_ruby_statement] = STATE(2822),
    [sym_python_statement] = STATE(2822),
    [sym_perl_statement] = STATE(2822),
    [sym_for_loop] = STATE(2822),
    [sym_while_loop] = STATE(2822),
    [sym_if_statement] = STATE(2822),
    [sym_try_statement] = STATE(2822),
    [sym_throw_statement] = STATE(2822),
    [sym_bang_filter_statement] = STATE(2822),
    [sym_let_statement] = STATE(2822),
    [sym_const_statement] = STATE(2822),
    [sym_set_statement] = STATE(2822),
    [sym_setlocal_statement] = STATE(2822),
    [sym_unlet_statement] = STATE(2822),
    [sym_call_statement] = STATE(2822),
    [sym_echo_statement] = STATE(2822),
    [sym_echon_statement] = STATE(2822),
    [sym_echohl_statement] = STATE(2822),
    [sym_echomsg_statement] = STATE(2822),
    [sym_echoerr_statement] = STATE(2822),
    [sym_execute_statement] = STATE(2822),
    [sym_silent_statement] = STATE(2822),
    [sym_tab_statement] = STATE(2822),
    [sym_vertical_statement] = STATE(2822),
    [sym_topleft_statement] = STATE(2822),
    [sym_botright_statement] = STATE(2822),
    [sym_aboveleft_statement] = STATE(2822),
    [sym_belowright_statement] = STATE(2822),
    [sym_user_command] = STATE(2822),
    [sym_shebang] = STATE(2822),
    [sym_function_definition] = STATE(2822),
    [sym_range_statement] = STATE(2822),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2822),
    [sym_map_statement] = STATE(2822),
    [sym_sign_statement] = STATE(2822),
    [sym_eval_statement] = STATE(2822),
    [sym_substitute_statement] = STATE(2822),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2822),
    [sym_augroup_statement] = STATE(2822),
    [sym_command_statement] = STATE(2822),
    [sym_comclear_statement] = STATE(2822),
    [sym_delcommand_statement] = STATE(2822),
    [sym_highlight_statement] = STATE(2822),
    [sym_syntax_statement] = STATE(2822),
    [sym_edit_statement] = STATE(2822),
    [sym_enew_statement] = STATE(2822),
    [sym_find_statement] = STATE(2822),
    [sym_ex_statement] = STATE(2822),
    [sym_visual_statement] = STATE(2822),
    [sym_view_statement] = STATE(2822),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(86)] = {
    [sym__statement] = STATE(2830),
    [sym_unknown_builtin_statement] = STATE(2830),
    [sym_return_statement] = STATE(2830),
    [sym_break_statement] = STATE(2830),
    [sym_continue_statement] = STATE(2830),
    [sym_normal_statement] = STATE(2830),
    [sym_setfiletype_statement] = STATE(2830),
    [sym_options_statement] = STATE(2830),
    [sym_startinsert_statement] = STATE(2830),
    [sym_stopinsert_statement] = STATE(2830),
    [sym_scriptencoding_statement] = STATE(2830),
    [sym_cnext_statement] = STATE(2830),
    [sym_cprevious_statement] = STATE(2830),
    [sym_runtime_statement] = STATE(2830),
    [sym_wincmd_statement] = STATE(2830),
    [sym_source_statement] = STATE(2830),
    [sym_global_statement] = STATE(2830),
    [sym_filetype_statement] = STATE(2830),
    [sym_colorscheme_statement] = STATE(2830),
    [sym_lua_statement] = STATE(2830),
    [sym_ruby_statement] = STATE(2830),
    [sym_python_statement] = STATE(2830),
    [sym_perl_statement] = STATE(2830),
    [sym_for_loop] = STATE(2830),
    [sym_while_loop] = STATE(2830),
    [sym_if_statement] = STATE(2830),
    [sym_try_statement] = STATE(2830),
    [sym_throw_statement] = STATE(2830),
    [sym_bang_filter_statement] = STATE(2830),
    [sym_let_statement] = STATE(2830),
    [sym_const_statement] = STATE(2830),
    [sym_set_statement] = STATE(2830),
    [sym_setlocal_statement] = STATE(2830),
    [sym_unlet_statement] = STATE(2830),
    [sym_call_statement] = STATE(2830),
    [sym_echo_statement] = STATE(2830),
    [sym_echon_statement] = STATE(2830),
    [sym_echohl_statement] = STATE(2830),
    [sym_echomsg_statement] = STATE(2830),
    [sym_echoerr_statement] = STATE(2830),
    [sym_execute_statement] = STATE(2830),
    [sym_silent_statement] = STATE(2830),
    [sym_tab_statement] = STATE(2830),
    [sym_vertical_statement] = STATE(2830),
    [sym_topleft_statement] = STATE(2830),
    [sym_botright_statement] = STATE(2830),
    [sym_aboveleft_statement] = STATE(2830),
    [sym_belowright_statement] = STATE(2830),
    [sym_user_command] = STATE(2830),
    [sym_shebang] = STATE(2830),
    [sym_function_definition] = STATE(2830),
    [sym_range_statement] = STATE(2830),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2830),
    [sym_map_statement] = STATE(2830),
    [sym_sign_statement] = STATE(2830),
    [sym_eval_statement] = STATE(2830),
    [sym_substitute_statement] = STATE(2830),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2830),
    [sym_augroup_statement] = STATE(2830),
    [sym_command_statement] = STATE(2830),
    [sym_comclear_statement] = STATE(2830),
    [sym_delcommand_statement] = STATE(2830),
    [sym_highlight_statement] = STATE(2830),
    [sym_syntax_statement] = STATE(2830),
    [sym_edit_statement] = STATE(2830),
    [sym_enew_statement] = STATE(2830),
    [sym_find_statement] = STATE(2830),
    [sym_ex_statement] = STATE(2830),
    [sym_visual_statement] = STATE(2830),
    [sym_view_statement] = STATE(2830),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(87)] = {
    [sym__statement] = STATE(2820),
    [sym_unknown_builtin_statement] = STATE(2820),
    [sym_return_statement] = STATE(2820),
    [sym_break_statement] = STATE(2820),
    [sym_continue_statement] = STATE(2820),
    [sym_normal_statement] = STATE(2820),
    [sym_setfiletype_statement] = STATE(2820),
    [sym_options_statement] = STATE(2820),
    [sym_startinsert_statement] = STATE(2820),
    [sym_stopinsert_statement] = STATE(2820),
    [sym_scriptencoding_statement] = STATE(2820),
    [sym_cnext_statement] = STATE(2820),
    [sym_cprevious_statement] = STATE(2820),
    [sym_runtime_statement] = STATE(2820),
    [sym_wincmd_statement] = STATE(2820),
    [sym_source_statement] = STATE(2820),
    [sym_global_statement] = STATE(2820),
    [sym_filetype_statement] = STATE(2820),
    [sym_colorscheme_statement] = STATE(2820),
    [sym_lua_statement] = STATE(2820),
    [sym_ruby_statement] = STATE(2820),
    [sym_python_statement] = STATE(2820),
    [sym_perl_statement] = STATE(2820),
    [sym_for_loop] = STATE(2820),
    [sym_while_loop] = STATE(2820),
    [sym_if_statement] = STATE(2820),
    [sym_try_statement] = STATE(2820),
    [sym_throw_statement] = STATE(2820),
    [sym_bang_filter_statement] = STATE(2820),
    [sym_let_statement] = STATE(2820),
    [sym_const_statement] = STATE(2820),
    [sym_set_statement] = STATE(2820),
    [sym_setlocal_statement] = STATE(2820),
    [sym_unlet_statement] = STATE(2820),
    [sym_call_statement] = STATE(2820),
    [sym_echo_statement] = STATE(2820),
    [sym_echon_statement] = STATE(2820),
    [sym_echohl_statement] = STATE(2820),
    [sym_echomsg_statement] = STATE(2820),
    [sym_echoerr_statement] = STATE(2820),
    [sym_execute_statement] = STATE(2820),
    [sym_silent_statement] = STATE(2820),
    [sym_tab_statement] = STATE(2820),
    [sym_vertical_statement] = STATE(2820),
    [sym_topleft_statement] = STATE(2820),
    [sym_botright_statement] = STATE(2820),
    [sym_aboveleft_statement] = STATE(2820),
    [sym_belowright_statement] = STATE(2820),
    [sym_user_command] = STATE(2820),
    [sym_shebang] = STATE(2820),
    [sym_function_definition] = STATE(2820),
    [sym_range_statement] = STATE(2820),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2820),
    [sym_map_statement] = STATE(2820),
    [sym_sign_statement] = STATE(2820),
    [sym_eval_statement] = STATE(2820),
    [sym_substitute_statement] = STATE(2820),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2820),
    [sym_augroup_statement] = STATE(2820),
    [sym_command_statement] = STATE(2820),
    [sym_comclear_statement] = STATE(2820),
    [sym_delcommand_statement] = STATE(2820),
    [sym_highlight_statement] = STATE(2820),
    [sym_syntax_statement] = STATE(2820),
    [sym_edit_statement] = STATE(2820),
    [sym_enew_statement] = STATE(2820),
    [sym_find_statement] = STATE(2820),
    [sym_ex_statement] = STATE(2820),
    [sym_visual_statement] = STATE(2820),
    [sym_view_statement] = STATE(2820),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(88)] = {
    [sym__statement] = STATE(2598),
    [sym_unknown_builtin_statement] = STATE(2598),
    [sym_return_statement] = STATE(2598),
    [sym_break_statement] = STATE(2598),
    [sym_continue_statement] = STATE(2598),
    [sym_normal_statement] = STATE(2598),
    [sym_setfiletype_statement] = STATE(2598),
    [sym_options_statement] = STATE(2598),
    [sym_startinsert_statement] = STATE(2598),
    [sym_stopinsert_statement] = STATE(2598),
    [sym_scriptencoding_statement] = STATE(2598),
    [sym_cnext_statement] = STATE(2598),
    [sym_cprevious_statement] = STATE(2598),
    [sym_runtime_statement] = STATE(2598),
    [sym_wincmd_statement] = STATE(2598),
    [sym_source_statement] = STATE(2598),
    [sym_global_statement] = STATE(2598),
    [sym_filetype_statement] = STATE(2598),
    [sym_colorscheme_statement] = STATE(2598),
    [sym_lua_statement] = STATE(2598),
    [sym_ruby_statement] = STATE(2598),
    [sym_python_statement] = STATE(2598),
    [sym_perl_statement] = STATE(2598),
    [sym_for_loop] = STATE(2598),
    [sym_while_loop] = STATE(2598),
    [sym_if_statement] = STATE(2598),
    [sym_try_statement] = STATE(2598),
    [sym_throw_statement] = STATE(2598),
    [sym_bang_filter_statement] = STATE(2598),
    [sym_let_statement] = STATE(2598),
    [sym_const_statement] = STATE(2598),
    [sym_set_statement] = STATE(2598),
    [sym_setlocal_statement] = STATE(2598),
    [sym_unlet_statement] = STATE(2598),
    [sym_call_statement] = STATE(2598),
    [sym_echo_statement] = STATE(2598),
    [sym_echon_statement] = STATE(2598),
    [sym_echohl_statement] = STATE(2598),
    [sym_echomsg_statement] = STATE(2598),
    [sym_echoerr_statement] = STATE(2598),
    [sym_execute_statement] = STATE(2598),
    [sym_silent_statement] = STATE(2598),
    [sym_tab_statement] = STATE(2598),
    [sym_vertical_statement] = STATE(2598),
    [sym_topleft_statement] = STATE(2598),
    [sym_botright_statement] = STATE(2598),
    [sym_aboveleft_statement] = STATE(2598),
    [sym_belowright_statement] = STATE(2598),
    [sym_user_command] = STATE(2598),
    [sym_shebang] = STATE(2598),
    [sym_function_definition] = STATE(2598),
    [sym_range_statement] = STATE(2598),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2598),
    [sym_map_statement] = STATE(2598),
    [sym_sign_statement] = STATE(2598),
    [sym_eval_statement] = STATE(2598),
    [sym_substitute_statement] = STATE(2598),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2598),
    [sym_augroup_statement] = STATE(2598),
    [sym_command_statement] = STATE(2598),
    [sym_comclear_statement] = STATE(2598),
    [sym_delcommand_statement] = STATE(2598),
    [sym_highlight_statement] = STATE(2598),
    [sym_syntax_statement] = STATE(2598),
    [sym_edit_statement] = STATE(2598),
    [sym_enew_statement] = STATE(2598),
    [sym_find_statement] = STATE(2598),
    [sym_ex_statement] = STATE(2598),
    [sym_visual_statement] = STATE(2598),
    [sym_view_statement] = STATE(2598),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(89)] = {
    [sym__statement] = STATE(2826),
    [sym_unknown_builtin_statement] = STATE(2826),
    [sym_return_statement] = STATE(2826),
    [sym_break_statement] = STATE(2826),
    [sym_continue_statement] = STATE(2826),
    [sym_normal_statement] = STATE(2826),
    [sym_setfiletype_statement] = STATE(2826),
    [sym_options_statement] = STATE(2826),
    [sym_startinsert_statement] = STATE(2826),
    [sym_stopinsert_statement] = STATE(2826),
    [sym_scriptencoding_statement] = STATE(2826),
    [sym_cnext_statement] = STATE(2826),
    [sym_cprevious_statement] = STATE(2826),
    [sym_runtime_statement] = STATE(2826),
    [sym_wincmd_statement] = STATE(2826),
    [sym_source_statement] = STATE(2826),
    [sym_global_statement] = STATE(2826),
    [sym_filetype_statement] = STATE(2826),
    [sym_colorscheme_statement] = STATE(2826),
    [sym_lua_statement] = STATE(2826),
    [sym_ruby_statement] = STATE(2826),
    [sym_python_statement] = STATE(2826),
    [sym_perl_statement] = STATE(2826),
    [sym_for_loop] = STATE(2826),
    [sym_while_loop] = STATE(2826),
    [sym_if_statement] = STATE(2826),
    [sym_try_statement] = STATE(2826),
    [sym_throw_statement] = STATE(2826),
    [sym_bang_filter_statement] = STATE(2826),
    [sym_let_statement] = STATE(2826),
    [sym_const_statement] = STATE(2826),
    [sym_set_statement] = STATE(2826),
    [sym_setlocal_statement] = STATE(2826),
    [sym_unlet_statement] = STATE(2826),
    [sym_call_statement] = STATE(2826),
    [sym_echo_statement] = STATE(2826),
    [sym_echon_statement] = STATE(2826),
    [sym_echohl_statement] = STATE(2826),
    [sym_echomsg_statement] = STATE(2826),
    [sym_echoerr_statement] = STATE(2826),
    [sym_execute_statement] = STATE(2826),
    [sym_silent_statement] = STATE(2826),
    [sym_tab_statement] = STATE(2826),
    [sym_vertical_statement] = STATE(2826),
    [sym_topleft_statement] = STATE(2826),
    [sym_botright_statement] = STATE(2826),
    [sym_aboveleft_statement] = STATE(2826),
    [sym_belowright_statement] = STATE(2826),
    [sym_user_command] = STATE(2826),
    [sym_shebang] = STATE(2826),
    [sym_function_definition] = STATE(2826),
    [sym_range_statement] = STATE(2826),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2826),
    [sym_map_statement] = STATE(2826),
    [sym_sign_statement] = STATE(2826),
    [sym_eval_statement] = STATE(2826),
    [sym_substitute_statement] = STATE(2826),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2826),
    [sym_augroup_statement] = STATE(2826),
    [sym_command_statement] = STATE(2826),
    [sym_comclear_statement] = STATE(2826),
    [sym_delcommand_statement] = STATE(2826),
    [sym_highlight_statement] = STATE(2826),
    [sym_syntax_statement] = STATE(2826),
    [sym_edit_statement] = STATE(2826),
    [sym_enew_statement] = STATE(2826),
    [sym_find_statement] = STATE(2826),
    [sym_ex_statement] = STATE(2826),
    [sym_visual_statement] = STATE(2826),
    [sym_view_statement] = STATE(2826),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(90)] = {
    [sym__statement] = STATE(2967),
    [sym_unknown_builtin_statement] = STATE(2967),
    [sym_return_statement] = STATE(2967),
    [sym_break_statement] = STATE(2967),
    [sym_continue_statement] = STATE(2967),
    [sym_normal_statement] = STATE(2967),
    [sym_setfiletype_statement] = STATE(2967),
    [sym_options_statement] = STATE(2967),
    [sym_startinsert_statement] = STATE(2967),
    [sym_stopinsert_statement] = STATE(2967),
    [sym_scriptencoding_statement] = STATE(2967),
    [sym_cnext_statement] = STATE(2967),
    [sym_cprevious_statement] = STATE(2967),
    [sym_runtime_statement] = STATE(2967),
    [sym_wincmd_statement] = STATE(2967),
    [sym_source_statement] = STATE(2967),
    [sym_global_statement] = STATE(2967),
    [sym_filetype_statement] = STATE(2967),
    [sym_colorscheme_statement] = STATE(2967),
    [sym_lua_statement] = STATE(2967),
    [sym_ruby_statement] = STATE(2967),
    [sym_python_statement] = STATE(2967),
    [sym_perl_statement] = STATE(2967),
    [sym_for_loop] = STATE(2967),
    [sym_while_loop] = STATE(2967),
    [sym_if_statement] = STATE(2967),
    [sym_try_statement] = STATE(2967),
    [sym_throw_statement] = STATE(2967),
    [sym_bang_filter_statement] = STATE(2967),
    [sym_let_statement] = STATE(2967),
    [sym_const_statement] = STATE(2967),
    [sym_set_statement] = STATE(2967),
    [sym_setlocal_statement] = STATE(2967),
    [sym_unlet_statement] = STATE(2967),
    [sym_call_statement] = STATE(2967),
    [sym_echo_statement] = STATE(2967),
    [sym_echon_statement] = STATE(2967),
    [sym_echohl_statement] = STATE(2967),
    [sym_echomsg_statement] = STATE(2967),
    [sym_echoerr_statement] = STATE(2967),
    [sym_execute_statement] = STATE(2967),
    [sym_silent_statement] = STATE(2967),
    [sym_tab_statement] = STATE(2967),
    [sym_vertical_statement] = STATE(2967),
    [sym_topleft_statement] = STATE(2967),
    [sym_botright_statement] = STATE(2967),
    [sym_aboveleft_statement] = STATE(2967),
    [sym_belowright_statement] = STATE(2967),
    [sym_user_command] = STATE(2967),
    [sym_shebang] = STATE(2967),
    [sym_function_definition] = STATE(2967),
    [sym_range_statement] = STATE(2967),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2967),
    [sym_map_statement] = STATE(2967),
    [sym_sign_statement] = STATE(2967),
    [sym_eval_statement] = STATE(2967),
    [sym_substitute_statement] = STATE(2967),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2967),
    [sym_augroup_statement] = STATE(2967),
    [sym_command_statement] = STATE(2967),
    [sym_comclear_statement] = STATE(2967),
    [sym_delcommand_statement] = STATE(2967),
    [sym_highlight_statement] = STATE(2967),
    [sym_syntax_statement] = STATE(2967),
    [sym_edit_statement] = STATE(2967),
    [sym_enew_statement] = STATE(2967),
    [sym_find_statement] = STATE(2967),
    [sym_ex_statement] = STATE(2967),
    [sym_visual_statement] = STATE(2967),
    [sym_view_statement] = STATE(2967),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(91)] = {
    [sym__statement] = STATE(2248),
    [sym_unknown_builtin_statement] = STATE(2248),
    [sym_return_statement] = STATE(2248),
    [sym_break_statement] = STATE(2248),
    [sym_continue_statement] = STATE(2248),
    [sym_normal_statement] = STATE(2248),
    [sym_setfiletype_statement] = STATE(2248),
    [sym_options_statement] = STATE(2248),
    [sym_startinsert_statement] = STATE(2248),
    [sym_stopinsert_statement] = STATE(2248),
    [sym_scriptencoding_statement] = STATE(2248),
    [sym_cnext_statement] = STATE(2248),
    [sym_cprevious_statement] = STATE(2248),
    [sym_runtime_statement] = STATE(2248),
    [sym_wincmd_statement] = STATE(2248),
    [sym_source_statement] = STATE(2248),
    [sym_global_statement] = STATE(2248),
    [sym_filetype_statement] = STATE(2248),
    [sym_colorscheme_statement] = STATE(2248),
    [sym_lua_statement] = STATE(2248),
    [sym_ruby_statement] = STATE(2248),
    [sym_python_statement] = STATE(2248),
    [sym_perl_statement] = STATE(2248),
    [sym_for_loop] = STATE(2248),
    [sym_while_loop] = STATE(2248),
    [sym_if_statement] = STATE(2248),
    [sym_try_statement] = STATE(2248),
    [sym_throw_statement] = STATE(2248),
    [sym_bang_filter_statement] = STATE(2248),
    [sym_let_statement] = STATE(2248),
    [sym_const_statement] = STATE(2248),
    [sym_set_statement] = STATE(2248),
    [sym_setlocal_statement] = STATE(2248),
    [sym_unlet_statement] = STATE(2248),
    [sym_call_statement] = STATE(2248),
    [sym_echo_statement] = STATE(2248),
    [sym_echon_statement] = STATE(2248),
    [sym_echohl_statement] = STATE(2248),
    [sym_echomsg_statement] = STATE(2248),
    [sym_echoerr_statement] = STATE(2248),
    [sym_execute_statement] = STATE(2248),
    [sym_silent_statement] = STATE(2248),
    [sym_tab_statement] = STATE(2248),
    [sym_vertical_statement] = STATE(2248),
    [sym_topleft_statement] = STATE(2248),
    [sym_botright_statement] = STATE(2248),
    [sym_aboveleft_statement] = STATE(2248),
    [sym_belowright_statement] = STATE(2248),
    [sym_user_command] = STATE(2248),
    [sym_shebang] = STATE(2248),
    [sym_function_definition] = STATE(2248),
    [sym_range_statement] = STATE(2248),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2248),
    [sym_map_statement] = STATE(2248),
    [sym_sign_statement] = STATE(2248),
    [sym_eval_statement] = STATE(2248),
    [sym_substitute_statement] = STATE(2248),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2248),
    [sym_augroup_statement] = STATE(2248),
    [sym_command_statement] = STATE(2248),
    [sym_comclear_statement] = STATE(2248),
    [sym_delcommand_statement] = STATE(2248),
    [sym_highlight_statement] = STATE(2248),
    [sym_syntax_statement] = STATE(2248),
    [sym_edit_statement] = STATE(2248),
    [sym_enew_statement] = STATE(2248),
    [sym_find_statement] = STATE(2248),
    [sym_ex_statement] = STATE(2248),
    [sym_visual_statement] = STATE(2248),
    [sym_view_statement] = STATE(2248),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(92)] = {
    [sym__statement] = STATE(2853),
    [sym_unknown_builtin_statement] = STATE(2853),
    [sym_return_statement] = STATE(2853),
    [sym_break_statement] = STATE(2853),
    [sym_continue_statement] = STATE(2853),
    [sym_normal_statement] = STATE(2853),
    [sym_setfiletype_statement] = STATE(2853),
    [sym_options_statement] = STATE(2853),
    [sym_startinsert_statement] = STATE(2853),
    [sym_stopinsert_statement] = STATE(2853),
    [sym_scriptencoding_statement] = STATE(2853),
    [sym_cnext_statement] = STATE(2853),
    [sym_cprevious_statement] = STATE(2853),
    [sym_runtime_statement] = STATE(2853),
    [sym_wincmd_statement] = STATE(2853),
    [sym_source_statement] = STATE(2853),
    [sym_global_statement] = STATE(2853),
    [sym_filetype_statement] = STATE(2853),
    [sym_colorscheme_statement] = STATE(2853),
    [sym_lua_statement] = STATE(2853),
    [sym_ruby_statement] = STATE(2853),
    [sym_python_statement] = STATE(2853),
    [sym_perl_statement] = STATE(2853),
    [sym_for_loop] = STATE(2853),
    [sym_while_loop] = STATE(2853),
    [sym_if_statement] = STATE(2853),
    [sym_try_statement] = STATE(2853),
    [sym_throw_statement] = STATE(2853),
    [sym_bang_filter_statement] = STATE(2853),
    [sym_let_statement] = STATE(2853),
    [sym_const_statement] = STATE(2853),
    [sym_set_statement] = STATE(2853),
    [sym_setlocal_statement] = STATE(2853),
    [sym_unlet_statement] = STATE(2853),
    [sym_call_statement] = STATE(2853),
    [sym_echo_statement] = STATE(2853),
    [sym_echon_statement] = STATE(2853),
    [sym_echohl_statement] = STATE(2853),
    [sym_echomsg_statement] = STATE(2853),
    [sym_echoerr_statement] = STATE(2853),
    [sym_execute_statement] = STATE(2853),
    [sym_silent_statement] = STATE(2853),
    [sym_tab_statement] = STATE(2853),
    [sym_vertical_statement] = STATE(2853),
    [sym_topleft_statement] = STATE(2853),
    [sym_botright_statement] = STATE(2853),
    [sym_aboveleft_statement] = STATE(2853),
    [sym_belowright_statement] = STATE(2853),
    [sym_user_command] = STATE(2853),
    [sym_shebang] = STATE(2853),
    [sym_function_definition] = STATE(2853),
    [sym_range_statement] = STATE(2853),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2853),
    [sym_map_statement] = STATE(2853),
    [sym_sign_statement] = STATE(2853),
    [sym_eval_statement] = STATE(2853),
    [sym_substitute_statement] = STATE(2853),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2853),
    [sym_augroup_statement] = STATE(2853),
    [sym_command_statement] = STATE(2853),
    [sym_comclear_statement] = STATE(2853),
    [sym_delcommand_statement] = STATE(2853),
    [sym_highlight_statement] = STATE(2853),
    [sym_syntax_statement] = STATE(2853),
    [sym_edit_statement] = STATE(2853),
    [sym_enew_statement] = STATE(2853),
    [sym_find_statement] = STATE(2853),
    [sym_ex_statement] = STATE(2853),
    [sym_visual_statement] = STATE(2853),
    [sym_view_statement] = STATE(2853),
    [aux_sym__statement_repeat1] = STATE(94),
    [anon_sym_COLON] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(93)] = {
    [sym__statement] = STATE(2676),
    [sym_unknown_builtin_statement] = STATE(2676),
    [sym_return_statement] = STATE(2676),
    [sym_break_statement] = STATE(2676),
    [sym_continue_statement] = STATE(2676),
    [sym_normal_statement] = STATE(2676),
    [sym_setfiletype_statement] = STATE(2676),
    [sym_options_statement] = STATE(2676),
    [sym_startinsert_statement] = STATE(2676),
    [sym_stopinsert_statement] = STATE(2676),
    [sym_scriptencoding_statement] = STATE(2676),
    [sym_cnext_statement] = STATE(2676),
    [sym_cprevious_statement] = STATE(2676),
    [sym_runtime_statement] = STATE(2676),
    [sym_wincmd_statement] = STATE(2676),
    [sym_source_statement] = STATE(2676),
    [sym_global_statement] = STATE(2676),
    [sym_filetype_statement] = STATE(2676),
    [sym_colorscheme_statement] = STATE(2676),
    [sym_lua_statement] = STATE(2676),
    [sym_ruby_statement] = STATE(2676),
    [sym_python_statement] = STATE(2676),
    [sym_perl_statement] = STATE(2676),
    [sym_for_loop] = STATE(2676),
    [sym_while_loop] = STATE(2676),
    [sym_if_statement] = STATE(2676),
    [sym_try_statement] = STATE(2676),
    [sym_throw_statement] = STATE(2676),
    [sym_bang_filter_statement] = STATE(2676),
    [sym_let_statement] = STATE(2676),
    [sym_const_statement] = STATE(2676),
    [sym_set_statement] = STATE(2676),
    [sym_setlocal_statement] = STATE(2676),
    [sym_unlet_statement] = STATE(2676),
    [sym_call_statement] = STATE(2676),
    [sym_echo_statement] = STATE(2676),
    [sym_echon_statement] = STATE(2676),
    [sym_echohl_statement] = STATE(2676),
    [sym_echomsg_statement] = STATE(2676),
    [sym_echoerr_statement] = STATE(2676),
    [sym_execute_statement] = STATE(2676),
    [sym_silent_statement] = STATE(2676),
    [sym_tab_statement] = STATE(2676),
    [sym_vertical_statement] = STATE(2676),
    [sym_topleft_statement] = STATE(2676),
    [sym_botright_statement] = STATE(2676),
    [sym_aboveleft_statement] = STATE(2676),
    [sym_belowright_statement] = STATE(2676),
    [sym_user_command] = STATE(2676),
    [sym_shebang] = STATE(2676),
    [sym_function_definition] = STATE(2676),
    [sym_range_statement] = STATE(2676),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2676),
    [sym_map_statement] = STATE(2676),
    [sym_sign_statement] = STATE(2676),
    [sym_eval_statement] = STATE(2676),
    [sym_substitute_statement] = STATE(2676),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2676),
    [sym_augroup_statement] = STATE(2676),
    [sym_command_statement] = STATE(2676),
    [sym_comclear_statement] = STATE(2676),
    [sym_delcommand_statement] = STATE(2676),
    [sym_highlight_statement] = STATE(2676),
    [sym_syntax_statement] = STATE(2676),
    [sym_edit_statement] = STATE(2676),
    [sym_enew_statement] = STATE(2676),
    [sym_find_statement] = STATE(2676),
    [sym_ex_statement] = STATE(2676),
    [sym_visual_statement] = STATE(2676),
    [sym_view_statement] = STATE(2676),
    [aux_sym__statement_repeat1] = STATE(95),
    [anon_sym_COLON] = ACTIONS(479),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(94)] = {
    [sym_unknown_builtin_statement] = STATE(2935),
    [sym_return_statement] = STATE(2935),
    [sym_break_statement] = STATE(2935),
    [sym_continue_statement] = STATE(2935),
    [sym_normal_statement] = STATE(2935),
    [sym_setfiletype_statement] = STATE(2935),
    [sym_options_statement] = STATE(2935),
    [sym_startinsert_statement] = STATE(2935),
    [sym_stopinsert_statement] = STATE(2935),
    [sym_scriptencoding_statement] = STATE(2935),
    [sym_cnext_statement] = STATE(2935),
    [sym_cprevious_statement] = STATE(2935),
    [sym_runtime_statement] = STATE(2935),
    [sym_wincmd_statement] = STATE(2935),
    [sym_source_statement] = STATE(2935),
    [sym_global_statement] = STATE(2935),
    [sym_filetype_statement] = STATE(2935),
    [sym_colorscheme_statement] = STATE(2935),
    [sym_lua_statement] = STATE(2935),
    [sym_ruby_statement] = STATE(2935),
    [sym_python_statement] = STATE(2935),
    [sym_perl_statement] = STATE(2935),
    [sym_for_loop] = STATE(2935),
    [sym_while_loop] = STATE(2935),
    [sym_if_statement] = STATE(2935),
    [sym_try_statement] = STATE(2935),
    [sym_throw_statement] = STATE(2935),
    [sym_bang_filter_statement] = STATE(2935),
    [sym_let_statement] = STATE(2935),
    [sym_const_statement] = STATE(2935),
    [sym_set_statement] = STATE(2935),
    [sym_setlocal_statement] = STATE(2935),
    [sym_unlet_statement] = STATE(2935),
    [sym_call_statement] = STATE(2935),
    [sym_echo_statement] = STATE(2935),
    [sym_echon_statement] = STATE(2935),
    [sym_echohl_statement] = STATE(2935),
    [sym_echomsg_statement] = STATE(2935),
    [sym_echoerr_statement] = STATE(2935),
    [sym_execute_statement] = STATE(2935),
    [sym_silent_statement] = STATE(2935),
    [sym_tab_statement] = STATE(2935),
    [sym_vertical_statement] = STATE(2935),
    [sym_topleft_statement] = STATE(2935),
    [sym_botright_statement] = STATE(2935),
    [sym_aboveleft_statement] = STATE(2935),
    [sym_belowright_statement] = STATE(2935),
    [sym_user_command] = STATE(2935),
    [sym_shebang] = STATE(2935),
    [sym_function_definition] = STATE(2935),
    [sym_range_statement] = STATE(2935),
    [sym__range] = STATE(2164),
    [sym__range_explicit] = STATE(2593),
    [sym__range_marker] = STATE(2186),
    [sym__complete_range] = STATE(1813),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1361),
    [sym_next_line] = STATE(1361),
    [sym_last_line] = STATE(1361),
    [sym_previous_pattern] = STATE(1361),
    [sym_register_statement] = STATE(2935),
    [sym_map_statement] = STATE(2935),
    [sym_sign_statement] = STATE(2935),
    [sym_eval_statement] = STATE(2935),
    [sym_substitute_statement] = STATE(2935),
    [sym__autocmd_define] = STATE(2854),
    [sym__autocmd_remove] = STATE(2866),
    [sym__autocmd_list] = STATE(2868),
    [sym_autocmd_statement] = STATE(2935),
    [sym_augroup_statement] = STATE(2935),
    [sym_command_statement] = STATE(2935),
    [sym_comclear_statement] = STATE(2935),
    [sym_delcommand_statement] = STATE(2935),
    [sym_highlight_statement] = STATE(2935),
    [sym_syntax_statement] = STATE(2935),
    [sym_edit_statement] = STATE(2935),
    [sym_enew_statement] = STATE(2935),
    [sym_find_statement] = STATE(2935),
    [sym_ex_statement] = STATE(2935),
    [sym_visual_statement] = STATE(2935),
    [sym_view_statement] = STATE(2935),
    [aux_sym__statement_repeat1] = STATE(120),
    [anon_sym_COLON] = ACTIONS(703),
    [anon_sym_EQ] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(11),
    [anon_sym_POUND_BANG] = ACTIONS(13),
    [sym_mark] = ACTIONS(15),
    [anon_sym_PERCENT] = ACTIONS(17),
    [anon_sym_SLASH] = ACTIONS(19),
    [anon_sym_DOT2] = ACTIONS(21),
    [anon_sym_PLUS] = ACTIONS(23),
    [anon_sym_DOLLAR] = ACTIONS(25),
    [anon_sym_BSLASH_SLASH] = ACTIONS(27),
    [anon_sym_BSLASH_QMARK] = ACTIONS(27),
    [anon_sym_BSLASH_AMP] = ACTIONS(27),
    [sym_integer_literal] = ACTIONS(29),
    [sym_register] = ACTIONS(31),
    [sym_command_name] = ACTIONS(33),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(37),
    [sym__for] = ACTIONS(39),
    [sym__while] = ACTIONS(41),
    [sym__if] = ACTIONS(43),
    [sym__try] = ACTIONS(45),
    [sym__cnext] = ACTIONS(47),
    [sym__cprevious] = ACTIONS(49),
    [sym__cNext] = ACTIONS(49),
    [sym__const] = ACTIONS(51),
    [sym__normal] = ACTIONS(53),
    [sym__return] = ACTIONS(55),
    [sym__perl] = ACTIONS(57),
    [sym__lua] = ACTIONS(9),
    [sym__ruby] = ACTIONS(59),
    [sym__python] = ACTIONS(61),
    [sym__throw] = ACTIONS(63),
    [sym__execute] = ACTIONS(65),
    [sym__autocmd] = ACTIONS(67),
    [sym__silent] = ACTIONS(69),
    [sym__echo] = ACTIONS(71),
    [sym__echon] = ACTIONS(73),
    [sym__echohl] = ACTIONS(75),
    [sym__echomsg] = ACTIONS(77),
    [sym__echoerr] = ACTIONS(79),
    [sym__map] = ACTIONS(81),
    [sym__nmap] = ACTIONS(81),
    [sym__vmap] = ACTIONS(81),
    [sym__xmap] = ACTIONS(81),
    [sym__smap] = ACTIONS(81),
    [sym__omap] = ACTIONS(81),
    [sym__imap] = ACTIONS(81),
    [sym__lmap] = ACTIONS(81),
    [sym__cmap] = ACTIONS(81),
    [sym__tmap] = ACTIONS(81),
    [sym__noremap] = ACTIONS(81),
    [sym__nnoremap] = ACTIONS(81),
    [sym__vnoremap] = ACTIONS(81),
    [sym__xnoremap] = ACTIONS(81),
    [sym__snoremap] = ACTIONS(81),
    [sym__onoremap] = ACTIONS(81),
    [sym__inoremap] = ACTIONS(81),
    [sym__lnoremap] = ACTIONS(81),
    [sym__cnoremap] = ACTIONS(81),
    [sym__tnoremap] = ACTIONS(81),
    [sym__augroup] = ACTIONS(83),
    [sym__highlight] = ACTIONS(85),
    [sym__syntax] = ACTIONS(87),
    [sym__set] = ACTIONS(89),
    [sym__setlocal] = ACTIONS(91),
    [sym__setfiletype] = ACTIONS(93),
    [sym__browse] = ACTIONS(95),
    [sym__options] = ACTIONS(97),
    [sym__startinsert] = ACTIONS(99),
    [sym__stopinsert] = ACTIONS(101),
    [sym__scriptencoding] = ACTIONS(103),
    [sym__source] = ACTIONS(105),
    [sym__global] = ACTIONS(107),
    [sym__colorscheme] = ACTIONS(109),
    [sym__command] = ACTIONS(111),
    [sym__comclear] = ACTIONS(113),
    [sym__delcommand] = ACTIONS(115),
    [sym__runtime] = ACTIONS(117),
    [sym__wincmd] = ACTIONS(119),
    [sym__sign] = ACTIONS(121),
    [sym__filetype] = ACTIONS(123),
    [sym__let] = ACTIONS(125),
    [sym__unlet] = ACTIONS(127),
    [sym__call] = ACTIONS(129),
    [sym__break] = ACTIONS(131),
    [sym__continue] = ACTIONS(133),
    [sym__tab] = ACTIONS(135),
    [sym__vertical] = ACTIONS(137),
    [sym__leftabove] = ACTIONS(139),
    [sym__aboveleft] = ACTIONS(139),
    [sym__rightbelow] = ACTIONS(141),
    [sym__belowright] = ACTIONS(141),
    [sym__topleft] = ACTIONS(143),
    [sym__botright] = ACTIONS(145),
    [sym__edit] = ACTIONS(147),
    [sym__enew] = ACTIONS(149),
    [sym__find] = ACTIONS(151),
    [sym__ex] = ACTIONS(153),
    [sym__visual] = ACTIONS(155),
    [sym__view] = ACTIONS(157),
    [sym__eval] = ACTIONS(159),
    [sym__substitute] = ACTIONS(161),
    [sym_unknown_command_name] = ACTIONS(163),
  },
  [STATE(95)] = {
    [sym_unknown_builtin_statement] = STATE(2508),
    [sym_return_statement] = STATE(2508),
    [sym_break_statement] = STATE(2508),
    [sym_continue_statement] = STATE(2508),
    [sym_normal_statement] = STATE(2508),
    [sym_setfiletype_statement] = STATE(2508),
    [sym_options_statement] = STATE(2508),
    [sym_startinsert_statement] = STATE(2508),
    [sym_stopinsert_statement] = STATE(2508),
    [sym_scriptencoding_statement] = STATE(2508),
    [sym_cnext_statement] = STATE(2508),
    [sym_cprevious_statement] = STATE(2508),
    [sym_runtime_statement] = STATE(2508),
    [sym_wincmd_statement] = STATE(2508),
    [sym_source_statement] = STATE(2508),
    [sym_global_statement] = STATE(2508),
    [sym_filetype_statement] = STATE(2508),
    [sym_colorscheme_statement] = STATE(2508),
    [sym_lua_statement] = STATE(2508),
    [sym_ruby_statement] = STATE(2508),
    [sym_python_statement] = STATE(2508),
    [sym_perl_statement] = STATE(2508),
    [sym_for_loop] = STATE(2508),
    [sym_while_loop] = STATE(2508),
    [sym_if_statement] = STATE(2508),
    [sym_try_statement] = STATE(2508),
    [sym_throw_statement] = STATE(2508),
    [sym_bang_filter_statement] = STATE(2508),
    [sym_let_statement] = STATE(2508),
    [sym_const_statement] = STATE(2508),
    [sym_set_statement] = STATE(2508),
    [sym_setlocal_statement] = STATE(2508),
    [sym_unlet_statement] = STATE(2508),
    [sym_call_statement] = STATE(2508),
    [sym_echo_statement] = STATE(2508),
    [sym_echon_statement] = STATE(2508),
    [sym_echohl_statement] = STATE(2508),
    [sym_echomsg_statement] = STATE(2508),
    [sym_echoerr_statement] = STATE(2508),
    [sym_execute_statement] = STATE(2508),
    [sym_silent_statement] = STATE(2508),
    [sym_tab_statement] = STATE(2508),
    [sym_vertical_statement] = STATE(2508),
    [sym_topleft_statement] = STATE(2508),
    [sym_botright_statement] = STATE(2508),
    [sym_aboveleft_statement] = STATE(2508),
    [sym_belowright_statement] = STATE(2508),
    [sym_user_command] = STATE(2508),
    [sym_shebang] = STATE(2508),
    [sym_function_definition] = STATE(2508),
    [sym_range_statement] = STATE(2508),
    [sym__range] = STATE(2026),
    [sym__range_explicit] = STATE(2271),
    [sym__range_marker] = STATE(2036),
    [sym__complete_range] = STATE(1830),
    [sym__complete_range_explicit] = STATE(1823),
    [sym__complete_range_marker] = STATE(1634),
    [sym_current_line] = STATE(1289),
    [sym_next_line] = STATE(1289),
    [sym_last_line] = STATE(1289),
    [sym_previous_pattern] = STATE(1289),
    [sym_register_statement] = STATE(2508),
    [sym_map_statement] = STATE(2508),
    [sym_sign_statement] = STATE(2508),
    [sym_eval_statement] = STATE(2508),
    [sym_substitute_statement] = STATE(2508),
    [sym__autocmd_define] = STATE(2562),
    [sym__autocmd_remove] = STATE(2567),
    [sym__autocmd_list] = STATE(2595),
    [sym_autocmd_statement] = STATE(2508),
    [sym_augroup_statement] = STATE(2508),
    [sym_command_statement] = STATE(2508),
    [sym_comclear_statement] = STATE(2508),
    [sym_delcommand_statement] = STATE(2508),
    [sym_highlight_statement] = STATE(2508),
    [sym_syntax_statement] = STATE(2508),
    [sym_edit_statement] = STATE(2508),
    [sym_enew_statement] = STATE(2508),
    [sym_find_statement] = STATE(2508),
    [sym_ex_statement] = STATE(2508),
    [sym_visual_statement] = STATE(2508),
    [sym_view_statement] = STATE(2508),
    [aux_sym__statement_repeat1] = STATE(120),
    [anon_sym_COLON] = ACTIONS(703),
    [anon_sym_EQ] = ACTIONS(481),
    [anon_sym_QMARK] = ACTIONS(483),
    [anon_sym_POUND_BANG] = ACTIONS(485),
    [sym_mark] = ACTIONS(487),
    [anon_sym_PERCENT] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(491),
    [anon_sym_DOT2] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(495),
    [anon_sym_DOLLAR] = ACTIONS(497),
    [anon_sym_BSLASH_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH_QMARK] = ACTIONS(499),
    [anon_sym_BSLASH_AMP] = ACTIONS(499),
    [sym_integer_literal] = ACTIONS(503),
    [sym_register] = ACTIONS(505),
    [sym_command_name] = ACTIONS(511),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(513),
    [sym__for] = ACTIONS(515),
    [sym__while] = ACTIONS(517),
    [sym__if] = ACTIONS(519),
    [sym__try] = ACTIONS(521),
    [sym__cnext] = ACTIONS(523),
    [sym__cprevious] = ACTIONS(525),
    [sym__cNext] = ACTIONS(525),
    [sym__const] = ACTIONS(527),
    [sym__normal] = ACTIONS(529),
    [sym__return] = ACTIONS(531),
    [sym__perl] = ACTIONS(533),
    [sym__lua] = ACTIONS(481),
    [sym__ruby] = ACTIONS(535),
    [sym__python] = ACTIONS(537),
    [sym__throw] = ACTIONS(539),
    [sym__execute] = ACTIONS(541),
    [sym__autocmd] = ACTIONS(543),
    [sym__silent] = ACTIONS(545),
    [sym__echo] = ACTIONS(547),
    [sym__echon] = ACTIONS(549),
    [sym__echohl] = ACTIONS(551),
    [sym__echomsg] = ACTIONS(553),
    [sym__echoerr] = ACTIONS(555),
    [sym__map] = ACTIONS(557),
    [sym__nmap] = ACTIONS(557),
    [sym__vmap] = ACTIONS(557),
    [sym__xmap] = ACTIONS(557),
    [sym__smap] = ACTIONS(557),
    [sym__omap] = ACTIONS(557),
    [sym__imap] = ACTIONS(557),
    [sym__lmap] = ACTIONS(557),
    [sym__cmap] = ACTIONS(557),
    [sym__tmap] = ACTIONS(557),
    [sym__noremap] = ACTIONS(557),
    [sym__nnoremap] = ACTIONS(557),
    [sym__vnoremap] = ACTIONS(557),
    [sym__xnoremap] = ACTIONS(557),
    [sym__snoremap] = ACTIONS(557),
    [sym__onoremap] = ACTIONS(557),
    [sym__inoremap] = ACTIONS(557),
    [sym__lnoremap] = ACTIONS(557),
    [sym__cnoremap] = ACTIONS(557),
    [sym__tnoremap] = ACTIONS(557),
    [sym__augroup] = ACTIONS(559),
    [sym__highlight] = ACTIONS(561),
    [sym__syntax] = ACTIONS(563),
    [sym__set] = ACTIONS(565),
    [sym__setlocal] = ACTIONS(567),
    [sym__setfiletype] = ACTIONS(569),
    [sym__browse] = ACTIONS(571),
    [sym__options] = ACTIONS(573),
    [sym__startinsert] = ACTIONS(575),
    [sym__stopinsert] = ACTIONS(577),
    [sym__scriptencoding] = ACTIONS(579),
    [sym__source] = ACTIONS(581),
    [sym__global] = ACTIONS(583),
    [sym__colorscheme] = ACTIONS(585),
    [sym__command] = ACTIONS(587),
    [sym__comclear] = ACTIONS(589),
    [sym__delcommand] = ACTIONS(591),
    [sym__runtime] = ACTIONS(593),
    [sym__wincmd] = ACTIONS(595),
    [sym__sign] = ACTIONS(597),
    [sym__filetype] = ACTIONS(599),
    [sym__let] = ACTIONS(601),
    [sym__unlet] = ACTIONS(603),
    [sym__call] = ACTIONS(605),
    [sym__break] = ACTIONS(607),
    [sym__continue] = ACTIONS(609),
    [sym__tab] = ACTIONS(611),
    [sym__vertical] = ACTIONS(613),
    [sym__leftabove] = ACTIONS(615),
    [sym__aboveleft] = ACTIONS(615),
    [sym__rightbelow] = ACTIONS(617),
    [sym__belowright] = ACTIONS(617),
    [sym__topleft] = ACTIONS(619),
    [sym__botright] = ACTIONS(621),
    [sym__edit] = ACTIONS(623),
    [sym__enew] = ACTIONS(625),
    [sym__find] = ACTIONS(627),
    [sym__ex] = ACTIONS(629),
    [sym__visual] = ACTIONS(631),
    [sym__view] = ACTIONS(633),
    [sym__eval] = ACTIONS(635),
    [sym__substitute] = ACTIONS(637),
    [sym_unknown_command_name] = ACTIONS(639),
  },
  [STATE(96)] = {
    [aux_sym__autocmd_pattern_repeat1] = STATE(97),
    [anon_sym_COLON] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(705),
    [anon_sym_POUND_BANG] = ACTIONS(705),
    [anon_sym_COMMA] = ACTIONS(707),
    [sym_mark] = ACTIONS(705),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(705),
    [anon_sym_DOT2] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [anon_sym_BSLASH_SLASH] = ACTIONS(705),
    [anon_sym_BSLASH_QMARK] = ACTIONS(705),
    [anon_sym_BSLASH_AMP] = ACTIONS(705),
    [anon_sym_BSLASH_PIPE] = ACTIONS(705),
    [aux_sym__map_rhs_statement_token2] = ACTIONS(705),
    [aux_sym__map_rhs_statement_token3] = ACTIONS(705),
    [sym_integer_literal] = ACTIONS(705),
    [sym_register] = ACTIONS(705),
    [sym_au_once] = ACTIONS(705),
    [sym_au_nested] = ACTIONS(705),
    [sym_command_name] = ACTIONS(705),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(705),
    [sym__for] = ACTIONS(705),
    [sym__while] = ACTIONS(705),
    [sym__if] = ACTIONS(705),
    [sym__try] = ACTIONS(705),
    [sym__cnext] = ACTIONS(705),
    [sym__cprevious] = ACTIONS(705),
    [sym__cNext] = ACTIONS(705),
    [sym__const] = ACTIONS(705),
    [sym__normal] = ACTIONS(705),
    [sym__return] = ACTIONS(705),
    [sym__perl] = ACTIONS(705),
    [sym__lua] = ACTIONS(705),
    [sym__ruby] = ACTIONS(705),
    [sym__python] = ACTIONS(705),
    [sym__throw] = ACTIONS(705),
    [sym__execute] = ACTIONS(705),
    [sym__autocmd] = ACTIONS(705),
    [sym__silent] = ACTIONS(705),
    [sym__echo] = ACTIONS(705),
    [sym__echon] = ACTIONS(705),
    [sym__echohl] = ACTIONS(705),
    [sym__echomsg] = ACTIONS(705),
    [sym__echoerr] = ACTIONS(705),
    [sym__map] = ACTIONS(705),
    [sym__nmap] = ACTIONS(705),
    [sym__vmap] = ACTIONS(705),
    [sym__xmap] = ACTIONS(705),
    [sym__smap] = ACTIONS(705),
    [sym__omap] = ACTIONS(705),
    [sym__imap] = ACTIONS(705),
    [sym__lmap] = ACTIONS(705),
    [sym__cmap] = ACTIONS(705),
    [sym__tmap] = ACTIONS(705),
    [sym__noremap] = ACTIONS(705),
    [sym__nnoremap] = ACTIONS(705),
    [sym__vnoremap] = ACTIONS(705),
    [sym__xnoremap] = ACTIONS(705),
    [sym__snoremap] = ACTIONS(705),
    [sym__onoremap] = ACTIONS(705),
    [sym__inoremap] = ACTIONS(705),
    [sym__lnoremap] = ACTIONS(705),
    [sym__cnoremap] = ACTIONS(705),
    [sym__tnoremap] = ACTIONS(705),
    [sym__augroup] = ACTIONS(705),
    [sym__highlight] = ACTIONS(705),
    [sym__syntax] = ACTIONS(705),
    [sym__set] = ACTIONS(705),
    [sym__setlocal] = ACTIONS(705),
    [sym__setfiletype] = ACTIONS(705),
    [sym__browse] = ACTIONS(705),
    [sym__options] = ACTIONS(705),
    [sym__startinsert] = ACTIONS(705),
    [sym__stopinsert] = ACTIONS(705),
    [sym__scriptencoding] = ACTIONS(705),
    [sym__source] = ACTIONS(705),
    [sym__global] = ACTIONS(705),
    [sym__colorscheme] = ACTIONS(705),
    [sym__command] = ACTIONS(705),
    [sym__comclear] = ACTIONS(705),
    [sym__delcommand] = ACTIONS(705),
    [sym__runtime] = ACTIONS(705),
    [sym__wincmd] = ACTIONS(705),
    [sym__sign] = ACTIONS(705),
    [sym__filetype] = ACTIONS(705),
    [sym__let] = ACTIONS(705),
    [sym__unlet] = ACTIONS(705),
    [sym__call] = ACTIONS(705),
    [sym__break] = ACTIONS(705),
    [sym__continue] = ACTIONS(705),
    [sym__tab] = ACTIONS(705),
    [sym__vertical] = ACTIONS(705),
    [sym__leftabove] = ACTIONS(705),
    [sym__aboveleft] = ACTIONS(705),
    [sym__rightbelow] = ACTIONS(705),
    [sym__belowright] = ACTIONS(705),
    [sym__topleft] = ACTIONS(705),
    [sym__botright] = ACTIONS(705),
    [sym__edit] = ACTIONS(705),
    [sym__enew] = ACTIONS(705),
    [sym__find] = ACTIONS(705),
    [sym__ex] = ACTIONS(705),
    [sym__visual] = ACTIONS(705),
    [sym__view] = ACTIONS(705),
    [sym__eval] = ACTIONS(705),
    [sym__substitute] = ACTIONS(705),
    [sym_unknown_command_name] = ACTIONS(705),
  },
  [STATE(97)] = {
    [aux_sym__autocmd_pattern_repeat1] = STATE(98),
    [anon_sym_COLON] = ACTIONS(711),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_QMARK] = ACTIONS(711),
    [anon_sym_POUND_BANG] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(707),
    [sym_mark] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(711),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_DOT2] = ACTIONS(711),
    [anon_sym_PLUS] = ACTIONS(713),
    [anon_sym_DOLLAR] = ACTIONS(711),
    [anon_sym_BSLASH_SLASH] = ACTIONS(711),
    [anon_sym_BSLASH_QMARK] = ACTIONS(711),
    [anon_sym_BSLASH_AMP] = ACTIONS(711),
    [anon_sym_BSLASH_PIPE] = ACTIONS(711),
    [aux_sym__map_rhs_statement_token2] = ACTIONS(711),
    [aux_sym__map_rhs_statement_token3] = ACTIONS(711),
    [sym_integer_literal] = ACTIONS(711),
    [sym_register] = ACTIONS(711),
    [sym_au_once] = ACTIONS(711),
    [sym_au_nested] = ACTIONS(711),
    [sym_command_name] = ACTIONS(711),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(711),
    [sym__for] = ACTIONS(711),
    [sym__while] = ACTIONS(711),
    [sym__if] = ACTIONS(711),
    [sym__try] = ACTIONS(711),
    [sym__cnext] = ACTIONS(711),
    [sym__cprevious] = ACTIONS(711),
    [sym__cNext] = ACTIONS(711),
    [sym__const] = ACTIONS(711),
    [sym__normal] = ACTIONS(711),
    [sym__return] = ACTIONS(711),
    [sym__perl] = ACTIONS(711),
    [sym__lua] = ACTIONS(711),
    [sym__ruby] = ACTIONS(711),
    [sym__python] = ACTIONS(711),
    [sym__throw] = ACTIONS(711),
    [sym__execute] = ACTIONS(711),
    [sym__autocmd] = ACTIONS(711),
    [sym__silent] = ACTIONS(711),
    [sym__echo] = ACTIONS(711),
    [sym__echon] = ACTIONS(711),
    [sym__echohl] = ACTIONS(711),
    [sym__echomsg] = ACTIONS(711),
    [sym__echoerr] = ACTIONS(711),
    [sym__map] = ACTIONS(711),
    [sym__nmap] = ACTIONS(711),
    [sym__vmap] = ACTIONS(711),
    [sym__xmap] = ACTIONS(711),
    [sym__smap] = ACTIONS(711),
    [sym__omap] = ACTIONS(711),
    [sym__imap] = ACTIONS(711),
    [sym__lmap] = ACTIONS(711),
    [sym__cmap] = ACTIONS(711),
    [sym__tmap] = ACTIONS(711),
    [sym__noremap] = ACTIONS(711),
    [sym__nnoremap] = ACTIONS(711),
    [sym__vnoremap] = ACTIONS(711),
    [sym__xnoremap] = ACTIONS(711),
    [sym__snoremap] = ACTIONS(711),
    [sym__onoremap] = ACTIONS(711),
    [sym__inoremap] = ACTIONS(711),
    [sym__lnoremap] = ACTIONS(711),
    [sym__cnoremap] = ACTIONS(711),
    [sym__tnoremap] = ACTIONS(711),
    [sym__augroup] = ACTIONS(711),
    [sym__highlight] = ACTIONS(711),
    [sym__syntax] = ACTIONS(711),
    [sym__set] = ACTIONS(711),
    [sym__setlocal] = ACTIONS(711),
    [sym__setfiletype] = ACTIONS(711),
    [sym__browse] = ACTIONS(711),
    [sym__options] = ACTIONS(711),
    [sym__startinsert] = ACTIONS(711),
    [sym__stopinsert] = ACTIONS(711),
    [sym__scriptencoding] = ACTIONS(711),
    [sym__source] = ACTIONS(711),
    [sym__global] = ACTIONS(711),
    [sym__colorscheme] = ACTIONS(711),
    [sym__command] = ACTIONS(711),
    [sym__comclear] = ACTIONS(711),
    [sym__delcommand] = ACTIONS(711),
    [sym__runtime] = ACTIONS(711),
    [sym__wincmd] = ACTIONS(711),
    [sym__sign] = ACTIONS(711),
    [sym__filetype] = ACTIONS(711),
    [sym__let] = ACTIONS(711),
    [sym__unlet] = ACTIONS(711),
    [sym__call] = ACTIONS(711),
    [sym__break] = ACTIONS(711),
    [sym__continue] = ACTIONS(711),
    [sym__tab] = ACTIONS(711),
    [sym__vertical] = ACTIONS(711),
    [sym__leftabove] = ACTIONS(711),
    [sym__aboveleft] = ACTIONS(711),
    [sym__rightbelow] = ACTIONS(711),
    [sym__belowright] = ACTIONS(711),
    [sym__topleft] = ACTIONS(711),
    [sym__botright] = ACTIONS(711),
    [sym__edit] = ACTIONS(711),
    [sym__enew] = ACTIONS(711),
    [sym__find] = ACTIONS(711),
    [sym__ex] = ACTIONS(711),
    [sym__visual] = ACTIONS(711),
    [sym__view] = ACTIONS(711),
    [sym__eval] = ACTIONS(711),
    [sym__substitute] = ACTIONS(711),
    [sym_unknown_command_name] = ACTIONS(711),
  },
  [STATE(98)] = {
    [aux_sym__autocmd_pattern_repeat1] = STATE(98),
    [anon_sym_COLON] = ACTIONS(715),
    [anon_sym_EQ] = ACTIONS(715),
    [anon_sym_QMARK] = ACTIONS(715),
    [anon_sym_POUND_BANG] = ACTIONS(715),
    [anon_sym_COMMA] = ACTIONS(717),
    [sym_mark] = ACTIONS(715),
    [anon_sym_PERCENT] = ACTIONS(715),
    [anon_sym_SLASH] = ACTIONS(715),
    [anon_sym_DOT2] = ACTIONS(715),
    [anon_sym_PLUS] = ACTIONS(720),
    [anon_sym_DOLLAR] = ACTIONS(715),
    [anon_sym_BSLASH_SLASH] = ACTIONS(715),
    [anon_sym_BSLASH_QMARK] = ACTIONS(715),
    [anon_sym_BSLASH_AMP] = ACTIONS(715),
    [anon_sym_BSLASH_PIPE] = ACTIONS(715),
    [aux_sym__map_rhs_statement_token2] = ACTIONS(715),
    [aux_sym__map_rhs_statement_token3] = ACTIONS(715),
    [sym_integer_literal] = ACTIONS(715),
    [sym_register] = ACTIONS(715),
    [sym_au_once] = ACTIONS(715),
    [sym_au_nested] = ACTIONS(715),
    [sym_command_name] = ACTIONS(715),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(715),
    [sym__for] = ACTIONS(715),
    [sym__while] = ACTIONS(715),
    [sym__if] = ACTIONS(715),
    [sym__try] = ACTIONS(715),
    [sym__cnext] = ACTIONS(715),
    [sym__cprevious] = ACTIONS(715),
    [sym__cNext] = ACTIONS(715),
    [sym__const] = ACTIONS(715),
    [sym__normal] = ACTIONS(715),
    [sym__return] = ACTIONS(715),
    [sym__perl] = ACTIONS(715),
    [sym__lua] = ACTIONS(715),
    [sym__ruby] = ACTIONS(715),
    [sym__python] = ACTIONS(715),
    [sym__throw] = ACTIONS(715),
    [sym__execute] = ACTIONS(715),
    [sym__autocmd] = ACTIONS(715),
    [sym__silent] = ACTIONS(715),
    [sym__echo] = ACTIONS(715),
    [sym__echon] = ACTIONS(715),
    [sym__echohl] = ACTIONS(715),
    [sym__echomsg] = ACTIONS(715),
    [sym__echoerr] = ACTIONS(715),
    [sym__map] = ACTIONS(715),
    [sym__nmap] = ACTIONS(715),
    [sym__vmap] = ACTIONS(715),
    [sym__xmap] = ACTIONS(715),
    [sym__smap] = ACTIONS(715),
    [sym__omap] = ACTIONS(715),
    [sym__imap] = ACTIONS(715),
    [sym__lmap] = ACTIONS(715),
    [sym__cmap] = ACTIONS(715),
    [sym__tmap] = ACTIONS(715),
    [sym__noremap] = ACTIONS(715),
    [sym__nnoremap] = ACTIONS(715),
    [sym__vnoremap] = ACTIONS(715),
    [sym__xnoremap] = ACTIONS(715),
    [sym__snoremap] = ACTIONS(715),
    [sym__onoremap] = ACTIONS(715),
    [sym__inoremap] = ACTIONS(715),
    [sym__lnoremap] = ACTIONS(715),
    [sym__cnoremap] = ACTIONS(715),
    [sym__tnoremap] = ACTIONS(715),
    [sym__augroup] = ACTIONS(715),
    [sym__highlight] = ACTIONS(715),
    [sym__syntax] = ACTIONS(715),
    [sym__set] = ACTIONS(715),
    [sym__setlocal] = ACTIONS(715),
    [sym__setfiletype] = ACTIONS(715),
    [sym__browse] = ACTIONS(715),
    [sym__options] = ACTIONS(715),
    [sym__startinsert] = ACTIONS(715),
    [sym__stopinsert] = ACTIONS(715),
    [sym__scriptencoding] = ACTIONS(715),
    [sym__source] = ACTIONS(715),
    [sym__global] = ACTIONS(715),
    [sym__colorscheme] = ACTIONS(715),
    [sym__command] = ACTIONS(715),
    [sym__comclear] = ACTIONS(715),
    [sym__delcommand] = ACTIONS(715),
    [sym__runtime] = ACTIONS(715),
    [sym__wincmd] = ACTIONS(715),
    [sym__sign] = ACTIONS(715),
    [sym__filetype] = ACTIONS(715),
    [sym__let] = ACTIONS(715),
    [sym__unlet] = ACTIONS(715),
    [sym__call] = ACTIONS(715),
    [sym__break] = ACTIONS(715),
    [sym__continue] = ACTIONS(715),
    [sym__tab] = ACTIONS(715),
    [sym__vertical] = ACTIONS(715),
    [sym__leftabove] = ACTIONS(715),
    [sym__aboveleft] = ACTIONS(715),
    [sym__rightbelow] = ACTIONS(715),
    [sym__belowright] = ACTIONS(715),
    [sym__topleft] = ACTIONS(715),
    [sym__botright] = ACTIONS(715),
    [sym__edit] = ACTIONS(715),
    [sym__enew] = ACTIONS(715),
    [sym__find] = ACTIONS(715),
    [sym__ex] = ACTIONS(715),
    [sym__visual] = ACTIONS(715),
    [sym__view] = ACTIONS(715),
    [sym__eval] = ACTIONS(715),
    [sym__substitute] = ACTIONS(715),
    [sym_unknown_command_name] = ACTIONS(715),
  },
  [STATE(99)] = {
    [aux_sym__autocmd_pattern_repeat1] = STATE(102),
    [anon_sym_COLON] = ACTIONS(711),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_QMARK] = ACTIONS(711),
    [anon_sym_POUND_BANG] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(722),
    [sym_mark] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(711),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_DOT2] = ACTIONS(711),
    [anon_sym_PLUS] = ACTIONS(713),
    [anon_sym_DOLLAR] = ACTIONS(711),
    [anon_sym_BSLASH_SLASH] = ACTIONS(711),
    [anon_sym_BSLASH_QMARK] = ACTIONS(711),
    [anon_sym_BSLASH_AMP] = ACTIONS(711),
    [sym_integer_literal] = ACTIONS(711),
    [sym_register] = ACTIONS(711),
    [sym_au_once] = ACTIONS(711),
    [sym_au_nested] = ACTIONS(711),
    [sym_command_name] = ACTIONS(711),
    [sym__newline_or_pipe] = ACTIONS(711),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(711),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(711),
    [sym__for] = ACTIONS(711),
    [sym__while] = ACTIONS(711),
    [sym__if] = ACTIONS(711),
    [sym__try] = ACTIONS(711),
    [sym__cnext] = ACTIONS(711),
    [sym__cprevious] = ACTIONS(711),
    [sym__cNext] = ACTIONS(711),
    [sym__const] = ACTIONS(711),
    [sym__normal] = ACTIONS(711),
    [sym__return] = ACTIONS(711),
    [sym__perl] = ACTIONS(711),
    [sym__lua] = ACTIONS(711),
    [sym__ruby] = ACTIONS(711),
    [sym__python] = ACTIONS(711),
    [sym__throw] = ACTIONS(711),
    [sym__execute] = ACTIONS(711),
    [sym__autocmd] = ACTIONS(711),
    [sym__silent] = ACTIONS(711),
    [sym__echo] = ACTIONS(711),
    [sym__echon] = ACTIONS(711),
    [sym__echohl] = ACTIONS(711),
    [sym__echomsg] = ACTIONS(711),
    [sym__echoerr] = ACTIONS(711),
    [sym__map] = ACTIONS(711),
    [sym__nmap] = ACTIONS(711),
    [sym__vmap] = ACTIONS(711),
    [sym__xmap] = ACTIONS(711),
    [sym__smap] = ACTIONS(711),
    [sym__omap] = ACTIONS(711),
    [sym__imap] = ACTIONS(711),
    [sym__lmap] = ACTIONS(711),
    [sym__cmap] = ACTIONS(711),
    [sym__tmap] = ACTIONS(711),
    [sym__noremap] = ACTIONS(711),
    [sym__nnoremap] = ACTIONS(711),
    [sym__vnoremap] = ACTIONS(711),
    [sym__xnoremap] = ACTIONS(711),
    [sym__snoremap] = ACTIONS(711),
    [sym__onoremap] = ACTIONS(711),
    [sym__inoremap] = ACTIONS(711),
    [sym__lnoremap] = ACTIONS(711),
    [sym__cnoremap] = ACTIONS(711),
    [sym__tnoremap] = ACTIONS(711),
    [sym__augroup] = ACTIONS(711),
    [sym__highlight] = ACTIONS(711),
    [sym__syntax] = ACTIONS(711),
    [sym__set] = ACTIONS(711),
    [sym__setlocal] = ACTIONS(711),
    [sym__setfiletype] = ACTIONS(711),
    [sym__browse] = ACTIONS(711),
    [sym__options] = ACTIONS(711),
    [sym__startinsert] = ACTIONS(711),
    [sym__stopinsert] = ACTIONS(711),
    [sym__scriptencoding] = ACTIONS(711),
    [sym__source] = ACTIONS(711),
    [sym__global] = ACTIONS(711),
    [sym__colorscheme] = ACTIONS(711),
    [sym__command] = ACTIONS(711),
    [sym__comclear] = ACTIONS(711),
    [sym__delcommand] = ACTIONS(711),
    [sym__runtime] = ACTIONS(711),
    [sym__wincmd] = ACTIONS(711),
    [sym__sign] = ACTIONS(711),
    [sym__filetype] = ACTIONS(711),
    [sym__let] = ACTIONS(711),
    [sym__unlet] = ACTIONS(711),
    [sym__call] = ACTIONS(711),
    [sym__break] = ACTIONS(711),
    [sym__continue] = ACTIONS(711),
    [sym__tab] = ACTIONS(711),
    [sym__vertical] = ACTIONS(711),
    [sym__leftabove] = ACTIONS(711),
    [sym__aboveleft] = ACTIONS(711),
    [sym__rightbelow] = ACTIONS(711),
    [sym__belowright] = ACTIONS(711),
    [sym__topleft] = ACTIONS(711),
    [sym__botright] = ACTIONS(711),
    [sym__edit] = ACTIONS(711),
    [sym__enew] = ACTIONS(711),
    [sym__find] = ACTIONS(711),
    [sym__ex] = ACTIONS(711),
    [sym__visual] = ACTIONS(711),
    [sym__view] = ACTIONS(711),
    [sym__eval] = ACTIONS(711),
    [sym__substitute] = ACTIONS(711),
    [sym_unknown_command_name] = ACTIONS(711),
  },
  [STATE(100)] = {
    [aux_sym__autocmd_pattern_repeat1] = STATE(99),
    [anon_sym_COLON] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(705),
    [anon_sym_POUND_BANG] = ACTIONS(705),
    [anon_sym_COMMA] = ACTIONS(722),
    [sym_mark] = ACTIONS(705),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(705),
    [anon_sym_DOT2] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(709),
    [anon_sym_DOLLAR] = ACTIONS(705),
    [anon_sym_BSLASH_SLASH] = ACTIONS(705),
    [anon_sym_BSLASH_QMARK] = ACTIONS(705),
    [anon_sym_BSLASH_AMP] = ACTIONS(705),
    [sym_integer_literal] = ACTIONS(705),
    [sym_register] = ACTIONS(705),
    [sym_au_once] = ACTIONS(705),
    [sym_au_nested] = ACTIONS(705),
    [sym_command_name] = ACTIONS(705),
    [sym__newline_or_pipe] = ACTIONS(705),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(705),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(705),
    [sym__for] = ACTIONS(705),
    [sym__while] = ACTIONS(705),
    [sym__if] = ACTIONS(705),
    [sym__try] = ACTIONS(705),
    [sym__cnext] = ACTIONS(705),
    [sym__cprevious] = ACTIONS(705),
    [sym__cNext] = ACTIONS(705),
    [sym__const] = ACTIONS(705),
    [sym__normal] = ACTIONS(705),
    [sym__return] = ACTIONS(705),
    [sym__perl] = ACTIONS(705),
    [sym__lua] = ACTIONS(705),
    [sym__ruby] = ACTIONS(705),
    [sym__python] = ACTIONS(705),
    [sym__throw] = ACTIONS(705),
    [sym__execute] = ACTIONS(705),
    [sym__autocmd] = ACTIONS(705),
    [sym__silent] = ACTIONS(705),
    [sym__echo] = ACTIONS(705),
    [sym__echon] = ACTIONS(705),
    [sym__echohl] = ACTIONS(705),
    [sym__echomsg] = ACTIONS(705),
    [sym__echoerr] = ACTIONS(705),
    [sym__map] = ACTIONS(705),
    [sym__nmap] = ACTIONS(705),
    [sym__vmap] = ACTIONS(705),
    [sym__xmap] = ACTIONS(705),
    [sym__smap] = ACTIONS(705),
    [sym__omap] = ACTIONS(705),
    [sym__imap] = ACTIONS(705),
    [sym__lmap] = ACTIONS(705),
    [sym__cmap] = ACTIONS(705),
    [sym__tmap] = ACTIONS(705),
    [sym__noremap] = ACTIONS(705),
    [sym__nnoremap] = ACTIONS(705),
    [sym__vnoremap] = ACTIONS(705),
    [sym__xnoremap] = ACTIONS(705),
    [sym__snoremap] = ACTIONS(705),
    [sym__onoremap] = ACTIONS(705),
    [sym__inoremap] = ACTIONS(705),
    [sym__lnoremap] = ACTIONS(705),
    [sym__cnoremap] = ACTIONS(705),
    [sym__tnoremap] = ACTIONS(705),
    [sym__augroup] = ACTIONS(705),
    [sym__highlight] = ACTIONS(705),
    [sym__syntax] = ACTIONS(705),
    [sym__set] = ACTIONS(705),
    [sym__setlocal] = ACTIONS(705),
    [sym__setfiletype] = ACTIONS(705),
    [sym__browse] = ACTIONS(705),
    [sym__options] = ACTIONS(705),
    [sym__startinsert] = ACTIONS(705),
    [sym__stopinsert] = ACTIONS(705),
    [sym__scriptencoding] = ACTIONS(705),
    [sym__source] = ACTIONS(705),
    [sym__global] = ACTIONS(705),
    [sym__colorscheme] = ACTIONS(705),
    [sym__command] = ACTIONS(705),
    [sym__comclear] = ACTIONS(705),
    [sym__delcommand] = ACTIONS(705),
    [sym__runtime] = ACTIONS(705),
    [sym__wincmd] = ACTIONS(705),
    [sym__sign] = ACTIONS(705),
    [sym__filetype] = ACTIONS(705),
    [sym__let] = ACTIONS(705),
    [sym__unlet] = ACTIONS(705),
    [sym__call] = ACTIONS(705),
    [sym__break] = ACTIONS(705),
    [sym__continue] = ACTIONS(705),
    [sym__tab] = ACTIONS(705),
    [sym__vertical] = ACTIONS(705),
    [sym__leftabove] = ACTIONS(705),
    [sym__aboveleft] = ACTIONS(705),
    [sym__rightbelow] = ACTIONS(705),
    [sym__belowright] = ACTIONS(705),
    [sym__topleft] = ACTIONS(705),
    [sym__botright] = ACTIONS(705),
    [sym__edit] = ACTIONS(705),
    [sym__enew] = ACTIONS(705),
    [sym__find] = ACTIONS(705),
    [sym__ex] = ACTIONS(705),
    [sym__visual] = ACTIONS(705),
    [sym__view] = ACTIONS(705),
    [sym__eval] = ACTIONS(705),
    [sym__substitute] = ACTIONS(705),
    [sym_unknown_command_name] = ACTIONS(705),
  },
  [STATE(101)] = {
    [anon_sym_COLON] = ACTIONS(715),
    [anon_sym_EQ] = ACTIONS(715),
    [anon_sym_QMARK] = ACTIONS(715),
    [anon_sym_POUND_BANG] = ACTIONS(715),
    [anon_sym_COMMA] = ACTIONS(715),
    [sym_mark] = ACTIONS(715),
    [anon_sym_PERCENT] = ACTIONS(715),
    [anon_sym_SLASH] = ACTIONS(715),
    [anon_sym_DOT2] = ACTIONS(715),
    [anon_sym_PLUS] = ACTIONS(720),
    [anon_sym_DOLLAR] = ACTIONS(715),
    [anon_sym_BSLASH_SLASH] = ACTIONS(715),
    [anon_sym_BSLASH_QMARK] = ACTIONS(715),
    [anon_sym_BSLASH_AMP] = ACTIONS(715),
    [anon_sym_BSLASH_PIPE] = ACTIONS(715),
    [aux_sym__map_rhs_statement_token2] = ACTIONS(715),
    [aux_sym__map_rhs_statement_token3] = ACTIONS(715),
    [sym_integer_literal] = ACTIONS(715),
    [sym_register] = ACTIONS(715),
    [sym_au_once] = ACTIONS(715),
    [sym_au_nested] = ACTIONS(715),
    [sym_command_name] = ACTIONS(715),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(715),
    [sym__for] = ACTIONS(715),
    [sym__while] = ACTIONS(715),
    [sym__if] = ACTIONS(715),
    [sym__try] = ACTIONS(715),
    [sym__cnext] = ACTIONS(715),
    [sym__cprevious] = ACTIONS(715),
    [sym__cNext] = ACTIONS(715),
    [sym__const] = ACTIONS(715),
    [sym__normal] = ACTIONS(715),
    [sym__return] = ACTIONS(715),
    [sym__perl] = ACTIONS(715),
    [sym__lua] = ACTIONS(715),
    [sym__ruby] = ACTIONS(715),
    [sym__python] = ACTIONS(715),
    [sym__throw] = ACTIONS(715),
    [sym__execute] = ACTIONS(715),
    [sym__autocmd] = ACTIONS(715),
    [sym__silent] = ACTIONS(715),
    [sym__echo] = ACTIONS(715),
    [sym__echon] = ACTIONS(715),
    [sym__echohl] = ACTIONS(715),
    [sym__echomsg] = ACTIONS(715),
    [sym__echoerr] = ACTIONS(715),
    [sym__map] = ACTIONS(715),
    [sym__nmap] = ACTIONS(715),
    [sym__vmap] = ACTIONS(715),
    [sym__xmap] = ACTIONS(715),
    [sym__smap] = ACTIONS(715),
    [sym__omap] = ACTIONS(715),
    [sym__imap] = ACTIONS(715),
    [sym__lmap] = ACTIONS(715),
    [sym__cmap] = ACTIONS(715),
    [sym__tmap] = ACTIONS(715),
    [sym__noremap] = ACTIONS(715),
    [sym__nnoremap] = ACTIONS(715),
    [sym__vnoremap] = ACTIONS(715),
    [sym__xnoremap] = ACTIONS(715),
    [sym__snoremap] = ACTIONS(715),
    [sym__onoremap] = ACTIONS(715),
    [sym__inoremap] = ACTIONS(715),
    [sym__lnoremap] = ACTIONS(715),
    [sym__cnoremap] = ACTIONS(715),
    [sym__tnoremap] = ACTIONS(715),
    [sym__augroup] = ACTIONS(715),
    [sym__highlight] = ACTIONS(715),
    [sym__syntax] = ACTIONS(715),
    [sym__set] = ACTIONS(715),
    [sym__setlocal] = ACTIONS(715),
    [sym__setfiletype] = ACTIONS(715),
    [sym__browse] = ACTIONS(715),
    [sym__options] = ACTIONS(715),
    [sym__startinsert] = ACTIONS(715),
    [sym__stopinsert] = ACTIONS(715),
    [sym__scriptencoding] = ACTIONS(715),
    [sym__source] = ACTIONS(715),
    [sym__global] = ACTIONS(715),
    [sym__colorscheme] = ACTIONS(715),
    [sym__command] = ACTIONS(715),
    [sym__comclear] = ACTIONS(715),
    [sym__delcommand] = ACTIONS(715),
    [sym__runtime] = ACTIONS(715),
    [sym__wincmd] = ACTIONS(715),
    [sym__sign] = ACTIONS(715),
    [sym__filetype] = ACTIONS(715),
    [sym__let] = ACTIONS(715),
    [sym__unlet] = ACTIONS(715),
    [sym__call] = ACTIONS(715),
    [sym__break] = ACTIONS(715),
    [sym__continue] = ACTIONS(715),
    [sym__tab] = ACTIONS(715),
    [sym__vertical] = ACTIONS(715),
    [sym__leftabove] = ACTIONS(715),
    [sym__aboveleft] = ACTIONS(715),
    [sym__rightbelow] = ACTIONS(715),
    [sym__belowright] = ACTIONS(715),
    [sym__topleft] = ACTIONS(715),
    [sym__botright] = ACTIONS(715),
    [sym__edit] = ACTIONS(715),
    [sym__enew] = ACTIONS(715),
    [sym__find] = ACTIONS(715),
    [sym__ex] = ACTIONS(715),
    [sym__visual] = ACTIONS(715),
    [sym__view] = ACTIONS(715),
    [sym__eval] = ACTIONS(715),
    [sym__substitute] = ACTIONS(715),
    [sym_unknown_command_name] = ACTIONS(715),
  },
  [STATE(102)] = {
    [aux_sym__autocmd_pattern_repeat1] = STATE(102),
    [anon_sym_COLON] = ACTIONS(715),
    [anon_sym_EQ] = ACTIONS(715),
    [anon_sym_QMARK] = ACTIONS(715),
    [anon_sym_POUND_BANG] = ACTIONS(715),
    [anon_sym_COMMA] = ACTIONS(724),
    [sym_mark] = ACTIONS(715),
    [anon_sym_PERCENT] = ACTIONS(715),
    [anon_sym_SLASH] = ACTIONS(715),
    [anon_sym_DOT2] = ACTIONS(715),
    [anon_sym_PLUS] = ACTIONS(720),
    [anon_sym_DOLLAR] = ACTIONS(715),
    [anon_sym_BSLASH_SLASH] = ACTIONS(715),
    [anon_sym_BSLASH_QMARK] = ACTIONS(715),
    [anon_sym_BSLASH_AMP] = ACTIONS(715),
    [sym_integer_literal] = ACTIONS(715),
    [sym_register] = ACTIONS(715),
    [sym_au_once] = ACTIONS(715),
    [sym_au_nested] = ACTIONS(715),
    [sym_command_name] = ACTIONS(715),
    [sym__newline_or_pipe] = ACTIONS(715),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(715),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(715),
    [sym__for] = ACTIONS(715),
    [sym__while] = ACTIONS(715),
    [sym__if] = ACTIONS(715),
    [sym__try] = ACTIONS(715),
    [sym__cnext] = ACTIONS(715),
    [sym__cprevious] = ACTIONS(715),
    [sym__cNext] = ACTIONS(715),
    [sym__const] = ACTIONS(715),
    [sym__normal] = ACTIONS(715),
    [sym__return] = ACTIONS(715),
    [sym__perl] = ACTIONS(715),
    [sym__lua] = ACTIONS(715),
    [sym__ruby] = ACTIONS(715),
    [sym__python] = ACTIONS(715),
    [sym__throw] = ACTIONS(715),
    [sym__execute] = ACTIONS(715),
    [sym__autocmd] = ACTIONS(715),
    [sym__silent] = ACTIONS(715),
    [sym__echo] = ACTIONS(715),
    [sym__echon] = ACTIONS(715),
    [sym__echohl] = ACTIONS(715),
    [sym__echomsg] = ACTIONS(715),
    [sym__echoerr] = ACTIONS(715),
    [sym__map] = ACTIONS(715),
    [sym__nmap] = ACTIONS(715),
    [sym__vmap] = ACTIONS(715),
    [sym__xmap] = ACTIONS(715),
    [sym__smap] = ACTIONS(715),
    [sym__omap] = ACTIONS(715),
    [sym__imap] = ACTIONS(715),
    [sym__lmap] = ACTIONS(715),
    [sym__cmap] = ACTIONS(715),
    [sym__tmap] = ACTIONS(715),
    [sym__noremap] = ACTIONS(715),
    [sym__nnoremap] = ACTIONS(715),
    [sym__vnoremap] = ACTIONS(715),
    [sym__xnoremap] = ACTIONS(715),
    [sym__snoremap] = ACTIONS(715),
    [sym__onoremap] = ACTIONS(715),
    [sym__inoremap] = ACTIONS(715),
    [sym__lnoremap] = ACTIONS(715),
    [sym__cnoremap] = ACTIONS(715),
    [sym__tnoremap] = ACTIONS(715),
    [sym__augroup] = ACTIONS(715),
    [sym__highlight] = ACTIONS(715),
    [sym__syntax] = ACTIONS(715),
    [sym__set] = ACTIONS(715),
    [sym__setlocal] = ACTIONS(715),
    [sym__setfiletype] = ACTIONS(715),
    [sym__browse] = ACTIONS(715),
    [sym__options] = ACTIONS(715),
    [sym__startinsert] = ACTIONS(715),
    [sym__stopinsert] = ACTIONS(715),
    [sym__scriptencoding] = ACTIONS(715),
    [sym__source] = ACTIONS(715),
    [sym__global] = ACTIONS(715),
    [sym__colorscheme] = ACTIONS(715),
    [sym__command] = ACTIONS(715),
    [sym__comclear] = ACTIONS(715),
    [sym__delcommand] = ACTIONS(715),
    [sym__runtime] = ACTIONS(715),
    [sym__wincmd] = ACTIONS(715),
    [sym__sign] = ACTIONS(715),
    [sym__filetype] = ACTIONS(715),
    [sym__let] = ACTIONS(715),
    [sym__unlet] = ACTIONS(715),
    [sym__call] = ACTIONS(715),
    [sym__break] = ACTIONS(715),
    [sym__continue] = ACTIONS(715),
    [sym__tab] = ACTIONS(715),
    [sym__vertical] = ACTIONS(715),
    [sym__leftabove] = ACTIONS(715),
    [sym__aboveleft] = ACTIONS(715),
    [sym__rightbelow] = ACTIONS(715),
    [sym__belowright] = ACTIONS(715),
    [sym__topleft] = ACTIONS(715),
    [sym__botright] = ACTIONS(715),
    [sym__edit] = ACTIONS(715),
    [sym__enew] = ACTIONS(715),
    [sym__find] = ACTIONS(715),
    [sym__ex] = ACTIONS(715),
    [sym__visual] = ACTIONS(715),
    [sym__view] = ACTIONS(715),
    [sym__eval] = ACTIONS(715),
    [sym__substitute] = ACTIONS(715),
    [sym_unknown_command_name] = ACTIONS(715),
  },
  [STATE(103)] = {
    [anon_sym_COLON] = ACTIONS(260),
    [anon_sym_EQ] = ACTIONS(260),
    [anon_sym_QMARK] = ACTIONS(260),
    [anon_sym_POUND_BANG] = ACTIONS(260),
    [sym_mark] = ACTIONS(260),
    [anon_sym_PERCENT] = ACTIONS(260),
    [anon_sym_SLASH] = ACTIONS(260),
    [anon_sym_DOT2] = ACTIONS(260),
    [anon_sym_PLUS] = ACTIONS(727),
    [anon_sym_DOLLAR] = ACTIONS(260),
    [anon_sym_BSLASH_SLASH] = ACTIONS(260),
    [anon_sym_BSLASH_QMARK] = ACTIONS(260),
    [anon_sym_BSLASH_AMP] = ACTIONS(260),
    [sym_integer_literal] = ACTIONS(260),
    [sym_register] = ACTIONS(260),
    [sym_command_name] = ACTIONS(260),
    [sym__newline_or_pipe] = ACTIONS(260),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(260),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(260),
    [sym__for] = ACTIONS(260),
    [sym__while] = ACTIONS(260),
    [sym__if] = ACTIONS(260),
    [sym__elseif] = ACTIONS(260),
    [sym__else] = ACTIONS(260),
    [sym__endif] = ACTIONS(260),
    [sym__try] = ACTIONS(260),
    [sym__cnext] = ACTIONS(260),
    [sym__cprevious] = ACTIONS(260),
    [sym__cNext] = ACTIONS(260),
    [sym__const] = ACTIONS(260),
    [sym__normal] = ACTIONS(260),
    [sym__return] = ACTIONS(260),
    [sym__perl] = ACTIONS(260),
    [sym__lua] = ACTIONS(260),
    [sym__ruby] = ACTIONS(260),
    [sym__python] = ACTIONS(260),
    [sym__throw] = ACTIONS(260),
    [sym__execute] = ACTIONS(260),
    [sym__autocmd] = ACTIONS(260),
    [sym__silent] = ACTIONS(260),
    [sym__echo] = ACTIONS(260),
    [sym__echon] = ACTIONS(260),
    [sym__echohl] = ACTIONS(260),
    [sym__echomsg] = ACTIONS(260),
    [sym__echoerr] = ACTIONS(260),
    [sym__map] = ACTIONS(260),
    [sym__nmap] = ACTIONS(260),
    [sym__vmap] = ACTIONS(260),
    [sym__xmap] = ACTIONS(260),
    [sym__smap] = ACTIONS(260),
    [sym__omap] = ACTIONS(260),
    [sym__imap] = ACTIONS(260),
    [sym__lmap] = ACTIONS(260),
    [sym__cmap] = ACTIONS(260),
    [sym__tmap] = ACTIONS(260),
    [sym__noremap] = ACTIONS(260),
    [sym__nnoremap] = ACTIONS(260),
    [sym__vnoremap] = ACTIONS(260),
    [sym__xnoremap] = ACTIONS(260),
    [sym__snoremap] = ACTIONS(260),
    [sym__onoremap] = ACTIONS(260),
    [sym__inoremap] = ACTIONS(260),
    [sym__lnoremap] = ACTIONS(260),
    [sym__cnoremap] = ACTIONS(260),
    [sym__tnoremap] = ACTIONS(260),
    [sym__augroup] = ACTIONS(260),
    [sym__highlight] = ACTIONS(260),
    [sym__syntax] = ACTIONS(260),
    [sym__set] = ACTIONS(260),
    [sym__setlocal] = ACTIONS(260),
    [sym__setfiletype] = ACTIONS(260),
    [sym__browse] = ACTIONS(260),
    [sym__options] = ACTIONS(260),
    [sym__startinsert] = ACTIONS(260),
    [sym__stopinsert] = ACTIONS(260),
    [sym__scriptencoding] = ACTIONS(260),
    [sym__source] = ACTIONS(260),
    [sym__global] = ACTIONS(260),
    [sym__colorscheme] = ACTIONS(260),
    [sym__command] = ACTIONS(260),
    [sym__comclear] = ACTIONS(260),
    [sym__delcommand] = ACTIONS(260),
    [sym__runtime] = ACTIONS(260),
    [sym__wincmd] = ACTIONS(260),
    [sym__sign] = ACTIONS(260),
    [sym__filetype] = ACTIONS(260),
    [sym__let] = ACTIONS(260),
    [sym__unlet] = ACTIONS(260),
    [sym__call] = ACTIONS(260),
    [sym__break] = ACTIONS(260),
    [sym__continue] = ACTIONS(260),
    [sym__tab] = ACTIONS(260),
    [sym__vertical] = ACTIONS(260),
    [sym__leftabove] = ACTIONS(260),
    [sym__aboveleft] = ACTIONS(260),
    [sym__rightbelow] = ACTIONS(260),
    [sym__belowright] = ACTIONS(260),
    [sym__topleft] = ACTIONS(260),
    [sym__botright] = ACTIONS(260),
    [sym__edit] = ACTIONS(260),
    [sym__enew] = ACTIONS(260),
    [sym__find] = ACTIONS(260),
    [sym__ex] = ACTIONS(260),
    [sym__visual] = ACTIONS(260),
    [sym__view] = ACTIONS(260),
    [sym__eval] = ACTIONS(260),
    [sym__substitute] = ACTIONS(260),
    [sym_unknown_command_name] = ACTIONS(260),
  },
  [STATE(104)] = {
    [anon_sym_COLON] = ACTIONS(715),
    [anon_sym_EQ] = ACTIONS(715),
    [anon_sym_QMARK] = ACTIONS(715),
    [anon_sym_POUND_BANG] = ACTIONS(715),
    [anon_sym_COMMA] = ACTIONS(715),
    [sym_mark] = ACTIONS(715),
    [anon_sym_PERCENT] = ACTIONS(715),
    [anon_sym_SLASH] = ACTIONS(715),
    [anon_sym_DOT2] = ACTIONS(715),
    [anon_sym_PLUS] = ACTIONS(720),
    [anon_sym_DOLLAR] = ACTIONS(715),
    [anon_sym_BSLASH_SLASH] = ACTIONS(715),
    [anon_sym_BSLASH_QMARK] = ACTIONS(715),
    [anon_sym_BSLASH_AMP] = ACTIONS(715),
    [sym_integer_literal] = ACTIONS(715),
    [sym_register] = ACTIONS(715),
    [sym_au_once] = ACTIONS(715),
    [sym_au_nested] = ACTIONS(715),
    [sym_command_name] = ACTIONS(715),
    [sym__newline_or_pipe] = ACTIONS(715),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(715),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(715),
    [sym__for] = ACTIONS(715),
    [sym__while] = ACTIONS(715),
    [sym__if] = ACTIONS(715),
    [sym__try] = ACTIONS(715),
    [sym__cnext] = ACTIONS(715),
    [sym__cprevious] = ACTIONS(715),
    [sym__cNext] = ACTIONS(715),
    [sym__const] = ACTIONS(715),
    [sym__normal] = ACTIONS(715),
    [sym__return] = ACTIONS(715),
    [sym__perl] = ACTIONS(715),
    [sym__lua] = ACTIONS(715),
    [sym__ruby] = ACTIONS(715),
    [sym__python] = ACTIONS(715),
    [sym__throw] = ACTIONS(715),
    [sym__execute] = ACTIONS(715),
    [sym__autocmd] = ACTIONS(715),
    [sym__silent] = ACTIONS(715),
    [sym__echo] = ACTIONS(715),
    [sym__echon] = ACTIONS(715),
    [sym__echohl] = ACTIONS(715),
    [sym__echomsg] = ACTIONS(715),
    [sym__echoerr] = ACTIONS(715),
    [sym__map] = ACTIONS(715),
    [sym__nmap] = ACTIONS(715),
    [sym__vmap] = ACTIONS(715),
    [sym__xmap] = ACTIONS(715),
    [sym__smap] = ACTIONS(715),
    [sym__omap] = ACTIONS(715),
    [sym__imap] = ACTIONS(715),
    [sym__lmap] = ACTIONS(715),
    [sym__cmap] = ACTIONS(715),
    [sym__tmap] = ACTIONS(715),
    [sym__noremap] = ACTIONS(715),
    [sym__nnoremap] = ACTIONS(715),
    [sym__vnoremap] = ACTIONS(715),
    [sym__xnoremap] = ACTIONS(715),
    [sym__snoremap] = ACTIONS(715),
    [sym__onoremap] = ACTIONS(715),
    [sym__inoremap] = ACTIONS(715),
    [sym__lnoremap] = ACTIONS(715),
    [sym__cnoremap] = ACTIONS(715),
    [sym__tnoremap] = ACTIONS(715),
    [sym__augroup] = ACTIONS(715),
    [sym__highlight] = ACTIONS(715),
    [sym__syntax] = ACTIONS(715),
    [sym__set] = ACTIONS(715),
    [sym__setlocal] = ACTIONS(715),
    [sym__setfiletype] = ACTIONS(715),
    [sym__browse] = ACTIONS(715),
    [sym__options] = ACTIONS(715),
    [sym__startinsert] = ACTIONS(715),
    [sym__stopinsert] = ACTIONS(715),
    [sym__scriptencoding] = ACTIONS(715),
    [sym__source] = ACTIONS(715),
    [sym__global] = ACTIONS(715),
    [sym__colorscheme] = ACTIONS(715),
    [sym__command] = ACTIONS(715),
    [sym__comclear] = ACTIONS(715),
    [sym__delcommand] = ACTIONS(715),
    [sym__runtime] = ACTIONS(715),
    [sym__wincmd] = ACTIONS(715),
    [sym__sign] = ACTIONS(715),
    [sym__filetype] = ACTIONS(715),
    [sym__let] = ACTIONS(715),
    [sym__unlet] = ACTIONS(715),
    [sym__call] = ACTIONS(715),
    [sym__break] = ACTIONS(715),
    [sym__continue] = ACTIONS(715),
    [sym__tab] = ACTIONS(715),
    [sym__vertical] = ACTIONS(715),
    [sym__leftabove] = ACTIONS(715),
    [sym__aboveleft] = ACTIONS(715),
    [sym__rightbelow] = ACTIONS(715),
    [sym__belowright] = ACTIONS(715),
    [sym__topleft] = ACTIONS(715),
    [sym__botright] = ACTIONS(715),
    [sym__edit] = ACTIONS(715),
    [sym__enew] = ACTIONS(715),
    [sym__find] = ACTIONS(715),
    [sym__ex] = ACTIONS(715),
    [sym__visual] = ACTIONS(715),
    [sym__view] = ACTIONS(715),
    [sym__eval] = ACTIONS(715),
    [sym__substitute] = ACTIONS(715),
    [sym_unknown_command_name] = ACTIONS(715),
  },
  [STATE(105)] = {
    [anon_sym_COLON] = ACTIONS(729),
    [anon_sym_EQ] = ACTIONS(729),
    [anon_sym_QMARK] = ACTIONS(729),
    [anon_sym_POUND_BANG] = ACTIONS(729),
    [sym_mark] = ACTIONS(729),
    [anon_sym_PERCENT] = ACTIONS(729),
    [anon_sym_SLASH] = ACTIONS(729),
    [anon_sym_DOT2] = ACTIONS(729),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DOLLAR] = ACTIONS(729),
    [anon_sym_BSLASH_SLASH] = ACTIONS(729),
    [anon_sym_BSLASH_QMARK] = ACTIONS(729),
    [anon_sym_BSLASH_AMP] = ACTIONS(729),
    [sym_integer_literal] = ACTIONS(729),
    [sym_register] = ACTIONS(729),
    [sym_command_name] = ACTIONS(729),
    [sym__newline_or_pipe] = ACTIONS(729),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(729),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(729),
    [sym__for] = ACTIONS(729),
    [sym__while] = ACTIONS(729),
    [sym__if] = ACTIONS(729),
    [sym__elseif] = ACTIONS(729),
    [sym__else] = ACTIONS(729),
    [sym__endif] = ACTIONS(729),
    [sym__try] = ACTIONS(729),
    [sym__cnext] = ACTIONS(729),
    [sym__cprevious] = ACTIONS(729),
    [sym__cNext] = ACTIONS(729),
    [sym__const] = ACTIONS(729),
    [sym__normal] = ACTIONS(729),
    [sym__return] = ACTIONS(729),
    [sym__perl] = ACTIONS(729),
    [sym__lua] = ACTIONS(729),
    [sym__ruby] = ACTIONS(729),
    [sym__python] = ACTIONS(729),
    [sym__throw] = ACTIONS(729),
    [sym__execute] = ACTIONS(729),
    [sym__autocmd] = ACTIONS(729),
    [sym__silent] = ACTIONS(729),
    [sym__echo] = ACTIONS(729),
    [sym__echon] = ACTIONS(729),
    [sym__echohl] = ACTIONS(729),
    [sym__echomsg] = ACTIONS(729),
    [sym__echoerr] = ACTIONS(729),
    [sym__map] = ACTIONS(729),
    [sym__nmap] = ACTIONS(729),
    [sym__vmap] = ACTIONS(729),
    [sym__xmap] = ACTIONS(729),
    [sym__smap] = ACTIONS(729),
    [sym__omap] = ACTIONS(729),
    [sym__imap] = ACTIONS(729),
    [sym__lmap] = ACTIONS(729),
    [sym__cmap] = ACTIONS(729),
    [sym__tmap] = ACTIONS(729),
    [sym__noremap] = ACTIONS(729),
    [sym__nnoremap] = ACTIONS(729),
    [sym__vnoremap] = ACTIONS(729),
    [sym__xnoremap] = ACTIONS(729),
    [sym__snoremap] = ACTIONS(729),
    [sym__onoremap] = ACTIONS(729),
    [sym__inoremap] = ACTIONS(729),
    [sym__lnoremap] = ACTIONS(729),
    [sym__cnoremap] = ACTIONS(729),
    [sym__tnoremap] = ACTIONS(729),
    [sym__augroup] = ACTIONS(729),
    [sym__highlight] = ACTIONS(729),
    [sym__syntax] = ACTIONS(729),
    [sym__set] = ACTIONS(729),
    [sym__setlocal] = ACTIONS(729),
    [sym__setfiletype] = ACTIONS(729),
    [sym__browse] = ACTIONS(729),
    [sym__options] = ACTIONS(729),
    [sym__startinsert] = ACTIONS(729),
    [sym__stopinsert] = ACTIONS(729),
    [sym__scriptencoding] = ACTIONS(729),
    [sym__source] = ACTIONS(729),
    [sym__global] = ACTIONS(729),
    [sym__colorscheme] = ACTIONS(729),
    [sym__command] = ACTIONS(729),
    [sym__comclear] = ACTIONS(729),
    [sym__delcommand] = ACTIONS(729),
    [sym__runtime] = ACTIONS(729),
    [sym__wincmd] = ACTIONS(729),
    [sym__sign] = ACTIONS(729),
    [sym__filetype] = ACTIONS(729),
    [sym__let] = ACTIONS(729),
    [sym__unlet] = ACTIONS(729),
    [sym__call] = ACTIONS(729),
    [sym__break] = ACTIONS(729),
    [sym__continue] = ACTIONS(729),
    [sym__tab] = ACTIONS(729),
    [sym__vertical] = ACTIONS(729),
    [sym__leftabove] = ACTIONS(729),
    [sym__aboveleft] = ACTIONS(729),
    [sym__rightbelow] = ACTIONS(729),
    [sym__belowright] = ACTIONS(729),
    [sym__topleft] = ACTIONS(729),
    [sym__botright] = ACTIONS(729),
    [sym__edit] = ACTIONS(729),
    [sym__enew] = ACTIONS(729),
    [sym__find] = ACTIONS(729),
    [sym__ex] = ACTIONS(729),
    [sym__visual] = ACTIONS(729),
    [sym__view] = ACTIONS(729),
    [sym__eval] = ACTIONS(729),
    [sym__substitute] = ACTIONS(729),
    [sym_unknown_command_name] = ACTIONS(729),
  },
  [STATE(106)] = {
    [anon_sym_COLON] = ACTIONS(729),
    [anon_sym_EQ] = ACTIONS(729),
    [anon_sym_QMARK] = ACTIONS(729),
    [anon_sym_POUND_BANG] = ACTIONS(729),
    [sym_mark] = ACTIONS(729),
    [anon_sym_PERCENT] = ACTIONS(729),
    [anon_sym_SLASH] = ACTIONS(729),
    [anon_sym_DOT2] = ACTIONS(729),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DOLLAR] = ACTIONS(729),
    [anon_sym_BSLASH_SLASH] = ACTIONS(729),
    [anon_sym_BSLASH_QMARK] = ACTIONS(729),
    [anon_sym_BSLASH_AMP] = ACTIONS(729),
    [sym_integer_literal] = ACTIONS(729),
    [sym_register] = ACTIONS(729),
    [sym_command_name] = ACTIONS(729),
    [sym__newline_or_pipe] = ACTIONS(729),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(729),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(729),
    [sym__for] = ACTIONS(729),
    [sym__while] = ACTIONS(729),
    [sym__if] = ACTIONS(729),
    [sym__try] = ACTIONS(729),
    [sym__catch] = ACTIONS(729),
    [sym__cnext] = ACTIONS(729),
    [sym__cprevious] = ACTIONS(729),
    [sym__cNext] = ACTIONS(729),
    [sym__finally] = ACTIONS(729),
    [sym__endtry] = ACTIONS(729),
    [sym__const] = ACTIONS(729),
    [sym__normal] = ACTIONS(729),
    [sym__return] = ACTIONS(729),
    [sym__perl] = ACTIONS(729),
    [sym__lua] = ACTIONS(729),
    [sym__ruby] = ACTIONS(729),
    [sym__python] = ACTIONS(729),
    [sym__throw] = ACTIONS(729),
    [sym__execute] = ACTIONS(729),
    [sym__autocmd] = ACTIONS(729),
    [sym__silent] = ACTIONS(729),
    [sym__echo] = ACTIONS(729),
    [sym__echon] = ACTIONS(729),
    [sym__echohl] = ACTIONS(729),
    [sym__echomsg] = ACTIONS(729),
    [sym__echoerr] = ACTIONS(729),
    [sym__map] = ACTIONS(729),
    [sym__nmap] = ACTIONS(729),
    [sym__vmap] = ACTIONS(729),
    [sym__xmap] = ACTIONS(729),
    [sym__smap] = ACTIONS(729),
    [sym__omap] = ACTIONS(729),
    [sym__imap] = ACTIONS(729),
    [sym__lmap] = ACTIONS(729),
    [sym__cmap] = ACTIONS(729),
    [sym__tmap] = ACTIONS(729),
    [sym__noremap] = ACTIONS(729),
    [sym__nnoremap] = ACTIONS(729),
    [sym__vnoremap] = ACTIONS(729),
    [sym__xnoremap] = ACTIONS(729),
    [sym__snoremap] = ACTIONS(729),
    [sym__onoremap] = ACTIONS(729),
    [sym__inoremap] = ACTIONS(729),
    [sym__lnoremap] = ACTIONS(729),
    [sym__cnoremap] = ACTIONS(729),
    [sym__tnoremap] = ACTIONS(729),
    [sym__augroup] = ACTIONS(729),
    [sym__highlight] = ACTIONS(729),
    [sym__syntax] = ACTIONS(729),
    [sym__set] = ACTIONS(729),
    [sym__setlocal] = ACTIONS(729),
    [sym__setfiletype] = ACTIONS(729),
    [sym__browse] = ACTIONS(729),
    [sym__options] = ACTIONS(729),
    [sym__startinsert] = ACTIONS(729),
    [sym__stopinsert] = ACTIONS(729),
    [sym__scriptencoding] = ACTIONS(729),
    [sym__source] = ACTIONS(729),
    [sym__global] = ACTIONS(729),
    [sym__colorscheme] = ACTIONS(729),
    [sym__command] = ACTIONS(729),
    [sym__comclear] = ACTIONS(729),
    [sym__delcommand] = ACTIONS(729),
    [sym__runtime] = ACTIONS(729),
    [sym__wincmd] = ACTIONS(729),
    [sym__sign] = ACTIONS(729),
    [sym__filetype] = ACTIONS(729),
    [sym__let] = ACTIONS(729),
    [sym__unlet] = ACTIONS(729),
    [sym__call] = ACTIONS(729),
    [sym__break] = ACTIONS(729),
    [sym__continue] = ACTIONS(729),
    [sym__tab] = ACTIONS(729),
    [sym__vertical] = ACTIONS(729),
    [sym__leftabove] = ACTIONS(729),
    [sym__aboveleft] = ACTIONS(729),
    [sym__rightbelow] = ACTIONS(729),
    [sym__belowright] = ACTIONS(729),
    [sym__topleft] = ACTIONS(729),
    [sym__botright] = ACTIONS(729),
    [sym__edit] = ACTIONS(729),
    [sym__enew] = ACTIONS(729),
    [sym__find] = ACTIONS(729),
    [sym__ex] = ACTIONS(729),
    [sym__visual] = ACTIONS(729),
    [sym__view] = ACTIONS(729),
    [sym__eval] = ACTIONS(729),
    [sym__substitute] = ACTIONS(729),
    [sym_unknown_command_name] = ACTIONS(729),
  },
  [STATE(107)] = {
    [anon_sym_COLON] = ACTIONS(260),
    [anon_sym_EQ] = ACTIONS(260),
    [anon_sym_QMARK] = ACTIONS(260),
    [anon_sym_POUND_BANG] = ACTIONS(260),
    [sym_mark] = ACTIONS(260),
    [anon_sym_PERCENT] = ACTIONS(260),
    [anon_sym_SLASH] = ACTIONS(260),
    [anon_sym_DOT2] = ACTIONS(260),
    [anon_sym_PLUS] = ACTIONS(727),
    [anon_sym_DOLLAR] = ACTIONS(260),
    [anon_sym_BSLASH_SLASH] = ACTIONS(260),
    [anon_sym_BSLASH_QMARK] = ACTIONS(260),
    [anon_sym_BSLASH_AMP] = ACTIONS(260),
    [sym_integer_literal] = ACTIONS(260),
    [sym_register] = ACTIONS(260),
    [sym_command_name] = ACTIONS(260),
    [sym__newline_or_pipe] = ACTIONS(260),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(260),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(260),
    [sym__for] = ACTIONS(260),
    [sym__while] = ACTIONS(260),
    [sym__if] = ACTIONS(260),
    [sym__try] = ACTIONS(260),
    [sym__catch] = ACTIONS(260),
    [sym__cnext] = ACTIONS(260),
    [sym__cprevious] = ACTIONS(260),
    [sym__cNext] = ACTIONS(260),
    [sym__finally] = ACTIONS(260),
    [sym__endtry] = ACTIONS(260),
    [sym__const] = ACTIONS(260),
    [sym__normal] = ACTIONS(260),
    [sym__return] = ACTIONS(260),
    [sym__perl] = ACTIONS(260),
    [sym__lua] = ACTIONS(260),
    [sym__ruby] = ACTIONS(260),
    [sym__python] = ACTIONS(260),
    [sym__throw] = ACTIONS(260),
    [sym__execute] = ACTIONS(260),
    [sym__autocmd] = ACTIONS(260),
    [sym__silent] = ACTIONS(260),
    [sym__echo] = ACTIONS(260),
    [sym__echon] = ACTIONS(260),
    [sym__echohl] = ACTIONS(260),
    [sym__echomsg] = ACTIONS(260),
    [sym__echoerr] = ACTIONS(260),
    [sym__map] = ACTIONS(260),
    [sym__nmap] = ACTIONS(260),
    [sym__vmap] = ACTIONS(260),
    [sym__xmap] = ACTIONS(260),
    [sym__smap] = ACTIONS(260),
    [sym__omap] = ACTIONS(260),
    [sym__imap] = ACTIONS(260),
    [sym__lmap] = ACTIONS(260),
    [sym__cmap] = ACTIONS(260),
    [sym__tmap] = ACTIONS(260),
    [sym__noremap] = ACTIONS(260),
    [sym__nnoremap] = ACTIONS(260),
    [sym__vnoremap] = ACTIONS(260),
    [sym__xnoremap] = ACTIONS(260),
    [sym__snoremap] = ACTIONS(260),
    [sym__onoremap] = ACTIONS(260),
    [sym__inoremap] = ACTIONS(260),
    [sym__lnoremap] = ACTIONS(260),
    [sym__cnoremap] = ACTIONS(260),
    [sym__tnoremap] = ACTIONS(260),
    [sym__augroup] = ACTIONS(260),
    [sym__highlight] = ACTIONS(260),
    [sym__syntax] = ACTIONS(260),
    [sym__set] = ACTIONS(260),
    [sym__setlocal] = ACTIONS(260),
    [sym__setfiletype] = ACTIONS(260),
    [sym__browse] = ACTIONS(260),
    [sym__options] = ACTIONS(260),
    [sym__startinsert] = ACTIONS(260),
    [sym__stopinsert] = ACTIONS(260),
    [sym__scriptencoding] = ACTIONS(260),
    [sym__source] = ACTIONS(260),
    [sym__global] = ACTIONS(260),
    [sym__colorscheme] = ACTIONS(260),
    [sym__command] = ACTIONS(260),
    [sym__comclear] = ACTIONS(260),
    [sym__delcommand] = ACTIONS(260),
    [sym__runtime] = ACTIONS(260),
    [sym__wincmd] = ACTIONS(260),
    [sym__sign] = ACTIONS(260),
    [sym__filetype] = ACTIONS(260),
    [sym__let] = ACTIONS(260),
    [sym__unlet] = ACTIONS(260),
    [sym__call] = ACTIONS(260),
    [sym__break] = ACTIONS(260),
    [sym__continue] = ACTIONS(260),
    [sym__tab] = ACTIONS(260),
    [sym__vertical] = ACTIONS(260),
    [sym__leftabove] = ACTIONS(260),
    [sym__aboveleft] = ACTIONS(260),
    [sym__rightbelow] = ACTIONS(260),
    [sym__belowright] = ACTIONS(260),
    [sym__topleft] = ACTIONS(260),
    [sym__botright] = ACTIONS(260),
    [sym__edit] = ACTIONS(260),
    [sym__enew] = ACTIONS(260),
    [sym__find] = ACTIONS(260),
    [sym__ex] = ACTIONS(260),
    [sym__visual] = ACTIONS(260),
    [sym__view] = ACTIONS(260),
    [sym__eval] = ACTIONS(260),
    [sym__substitute] = ACTIONS(260),
    [sym_unknown_command_name] = ACTIONS(260),
  },
  [STATE(108)] = {
    [ts_builtin_sym_end] = ACTIONS(260),
    [anon_sym_COLON] = ACTIONS(260),
    [anon_sym_EQ] = ACTIONS(260),
    [anon_sym_QMARK] = ACTIONS(260),
    [anon_sym_POUND_BANG] = ACTIONS(260),
    [sym_mark] = ACTIONS(260),
    [anon_sym_PERCENT] = ACTIONS(260),
    [anon_sym_SLASH] = ACTIONS(260),
    [anon_sym_DOT2] = ACTIONS(260),
    [anon_sym_PLUS] = ACTIONS(727),
    [anon_sym_DOLLAR] = ACTIONS(260),
    [anon_sym_BSLASH_SLASH] = ACTIONS(260),
    [anon_sym_BSLASH_QMARK] = ACTIONS(260),
    [anon_sym_BSLASH_AMP] = ACTIONS(260),
    [sym_integer_literal] = ACTIONS(260),
    [sym_register] = ACTIONS(260),
    [sym_command_name] = ACTIONS(260),
    [sym__newline_or_pipe] = ACTIONS(260),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(260),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(260),
    [sym__for] = ACTIONS(260),
    [sym__while] = ACTIONS(260),
    [sym__if] = ACTIONS(260),
    [sym__try] = ACTIONS(260),
    [sym__cnext] = ACTIONS(260),
    [sym__cprevious] = ACTIONS(260),
    [sym__cNext] = ACTIONS(260),
    [sym__const] = ACTIONS(260),
    [sym__normal] = ACTIONS(260),
    [sym__return] = ACTIONS(260),
    [sym__perl] = ACTIONS(260),
    [sym__lua] = ACTIONS(260),
    [sym__ruby] = ACTIONS(260),
    [sym__python] = ACTIONS(260),
    [sym__throw] = ACTIONS(260),
    [sym__execute] = ACTIONS(260),
    [sym__autocmd] = ACTIONS(260),
    [sym__silent] = ACTIONS(260),
    [sym__echo] = ACTIONS(260),
    [sym__echon] = ACTIONS(260),
    [sym__echohl] = ACTIONS(260),
    [sym__echomsg] = ACTIONS(260),
    [sym__echoerr] = ACTIONS(260),
    [sym__map] = ACTIONS(260),
    [sym__nmap] = ACTIONS(260),
    [sym__vmap] = ACTIONS(260),
    [sym__xmap] = ACTIONS(260),
    [sym__smap] = ACTIONS(260),
    [sym__omap] = ACTIONS(260),
    [sym__imap] = ACTIONS(260),
    [sym__lmap] = ACTIONS(260),
    [sym__cmap] = ACTIONS(260),
    [sym__tmap] = ACTIONS(260),
    [sym__noremap] = ACTIONS(260),
    [sym__nnoremap] = ACTIONS(260),
    [sym__vnoremap] = ACTIONS(260),
    [sym__xnoremap] = ACTIONS(260),
    [sym__snoremap] = ACTIONS(260),
    [sym__onoremap] = ACTIONS(260),
    [sym__inoremap] = ACTIONS(260),
    [sym__lnoremap] = ACTIONS(260),
    [sym__cnoremap] = ACTIONS(260),
    [sym__tnoremap] = ACTIONS(260),
    [sym__augroup] = ACTIONS(260),
    [sym__highlight] = ACTIONS(260),
    [sym__syntax] = ACTIONS(260),
    [sym__set] = ACTIONS(260),
    [sym__setlocal] = ACTIONS(260),
    [sym__setfiletype] = ACTIONS(260),
    [sym__browse] = ACTIONS(260),
    [sym__options] = ACTIONS(260),
    [sym__startinsert] = ACTIONS(260),
    [sym__stopinsert] = ACTIONS(260),
    [sym__scriptencoding] = ACTIONS(260),
    [sym__source] = ACTIONS(260),
    [sym__global] = ACTIONS(260),
    [sym__colorscheme] = ACTIONS(260),
    [sym__command] = ACTIONS(260),
    [sym__comclear] = ACTIONS(260),
    [sym__delcommand] = ACTIONS(260),
    [sym__runtime] = ACTIONS(260),
    [sym__wincmd] = ACTIONS(260),
    [sym__sign] = ACTIONS(260),
    [sym__filetype] = ACTIONS(260),
    [sym__let] = ACTIONS(260),
    [sym__unlet] = ACTIONS(260),
    [sym__call] = ACTIONS(260),
    [sym__break] = ACTIONS(260),
    [sym__continue] = ACTIONS(260),
    [sym__tab] = ACTIONS(260),
    [sym__vertical] = ACTIONS(260),
    [sym__leftabove] = ACTIONS(260),
    [sym__aboveleft] = ACTIONS(260),
    [sym__rightbelow] = ACTIONS(260),
    [sym__belowright] = ACTIONS(260),
    [sym__topleft] = ACTIONS(260),
    [sym__botright] = ACTIONS(260),
    [sym__edit] = ACTIONS(260),
    [sym__enew] = ACTIONS(260),
    [sym__find] = ACTIONS(260),
    [sym__ex] = ACTIONS(260),
    [sym__visual] = ACTIONS(260),
    [sym__view] = ACTIONS(260),
    [sym__eval] = ACTIONS(260),
    [sym__substitute] = ACTIONS(260),
    [sym_unknown_command_name] = ACTIONS(260),
  },
  [STATE(109)] = {
    [anon_sym_COLON] = ACTIONS(729),
    [anon_sym_EQ] = ACTIONS(729),
    [anon_sym_QMARK] = ACTIONS(729),
    [anon_sym_POUND_BANG] = ACTIONS(729),
    [sym_mark] = ACTIONS(729),
    [anon_sym_PERCENT] = ACTIONS(729),
    [anon_sym_SLASH] = ACTIONS(729),
    [anon_sym_DOT2] = ACTIONS(729),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DOLLAR] = ACTIONS(729),
    [anon_sym_BSLASH_SLASH] = ACTIONS(729),
    [anon_sym_BSLASH_QMARK] = ACTIONS(729),
    [anon_sym_BSLASH_AMP] = ACTIONS(729),
    [sym_integer_literal] = ACTIONS(729),
    [sym_register] = ACTIONS(729),
    [sym_command_name] = ACTIONS(729),
    [sym__newline_or_pipe] = ACTIONS(729),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(729),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(729),
    [sym__endfunction] = ACTIONS(729),
    [sym__for] = ACTIONS(729),
    [sym__while] = ACTIONS(729),
    [sym__if] = ACTIONS(729),
    [sym__try] = ACTIONS(729),
    [sym__cnext] = ACTIONS(729),
    [sym__cprevious] = ACTIONS(729),
    [sym__cNext] = ACTIONS(729),
    [sym__const] = ACTIONS(729),
    [sym__normal] = ACTIONS(729),
    [sym__return] = ACTIONS(729),
    [sym__perl] = ACTIONS(729),
    [sym__lua] = ACTIONS(729),
    [sym__ruby] = ACTIONS(729),
    [sym__python] = ACTIONS(729),
    [sym__throw] = ACTIONS(729),
    [sym__execute] = ACTIONS(729),
    [sym__autocmd] = ACTIONS(729),
    [sym__silent] = ACTIONS(729),
    [sym__echo] = ACTIONS(729),
    [sym__echon] = ACTIONS(729),
    [sym__echohl] = ACTIONS(729),
    [sym__echomsg] = ACTIONS(729),
    [sym__echoerr] = ACTIONS(729),
    [sym__map] = ACTIONS(729),
    [sym__nmap] = ACTIONS(729),
    [sym__vmap] = ACTIONS(729),
    [sym__xmap] = ACTIONS(729),
    [sym__smap] = ACTIONS(729),
    [sym__omap] = ACTIONS(729),
    [sym__imap] = ACTIONS(729),
    [sym__lmap] = ACTIONS(729),
    [sym__cmap] = ACTIONS(729),
    [sym__tmap] = ACTIONS(729),
    [sym__noremap] = ACTIONS(729),
    [sym__nnoremap] = ACTIONS(729),
    [sym__vnoremap] = ACTIONS(729),
    [sym__xnoremap] = ACTIONS(729),
    [sym__snoremap] = ACTIONS(729),
    [sym__onoremap] = ACTIONS(729),
    [sym__inoremap] = ACTIONS(729),
    [sym__lnoremap] = ACTIONS(729),
    [sym__cnoremap] = ACTIONS(729),
    [sym__tnoremap] = ACTIONS(729),
    [sym__augroup] = ACTIONS(729),
    [sym__highlight] = ACTIONS(729),
    [sym__syntax] = ACTIONS(729),
    [sym__set] = ACTIONS(729),
    [sym__setlocal] = ACTIONS(729),
    [sym__setfiletype] = ACTIONS(729),
    [sym__browse] = ACTIONS(729),
    [sym__options] = ACTIONS(729),
    [sym__startinsert] = ACTIONS(729),
    [sym__stopinsert] = ACTIONS(729),
    [sym__scriptencoding] = ACTIONS(729),
    [sym__source] = ACTIONS(729),
    [sym__global] = ACTIONS(729),
    [sym__colorscheme] = ACTIONS(729),
    [sym__command] = ACTIONS(729),
    [sym__comclear] = ACTIONS(729),
    [sym__delcommand] = ACTIONS(729),
    [sym__runtime] = ACTIONS(729),
    [sym__wincmd] = ACTIONS(729),
    [sym__sign] = ACTIONS(729),
    [sym__filetype] = ACTIONS(729),
    [sym__let] = ACTIONS(729),
    [sym__unlet] = ACTIONS(729),
    [sym__call] = ACTIONS(729),
    [sym__break] = ACTIONS(729),
    [sym__continue] = ACTIONS(729),
    [sym__tab] = ACTIONS(729),
    [sym__vertical] = ACTIONS(729),
    [sym__leftabove] = ACTIONS(729),
    [sym__aboveleft] = ACTIONS(729),
    [sym__rightbelow] = ACTIONS(729),
    [sym__belowright] = ACTIONS(729),
    [sym__topleft] = ACTIONS(729),
    [sym__botright] = ACTIONS(729),
    [sym__edit] = ACTIONS(729),
    [sym__enew] = ACTIONS(729),
    [sym__find] = ACTIONS(729),
    [sym__ex] = ACTIONS(729),
    [sym__visual] = ACTIONS(729),
    [sym__view] = ACTIONS(729),
    [sym__eval] = ACTIONS(729),
    [sym__substitute] = ACTIONS(729),
    [sym_unknown_command_name] = ACTIONS(729),
  },
  [STATE(110)] = {
    [anon_sym_COLON] = ACTIONS(260),
    [anon_sym_EQ] = ACTIONS(260),
    [anon_sym_QMARK] = ACTIONS(260),
    [anon_sym_POUND_BANG] = ACTIONS(260),
    [sym_mark] = ACTIONS(260),
    [anon_sym_PERCENT] = ACTIONS(260),
    [anon_sym_SLASH] = ACTIONS(260),
    [anon_sym_DOT2] = ACTIONS(260),
    [anon_sym_PLUS] = ACTIONS(727),
    [anon_sym_DOLLAR] = ACTIONS(260),
    [anon_sym_BSLASH_SLASH] = ACTIONS(260),
    [anon_sym_BSLASH_QMARK] = ACTIONS(260),
    [anon_sym_BSLASH_AMP] = ACTIONS(260),
    [sym_integer_literal] = ACTIONS(260),
    [sym_register] = ACTIONS(260),
    [sym_command_name] = ACTIONS(260),
    [sym__newline_or_pipe] = ACTIONS(260),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(260),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(260),
    [sym__for] = ACTIONS(260),
    [sym__while] = ACTIONS(260),
    [sym__if] = ACTIONS(260),
    [sym__try] = ACTIONS(260),
    [sym__cnext] = ACTIONS(260),
    [sym__cprevious] = ACTIONS(260),
    [sym__cNext] = ACTIONS(260),
    [sym__endtry] = ACTIONS(260),
    [sym__const] = ACTIONS(260),
    [sym__normal] = ACTIONS(260),
    [sym__return] = ACTIONS(260),
    [sym__perl] = ACTIONS(260),
    [sym__lua] = ACTIONS(260),
    [sym__ruby] = ACTIONS(260),
    [sym__python] = ACTIONS(260),
    [sym__throw] = ACTIONS(260),
    [sym__execute] = ACTIONS(260),
    [sym__autocmd] = ACTIONS(260),
    [sym__silent] = ACTIONS(260),
    [sym__echo] = ACTIONS(260),
    [sym__echon] = ACTIONS(260),
    [sym__echohl] = ACTIONS(260),
    [sym__echomsg] = ACTIONS(260),
    [sym__echoerr] = ACTIONS(260),
    [sym__map] = ACTIONS(260),
    [sym__nmap] = ACTIONS(260),
    [sym__vmap] = ACTIONS(260),
    [sym__xmap] = ACTIONS(260),
    [sym__smap] = ACTIONS(260),
    [sym__omap] = ACTIONS(260),
    [sym__imap] = ACTIONS(260),
    [sym__lmap] = ACTIONS(260),
    [sym__cmap] = ACTIONS(260),
    [sym__tmap] = ACTIONS(260),
    [sym__noremap] = ACTIONS(260),
    [sym__nnoremap] = ACTIONS(260),
    [sym__vnoremap] = ACTIONS(260),
    [sym__xnoremap] = ACTIONS(260),
    [sym__snoremap] = ACTIONS(260),
    [sym__onoremap] = ACTIONS(260),
    [sym__inoremap] = ACTIONS(260),
    [sym__lnoremap] = ACTIONS(260),
    [sym__cnoremap] = ACTIONS(260),
    [sym__tnoremap] = ACTIONS(260),
    [sym__augroup] = ACTIONS(260),
    [sym__highlight] = ACTIONS(260),
    [sym__syntax] = ACTIONS(260),
    [sym__set] = ACTIONS(260),
    [sym__setlocal] = ACTIONS(260),
    [sym__setfiletype] = ACTIONS(260),
    [sym__browse] = ACTIONS(260),
    [sym__options] = ACTIONS(260),
    [sym__startinsert] = ACTIONS(260),
    [sym__stopinsert] = ACTIONS(260),
    [sym__scriptencoding] = ACTIONS(260),
    [sym__source] = ACTIONS(260),
    [sym__global] = ACTIONS(260),
    [sym__colorscheme] = ACTIONS(260),
    [sym__command] = ACTIONS(260),
    [sym__comclear] = ACTIONS(260),
    [sym__delcommand] = ACTIONS(260),
    [sym__runtime] = ACTIONS(260),
    [sym__wincmd] = ACTIONS(260),
    [sym__sign] = ACTIONS(260),
    [sym__filetype] = ACTIONS(260),
    [sym__let] = ACTIONS(260),
    [sym__unlet] = ACTIONS(260),
    [sym__call] = ACTIONS(260),
    [sym__break] = ACTIONS(260),
    [sym__continue] = ACTIONS(260),
    [sym__tab] = ACTIONS(260),
    [sym__vertical] = ACTIONS(260),
    [sym__leftabove] = ACTIONS(260),
    [sym__aboveleft] = ACTIONS(260),
    [sym__rightbelow] = ACTIONS(260),
    [sym__belowright] = ACTIONS(260),
    [sym__topleft] = ACTIONS(260),
    [sym__botright] = ACTIONS(260),
    [sym__edit] = ACTIONS(260),
    [sym__enew] = ACTIONS(260),
    [sym__find] = ACTIONS(260),
    [sym__ex] = ACTIONS(260),
    [sym__visual] = ACTIONS(260),
    [sym__view] = ACTIONS(260),
    [sym__eval] = ACTIONS(260),
    [sym__substitute] = ACTIONS(260),
    [sym_unknown_command_name] = ACTIONS(260),
  },
  [STATE(111)] = {
    [anon_sym_COLON] = ACTIONS(260),
    [anon_sym_EQ] = ACTIONS(260),
    [anon_sym_QMARK] = ACTIONS(260),
    [anon_sym_POUND_BANG] = ACTIONS(260),
    [sym_mark] = ACTIONS(260),
    [anon_sym_PERCENT] = ACTIONS(260),
    [anon_sym_SLASH] = ACTIONS(260),
    [anon_sym_DOT2] = ACTIONS(260),
    [anon_sym_PLUS] = ACTIONS(727),
    [anon_sym_DOLLAR] = ACTIONS(260),
    [anon_sym_BSLASH_SLASH] = ACTIONS(260),
    [anon_sym_BSLASH_QMARK] = ACTIONS(260),
    [anon_sym_BSLASH_AMP] = ACTIONS(260),
    [sym_integer_literal] = ACTIONS(260),
    [sym_register] = ACTIONS(260),
    [sym_command_name] = ACTIONS(260),
    [sym__newline_or_pipe] = ACTIONS(260),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(260),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(260),
    [sym__for] = ACTIONS(260),
    [sym__while] = ACTIONS(260),
    [sym__endwhile] = ACTIONS(260),
    [sym__if] = ACTIONS(260),
    [sym__try] = ACTIONS(260),
    [sym__cnext] = ACTIONS(260),
    [sym__cprevious] = ACTIONS(260),
    [sym__cNext] = ACTIONS(260),
    [sym__const] = ACTIONS(260),
    [sym__normal] = ACTIONS(260),
    [sym__return] = ACTIONS(260),
    [sym__perl] = ACTIONS(260),
    [sym__lua] = ACTIONS(260),
    [sym__ruby] = ACTIONS(260),
    [sym__python] = ACTIONS(260),
    [sym__throw] = ACTIONS(260),
    [sym__execute] = ACTIONS(260),
    [sym__autocmd] = ACTIONS(260),
    [sym__silent] = ACTIONS(260),
    [sym__echo] = ACTIONS(260),
    [sym__echon] = ACTIONS(260),
    [sym__echohl] = ACTIONS(260),
    [sym__echomsg] = ACTIONS(260),
    [sym__echoerr] = ACTIONS(260),
    [sym__map] = ACTIONS(260),
    [sym__nmap] = ACTIONS(260),
    [sym__vmap] = ACTIONS(260),
    [sym__xmap] = ACTIONS(260),
    [sym__smap] = ACTIONS(260),
    [sym__omap] = ACTIONS(260),
    [sym__imap] = ACTIONS(260),
    [sym__lmap] = ACTIONS(260),
    [sym__cmap] = ACTIONS(260),
    [sym__tmap] = ACTIONS(260),
    [sym__noremap] = ACTIONS(260),
    [sym__nnoremap] = ACTIONS(260),
    [sym__vnoremap] = ACTIONS(260),
    [sym__xnoremap] = ACTIONS(260),
    [sym__snoremap] = ACTIONS(260),
    [sym__onoremap] = ACTIONS(260),
    [sym__inoremap] = ACTIONS(260),
    [sym__lnoremap] = ACTIONS(260),
    [sym__cnoremap] = ACTIONS(260),
    [sym__tnoremap] = ACTIONS(260),
    [sym__augroup] = ACTIONS(260),
    [sym__highlight] = ACTIONS(260),
    [sym__syntax] = ACTIONS(260),
    [sym__set] = ACTIONS(260),
    [sym__setlocal] = ACTIONS(260),
    [sym__setfiletype] = ACTIONS(260),
    [sym__browse] = ACTIONS(260),
    [sym__options] = ACTIONS(260),
    [sym__startinsert] = ACTIONS(260),
    [sym__stopinsert] = ACTIONS(260),
    [sym__scriptencoding] = ACTIONS(260),
    [sym__source] = ACTIONS(260),
    [sym__global] = ACTIONS(260),
    [sym__colorscheme] = ACTIONS(260),
    [sym__command] = ACTIONS(260),
    [sym__comclear] = ACTIONS(260),
    [sym__delcommand] = ACTIONS(260),
    [sym__runtime] = ACTIONS(260),
    [sym__wincmd] = ACTIONS(260),
    [sym__sign] = ACTIONS(260),
    [sym__filetype] = ACTIONS(260),
    [sym__let] = ACTIONS(260),
    [sym__unlet] = ACTIONS(260),
    [sym__call] = ACTIONS(260),
    [sym__break] = ACTIONS(260),
    [sym__continue] = ACTIONS(260),
    [sym__tab] = ACTIONS(260),
    [sym__vertical] = ACTIONS(260),
    [sym__leftabove] = ACTIONS(260),
    [sym__aboveleft] = ACTIONS(260),
    [sym__rightbelow] = ACTIONS(260),
    [sym__belowright] = ACTIONS(260),
    [sym__topleft] = ACTIONS(260),
    [sym__botright] = ACTIONS(260),
    [sym__edit] = ACTIONS(260),
    [sym__enew] = ACTIONS(260),
    [sym__find] = ACTIONS(260),
    [sym__ex] = ACTIONS(260),
    [sym__visual] = ACTIONS(260),
    [sym__view] = ACTIONS(260),
    [sym__eval] = ACTIONS(260),
    [sym__substitute] = ACTIONS(260),
    [sym_unknown_command_name] = ACTIONS(260),
  },
  [STATE(112)] = {
    [anon_sym_COLON] = ACTIONS(260),
    [anon_sym_EQ] = ACTIONS(260),
    [anon_sym_QMARK] = ACTIONS(260),
    [anon_sym_POUND_BANG] = ACTIONS(260),
    [sym_mark] = ACTIONS(260),
    [anon_sym_PERCENT] = ACTIONS(260),
    [anon_sym_SLASH] = ACTIONS(260),
    [anon_sym_DOT2] = ACTIONS(260),
    [anon_sym_PLUS] = ACTIONS(727),
    [anon_sym_DOLLAR] = ACTIONS(260),
    [anon_sym_BSLASH_SLASH] = ACTIONS(260),
    [anon_sym_BSLASH_QMARK] = ACTIONS(260),
    [anon_sym_BSLASH_AMP] = ACTIONS(260),
    [sym_integer_literal] = ACTIONS(260),
    [sym_register] = ACTIONS(260),
    [sym_command_name] = ACTIONS(260),
    [sym__newline_or_pipe] = ACTIONS(260),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(260),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(260),
    [sym__endfunction] = ACTIONS(260),
    [sym__for] = ACTIONS(260),
    [sym__while] = ACTIONS(260),
    [sym__if] = ACTIONS(260),
    [sym__try] = ACTIONS(260),
    [sym__cnext] = ACTIONS(260),
    [sym__cprevious] = ACTIONS(260),
    [sym__cNext] = ACTIONS(260),
    [sym__const] = ACTIONS(260),
    [sym__normal] = ACTIONS(260),
    [sym__return] = ACTIONS(260),
    [sym__perl] = ACTIONS(260),
    [sym__lua] = ACTIONS(260),
    [sym__ruby] = ACTIONS(260),
    [sym__python] = ACTIONS(260),
    [sym__throw] = ACTIONS(260),
    [sym__execute] = ACTIONS(260),
    [sym__autocmd] = ACTIONS(260),
    [sym__silent] = ACTIONS(260),
    [sym__echo] = ACTIONS(260),
    [sym__echon] = ACTIONS(260),
    [sym__echohl] = ACTIONS(260),
    [sym__echomsg] = ACTIONS(260),
    [sym__echoerr] = ACTIONS(260),
    [sym__map] = ACTIONS(260),
    [sym__nmap] = ACTIONS(260),
    [sym__vmap] = ACTIONS(260),
    [sym__xmap] = ACTIONS(260),
    [sym__smap] = ACTIONS(260),
    [sym__omap] = ACTIONS(260),
    [sym__imap] = ACTIONS(260),
    [sym__lmap] = ACTIONS(260),
    [sym__cmap] = ACTIONS(260),
    [sym__tmap] = ACTIONS(260),
    [sym__noremap] = ACTIONS(260),
    [sym__nnoremap] = ACTIONS(260),
    [sym__vnoremap] = ACTIONS(260),
    [sym__xnoremap] = ACTIONS(260),
    [sym__snoremap] = ACTIONS(260),
    [sym__onoremap] = ACTIONS(260),
    [sym__inoremap] = ACTIONS(260),
    [sym__lnoremap] = ACTIONS(260),
    [sym__cnoremap] = ACTIONS(260),
    [sym__tnoremap] = ACTIONS(260),
    [sym__augroup] = ACTIONS(260),
    [sym__highlight] = ACTIONS(260),
    [sym__syntax] = ACTIONS(260),
    [sym__set] = ACTIONS(260),
    [sym__setlocal] = ACTIONS(260),
    [sym__setfiletype] = ACTIONS(260),
    [sym__browse] = ACTIONS(260),
    [sym__options] = ACTIONS(260),
    [sym__startinsert] = ACTIONS(260),
    [sym__stopinsert] = ACTIONS(260),
    [sym__scriptencoding] = ACTIONS(260),
    [sym__source] = ACTIONS(260),
    [sym__global] = ACTIONS(260),
    [sym__colorscheme] = ACTIONS(260),
    [sym__command] = ACTIONS(260),
    [sym__comclear] = ACTIONS(260),
    [sym__delcommand] = ACTIONS(260),
    [sym__runtime] = ACTIONS(260),
    [sym__wincmd] = ACTIONS(260),
    [sym__sign] = ACTIONS(260),
    [sym__filetype] = ACTIONS(260),
    [sym__let] = ACTIONS(260),
    [sym__unlet] = ACTIONS(260),
    [sym__call] = ACTIONS(260),
    [sym__break] = ACTIONS(260),
    [sym__continue] = ACTIONS(260),
    [sym__tab] = ACTIONS(260),
    [sym__vertical] = ACTIONS(260),
    [sym__leftabove] = ACTIONS(260),
    [sym__aboveleft] = ACTIONS(260),
    [sym__rightbelow] = ACTIONS(260),
    [sym__belowright] = ACTIONS(260),
    [sym__topleft] = ACTIONS(260),
    [sym__botright] = ACTIONS(260),
    [sym__edit] = ACTIONS(260),
    [sym__enew] = ACTIONS(260),
    [sym__find] = ACTIONS(260),
    [sym__ex] = ACTIONS(260),
    [sym__visual] = ACTIONS(260),
    [sym__view] = ACTIONS(260),
    [sym__eval] = ACTIONS(260),
    [sym__substitute] = ACTIONS(260),
    [sym_unknown_command_name] = ACTIONS(260),
  },
  [STATE(113)] = {
    [anon_sym_COLON] = ACTIONS(729),
    [anon_sym_EQ] = ACTIONS(729),
    [anon_sym_QMARK] = ACTIONS(729),
    [anon_sym_POUND_BANG] = ACTIONS(729),
    [sym_mark] = ACTIONS(729),
    [anon_sym_PERCENT] = ACTIONS(729),
    [anon_sym_SLASH] = ACTIONS(729),
    [anon_sym_DOT2] = ACTIONS(729),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DOLLAR] = ACTIONS(729),
    [anon_sym_BSLASH_SLASH] = ACTIONS(729),
    [anon_sym_BSLASH_QMARK] = ACTIONS(729),
    [anon_sym_BSLASH_AMP] = ACTIONS(729),
    [sym_integer_literal] = ACTIONS(729),
    [sym_register] = ACTIONS(729),
    [sym_command_name] = ACTIONS(729),
    [sym__newline_or_pipe] = ACTIONS(729),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(729),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(729),
    [sym__for] = ACTIONS(729),
    [sym__while] = ACTIONS(729),
    [sym__if] = ACTIONS(729),
    [sym__try] = ACTIONS(729),
    [sym__cnext] = ACTIONS(729),
    [sym__cprevious] = ACTIONS(729),
    [sym__cNext] = ACTIONS(729),
    [sym__endtry] = ACTIONS(729),
    [sym__const] = ACTIONS(729),
    [sym__normal] = ACTIONS(729),
    [sym__return] = ACTIONS(729),
    [sym__perl] = ACTIONS(729),
    [sym__lua] = ACTIONS(729),
    [sym__ruby] = ACTIONS(729),
    [sym__python] = ACTIONS(729),
    [sym__throw] = ACTIONS(729),
    [sym__execute] = ACTIONS(729),
    [sym__autocmd] = ACTIONS(729),
    [sym__silent] = ACTIONS(729),
    [sym__echo] = ACTIONS(729),
    [sym__echon] = ACTIONS(729),
    [sym__echohl] = ACTIONS(729),
    [sym__echomsg] = ACTIONS(729),
    [sym__echoerr] = ACTIONS(729),
    [sym__map] = ACTIONS(729),
    [sym__nmap] = ACTIONS(729),
    [sym__vmap] = ACTIONS(729),
    [sym__xmap] = ACTIONS(729),
    [sym__smap] = ACTIONS(729),
    [sym__omap] = ACTIONS(729),
    [sym__imap] = ACTIONS(729),
    [sym__lmap] = ACTIONS(729),
    [sym__cmap] = ACTIONS(729),
    [sym__tmap] = ACTIONS(729),
    [sym__noremap] = ACTIONS(729),
    [sym__nnoremap] = ACTIONS(729),
    [sym__vnoremap] = ACTIONS(729),
    [sym__xnoremap] = ACTIONS(729),
    [sym__snoremap] = ACTIONS(729),
    [sym__onoremap] = ACTIONS(729),
    [sym__inoremap] = ACTIONS(729),
    [sym__lnoremap] = ACTIONS(729),
    [sym__cnoremap] = ACTIONS(729),
    [sym__tnoremap] = ACTIONS(729),
    [sym__augroup] = ACTIONS(729),
    [sym__highlight] = ACTIONS(729),
    [sym__syntax] = ACTIONS(729),
    [sym__set] = ACTIONS(729),
    [sym__setlocal] = ACTIONS(729),
    [sym__setfiletype] = ACTIONS(729),
    [sym__browse] = ACTIONS(729),
    [sym__options] = ACTIONS(729),
    [sym__startinsert] = ACTIONS(729),
    [sym__stopinsert] = ACTIONS(729),
    [sym__scriptencoding] = ACTIONS(729),
    [sym__source] = ACTIONS(729),
    [sym__global] = ACTIONS(729),
    [sym__colorscheme] = ACTIONS(729),
    [sym__command] = ACTIONS(729),
    [sym__comclear] = ACTIONS(729),
    [sym__delcommand] = ACTIONS(729),
    [sym__runtime] = ACTIONS(729),
    [sym__wincmd] = ACTIONS(729),
    [sym__sign] = ACTIONS(729),
    [sym__filetype] = ACTIONS(729),
    [sym__let] = ACTIONS(729),
    [sym__unlet] = ACTIONS(729),
    [sym__call] = ACTIONS(729),
    [sym__break] = ACTIONS(729),
    [sym__continue] = ACTIONS(729),
    [sym__tab] = ACTIONS(729),
    [sym__vertical] = ACTIONS(729),
    [sym__leftabove] = ACTIONS(729),
    [sym__aboveleft] = ACTIONS(729),
    [sym__rightbelow] = ACTIONS(729),
    [sym__belowright] = ACTIONS(729),
    [sym__topleft] = ACTIONS(729),
    [sym__botright] = ACTIONS(729),
    [sym__edit] = ACTIONS(729),
    [sym__enew] = ACTIONS(729),
    [sym__find] = ACTIONS(729),
    [sym__ex] = ACTIONS(729),
    [sym__visual] = ACTIONS(729),
    [sym__view] = ACTIONS(729),
    [sym__eval] = ACTIONS(729),
    [sym__substitute] = ACTIONS(729),
    [sym_unknown_command_name] = ACTIONS(729),
  },
  [STATE(114)] = {
    [anon_sym_COLON] = ACTIONS(729),
    [anon_sym_EQ] = ACTIONS(729),
    [anon_sym_QMARK] = ACTIONS(729),
    [anon_sym_POUND_BANG] = ACTIONS(729),
    [sym_mark] = ACTIONS(729),
    [anon_sym_PERCENT] = ACTIONS(729),
    [anon_sym_SLASH] = ACTIONS(729),
    [anon_sym_DOT2] = ACTIONS(729),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DOLLAR] = ACTIONS(729),
    [anon_sym_BSLASH_SLASH] = ACTIONS(729),
    [anon_sym_BSLASH_QMARK] = ACTIONS(729),
    [anon_sym_BSLASH_AMP] = ACTIONS(729),
    [sym_integer_literal] = ACTIONS(729),
    [sym_register] = ACTIONS(729),
    [sym_command_name] = ACTIONS(729),
    [sym__newline_or_pipe] = ACTIONS(729),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(729),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(729),
    [sym__for] = ACTIONS(729),
    [sym__while] = ACTIONS(729),
    [sym__if] = ACTIONS(729),
    [sym__endif] = ACTIONS(729),
    [sym__try] = ACTIONS(729),
    [sym__cnext] = ACTIONS(729),
    [sym__cprevious] = ACTIONS(729),
    [sym__cNext] = ACTIONS(729),
    [sym__const] = ACTIONS(729),
    [sym__normal] = ACTIONS(729),
    [sym__return] = ACTIONS(729),
    [sym__perl] = ACTIONS(729),
    [sym__lua] = ACTIONS(729),
    [sym__ruby] = ACTIONS(729),
    [sym__python] = ACTIONS(729),
    [sym__throw] = ACTIONS(729),
    [sym__execute] = ACTIONS(729),
    [sym__autocmd] = ACTIONS(729),
    [sym__silent] = ACTIONS(729),
    [sym__echo] = ACTIONS(729),
    [sym__echon] = ACTIONS(729),
    [sym__echohl] = ACTIONS(729),
    [sym__echomsg] = ACTIONS(729),
    [sym__echoerr] = ACTIONS(729),
    [sym__map] = ACTIONS(729),
    [sym__nmap] = ACTIONS(729),
    [sym__vmap] = ACTIONS(729),
    [sym__xmap] = ACTIONS(729),
    [sym__smap] = ACTIONS(729),
    [sym__omap] = ACTIONS(729),
    [sym__imap] = ACTIONS(729),
    [sym__lmap] = ACTIONS(729),
    [sym__cmap] = ACTIONS(729),
    [sym__tmap] = ACTIONS(729),
    [sym__noremap] = ACTIONS(729),
    [sym__nnoremap] = ACTIONS(729),
    [sym__vnoremap] = ACTIONS(729),
    [sym__xnoremap] = ACTIONS(729),
    [sym__snoremap] = ACTIONS(729),
    [sym__onoremap] = ACTIONS(729),
    [sym__inoremap] = ACTIONS(729),
    [sym__lnoremap] = ACTIONS(729),
    [sym__cnoremap] = ACTIONS(729),
    [sym__tnoremap] = ACTIONS(729),
    [sym__augroup] = ACTIONS(729),
    [sym__highlight] = ACTIONS(729),
    [sym__syntax] = ACTIONS(729),
    [sym__set] = ACTIONS(729),
    [sym__setlocal] = ACTIONS(729),
    [sym__setfiletype] = ACTIONS(729),
    [sym__browse] = ACTIONS(729),
    [sym__options] = ACTIONS(729),
    [sym__startinsert] = ACTIONS(729),
    [sym__stopinsert] = ACTIONS(729),
    [sym__scriptencoding] = ACTIONS(729),
    [sym__source] = ACTIONS(729),
    [sym__global] = ACTIONS(729),
    [sym__colorscheme] = ACTIONS(729),
    [sym__command] = ACTIONS(729),
    [sym__comclear] = ACTIONS(729),
    [sym__delcommand] = ACTIONS(729),
    [sym__runtime] = ACTIONS(729),
    [sym__wincmd] = ACTIONS(729),
    [sym__sign] = ACTIONS(729),
    [sym__filetype] = ACTIONS(729),
    [sym__let] = ACTIONS(729),
    [sym__unlet] = ACTIONS(729),
    [sym__call] = ACTIONS(729),
    [sym__break] = ACTIONS(729),
    [sym__continue] = ACTIONS(729),
    [sym__tab] = ACTIONS(729),
    [sym__vertical] = ACTIONS(729),
    [sym__leftabove] = ACTIONS(729),
    [sym__aboveleft] = ACTIONS(729),
    [sym__rightbelow] = ACTIONS(729),
    [sym__belowright] = ACTIONS(729),
    [sym__topleft] = ACTIONS(729),
    [sym__botright] = ACTIONS(729),
    [sym__edit] = ACTIONS(729),
    [sym__enew] = ACTIONS(729),
    [sym__find] = ACTIONS(729),
    [sym__ex] = ACTIONS(729),
    [sym__visual] = ACTIONS(729),
    [sym__view] = ACTIONS(729),
    [sym__eval] = ACTIONS(729),
    [sym__substitute] = ACTIONS(729),
    [sym_unknown_command_name] = ACTIONS(729),
  },
  [STATE(115)] = {
    [anon_sym_COLON] = ACTIONS(260),
    [anon_sym_EQ] = ACTIONS(260),
    [anon_sym_QMARK] = ACTIONS(260),
    [anon_sym_POUND_BANG] = ACTIONS(260),
    [sym_mark] = ACTIONS(260),
    [anon_sym_PERCENT] = ACTIONS(260),
    [anon_sym_SLASH] = ACTIONS(260),
    [anon_sym_DOT2] = ACTIONS(260),
    [anon_sym_PLUS] = ACTIONS(727),
    [anon_sym_DOLLAR] = ACTIONS(260),
    [anon_sym_BSLASH_SLASH] = ACTIONS(260),
    [anon_sym_BSLASH_QMARK] = ACTIONS(260),
    [anon_sym_BSLASH_AMP] = ACTIONS(260),
    [sym_integer_literal] = ACTIONS(260),
    [sym_register] = ACTIONS(260),
    [sym_command_name] = ACTIONS(260),
    [sym__newline_or_pipe] = ACTIONS(260),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(260),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(260),
    [sym__for] = ACTIONS(260),
    [sym__while] = ACTIONS(260),
    [sym__if] = ACTIONS(260),
    [sym__endif] = ACTIONS(260),
    [sym__try] = ACTIONS(260),
    [sym__cnext] = ACTIONS(260),
    [sym__cprevious] = ACTIONS(260),
    [sym__cNext] = ACTIONS(260),
    [sym__const] = ACTIONS(260),
    [sym__normal] = ACTIONS(260),
    [sym__return] = ACTIONS(260),
    [sym__perl] = ACTIONS(260),
    [sym__lua] = ACTIONS(260),
    [sym__ruby] = ACTIONS(260),
    [sym__python] = ACTIONS(260),
    [sym__throw] = ACTIONS(260),
    [sym__execute] = ACTIONS(260),
    [sym__autocmd] = ACTIONS(260),
    [sym__silent] = ACTIONS(260),
    [sym__echo] = ACTIONS(260),
    [sym__echon] = ACTIONS(260),
    [sym__echohl] = ACTIONS(260),
    [sym__echomsg] = ACTIONS(260),
    [sym__echoerr] = ACTIONS(260),
    [sym__map] = ACTIONS(260),
    [sym__nmap] = ACTIONS(260),
    [sym__vmap] = ACTIONS(260),
    [sym__xmap] = ACTIONS(260),
    [sym__smap] = ACTIONS(260),
    [sym__omap] = ACTIONS(260),
    [sym__imap] = ACTIONS(260),
    [sym__lmap] = ACTIONS(260),
    [sym__cmap] = ACTIONS(260),
    [sym__tmap] = ACTIONS(260),
    [sym__noremap] = ACTIONS(260),
    [sym__nnoremap] = ACTIONS(260),
    [sym__vnoremap] = ACTIONS(260),
    [sym__xnoremap] = ACTIONS(260),
    [sym__snoremap] = ACTIONS(260),
    [sym__onoremap] = ACTIONS(260),
    [sym__inoremap] = ACTIONS(260),
    [sym__lnoremap] = ACTIONS(260),
    [sym__cnoremap] = ACTIONS(260),
    [sym__tnoremap] = ACTIONS(260),
    [sym__augroup] = ACTIONS(260),
    [sym__highlight] = ACTIONS(260),
    [sym__syntax] = ACTIONS(260),
    [sym__set] = ACTIONS(260),
    [sym__setlocal] = ACTIONS(260),
    [sym__setfiletype] = ACTIONS(260),
    [sym__browse] = ACTIONS(260),
    [sym__options] = ACTIONS(260),
    [sym__startinsert] = ACTIONS(260),
    [sym__stopinsert] = ACTIONS(260),
    [sym__scriptencoding] = ACTIONS(260),
    [sym__source] = ACTIONS(260),
    [sym__global] = ACTIONS(260),
    [sym__colorscheme] = ACTIONS(260),
    [sym__command] = ACTIONS(260),
    [sym__comclear] = ACTIONS(260),
    [sym__delcommand] = ACTIONS(260),
    [sym__runtime] = ACTIONS(260),
    [sym__wincmd] = ACTIONS(260),
    [sym__sign] = ACTIONS(260),
    [sym__filetype] = ACTIONS(260),
    [sym__let] = ACTIONS(260),
    [sym__unlet] = ACTIONS(260),
    [sym__call] = ACTIONS(260),
    [sym__break] = ACTIONS(260),
    [sym__continue] = ACTIONS(260),
    [sym__tab] = ACTIONS(260),
    [sym__vertical] = ACTIONS(260),
    [sym__leftabove] = ACTIONS(260),
    [sym__aboveleft] = ACTIONS(260),
    [sym__rightbelow] = ACTIONS(260),
    [sym__belowright] = ACTIONS(260),
    [sym__topleft] = ACTIONS(260),
    [sym__botright] = ACTIONS(260),
    [sym__edit] = ACTIONS(260),
    [sym__enew] = ACTIONS(260),
    [sym__find] = ACTIONS(260),
    [sym__ex] = ACTIONS(260),
    [sym__visual] = ACTIONS(260),
    [sym__view] = ACTIONS(260),
    [sym__eval] = ACTIONS(260),
    [sym__substitute] = ACTIONS(260),
    [sym_unknown_command_name] = ACTIONS(260),
  },
  [STATE(116)] = {
    [anon_sym_COLON] = ACTIONS(729),
    [anon_sym_EQ] = ACTIONS(729),
    [anon_sym_QMARK] = ACTIONS(729),
    [anon_sym_POUND_BANG] = ACTIONS(729),
    [sym_mark] = ACTIONS(729),
    [anon_sym_PERCENT] = ACTIONS(729),
    [anon_sym_SLASH] = ACTIONS(729),
    [anon_sym_DOT2] = ACTIONS(729),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DOLLAR] = ACTIONS(729),
    [anon_sym_BSLASH_SLASH] = ACTIONS(729),
    [anon_sym_BSLASH_QMARK] = ACTIONS(729),
    [anon_sym_BSLASH_AMP] = ACTIONS(729),
    [sym_integer_literal] = ACTIONS(729),
    [sym_register] = ACTIONS(729),
    [sym_command_name] = ACTIONS(729),
    [sym__newline_or_pipe] = ACTIONS(729),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(729),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(729),
    [sym__for] = ACTIONS(729),
    [sym__endfor] = ACTIONS(729),
    [sym__while] = ACTIONS(729),
    [sym__if] = ACTIONS(729),
    [sym__try] = ACTIONS(729),
    [sym__cnext] = ACTIONS(729),
    [sym__cprevious] = ACTIONS(729),
    [sym__cNext] = ACTIONS(729),
    [sym__const] = ACTIONS(729),
    [sym__normal] = ACTIONS(729),
    [sym__return] = ACTIONS(729),
    [sym__perl] = ACTIONS(729),
    [sym__lua] = ACTIONS(729),
    [sym__ruby] = ACTIONS(729),
    [sym__python] = ACTIONS(729),
    [sym__throw] = ACTIONS(729),
    [sym__execute] = ACTIONS(729),
    [sym__autocmd] = ACTIONS(729),
    [sym__silent] = ACTIONS(729),
    [sym__echo] = ACTIONS(729),
    [sym__echon] = ACTIONS(729),
    [sym__echohl] = ACTIONS(729),
    [sym__echomsg] = ACTIONS(729),
    [sym__echoerr] = ACTIONS(729),
    [sym__map] = ACTIONS(729),
    [sym__nmap] = ACTIONS(729),
    [sym__vmap] = ACTIONS(729),
    [sym__xmap] = ACTIONS(729),
    [sym__smap] = ACTIONS(729),
    [sym__omap] = ACTIONS(729),
    [sym__imap] = ACTIONS(729),
    [sym__lmap] = ACTIONS(729),
    [sym__cmap] = ACTIONS(729),
    [sym__tmap] = ACTIONS(729),
    [sym__noremap] = ACTIONS(729),
    [sym__nnoremap] = ACTIONS(729),
    [sym__vnoremap] = ACTIONS(729),
    [sym__xnoremap] = ACTIONS(729),
    [sym__snoremap] = ACTIONS(729),
    [sym__onoremap] = ACTIONS(729),
    [sym__inoremap] = ACTIONS(729),
    [sym__lnoremap] = ACTIONS(729),
    [sym__cnoremap] = ACTIONS(729),
    [sym__tnoremap] = ACTIONS(729),
    [sym__augroup] = ACTIONS(729),
    [sym__highlight] = ACTIONS(729),
    [sym__syntax] = ACTIONS(729),
    [sym__set] = ACTIONS(729),
    [sym__setlocal] = ACTIONS(729),
    [sym__setfiletype] = ACTIONS(729),
    [sym__browse] = ACTIONS(729),
    [sym__options] = ACTIONS(729),
    [sym__startinsert] = ACTIONS(729),
    [sym__stopinsert] = ACTIONS(729),
    [sym__scriptencoding] = ACTIONS(729),
    [sym__source] = ACTIONS(729),
    [sym__global] = ACTIONS(729),
    [sym__colorscheme] = ACTIONS(729),
    [sym__command] = ACTIONS(729),
    [sym__comclear] = ACTIONS(729),
    [sym__delcommand] = ACTIONS(729),
    [sym__runtime] = ACTIONS(729),
    [sym__wincmd] = ACTIONS(729),
    [sym__sign] = ACTIONS(729),
    [sym__filetype] = ACTIONS(729),
    [sym__let] = ACTIONS(729),
    [sym__unlet] = ACTIONS(729),
    [sym__call] = ACTIONS(729),
    [sym__break] = ACTIONS(729),
    [sym__continue] = ACTIONS(729),
    [sym__tab] = ACTIONS(729),
    [sym__vertical] = ACTIONS(729),
    [sym__leftabove] = ACTIONS(729),
    [sym__aboveleft] = ACTIONS(729),
    [sym__rightbelow] = ACTIONS(729),
    [sym__belowright] = ACTIONS(729),
    [sym__topleft] = ACTIONS(729),
    [sym__botright] = ACTIONS(729),
    [sym__edit] = ACTIONS(729),
    [sym__enew] = ACTIONS(729),
    [sym__find] = ACTIONS(729),
    [sym__ex] = ACTIONS(729),
    [sym__visual] = ACTIONS(729),
    [sym__view] = ACTIONS(729),
    [sym__eval] = ACTIONS(729),
    [sym__substitute] = ACTIONS(729),
    [sym_unknown_command_name] = ACTIONS(729),
  },
  [STATE(117)] = {
    [anon_sym_COLON] = ACTIONS(260),
    [anon_sym_EQ] = ACTIONS(260),
    [anon_sym_QMARK] = ACTIONS(260),
    [anon_sym_POUND_BANG] = ACTIONS(260),
    [sym_mark] = ACTIONS(260),
    [anon_sym_PERCENT] = ACTIONS(260),
    [anon_sym_SLASH] = ACTIONS(260),
    [anon_sym_DOT2] = ACTIONS(260),
    [anon_sym_PLUS] = ACTIONS(727),
    [anon_sym_DOLLAR] = ACTIONS(260),
    [anon_sym_BSLASH_SLASH] = ACTIONS(260),
    [anon_sym_BSLASH_QMARK] = ACTIONS(260),
    [anon_sym_BSLASH_AMP] = ACTIONS(260),
    [sym_integer_literal] = ACTIONS(260),
    [sym_register] = ACTIONS(260),
    [sym_command_name] = ACTIONS(260),
    [sym__newline_or_pipe] = ACTIONS(260),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(260),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(260),
    [sym__for] = ACTIONS(260),
    [sym__endfor] = ACTIONS(260),
    [sym__while] = ACTIONS(260),
    [sym__if] = ACTIONS(260),
    [sym__try] = ACTIONS(260),
    [sym__cnext] = ACTIONS(260),
    [sym__cprevious] = ACTIONS(260),
    [sym__cNext] = ACTIONS(260),
    [sym__const] = ACTIONS(260),
    [sym__normal] = ACTIONS(260),
    [sym__return] = ACTIONS(260),
    [sym__perl] = ACTIONS(260),
    [sym__lua] = ACTIONS(260),
    [sym__ruby] = ACTIONS(260),
    [sym__python] = ACTIONS(260),
    [sym__throw] = ACTIONS(260),
    [sym__execute] = ACTIONS(260),
    [sym__autocmd] = ACTIONS(260),
    [sym__silent] = ACTIONS(260),
    [sym__echo] = ACTIONS(260),
    [sym__echon] = ACTIONS(260),
    [sym__echohl] = ACTIONS(260),
    [sym__echomsg] = ACTIONS(260),
    [sym__echoerr] = ACTIONS(260),
    [sym__map] = ACTIONS(260),
    [sym__nmap] = ACTIONS(260),
    [sym__vmap] = ACTIONS(260),
    [sym__xmap] = ACTIONS(260),
    [sym__smap] = ACTIONS(260),
    [sym__omap] = ACTIONS(260),
    [sym__imap] = ACTIONS(260),
    [sym__lmap] = ACTIONS(260),
    [sym__cmap] = ACTIONS(260),
    [sym__tmap] = ACTIONS(260),
    [sym__noremap] = ACTIONS(260),
    [sym__nnoremap] = ACTIONS(260),
    [sym__vnoremap] = ACTIONS(260),
    [sym__xnoremap] = ACTIONS(260),
    [sym__snoremap] = ACTIONS(260),
    [sym__onoremap] = ACTIONS(260),
    [sym__inoremap] = ACTIONS(260),
    [sym__lnoremap] = ACTIONS(260),
    [sym__cnoremap] = ACTIONS(260),
    [sym__tnoremap] = ACTIONS(260),
    [sym__augroup] = ACTIONS(260),
    [sym__highlight] = ACTIONS(260),
    [sym__syntax] = ACTIONS(260),
    [sym__set] = ACTIONS(260),
    [sym__setlocal] = ACTIONS(260),
    [sym__setfiletype] = ACTIONS(260),
    [sym__browse] = ACTIONS(260),
    [sym__options] = ACTIONS(260),
    [sym__startinsert] = ACTIONS(260),
    [sym__stopinsert] = ACTIONS(260),
    [sym__scriptencoding] = ACTIONS(260),
    [sym__source] = ACTIONS(260),
    [sym__global] = ACTIONS(260),
    [sym__colorscheme] = ACTIONS(260),
    [sym__command] = ACTIONS(260),
    [sym__comclear] = ACTIONS(260),
    [sym__delcommand] = ACTIONS(260),
    [sym__runtime] = ACTIONS(260),
    [sym__wincmd] = ACTIONS(260),
    [sym__sign] = ACTIONS(260),
    [sym__filetype] = ACTIONS(260),
    [sym__let] = ACTIONS(260),
    [sym__unlet] = ACTIONS(260),
    [sym__call] = ACTIONS(260),
    [sym__break] = ACTIONS(260),
    [sym__continue] = ACTIONS(260),
    [sym__tab] = ACTIONS(260),
    [sym__vertical] = ACTIONS(260),
    [sym__leftabove] = ACTIONS(260),
    [sym__aboveleft] = ACTIONS(260),
    [sym__rightbelow] = ACTIONS(260),
    [sym__belowright] = ACTIONS(260),
    [sym__topleft] = ACTIONS(260),
    [sym__botright] = ACTIONS(260),
    [sym__edit] = ACTIONS(260),
    [sym__enew] = ACTIONS(260),
    [sym__find] = ACTIONS(260),
    [sym__ex] = ACTIONS(260),
    [sym__visual] = ACTIONS(260),
    [sym__view] = ACTIONS(260),
    [sym__eval] = ACTIONS(260),
    [sym__substitute] = ACTIONS(260),
    [sym_unknown_command_name] = ACTIONS(260),
  },
  [STATE(118)] = {
    [ts_builtin_sym_end] = ACTIONS(729),
    [anon_sym_COLON] = ACTIONS(729),
    [anon_sym_EQ] = ACTIONS(729),
    [anon_sym_QMARK] = ACTIONS(729),
    [anon_sym_POUND_BANG] = ACTIONS(729),
    [sym_mark] = ACTIONS(729),
    [anon_sym_PERCENT] = ACTIONS(729),
    [anon_sym_SLASH] = ACTIONS(729),
    [anon_sym_DOT2] = ACTIONS(729),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DOLLAR] = ACTIONS(729),
    [anon_sym_BSLASH_SLASH] = ACTIONS(729),
    [anon_sym_BSLASH_QMARK] = ACTIONS(729),
    [anon_sym_BSLASH_AMP] = ACTIONS(729),
    [sym_integer_literal] = ACTIONS(729),
    [sym_register] = ACTIONS(729),
    [sym_command_name] = ACTIONS(729),
    [sym__newline_or_pipe] = ACTIONS(729),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(729),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(729),
    [sym__for] = ACTIONS(729),
    [sym__while] = ACTIONS(729),
    [sym__if] = ACTIONS(729),
    [sym__try] = ACTIONS(729),
    [sym__cnext] = ACTIONS(729),
    [sym__cprevious] = ACTIONS(729),
    [sym__cNext] = ACTIONS(729),
    [sym__const] = ACTIONS(729),
    [sym__normal] = ACTIONS(729),
    [sym__return] = ACTIONS(729),
    [sym__perl] = ACTIONS(729),
    [sym__lua] = ACTIONS(729),
    [sym__ruby] = ACTIONS(729),
    [sym__python] = ACTIONS(729),
    [sym__throw] = ACTIONS(729),
    [sym__execute] = ACTIONS(729),
    [sym__autocmd] = ACTIONS(729),
    [sym__silent] = ACTIONS(729),
    [sym__echo] = ACTIONS(729),
    [sym__echon] = ACTIONS(729),
    [sym__echohl] = ACTIONS(729),
    [sym__echomsg] = ACTIONS(729),
    [sym__echoerr] = ACTIONS(729),
    [sym__map] = ACTIONS(729),
    [sym__nmap] = ACTIONS(729),
    [sym__vmap] = ACTIONS(729),
    [sym__xmap] = ACTIONS(729),
    [sym__smap] = ACTIONS(729),
    [sym__omap] = ACTIONS(729),
    [sym__imap] = ACTIONS(729),
    [sym__lmap] = ACTIONS(729),
    [sym__cmap] = ACTIONS(729),
    [sym__tmap] = ACTIONS(729),
    [sym__noremap] = ACTIONS(729),
    [sym__nnoremap] = ACTIONS(729),
    [sym__vnoremap] = ACTIONS(729),
    [sym__xnoremap] = ACTIONS(729),
    [sym__snoremap] = ACTIONS(729),
    [sym__onoremap] = ACTIONS(729),
    [sym__inoremap] = ACTIONS(729),
    [sym__lnoremap] = ACTIONS(729),
    [sym__cnoremap] = ACTIONS(729),
    [sym__tnoremap] = ACTIONS(729),
    [sym__augroup] = ACTIONS(729),
    [sym__highlight] = ACTIONS(729),
    [sym__syntax] = ACTIONS(729),
    [sym__set] = ACTIONS(729),
    [sym__setlocal] = ACTIONS(729),
    [sym__setfiletype] = ACTIONS(729),
    [sym__browse] = ACTIONS(729),
    [sym__options] = ACTIONS(729),
    [sym__startinsert] = ACTIONS(729),
    [sym__stopinsert] = ACTIONS(729),
    [sym__scriptencoding] = ACTIONS(729),
    [sym__source] = ACTIONS(729),
    [sym__global] = ACTIONS(729),
    [sym__colorscheme] = ACTIONS(729),
    [sym__command] = ACTIONS(729),
    [sym__comclear] = ACTIONS(729),
    [sym__delcommand] = ACTIONS(729),
    [sym__runtime] = ACTIONS(729),
    [sym__wincmd] = ACTIONS(729),
    [sym__sign] = ACTIONS(729),
    [sym__filetype] = ACTIONS(729),
    [sym__let] = ACTIONS(729),
    [sym__unlet] = ACTIONS(729),
    [sym__call] = ACTIONS(729),
    [sym__break] = ACTIONS(729),
    [sym__continue] = ACTIONS(729),
    [sym__tab] = ACTIONS(729),
    [sym__vertical] = ACTIONS(729),
    [sym__leftabove] = ACTIONS(729),
    [sym__aboveleft] = ACTIONS(729),
    [sym__rightbelow] = ACTIONS(729),
    [sym__belowright] = ACTIONS(729),
    [sym__topleft] = ACTIONS(729),
    [sym__botright] = ACTIONS(729),
    [sym__edit] = ACTIONS(729),
    [sym__enew] = ACTIONS(729),
    [sym__find] = ACTIONS(729),
    [sym__ex] = ACTIONS(729),
    [sym__visual] = ACTIONS(729),
    [sym__view] = ACTIONS(729),
    [sym__eval] = ACTIONS(729),
    [sym__substitute] = ACTIONS(729),
    [sym_unknown_command_name] = ACTIONS(729),
  },
  [STATE(119)] = {
    [anon_sym_COLON] = ACTIONS(729),
    [anon_sym_EQ] = ACTIONS(729),
    [anon_sym_QMARK] = ACTIONS(729),
    [anon_sym_POUND_BANG] = ACTIONS(729),
    [sym_mark] = ACTIONS(729),
    [anon_sym_PERCENT] = ACTIONS(729),
    [anon_sym_SLASH] = ACTIONS(729),
    [anon_sym_DOT2] = ACTIONS(729),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DOLLAR] = ACTIONS(729),
    [anon_sym_BSLASH_SLASH] = ACTIONS(729),
    [anon_sym_BSLASH_QMARK] = ACTIONS(729),
    [anon_sym_BSLASH_AMP] = ACTIONS(729),
    [sym_integer_literal] = ACTIONS(729),
    [sym_register] = ACTIONS(729),
    [sym_command_name] = ACTIONS(729),
    [sym__newline_or_pipe] = ACTIONS(729),
    [sym__line_continuation] = ACTIONS(3),
    [sym_comment] = ACTIONS(729),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(729),
    [sym__for] = ACTIONS(729),
    [sym__while] = ACTIONS(729),
    [sym__endwhile] = ACTIONS(729),
    [sym__if] = ACTIONS(729),
    [sym__try] = ACTIONS(729),
    [sym__cnext] = ACTIONS(729),
    [sym__cprevious] = ACTIONS(729),
    [sym__cNext] = ACTIONS(729),
    [sym__const] = ACTIONS(729),
    [sym__normal] = ACTIONS(729),
    [sym__return] = ACTIONS(729),
    [sym__perl] = ACTIONS(729),
    [sym__lua] = ACTIONS(729),
    [sym__ruby] = ACTIONS(729),
    [sym__python] = ACTIONS(729),
    [sym__throw] = ACTIONS(729),
    [sym__execute] = ACTIONS(729),
    [sym__autocmd] = ACTIONS(729),
    [sym__silent] = ACTIONS(729),
    [sym__echo] = ACTIONS(729),
    [sym__echon] = ACTIONS(729),
    [sym__echohl] = ACTIONS(729),
    [sym__echomsg] = ACTIONS(729),
    [sym__echoerr] = ACTIONS(729),
    [sym__map] = ACTIONS(729),
    [sym__nmap] = ACTIONS(729),
    [sym__vmap] = ACTIONS(729),
    [sym__xmap] = ACTIONS(729),
    [sym__smap] = ACTIONS(729),
    [sym__omap] = ACTIONS(729),
    [sym__imap] = ACTIONS(729),
    [sym__lmap] = ACTIONS(729),
    [sym__cmap] = ACTIONS(729),
    [sym__tmap] = ACTIONS(729),
    [sym__noremap] = ACTIONS(729),
    [sym__nnoremap] = ACTIONS(729),
    [sym__vnoremap] = ACTIONS(729),
    [sym__xnoremap] = ACTIONS(729),
    [sym__snoremap] = ACTIONS(729),
    [sym__onoremap] = ACTIONS(729),
    [sym__inoremap] = ACTIONS(729),
    [sym__lnoremap] = ACTIONS(729),
    [sym__cnoremap] = ACTIONS(729),
    [sym__tnoremap] = ACTIONS(729),
    [sym__augroup] = ACTIONS(729),
    [sym__highlight] = ACTIONS(729),
    [sym__syntax] = ACTIONS(729),
    [sym__set] = ACTIONS(729),
    [sym__setlocal] = ACTIONS(729),
    [sym__setfiletype] = ACTIONS(729),
    [sym__browse] = ACTIONS(729),
    [sym__options] = ACTIONS(729),
    [sym__startinsert] = ACTIONS(729),
    [sym__stopinsert] = ACTIONS(729),
    [sym__scriptencoding] = ACTIONS(729),
    [sym__source] = ACTIONS(729),
    [sym__global] = ACTIONS(729),
    [sym__colorscheme] = ACTIONS(729),
    [sym__command] = ACTIONS(729),
    [sym__comclear] = ACTIONS(729),
    [sym__delcommand] = ACTIONS(729),
    [sym__runtime] = ACTIONS(729),
    [sym__wincmd] = ACTIONS(729),
    [sym__sign] = ACTIONS(729),
    [sym__filetype] = ACTIONS(729),
    [sym__let] = ACTIONS(729),
    [sym__unlet] = ACTIONS(729),
    [sym__call] = ACTIONS(729),
    [sym__break] = ACTIONS(729),
    [sym__continue] = ACTIONS(729),
    [sym__tab] = ACTIONS(729),
    [sym__vertical] = ACTIONS(729),
    [sym__leftabove] = ACTIONS(729),
    [sym__aboveleft] = ACTIONS(729),
    [sym__rightbelow] = ACTIONS(729),
    [sym__belowright] = ACTIONS(729),
    [sym__topleft] = ACTIONS(729),
    [sym__botright] = ACTIONS(729),
    [sym__edit] = ACTIONS(729),
    [sym__enew] = ACTIONS(729),
    [sym__find] = ACTIONS(729),
    [sym__ex] = ACTIONS(729),
    [sym__visual] = ACTIONS(729),
    [sym__view] = ACTIONS(729),
    [sym__eval] = ACTIONS(729),
    [sym__substitute] = ACTIONS(729),
    [sym_unknown_command_name] = ACTIONS(729),
  },
  [STATE(120)] = {
    [aux_sym__statement_repeat1] = STATE(120),
    [anon_sym_COLON] = ACTIONS(733),
    [anon_sym_EQ] = ACTIONS(736),
    [anon_sym_QMARK] = ACTIONS(736),
    [anon_sym_POUND_BANG] = ACTIONS(736),
    [sym_mark] = ACTIONS(736),
    [anon_sym_PERCENT] = ACTIONS(736),
    [anon_sym_SLASH] = ACTIONS(736),
    [anon_sym_DOT2] = ACTIONS(736),
    [anon_sym_PLUS] = ACTIONS(738),
    [anon_sym_DOLLAR] = ACTIONS(736),
    [anon_sym_BSLASH_SLASH] = ACTIONS(736),
    [anon_sym_BSLASH_QMARK] = ACTIONS(736),
    [anon_sym_BSLASH_AMP] = ACTIONS(736),
    [sym_integer_literal] = ACTIONS(736),
    [sym_register] = ACTIONS(736),
    [sym_command_name] = ACTIONS(736),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(736),
    [sym__for] = ACTIONS(736),
    [sym__while] = ACTIONS(736),
    [sym__if] = ACTIONS(736),
    [sym__try] = ACTIONS(736),
    [sym__cnext] = ACTIONS(736),
    [sym__cprevious] = ACTIONS(736),
    [sym__cNext] = ACTIONS(736),
    [sym__const] = ACTIONS(736),
    [sym__normal] = ACTIONS(736),
    [sym__return] = ACTIONS(736),
    [sym__perl] = ACTIONS(736),
    [sym__lua] = ACTIONS(736),
    [sym__ruby] = ACTIONS(736),
    [sym__python] = ACTIONS(736),
    [sym__throw] = ACTIONS(736),
    [sym__execute] = ACTIONS(736),
    [sym__autocmd] = ACTIONS(736),
    [sym__silent] = ACTIONS(736),
    [sym__echo] = ACTIONS(736),
    [sym__echon] = ACTIONS(736),
    [sym__echohl] = ACTIONS(736),
    [sym__echomsg] = ACTIONS(736),
    [sym__echoerr] = ACTIONS(736),
    [sym__map] = ACTIONS(736),
    [sym__nmap] = ACTIONS(736),
    [sym__vmap] = ACTIONS(736),
    [sym__xmap] = ACTIONS(736),
    [sym__smap] = ACTIONS(736),
    [sym__omap] = ACTIONS(736),
    [sym__imap] = ACTIONS(736),
    [sym__lmap] = ACTIONS(736),
    [sym__cmap] = ACTIONS(736),
    [sym__tmap] = ACTIONS(736),
    [sym__noremap] = ACTIONS(736),
    [sym__nnoremap] = ACTIONS(736),
    [sym__vnoremap] = ACTIONS(736),
    [sym__xnoremap] = ACTIONS(736),
    [sym__snoremap] = ACTIONS(736),
    [sym__onoremap] = ACTIONS(736),
    [sym__inoremap] = ACTIONS(736),
    [sym__lnoremap] = ACTIONS(736),
    [sym__cnoremap] = ACTIONS(736),
    [sym__tnoremap] = ACTIONS(736),
    [sym__augroup] = ACTIONS(736),
    [sym__highlight] = ACTIONS(736),
    [sym__syntax] = ACTIONS(736),
    [sym__set] = ACTIONS(736),
    [sym__setlocal] = ACTIONS(736),
    [sym__setfiletype] = ACTIONS(736),
    [sym__browse] = ACTIONS(736),
    [sym__options] = ACTIONS(736),
    [sym__startinsert] = ACTIONS(736),
    [sym__stopinsert] = ACTIONS(736),
    [sym__scriptencoding] = ACTIONS(736),
    [sym__source] = ACTIONS(736),
    [sym__global] = ACTIONS(736),
    [sym__colorscheme] = ACTIONS(736),
    [sym__command] = ACTIONS(736),
    [sym__comclear] = ACTIONS(736),
    [sym__delcommand] = ACTIONS(736),
    [sym__runtime] = ACTIONS(736),
    [sym__wincmd] = ACTIONS(736),
    [sym__sign] = ACTIONS(736),
    [sym__filetype] = ACTIONS(736),
    [sym__let] = ACTIONS(736),
    [sym__unlet] = ACTIONS(736),
    [sym__call] = ACTIONS(736),
    [sym__break] = ACTIONS(736),
    [sym__continue] = ACTIONS(736),
    [sym__tab] = ACTIONS(736),
    [sym__vertical] = ACTIONS(736),
    [sym__leftabove] = ACTIONS(736),
    [sym__aboveleft] = ACTIONS(736),
    [sym__rightbelow] = ACTIONS(736),
    [sym__belowright] = ACTIONS(736),
    [sym__topleft] = ACTIONS(736),
    [sym__botright] = ACTIONS(736),
    [sym__edit] = ACTIONS(736),
    [sym__enew] = ACTIONS(736),
    [sym__find] = ACTIONS(736),
    [sym__ex] = ACTIONS(736),
    [sym__visual] = ACTIONS(736),
    [sym__view] = ACTIONS(736),
    [sym__eval] = ACTIONS(736),
    [sym__substitute] = ACTIONS(736),
    [sym_unknown_command_name] = ACTIONS(736),
  },
  [STATE(121)] = {
    [anon_sym_COLON] = ACTIONS(740),
    [anon_sym_EQ] = ACTIONS(740),
    [anon_sym_QMARK] = ACTIONS(740),
    [anon_sym_POUND_BANG] = ACTIONS(740),
    [sym_mark] = ACTIONS(740),
    [anon_sym_PERCENT] = ACTIONS(740),
    [anon_sym_SLASH] = ACTIONS(740),
    [anon_sym_DOT2] = ACTIONS(740),
    [anon_sym_PLUS] = ACTIONS(742),
    [anon_sym_DOLLAR] = ACTIONS(740),
    [anon_sym_BSLASH_SLASH] = ACTIONS(740),
    [anon_sym_BSLASH_QMARK] = ACTIONS(740),
    [anon_sym_BSLASH_AMP] = ACTIONS(740),
    [sym_integer_literal] = ACTIONS(740),
    [sym_register] = ACTIONS(740),
    [sym_command_name] = ACTIONS(740),
    [sym__line_continuation] = ACTIONS(3),
    [sym_line_continuation_comment] = ACTIONS(3),
    [sym__function] = ACTIONS(740),
    [sym__for] = ACTIONS(740),
    [sym__while] = ACTIONS(740),
    [sym__if] = ACTIONS(740),
    [sym__try] = ACTIONS(740),
    [sym__cnext] = ACTIONS(740),
    [sym__cprevious] = ACTIONS(740),
    [sym__cNext] = ACTIONS(740),
    [sym__const] = ACTIONS(740),
    [sym__normal] = ACTIONS(740),
    [sym__return] = ACTIONS(740),
    [sym__perl] = ACTIONS(740),
    [sym__lua] = ACTIONS(740),
    [sym__ruby] = ACTIONS(740),
    [sym__python] = ACTIONS(740),
    [sym__throw] = ACTIONS(740),
    [sym__execute] = ACTIONS(740),
    [sym__autocmd] = ACTIONS(740),
    [sym__silent] = ACTIONS(740),
    [sym__echo] = ACTIONS(740),
    [sym__echon] = ACTIONS(740),
    [sym__echohl] = ACTIONS(740),
    [sym__echomsg] = ACTIONS(740),
    [sym__echoerr] = ACTIONS(740),
    [sym__map] = ACTIONS(740),
    [sym__nmap] = ACTIONS(740),
    [sym__vmap] = ACTIONS(740),
    [sym__xmap] = ACTIONS(740),
    [sym__smap] = ACTIONS(740),
    [sym__omap] = ACTIONS(740),
    [sym__imap] = ACTIONS(740),
    [sym__lmap] = ACTIONS(740),
    [sym__cmap] = ACTIONS(740),
    [sym__tmap] = ACTIONS(740),
    [sym__noremap] = ACTIONS(740),
    [sym__nnoremap] = ACTIONS(740),
    [sym__vnoremap] = ACTIONS(740),
    [sym__xnoremap] = ACTIONS(740),
    [sym__snoremap] = ACTIONS(740),
    [sym__onoremap] = ACTIONS(740),
    [sym__inoremap] = ACTIONS(740),
    [sym__lnoremap] = ACTIONS(740),
    [sym__cnoremap] = ACTIONS(740),
    [sym__tnoremap] = ACTIONS(740),
    [sym__augroup] = ACTIONS(740),
    [sym__highlight] = ACTIONS(740),
    [sym__syntax] = ACTIONS(740),
    [sym__set] = ACTIONS(740),
    [sym__setlocal] = ACTIONS(740),
    [sym__setfiletype] = ACTIONS(740),
    [sym__browse] = ACTIONS(740),
    [sym__options] = ACTIONS(740),
    [sym__startinsert] = ACTIONS(740),
    [sym__stopinsert] = ACTIONS(740),
    [sym__scriptencoding] = ACTIONS(740),
    [sym__source] = ACTIONS(740),
    [sym__global] = ACTIONS(740),
    [sym__colorscheme] = ACTIONS(740),
    [sym__command] = ACTIONS(740),
    [sym__comclear] = ACTIONS(740),
    [sym__delcommand] = ACTIONS(740),
    [sym__runtime] = ACTIONS(740),
    [sym__wincmd] = ACTIONS(740),
    [sym__sign] = ACTIONS(740),
    [sym__filetype] = ACTIONS(740),
    [sym__let] = ACTIONS(740),
    [sym__unlet] = ACTIONS(740),
    [sym__call] = ACTIONS(740),
    [sym__break] = ACTIONS(740),
    [sym__continue] = ACTIONS(740),
    [sym__tab] = ACTIONS(740),
    [sym__vertical] = ACTIONS(740),
    [sym__leftabove] = ACTIONS(740),
    [sym__aboveleft] = ACTIONS(740),
    [sym__rightbelow] = ACTIONS(740),
    [sym__belowright] = ACTIONS(740),
    [sym__topleft] = ACTIONS(740),
    [sym__botright] = ACTIONS(740),
    [sym__edit] = ACTIONS(740),
    [sym__enew] = ACTIONS(740),
    [sym__find] = ACTIONS(740),
    [sym__ex] = ACTIONS(740),
    [sym__visual] = ACTIONS(740),
    [sym__view] = ACTIONS(740),
    [sym__eval] = ACTIONS(740),
    [sym__substitute] = ACTIONS(740),
    [sym_unknown_command_name] = ACTIONS(740),
  },
  [STATE(122)] = {
    [sym__keycode_in] = STATE(3170),
    [sym__immediate_keycode] = STATE(1019),
    [aux_sym__map_lhs_repeat1] = STATE(959),
    [anon_sym_a_COLON] = ACTIONS(744),
    [aux_sym__bang_filter_command_argument_token3] = ACTIONS(746),
    [anon_sym_LBRACE] = ACTIONS(744),
    [aux_sym_identifier_token1] = ACTIONS(748),
    [anon_sym_AMP] = ACTIONS(744),
    [anon_sym_LPAREN] = ACTIONS(744),
    [anon_sym_PLUS] = ACTIONS(748),
    [anon_sym_DOLLAR] = ACTIONS(744),
    [sym__keycode_modifier] = ACTIONS(750),
    [aux_sym__keycode_in_token1] = ACTIONS(752),
    [aux_sym__keycode_in_token2] = ACTIONS(752),
    [aux_sym__keycode_in_token3] = ACTIONS(752),
    [aux_sym__keycode_in_token4] = ACTIONS(752),
    [aux_sym__keycode_in_token5] = ACTIONS(752),
    [aux_sym__keycode_in_token6] = ACTIONS(752),
    [aux_sym__keycode_in_token7] = ACTIONS(752),
    [aux_sym__keycode_in_token8] = ACTIONS(752),
    [aux_sym__keycode_in_token9] = ACTIONS(752),
    [aux_sym__keycode_in_token10] = ACTIONS(752),
    [aux_sym__keycode_in_token11] = ACTIONS(752),
    [aux_sym__keycode_in_token12] = ACTIONS(752),
    [aux_sym__keycode_in_token13] = ACTIONS(752),
    [aux_sym__keycode_in_token14] = ACTIONS(752),
    [aux_sym__keycode_in_token15] = ACTIONS(752),
    [aux_sym__keycode_in_token16] = ACTIONS(752),
    [aux_sym__keycode_in_token17] = ACTIONS(752),
    [aux_sym__keycode_in_token18] = ACTIONS(752),
    [aux_sym__keycode_in_token19] = ACTIONS(752),
    [aux_sym__keycode_in_token20] = ACTIONS(752),
    [aux_sym__keycode_in_token21] = ACTIONS(752),
    [aux_sym__keycode_in_token22] = ACTIONS(752),
    [aux_sym__keycode_in_token23] = ACTIONS(752),
    [aux_sym__keycode_in_token24] = ACTIONS(754),
    [aux_sym__keycode_in_token25] = ACTIONS(752),
    [aux_sym__keycode_in_token26] = ACTIONS(752),
    [aux_sym__keycode_in_token27] = ACTIONS(752),
    [aux_sym__keycode_in_token28] = ACTIONS(752),
    [aux_sym__keycode_in_token29] = ACTIONS(752),
    [aux_sym__keycode_in_token30] = ACTIONS(752),
    [aux_sym__keycode_in_token31] = ACTIONS(752),
    [aux_sym__keycode_in_token32] = ACTIONS(752),
    [aux_sym__keycode_in_token33] = ACTIONS(752),
    [aux_sym__keycode_in_token34] = ACTIONS(752),
    [aux_sym__keycode_in_token35] = ACTIONS(752),
    [aux_sym__keycode_in_token36] = ACTIONS(752),
    [aux_sym__keycode_in_token37] = ACTIONS(752),
    [aux_sym__keycode_in_token38] = ACTIONS(752),
    [aux_sym__keycode_in_token39] = ACTIONS(754),
    [aux_sym__keycode_in_token40] = ACTIONS(752),
    [aux_sym__keycode_in_token41] = ACTIONS(752),
    [aux_sym__keycode_in_token42] = ACTIONS(752),
    [aux_sym__keycode_in_token43] = ACTIONS(754),
    [anon_sym_LT] = ACTIONS(756),
    [anon_sym_BSLASH2] = ACTIONS(758),
    [anon_sym_DASH] = ACTIONS(748),
    [anon_sym_BANG2] = ACTIONS(744),
    [sym_float_literal] = ACTIONS(744),
    [sym_integer_literal] = ACTIONS(748),
    [anon_sym_LBRACK] = ACTIONS(744),
    [sym_register] = ACTIONS(744),
    [anon_sym_POUND_LBRACE] = ACTIONS(744),
    [sym__line_continuation] = ACTIONS(3),
    [sym__scope_dict] = ACTIONS(744),
    [sym_scope] = ACTIONS(744),
    [sym_string_literal] = ACTIONS(744),
    [sym_line_continuation_comment] = ACTIONS(3),
  },
  [STATE(123)] = {
    [sym__keycode_in] = STATE(3341),
    [anon_sym_a_COLON] = ACTIONS(760),
    [aux_sym__bang_filter_command_argument_token3] = ACTIONS(762),
    [anon_sym_LBRACE] = ACTIONS(760),
    [aux_sym_identifier_token1] = ACTIONS(762),
    [anon_sym_AMP] = ACTIONS(760),
    [anon_sym_LPAREN] = ACTIONS(760),
    [anon_sym_PLUS] = ACTIONS(762),
    [anon_sym_DOLLAR] = ACTIONS(760),
    [sym__keycode_modifier] = ACTIONS(750),
    [aux_sym__keycode_in_token1] = ACTIONS(764),
    [aux_sym__keycode_in_token2] = ACTIONS(764),
    [aux_sym__keycode_in_token3] = ACTIONS(764),
    [aux_sym__keycode_in_token4] = ACTIONS(764),
    [aux_sym__keycode_in_token5] = ACTIONS(764),
    [aux_sym__keycode_in_token6] = ACTIONS(764),
    [aux_sym__keycode_in_token7] = ACTIONS(764),
    [aux_sym__keycode_in_token8] = ACTIONS(764),
    [aux_sym__keycode_in_token9] = ACTIONS(764),
    [aux_sym__keycode_in_token10] = ACTIONS(764),
    [aux_sym__keycode_in_token11] = ACTIONS(764),
    [aux_sym__keycode_in_token12] = ACTIONS(764),
    [aux_sym__keycode_in_token13] = ACTIONS(764),
    [aux_sym__keycode_in_token14] = ACTIONS(764),
    [aux_sym__keycode_in_token15] = ACTIONS(764),
    [aux_sym__keycode_in_token16] = ACTIONS(764),
    [aux_sym__keycode_in_token17] = ACTIONS(764),
    [aux_sym__keycode_in_token18] = ACTIONS(764),
    [aux_sym__keycode_in_token19] = ACTIONS(764),
    [aux_sym__keycode_in_token20] = ACTIONS(764),
    [aux_sym__keycode_in_token21] = ACTIONS(764),
    [aux_sym__keycode_in_token22] = ACTIONS(764),
    [aux_sym__keycode_in_token23] = ACTIONS(764),
    [aux_sym__keycode_in_token24] = ACTIONS(766),
    [aux_sym__keycode_in_token25] = ACTIONS(764),
    [aux_sym__keycode_in_token26] = ACTIONS(764),
    [aux_sym__keycode_in_token27] = ACTIONS(764),
    [aux_sym__keycode_in_token28] = ACTIONS(764),
    [aux_sym__keycode_in_token29] = ACTIONS(764),
    [aux_sym__keycode_in_token30] = ACTIONS(764),
    [aux_sym__keycode_in_token31] = ACTIONS(764),
    [aux_sym__keycode_in_token32] = ACTIONS(764),
    [aux_sym__keycode_in_token33] = ACTIONS(764),
    [aux_sym__keycode_in_token34] = ACTIONS(764),
    [aux_sym__keycode_in_token35] = ACTIONS(764),
    [aux_sym__keycode_in_token36] = ACTIONS(764),
    [aux_sym__keycode_in_token37] = ACTIONS(764),
    [aux_sym__keycode_in_token38] = ACTIONS(764),
    [aux_sym__keycode_in_token39] = ACTIONS(766),
    [aux_sym__keycode_in_token40] = ACTIONS(764),
    [aux_sym__keycode_in_token41] = ACTIONS(764),
    [aux_sym__keycode_in_token42] = ACTIONS(764),
    [aux_sym__keycode_in_token43] = ACTIONS(766),
    [anon_sym_LT] = ACTIONS(760),
    [anon_sym_BSLASH2] = ACTIONS(760),
    [anon_sym_DASH] = ACTIONS(762),
    [anon_sym_BANG2] = ACTIONS(760),
    [sym_float_literal] = ACTIONS(760),
    [sym_integer_literal] = ACTIONS(762),
    [anon_sym_LBRACK] = ACTIONS(760),
    [sym_register] = ACTIONS(760),
    [anon_sym_POUND_LBRACE] = ACTIONS(760),
    [sym__line_continuation] = ACTIONS(3),
    [sym__scope_dict] = ACTIONS(760),
    [sym_scope] = ACTIONS(760),
    [sym_string_literal] = ACTIONS(760),
    [sym_line_continuation_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 5,
    STATE(2415), 1,
      sym_encoding,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(772), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(770), 4,
      anon_sym_ucs_DASH2,
      anon_sym_utf_DASH16,
      anon_sym_ucs_DASH4,
      anon_sym_utf_DASH32,
    ACTIONS(768), 54,
      anon_sym_latin1,
      anon_sym_iso,
      anon_sym_koi8,
      anon_sym_macroman,
      anon_sym_cp437,
      anon_sym_cp737,
      anon_sym_cp775,
      anon_sym_cp850,
      anon_sym_cp852,
      anon_sym_cp855,
      anon_sym_cp857,
      anon_sym_cp860,
      anon_sym_cp861,
      anon_sym_cp862,
      anon_sym_cp863,
      anon_sym_cp865,
      anon_sym_cp866,
      anon_sym_cp869,
      anon_sym_cp874,
      anon_sym_cp1250,
      anon_sym_cp1251,
      anon_sym_cp1253,
      anon_sym_cp1254,
      anon_sym_cp1255,
      anon_sym_cp1256,
      anon_sym_cp1257,
      anon_sym_cp1258,
      anon_sym_cp932,
      anon_sym_euc_DASHjp,
      anon_sym_sjis,
      anon_sym_cp949,
      anon_sym_euc_DASHkr,
      anon_sym_cp936,
      anon_sym_euc_DASHcn,
      anon_sym_cp950,
      anon_sym_big5,
      anon_sym_euc_DASHtw,
      anon_sym_utf_DASH8,
      anon_sym_ucs_DASH21e,
      anon_sym_utf_DASH16le,
      anon_sym_ucs_DASH4le,
      anon_sym_ansi,
      anon_sym_japan,
      anon_sym_korea,
      anon_sym_prc,
      anon_sym_chinese,
      anon_sym_taiwan,
      anon_sym_utf8,
      anon_sym_unicode,
      anon_sym_ucs2be,
      anon_sym_ucs_DASH2be,
      anon_sym_ucs_DASH4be,
      anon_sym_utf_DASH32le,
      anon_sym_default,
  [75] = 5,
    STATE(2846), 1,
      sym_encoding,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(772), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(776), 4,
      anon_sym_ucs_DASH2,
      anon_sym_utf_DASH16,
      anon_sym_ucs_DASH4,
      anon_sym_utf_DASH32,
    ACTIONS(774), 54,
      anon_sym_latin1,
      anon_sym_iso,
      anon_sym_koi8,
      anon_sym_macroman,
      anon_sym_cp437,
      anon_sym_cp737,
      anon_sym_cp775,
      anon_sym_cp850,
      anon_sym_cp852,
      anon_sym_cp855,
      anon_sym_cp857,
      anon_sym_cp860,
      anon_sym_cp861,
      anon_sym_cp862,
      anon_sym_cp863,
      anon_sym_cp865,
      anon_sym_cp866,
      anon_sym_cp869,
      anon_sym_cp874,
      anon_sym_cp1250,
      anon_sym_cp1251,
      anon_sym_cp1253,
      anon_sym_cp1254,
      anon_sym_cp1255,
      anon_sym_cp1256,
      anon_sym_cp1257,
      anon_sym_cp1258,
      anon_sym_cp932,
      anon_sym_euc_DASHjp,
      anon_sym_sjis,
      anon_sym_cp949,
      anon_sym_euc_DASHkr,
      anon_sym_cp936,
      anon_sym_euc_DASHcn,
      anon_sym_cp950,
      anon_sym_big5,
      anon_sym_euc_DASHtw,
      anon_sym_utf_DASH8,
      anon_sym_ucs_DASH21e,
      anon_sym_utf_DASH16le,
      anon_sym_ucs_DASH4le,
      anon_sym_ansi,
      anon_sym_japan,
      anon_sym_korea,
      anon_sym_prc,
      anon_sym_chinese,
      anon_sym_taiwan,
      anon_sym_utf8,
      anon_sym_unicode,
      anon_sym_ucs2be,
      anon_sym_ucs_DASH2be,
      anon_sym_ucs_DASH4be,
      anon_sym_utf_DASH32le,
      anon_sym_default,
  [149] = 4,
    STATE(1700), 1,
      sym__immediate_encoding,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(780), 4,
      anon_sym_ucs_DASH22,
      anon_sym_utf_DASH162,
      anon_sym_ucs_DASH42,
      anon_sym_utf_DASH322,
    ACTIONS(778), 54,
      anon_sym_latin12,
      anon_sym_iso2,
      anon_sym_koi82,
      anon_sym_macroman2,
      anon_sym_cp4372,
      anon_sym_cp7372,
      anon_sym_cp7752,
      anon_sym_cp8502,
      anon_sym_cp8522,
      anon_sym_cp8552,
      anon_sym_cp8572,
      anon_sym_cp8602,
      anon_sym_cp8612,
      anon_sym_cp8622,
      anon_sym_cp8632,
      anon_sym_cp8652,
      anon_sym_cp8662,
      anon_sym_cp8692,
      anon_sym_cp8742,
      anon_sym_cp12502,
      anon_sym_cp12512,
      anon_sym_cp12532,
      anon_sym_cp12542,
      anon_sym_cp12552,
      anon_sym_cp12562,
      anon_sym_cp12572,
      anon_sym_cp12582,
      anon_sym_cp9322,
      anon_sym_euc_DASHjp2,
      anon_sym_sjis2,
      anon_sym_cp9492,
      anon_sym_euc_DASHkr2,
      anon_sym_cp9362,
      anon_sym_euc_DASHcn2,
      anon_sym_cp9502,
      anon_sym_big52,
      anon_sym_euc_DASHtw2,
      anon_sym_utf_DASH82,
      anon_sym_ucs_DASH21e2,
      anon_sym_utf_DASH16le2,
      anon_sym_ucs_DASH4le2,
      anon_sym_ansi2,
      anon_sym_japan2,
      anon_sym_korea2,
      anon_sym_prc2,
      anon_sym_chinese2,
      anon_sym_taiwan2,
      anon_sym_utf82,
      anon_sym_unicode2,
      anon_sym_ucs2be2,
      anon_sym_ucs_DASH2be2,
      anon_sym_ucs_DASH4be2,
      anon_sym_utf_DASH32le2,
      anon_sym_default2,
  [219] = 4,
    STATE(1925), 1,
      sym__immediate_encoding,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(784), 4,
      anon_sym_ucs_DASH22,
      anon_sym_utf_DASH162,
      anon_sym_ucs_DASH42,
      anon_sym_utf_DASH322,
    ACTIONS(782), 54,
      anon_sym_latin12,
      anon_sym_iso2,
      anon_sym_koi82,
      anon_sym_macroman2,
      anon_sym_cp4372,
      anon_sym_cp7372,
      anon_sym_cp7752,
      anon_sym_cp8502,
      anon_sym_cp8522,
      anon_sym_cp8552,
      anon_sym_cp8572,
      anon_sym_cp8602,
      anon_sym_cp8612,
      anon_sym_cp8622,
      anon_sym_cp8632,
      anon_sym_cp8652,
      anon_sym_cp8662,
      anon_sym_cp8692,
      anon_sym_cp8742,
      anon_sym_cp12502,
      anon_sym_cp12512,
      anon_sym_cp12532,
      anon_sym_cp12542,
      anon_sym_cp12552,
      anon_sym_cp12562,
      anon_sym_cp12572,
      anon_sym_cp12582,
      anon_sym_cp9322,
      anon_sym_euc_DASHjp2,
      anon_sym_sjis2,
      anon_sym_cp9492,
      anon_sym_euc_DASHkr2,
      anon_sym_cp9362,
      anon_sym_euc_DASHcn2,
      anon_sym_cp9502,
      anon_sym_big52,
      anon_sym_euc_DASHtw2,
      anon_sym_utf_DASH82,
      anon_sym_ucs_DASH21e2,
      anon_sym_utf_DASH16le2,
      anon_sym_ucs_DASH4le2,
      anon_sym_ansi2,
      anon_sym_japan2,
      anon_sym_korea2,
      anon_sym_prc2,
      anon_sym_chinese2,
      anon_sym_taiwan2,
      anon_sym_utf82,
      anon_sym_unicode2,
      anon_sym_ucs2be2,
      anon_sym_ucs_DASH2be2,
      anon_sym_ucs_DASH4be2,
      anon_sym_utf_DASH32le2,
      anon_sym_default2,
  [289] = 4,
    STATE(1751), 1,
      sym__immediate_encoding,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(788), 4,
      anon_sym_ucs_DASH22,
      anon_sym_utf_DASH162,
      anon_sym_ucs_DASH42,
      anon_sym_utf_DASH322,
    ACTIONS(786), 54,
      anon_sym_latin12,
      anon_sym_iso2,
      anon_sym_koi82,
      anon_sym_macroman2,
      anon_sym_cp4372,
      anon_sym_cp7372,
      anon_sym_cp7752,
      anon_sym_cp8502,
      anon_sym_cp8522,
      anon_sym_cp8552,
      anon_sym_cp8572,
      anon_sym_cp8602,
      anon_sym_cp8612,
      anon_sym_cp8622,
      anon_sym_cp8632,
      anon_sym_cp8652,
      anon_sym_cp8662,
      anon_sym_cp8692,
      anon_sym_cp8742,
      anon_sym_cp12502,
      anon_sym_cp12512,
      anon_sym_cp12532,
      anon_sym_cp12542,
      anon_sym_cp12552,
      anon_sym_cp12562,
      anon_sym_cp12572,
      anon_sym_cp12582,
      anon_sym_cp9322,
      anon_sym_euc_DASHjp2,
      anon_sym_sjis2,
      anon_sym_cp9492,
      anon_sym_euc_DASHkr2,
      anon_sym_cp9362,
      anon_sym_euc_DASHcn2,
      anon_sym_cp9502,
      anon_sym_big52,
      anon_sym_euc_DASHtw2,
      anon_sym_utf_DASH82,
      anon_sym_ucs_DASH21e2,
      anon_sym_utf_DASH16le2,
      anon_sym_ucs_DASH4le2,
      anon_sym_ansi2,
      anon_sym_japan2,
      anon_sym_korea2,
      anon_sym_prc2,
      anon_sym_chinese2,
      anon_sym_taiwan2,
      anon_sym_utf82,
      anon_sym_unicode2,
      anon_sym_ucs2be2,
      anon_sym_ucs_DASH2be2,
      anon_sym_ucs_DASH4be2,
      anon_sym_utf_DASH32le2,
      anon_sym_default2,
  [359] = 4,
    STATE(1562), 1,
      sym__immediate_encoding,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(792), 4,
      anon_sym_ucs_DASH22,
      anon_sym_utf_DASH162,
      anon_sym_ucs_DASH42,
      anon_sym_utf_DASH322,
    ACTIONS(790), 54,
      anon_sym_latin12,
      anon_sym_iso2,
      anon_sym_koi82,
      anon_sym_macroman2,
      anon_sym_cp4372,
      anon_sym_cp7372,
      anon_sym_cp7752,
      anon_sym_cp8502,
      anon_sym_cp8522,
      anon_sym_cp8552,
      anon_sym_cp8572,
      anon_sym_cp8602,
      anon_sym_cp8612,
      anon_sym_cp8622,
      anon_sym_cp8632,
      anon_sym_cp8652,
      anon_sym_cp8662,
      anon_sym_cp8692,
      anon_sym_cp8742,
      anon_sym_cp12502,
      anon_sym_cp12512,
      anon_sym_cp12532,
      anon_sym_cp12542,
      anon_sym_cp12552,
      anon_sym_cp12562,
      anon_sym_cp12572,
      anon_sym_cp12582,
      anon_sym_cp9322,
      anon_sym_euc_DASHjp2,
      anon_sym_sjis2,
      anon_sym_cp9492,
      anon_sym_euc_DASHkr2,
      anon_sym_cp9362,
      anon_sym_euc_DASHcn2,
      anon_sym_cp9502,
      anon_sym_big52,
      anon_sym_euc_DASHtw2,
      anon_sym_utf_DASH82,
      anon_sym_ucs_DASH21e2,
      anon_sym_utf_DASH16le2,
      anon_sym_ucs_DASH4le2,
      anon_sym_ansi2,
      anon_sym_japan2,
      anon_sym_korea2,
      anon_sym_prc2,
      anon_sym_chinese2,
      anon_sym_taiwan2,
      anon_sym_utf82,
      anon_sym_unicode2,
      anon_sym_ucs2be2,
      anon_sym_ucs_DASH2be2,
      anon_sym_ucs_DASH4be2,
      anon_sym_utf_DASH32le2,
      anon_sym_default2,
  [429] = 4,
    STATE(1679), 1,
      sym__immediate_encoding,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(796), 4,
      anon_sym_ucs_DASH22,
      anon_sym_utf_DASH162,
      anon_sym_ucs_DASH42,
      anon_sym_utf_DASH322,
    ACTIONS(794), 54,
      anon_sym_latin12,
      anon_sym_iso2,
      anon_sym_koi82,
      anon_sym_macroman2,
      anon_sym_cp4372,
      anon_sym_cp7372,
      anon_sym_cp7752,
      anon_sym_cp8502,
      anon_sym_cp8522,
      anon_sym_cp8552,
      anon_sym_cp8572,
      anon_sym_cp8602,
      anon_sym_cp8612,
      anon_sym_cp8622,
      anon_sym_cp8632,
      anon_sym_cp8652,
      anon_sym_cp8662,
      anon_sym_cp8692,
      anon_sym_cp8742,
      anon_sym_cp12502,
      anon_sym_cp12512,
      anon_sym_cp12532,
      anon_sym_cp12542,
      anon_sym_cp12552,
      anon_sym_cp12562,
      anon_sym_cp12572,
      anon_sym_cp12582,
      anon_sym_cp9322,
      anon_sym_euc_DASHjp2,
      anon_sym_sjis2,
      anon_sym_cp9492,
      anon_sym_euc_DASHkr2,
      anon_sym_cp9362,
      anon_sym_euc_DASHcn2,
      anon_sym_cp9502,
      anon_sym_big52,
      anon_sym_euc_DASHtw2,
      anon_sym_utf_DASH82,
      anon_sym_ucs_DASH21e2,
      anon_sym_utf_DASH16le2,
      anon_sym_ucs_DASH4le2,
      anon_sym_ansi2,
      anon_sym_japan2,
      anon_sym_korea2,
      anon_sym_prc2,
      anon_sym_chinese2,
      anon_sym_taiwan2,
      anon_sym_utf82,
      anon_sym_unicode2,
      anon_sym_ucs2be2,
      anon_sym_ucs_DASH2be2,
      anon_sym_ucs_DASH4be2,
      anon_sym_utf_DASH32le2,
      anon_sym_default2,
  [499] = 12,
    ACTIONS(744), 1,
      aux_sym__map_rhs_statement_token1,
    ACTIONS(750), 1,
      sym__keycode_modifier,
    ACTIONS(798), 1,
      aux_sym__bang_filter_command_argument_token3,
    ACTIONS(804), 1,
      anon_sym_LT,
    ACTIONS(806), 1,
      anon_sym_BSLASH2,
    STATE(1726), 1,
      aux_sym__map_lhs_repeat1,
    STATE(1935), 1,
      sym__immediate_keycode,
    STATE(3087), 1,
      sym__keycode_in,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(748), 3,
      anon_sym_BSLASH,
      anon_sym_LT2,
      aux_sym__map_rhs_token1,
    ACTIONS(802), 3,
      aux_sym__keycode_in_token2,
      aux_sym__keycode_in_token20,
      aux_sym__keycode_in_token21,
    ACTIONS(800), 40,
      aux_sym__keycode_in_token1,
      aux_sym__keycode_in_token3,
      aux_sym__keycode_in_token4,
      aux_sym__keycode_in_token5,
      aux_sym__keycode_in_token6,
      aux_sym__keycode_in_token7,
      aux_sym__keycode_in_token8,
      aux_sym__keycode_in_token9,
      aux_sym__keycode_in_token10,
      aux_sym__keycode_in_token11,
      aux_sym__keycode_in_token12,
      aux_sym__keycode_in_token13,
      aux_sym__keycode_in_token14,
      aux_sym__keycode_in_token15,
      aux_sym__keycode_in_token16,
      aux_sym__keycode_in_token17,
      aux_sym__keycode_in_token18,
      aux_sym__keycode_in_token19,
      aux_sym__keycode_in_token22,
      aux_sym__keycode_in_token23,
      aux_sym__keycode_in_token24,
      aux_sym__keycode_in_token25,
      aux_sym__keycode_in_token26,
      aux_sym__keycode_in_token27,
      aux_sym__keycode_in_token28,
      aux_sym__keycode_in_token29,
      aux_sym__keycode_in_token30,
      aux_sym__keycode_in_token31,
      aux_sym__keycode_in_token32,
      aux_sym__keycode_in_token33,
      aux_sym__keycode_in_token34,
      aux_sym__keycode_in_token35,
      aux_sym__keycode_in_token36,
      aux_sym__keycode_in_token37,
      aux_sym__keycode_in_token38,
      aux_sym__keycode_in_token39,
      aux_sym__keycode_in_token40,
      aux_sym__keycode_in_token41,
      aux_sym__keycode_in_token42,
      aux_sym__keycode_in_token43,
  [580] = 11,
    ACTIONS(750), 1,
      sym__keycode_modifier,
    ACTIONS(812), 1,
      anon_sym_LT,
    ACTIONS(814), 1,
      anon_sym_BSLASH2,
    ACTIONS(818), 1,
      aux_sym__map_rhs_token2,
    STATE(1805), 1,
      aux_sym__map_rhs_repeat1,
    STATE(2006), 1,
      sym__immediate_keycode,
    STATE(3235), 1,
      sym__keycode_in,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(810), 3,
      aux_sym__keycode_in_token2,
      aux_sym__keycode_in_token20,
      aux_sym__keycode_in_token21,
    ACTIONS(816), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(808), 40,
      aux_sym__keycode_in_token1,
      aux_sym__keycode_in_token3,
      aux_sym__keycode_in_token4,
      aux_sym__keycode_in_token5,
      aux_sym__keycode_in_token6,
      aux_sym__keycode_in_token7,
      aux_sym__keycode_in_token8,
      aux_sym__keycode_in_token9,
      aux_sym__keycode_in_token10,
      aux_sym__keycode_in_token11,
      aux_sym__keycode_in_token12,
      aux_sym__keycode_in_token13,
      aux_sym__keycode_in_token14,
      aux_sym__keycode_in_token15,
      aux_sym__keycode_in_token16,
      aux_sym__keycode_in_token17,
      aux_sym__keycode_in_token18,
      aux_sym__keycode_in_token19,
      aux_sym__keycode_in_token22,
      aux_sym__keycode_in_token23,
      aux_sym__keycode_in_token24,
      aux_sym__keycode_in_token25,
      aux_sym__keycode_in_token26,
      aux_sym__keycode_in_token27,
      aux_sym__keycode_in_token28,
      aux_sym__keycode_in_token29,
      aux_sym__keycode_in_token30,
      aux_sym__keycode_in_token31,
      aux_sym__keycode_in_token32,
      aux_sym__keycode_in_token33,
      aux_sym__keycode_in_token34,
      aux_sym__keycode_in_token35,
      aux_sym__keycode_in_token36,
      aux_sym__keycode_in_token37,
      aux_sym__keycode_in_token38,
      aux_sym__keycode_in_token39,
      aux_sym__keycode_in_token40,
      aux_sym__keycode_in_token41,
      aux_sym__keycode_in_token42,
      aux_sym__keycode_in_token43,
  [658] = 11,
    ACTIONS(750), 1,
      sym__keycode_modifier,
    ACTIONS(824), 1,
      anon_sym_LT,
    ACTIONS(826), 1,
      anon_sym_BSLASH2,
    ACTIONS(828), 1,
      aux_sym__map_rhs_token2,
    STATE(1899), 1,
      aux_sym__map_rhs_repeat1,
    STATE(2138), 1,
      sym__immediate_keycode,
    STATE(3027), 1,
      sym__keycode_in,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(830), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(822), 3,
      aux_sym__keycode_in_token2,
      aux_sym__keycode_in_token20,
      aux_sym__keycode_in_token21,
    ACTIONS(820), 40,
      aux_sym__keycode_in_token1,
      aux_sym__keycode_in_token3,
      aux_sym__keycode_in_token4,
      aux_sym__keycode_in_token5,
      aux_sym__keycode_in_token6,
      aux_sym__keycode_in_token7,
      aux_sym__keycode_in_token8,
      aux_sym__keycode_in_token9,
      aux_sym__keycode_in_token10,
      aux_sym__keycode_in_token11,
      aux_sym__keycode_in_token12,
      aux_sym__keycode_in_token13,
      aux_sym__keycode_in_token14,
      aux_sym__keycode_in_token15,
      aux_sym__keycode_in_token16,
      aux_sym__keycode_in_token17,
      aux_sym__keycode_in_token18,
      aux_sym__keycode_in_token19,
      aux_sym__keycode_in_token22,
      aux_sym__keycode_in_token23,
      aux_sym__keycode_in_token24,
      aux_sym__keycode_in_token25,
      aux_sym__keycode_in_token26,
      aux_sym__keycode_in_token27,
      aux_sym__keycode_in_token28,
      aux_sym__keycode_in_token29,
      aux_sym__keycode_in_token30,
      aux_sym__keycode_in_token31,
      aux_sym__keycode_in_token32,
      aux_sym__keycode_in_token33,
      aux_sym__keycode_in_token34,
      aux_sym__keycode_in_token35,
      aux_sym__keycode_in_token36,
      aux_sym__keycode_in_token37,
      aux_sym__keycode_in_token38,
      aux_sym__keycode_in_token39,
      aux_sym__keycode_in_token40,
      aux_sym__keycode_in_token41,
      aux_sym__keycode_in_token42,
      aux_sym__keycode_in_token43,
  [735] = 7,
    ACTIONS(750), 1,
      sym__keycode_modifier,
    STATE(3009), 1,
      sym__keycode_in,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(760), 2,
      anon_sym_BSLASH2,
      aux_sym__map_rhs_statement_token1,
    ACTIONS(834), 3,
      aux_sym__keycode_in_token2,
      aux_sym__keycode_in_token20,
      aux_sym__keycode_in_token21,
    ACTIONS(762), 5,
      anon_sym_BSLASH,
      aux_sym__bang_filter_command_argument_token3,
      anon_sym_LT,
      anon_sym_LT2,
      aux_sym__map_rhs_token1,
    ACTIONS(832), 40,
      aux_sym__keycode_in_token1,
      aux_sym__keycode_in_token3,
      aux_sym__keycode_in_token4,
      aux_sym__keycode_in_token5,
      aux_sym__keycode_in_token6,
      aux_sym__keycode_in_token7,
      aux_sym__keycode_in_token8,
      aux_sym__keycode_in_token9,
      aux_sym__keycode_in_token10,
      aux_sym__keycode_in_token11,
      aux_sym__keycode_in_token12,
      aux_sym__keycode_in_token13,
      aux_sym__keycode_in_token14,
      aux_sym__keycode_in_token15,
      aux_sym__keycode_in_token16,
      aux_sym__keycode_in_token17,
      aux_sym__keycode_in_token18,
      aux_sym__keycode_in_token19,
      aux_sym__keycode_in_token22,
      aux_sym__keycode_in_token23,
      aux_sym__keycode_in_token24,
      aux_sym__keycode_in_token25,
      aux_sym__keycode_in_token26,
      aux_sym__keycode_in_token27,
      aux_sym__keycode_in_token28,
      aux_sym__keycode_in_token29,
      aux_sym__keycode_in_token30,
      aux_sym__keycode_in_token31,
      aux_sym__keycode_in_token32,
      aux_sym__keycode_in_token33,
      aux_sym__keycode_in_token34,
      aux_sym__keycode_in_token35,
      aux_sym__keycode_in_token36,
      aux_sym__keycode_in_token37,
      aux_sym__keycode_in_token38,
      aux_sym__keycode_in_token39,
      aux_sym__keycode_in_token40,
      aux_sym__keycode_in_token41,
      aux_sym__keycode_in_token42,
      aux_sym__keycode_in_token43,
  [804] = 6,
    ACTIONS(750), 1,
      sym__keycode_modifier,
    STATE(3023), 1,
      sym__keycode_in,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(838), 3,
      aux_sym__keycode_in_token2,
      aux_sym__keycode_in_token20,
      aux_sym__keycode_in_token21,
    ACTIONS(840), 6,
      anon_sym_LT,
      anon_sym_BSLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__map_rhs_token2,
    ACTIONS(836), 40,
      aux_sym__keycode_in_token1,
      aux_sym__keycode_in_token3,
      aux_sym__keycode_in_token4,
      aux_sym__keycode_in_token5,
      aux_sym__keycode_in_token6,
      aux_sym__keycode_in_token7,
      aux_sym__keycode_in_token8,
      aux_sym__keycode_in_token9,
      aux_sym__keycode_in_token10,
      aux_sym__keycode_in_token11,
      aux_sym__keycode_in_token12,
      aux_sym__keycode_in_token13,
      aux_sym__keycode_in_token14,
      aux_sym__keycode_in_token15,
      aux_sym__keycode_in_token16,
      aux_sym__keycode_in_token17,
      aux_sym__keycode_in_token18,
      aux_sym__keycode_in_token19,
      aux_sym__keycode_in_token22,
      aux_sym__keycode_in_token23,
      aux_sym__keycode_in_token24,
      aux_sym__keycode_in_token25,
      aux_sym__keycode_in_token26,
      aux_sym__keycode_in_token27,
      aux_sym__keycode_in_token28,
      aux_sym__keycode_in_token29,
      aux_sym__keycode_in_token30,
      aux_sym__keycode_in_token31,
      aux_sym__keycode_in_token32,
      aux_sym__keycode_in_token33,
      aux_sym__keycode_in_token34,
      aux_sym__keycode_in_token35,
      aux_sym__keycode_in_token36,
      aux_sym__keycode_in_token37,
      aux_sym__keycode_in_token38,
      aux_sym__keycode_in_token39,
      aux_sym__keycode_in_token40,
      aux_sym__keycode_in_token41,
      aux_sym__keycode_in_token42,
      aux_sym__keycode_in_token43,
  [870] = 7,
    ACTIONS(750), 1,
      sym__keycode_modifier,
    ACTIONS(840), 1,
      aux_sym__map_rhs_token2,
    STATE(3058), 1,
      sym__keycode_in,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(844), 3,
      aux_sym__keycode_in_token2,
      aux_sym__keycode_in_token20,
      aux_sym__keycode_in_token21,
    ACTIONS(846), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_LT,
      anon_sym_BSLASH2,
    ACTIONS(842), 40,
      aux_sym__keycode_in_token1,
      aux_sym__keycode_in_token3,
      aux_sym__keycode_in_token4,
      aux_sym__keycode_in_token5,
      aux_sym__keycode_in_token6,
      aux_sym__keycode_in_token7,
      aux_sym__keycode_in_token8,
      aux_sym__keycode_in_token9,
      aux_sym__keycode_in_token10,
      aux_sym__keycode_in_token11,
      aux_sym__keycode_in_token12,
      aux_sym__keycode_in_token13,
      aux_sym__keycode_in_token14,
      aux_sym__keycode_in_token15,
      aux_sym__keycode_in_token16,
      aux_sym__keycode_in_token17,
      aux_sym__keycode_in_token18,
      aux_sym__keycode_in_token19,
      aux_sym__keycode_in_token22,
      aux_sym__keycode_in_token23,
      aux_sym__keycode_in_token24,
      aux_sym__keycode_in_token25,
      aux_sym__keycode_in_token26,
      aux_sym__keycode_in_token27,
      aux_sym__keycode_in_token28,
      aux_sym__keycode_in_token29,
      aux_sym__keycode_in_token30,
      aux_sym__keycode_in_token31,
      aux_sym__keycode_in_token32,
      aux_sym__keycode_in_token33,
      aux_sym__keycode_in_token34,
      aux_sym__keycode_in_token35,
      aux_sym__keycode_in_token36,
      aux_sym__keycode_in_token37,
      aux_sym__keycode_in_token38,
      aux_sym__keycode_in_token39,
      aux_sym__keycode_in_token40,
      aux_sym__keycode_in_token41,
      aux_sym__keycode_in_token42,
      aux_sym__keycode_in_token43,
  [937] = 26,
    ACTIONS(848), 1,
      anon_sym_a_COLON,
    ACTIONS(850), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_identifier_token1,
    ACTIONS(854), 1,
      anon_sym_AMP,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(860), 1,
      anon_sym_DOLLAR,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(868), 1,
      sym_integer_literal,
    ACTIONS(870), 1,
      anon_sym_LBRACK,
    ACTIONS(872), 1,
      sym_register,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(876), 1,
      sym__scope_dict,
    ACTIONS(878), 1,
      sym_scope,
    STATE(165), 1,
      sym__curly_braces_name_expression,
    STATE(274), 1,
      sym_identifier,
    STATE(549), 1,
      sym_scope_dict,
    STATE(1618), 1,
      sym_list_assignment,
    STATE(2451), 1,
      sym__let_assignment,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(866), 2,
      sym_string_literal,
      sym_float_literal,
    STATE(1458), 2,
      sym__assignment_variable,
      aux_sym_let_statement_repeat1,
    ACTIONS(862), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(514), 3,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
    STATE(519), 5,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym_env_variable,
      sym_option,
    STATE(957), 11,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_call_expression,
      sym_method_expression,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [1038] = 5,
    ACTIONS(750), 1,
      sym__keycode_modifier,
    STATE(3046), 1,
      sym__keycode_in,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(880), 4,
      aux_sym__bang_filter_command_argument_token3,
      aux_sym__keycode_in_token2,
      aux_sym__keycode_in_token20,
      aux_sym__keycode_in_token21,
    ACTIONS(882), 40,
      aux_sym__keycode_in_token1,
      aux_sym__keycode_in_token3,
      aux_sym__keycode_in_token4,
      aux_sym__keycode_in_token5,
      aux_sym__keycode_in_token6,
      aux_sym__keycode_in_token7,
      aux_sym__keycode_in_token8,
      aux_sym__keycode_in_token9,
      aux_sym__keycode_in_token10,
      aux_sym__keycode_in_token11,
      aux_sym__keycode_in_token12,
      aux_sym__keycode_in_token13,
      aux_sym__keycode_in_token14,
      aux_sym__keycode_in_token15,
      aux_sym__keycode_in_token16,
      aux_sym__keycode_in_token17,
      aux_sym__keycode_in_token18,
      aux_sym__keycode_in_token19,
      aux_sym__keycode_in_token22,
      aux_sym__keycode_in_token23,
      aux_sym__keycode_in_token24,
      aux_sym__keycode_in_token25,
      aux_sym__keycode_in_token26,
      aux_sym__keycode_in_token27,
      aux_sym__keycode_in_token28,
      aux_sym__keycode_in_token29,
      aux_sym__keycode_in_token30,
      aux_sym__keycode_in_token31,
      aux_sym__keycode_in_token32,
      aux_sym__keycode_in_token33,
      aux_sym__keycode_in_token34,
      aux_sym__keycode_in_token35,
      aux_sym__keycode_in_token36,
      aux_sym__keycode_in_token37,
      aux_sym__keycode_in_token38,
      aux_sym__keycode_in_token39,
      aux_sym__keycode_in_token40,
      aux_sym__keycode_in_token41,
      aux_sym__keycode_in_token42,
      aux_sym__keycode_in_token43,
  [1097] = 26,
    ACTIONS(854), 1,
      anon_sym_AMP,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(860), 1,
      anon_sym_DOLLAR,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(868), 1,
      sym_integer_literal,
    ACTIONS(870), 1,
      anon_sym_LBRACK,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(878), 1,
      sym_scope,
    ACTIONS(884), 1,
      anon_sym_a_COLON,
    ACTIONS(886), 1,
      anon_sym_LBRACE,
    ACTIONS(888), 1,
      aux_sym_identifier_token1,
    ACTIONS(890), 1,
      sym_register,
    ACTIONS(892), 1,
      sym__scope_dict,
    STATE(172), 1,
      sym__curly_braces_name_expression,
    STATE(481), 1,
      sym_identifier,
    STATE(564), 1,
      sym_scope_dict,
    STATE(1573), 1,
      sym_list_assignment,
    STATE(2978), 1,
      sym__let_assignment,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(862), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(866), 2,
      sym_string_literal,
      sym_float_literal,
    STATE(1582), 2,
      sym__assignment_variable,
      aux_sym_let_statement_repeat1,
    STATE(516), 3,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
    STATE(515), 5,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym_env_variable,
      sym_option,
    STATE(957), 11,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_call_expression,
      sym_method_expression,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [1197] = 5,
    ACTIONS(750), 1,
      sym__keycode_modifier,
    STATE(3297), 1,
      sym__keycode_in,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(896), 3,
      aux_sym__keycode_in_token2,
      aux_sym__keycode_in_token20,
      aux_sym__keycode_in_token21,
    ACTIONS(894), 40,
      aux_sym__keycode_in_token1,
      aux_sym__keycode_in_token3,
      aux_sym__keycode_in_token4,
      aux_sym__keycode_in_token5,
      aux_sym__keycode_in_token6,
      aux_sym__keycode_in_token7,
      aux_sym__keycode_in_token8,
      aux_sym__keycode_in_token9,
      aux_sym__keycode_in_token10,
      aux_sym__keycode_in_token11,
      aux_sym__keycode_in_token12,
      aux_sym__keycode_in_token13,
      aux_sym__keycode_in_token14,
      aux_sym__keycode_in_token15,
      aux_sym__keycode_in_token16,
      aux_sym__keycode_in_token17,
      aux_sym__keycode_in_token18,
      aux_sym__keycode_in_token19,
      aux_sym__keycode_in_token22,
      aux_sym__keycode_in_token23,
      aux_sym__keycode_in_token24,
      aux_sym__keycode_in_token25,
      aux_sym__keycode_in_token26,
      aux_sym__keycode_in_token27,
      aux_sym__keycode_in_token28,
      aux_sym__keycode_in_token29,
      aux_sym__keycode_in_token30,
      aux_sym__keycode_in_token31,
      aux_sym__keycode_in_token32,
      aux_sym__keycode_in_token33,
      aux_sym__keycode_in_token34,
      aux_sym__keycode_in_token35,
      aux_sym__keycode_in_token36,
      aux_sym__keycode_in_token37,
      aux_sym__keycode_in_token38,
      aux_sym__keycode_in_token39,
      aux_sym__keycode_in_token40,
      aux_sym__keycode_in_token41,
      aux_sym__keycode_in_token42,
      aux_sym__keycode_in_token43,
  [1255] = 5,
    ACTIONS(750), 1,
      sym__keycode_modifier,
    STATE(3060), 1,
      sym__keycode_in,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(900), 3,
      aux_sym__keycode_in_token2,
      aux_sym__keycode_in_token20,
      aux_sym__keycode_in_token21,
    ACTIONS(898), 40,
      aux_sym__keycode_in_token1,
      aux_sym__keycode_in_token3,
      aux_sym__keycode_in_token4,
      aux_sym__keycode_in_token5,
      aux_sym__keycode_in_token6,
      aux_sym__keycode_in_token7,
      aux_sym__keycode_in_token8,
      aux_sym__keycode_in_token9,
      aux_sym__keycode_in_token10,
      aux_sym__keycode_in_token11,
      aux_sym__keycode_in_token12,
      aux_sym__keycode_in_token13,
      aux_sym__keycode_in_token14,
      aux_sym__keycode_in_token15,
      aux_sym__keycode_in_token16,
      aux_sym__keycode_in_token17,
      aux_sym__keycode_in_token18,
      aux_sym__keycode_in_token19,
      aux_sym__keycode_in_token22,
      aux_sym__keycode_in_token23,
      aux_sym__keycode_in_token24,
      aux_sym__keycode_in_token25,
      aux_sym__keycode_in_token26,
      aux_sym__keycode_in_token27,
      aux_sym__keycode_in_token28,
      aux_sym__keycode_in_token29,
      aux_sym__keycode_in_token30,
      aux_sym__keycode_in_token31,
      aux_sym__keycode_in_token32,
      aux_sym__keycode_in_token33,
      aux_sym__keycode_in_token34,
      aux_sym__keycode_in_token35,
      aux_sym__keycode_in_token36,
      aux_sym__keycode_in_token37,
      aux_sym__keycode_in_token38,
      aux_sym__keycode_in_token39,
      aux_sym__keycode_in_token40,
      aux_sym__keycode_in_token41,
      aux_sym__keycode_in_token42,
      aux_sym__keycode_in_token43,
  [1313] = 6,
    ACTIONS(906), 1,
      anon_sym_LBRACE2,
    ACTIONS(908), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(143), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(904), 14,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(902), 25,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [1371] = 6,
    ACTIONS(914), 1,
      anon_sym_LBRACE2,
    ACTIONS(917), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(143), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(912), 14,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(910), 25,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [1429] = 19,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(940), 1,
      sym_integer_literal,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    STATE(149), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(934), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(938), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(337), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [1513] = 19,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(940), 1,
      sym_integer_literal,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    STATE(149), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(938), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    ACTIONS(950), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(337), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [1597] = 19,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(940), 1,
      sym_integer_literal,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    STATE(149), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(938), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    ACTIONS(952), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(337), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [1681] = 19,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(940), 1,
      sym_integer_literal,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    STATE(155), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(938), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    ACTIONS(954), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(337), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [1765] = 19,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(940), 1,
      sym_integer_literal,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    STATE(149), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(938), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    ACTIONS(956), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(337), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [1849] = 19,
    ACTIONS(958), 1,
      anon_sym_a_COLON,
    ACTIONS(961), 1,
      anon_sym_LBRACE,
    ACTIONS(964), 1,
      aux_sym_identifier_token1,
    ACTIONS(967), 1,
      anon_sym_AMP,
    ACTIONS(970), 1,
      anon_sym_LPAREN,
    ACTIONS(976), 1,
      anon_sym_DOLLAR,
    ACTIONS(981), 1,
      anon_sym_BANG2,
    ACTIONS(987), 1,
      sym_integer_literal,
    ACTIONS(990), 1,
      anon_sym_LBRACK,
    ACTIONS(993), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(996), 1,
      sym__scope_dict,
    ACTIONS(999), 1,
      sym_scope,
    STATE(149), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(973), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(979), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(984), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(337), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [1933] = 22,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1006), 1,
      anon_sym_RBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1012), 1,
      anon_sym_COMMA,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1018), 1,
      sym_integer_literal,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1022), 1,
      anon_sym_DASH_GT,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(638), 1,
      sym_identifier,
    STATE(2521), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1016), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(743), 20,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [2023] = 22,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1028), 1,
      anon_sym_RBRACE,
    ACTIONS(1030), 1,
      anon_sym_COMMA,
    ACTIONS(1034), 1,
      sym_integer_literal,
    ACTIONS(1036), 1,
      anon_sym_DASH_GT,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(623), 1,
      sym_identifier,
    STATE(2452), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1032), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(796), 20,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [2113] = 19,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(940), 1,
      sym_integer_literal,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    STATE(148), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(938), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    ACTIONS(1038), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(337), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [2197] = 19,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(940), 1,
      sym_integer_literal,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    STATE(149), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(938), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    ACTIONS(1040), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(337), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [2281] = 19,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(940), 1,
      sym_integer_literal,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    STATE(144), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(938), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    ACTIONS(1042), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(337), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [2365] = 19,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(940), 1,
      sym_integer_literal,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    STATE(149), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(938), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    ACTIONS(1044), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(337), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [2449] = 22,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1028), 1,
      anon_sym_RBRACE,
    ACTIONS(1030), 1,
      anon_sym_COMMA,
    ACTIONS(1036), 1,
      anon_sym_DASH_GT,
    ACTIONS(1048), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(623), 1,
      sym_identifier,
    STATE(2452), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1046), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(780), 20,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [2539] = 19,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(940), 1,
      sym_integer_literal,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    STATE(149), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(938), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    ACTIONS(1050), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(337), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [2623] = 22,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1052), 1,
      anon_sym_RBRACE,
    ACTIONS(1054), 1,
      anon_sym_COMMA,
    ACTIONS(1058), 1,
      sym_integer_literal,
    ACTIONS(1060), 1,
      anon_sym_DASH_GT,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(639), 1,
      sym_identifier,
    STATE(2576), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1056), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(775), 20,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [2713] = 6,
    ACTIONS(1066), 1,
      anon_sym_LBRACE2,
    ACTIONS(1068), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(161), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1064), 12,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1062), 27,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [2771] = 22,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1070), 1,
      anon_sym_RBRACE,
    ACTIONS(1072), 1,
      anon_sym_COMMA,
    ACTIONS(1076), 1,
      sym_integer_literal,
    ACTIONS(1078), 1,
      anon_sym_DASH_GT,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(620), 1,
      sym_identifier,
    STATE(2602), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1074), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(792), 20,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [2861] = 6,
    ACTIONS(1066), 1,
      anon_sym_LBRACE2,
    ACTIONS(1080), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(163), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(904), 12,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(902), 27,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [2919] = 22,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1082), 1,
      anon_sym_RBRACE,
    ACTIONS(1084), 1,
      anon_sym_COMMA,
    ACTIONS(1088), 1,
      sym_integer_literal,
    ACTIONS(1090), 1,
      anon_sym_DASH_GT,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(624), 1,
      sym_identifier,
    STATE(2630), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1086), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(795), 20,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [3009] = 6,
    ACTIONS(1092), 1,
      anon_sym_LBRACE2,
    ACTIONS(1095), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(163), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(912), 12,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(910), 27,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [3067] = 22,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1028), 1,
      anon_sym_RBRACE,
    ACTIONS(1030), 1,
      anon_sym_COMMA,
    ACTIONS(1036), 1,
      anon_sym_DASH_GT,
    ACTIONS(1100), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(623), 1,
      sym_identifier,
    STATE(2452), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1098), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(781), 20,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [3157] = 6,
    ACTIONS(906), 1,
      anon_sym_LBRACE2,
    ACTIONS(1102), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(142), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1064), 14,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1062), 25,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [3215] = 19,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(940), 1,
      sym_integer_literal,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    STATE(145), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(938), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    ACTIONS(1104), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(337), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [3299] = 22,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1028), 1,
      anon_sym_RBRACE,
    ACTIONS(1030), 1,
      anon_sym_COMMA,
    ACTIONS(1036), 1,
      anon_sym_DASH_GT,
    ACTIONS(1108), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(623), 1,
      sym_identifier,
    STATE(2452), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1106), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(785), 20,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [3389] = 19,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1128), 1,
      sym_integer_literal,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    STATE(177), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(950), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1126), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(484), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [3472] = 21,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1138), 1,
      anon_sym_BANG,
    ACTIONS(1142), 1,
      sym_integer_literal,
    STATE(243), 1,
      sym_bang,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(835), 1,
      sym_field_expression,
    STATE(1870), 1,
      sym_function_declaration,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG2,
    ACTIONS(1140), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(844), 4,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
    STATE(939), 16,
      sym_scope_dict,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [3559] = 18,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1164), 1,
      sym_integer_literal,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1158), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(1162), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(687), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [3640] = 20,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1174), 1,
      anon_sym_QMARK,
    ACTIONS(1176), 1,
      anon_sym_POUND,
    ACTIONS(1180), 1,
      sym_integer_literal,
    STATE(455), 1,
      sym_match_case,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1178), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(592), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [3725] = 6,
    ACTIONS(1182), 1,
      anon_sym_LBRACE2,
    ACTIONS(1184), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(175), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1064), 14,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1062), 24,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [3782] = 19,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1128), 1,
      sym_integer_literal,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    STATE(180), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(954), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1126), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(484), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [3865] = 19,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1128), 1,
      sym_integer_literal,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    STATE(177), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1040), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1126), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(484), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [3948] = 6,
    ACTIONS(1182), 1,
      anon_sym_LBRACE2,
    ACTIONS(1186), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(176), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(904), 14,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(902), 24,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [4005] = 6,
    ACTIONS(1188), 1,
      anon_sym_LBRACE2,
    ACTIONS(1191), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(176), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(912), 14,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(910), 24,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [4062] = 19,
    ACTIONS(1194), 1,
      anon_sym_a_COLON,
    ACTIONS(1197), 1,
      anon_sym_LBRACE,
    ACTIONS(1200), 1,
      aux_sym_identifier_token1,
    ACTIONS(1203), 1,
      anon_sym_AMP,
    ACTIONS(1206), 1,
      anon_sym_LPAREN,
    ACTIONS(1212), 1,
      anon_sym_DOLLAR,
    ACTIONS(1215), 1,
      anon_sym_BANG2,
    ACTIONS(1221), 1,
      sym_integer_literal,
    ACTIONS(1224), 1,
      anon_sym_LBRACK,
    ACTIONS(1227), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1230), 1,
      sym__scope_dict,
    ACTIONS(1233), 1,
      sym_scope,
    STATE(177), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(979), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(1209), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1218), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(484), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [4145] = 19,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1128), 1,
      sym_integer_literal,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    ACTIONS(1138), 1,
      anon_sym_BANG,
    STATE(188), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    STATE(247), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1120), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG2,
    ACTIONS(1126), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(484), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [4228] = 19,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(940), 1,
      sym_integer_literal,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    ACTIONS(1138), 1,
      anon_sym_BANG,
    STATE(146), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    STATE(225), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG2,
    ACTIONS(938), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(337), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [4311] = 19,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1128), 1,
      sym_integer_literal,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    STATE(177), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1044), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1126), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(484), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [4394] = 19,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1128), 1,
      sym_integer_literal,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    STATE(177), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(956), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1126), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(484), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [4477] = 19,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1128), 1,
      sym_integer_literal,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    STATE(177), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(934), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1126), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(484), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [4560] = 19,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1128), 1,
      sym_integer_literal,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    STATE(177), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1050), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1126), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(484), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [4643] = 19,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1128), 1,
      sym_integer_literal,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    STATE(168), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1104), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1126), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(484), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [4726] = 20,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    ACTIONS(1174), 1,
      anon_sym_QMARK,
    ACTIONS(1176), 1,
      anon_sym_POUND,
    ACTIONS(1238), 1,
      sym_integer_literal,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    STATE(398), 1,
      sym_match_case,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1236), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(465), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [4811] = 20,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1240), 1,
      anon_sym_COMMA,
    ACTIONS(1242), 1,
      anon_sym_SEMI,
    ACTIONS(1246), 1,
      sym_integer_literal,
    ACTIONS(1248), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1244), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(630), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [4896] = 20,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    ACTIONS(1174), 1,
      anon_sym_QMARK,
    ACTIONS(1176), 1,
      anon_sym_POUND,
    ACTIONS(1252), 1,
      sym_integer_literal,
    STATE(284), 1,
      sym_match_case,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1250), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(704), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [4981] = 19,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1128), 1,
      sym_integer_literal,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    STATE(177), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(952), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1126), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(484), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [5064] = 20,
    ACTIONS(1174), 1,
      anon_sym_QMARK,
    ACTIONS(1176), 1,
      anon_sym_POUND,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1272), 1,
      sym_integer_literal,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    STATE(371), 1,
      sym_match_case,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1270), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(810), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [5149] = 19,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1128), 1,
      sym_integer_literal,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    STATE(181), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1038), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1126), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(484), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [5232] = 6,
    ACTIONS(1282), 1,
      anon_sym_LBRACE2,
    ACTIONS(1284), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(193), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1064), 12,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1062), 26,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [5289] = 19,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1128), 1,
      sym_integer_literal,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    STATE(182), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1042), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1126), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(484), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [5372] = 6,
    ACTIONS(1282), 1,
      anon_sym_LBRACE2,
    ACTIONS(1286), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(195), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(904), 12,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(902), 26,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [5429] = 20,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    ACTIONS(1174), 1,
      anon_sym_QMARK,
    ACTIONS(1176), 1,
      anon_sym_POUND,
    ACTIONS(1290), 1,
      sym_integer_literal,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    STATE(315), 1,
      sym_match_case,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1288), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(314), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [5514] = 6,
    ACTIONS(1292), 1,
      anon_sym_LBRACE2,
    ACTIONS(1295), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(195), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(912), 12,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(910), 26,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [5571] = 21,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1138), 1,
      anon_sym_BANG,
    ACTIONS(1142), 1,
      sym_integer_literal,
    STATE(261), 1,
      sym_bang,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(835), 1,
      sym_field_expression,
    STATE(1871), 1,
      sym_function_declaration,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG2,
    ACTIONS(1140), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(844), 4,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
    STATE(939), 16,
      sym_scope_dict,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [5658] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1242), 1,
      anon_sym_SEMI,
    ACTIONS(1300), 1,
      sym_integer_literal,
    ACTIONS(1302), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1298), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(621), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [5740] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1304), 1,
      anon_sym_COMMA,
    ACTIONS(1308), 1,
      sym_integer_literal,
    ACTIONS(1310), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1306), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(645), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [5822] = 5,
    ACTIONS(1314), 1,
      aux_sym_argument_token1,
    ACTIONS(1316), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1318), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1312), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [5876] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1322), 13,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      aux_sym_identifier_token2,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1320), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE2,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [5926] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1324), 1,
      anon_sym_RBRACE,
    ACTIONS(1328), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(2806), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1326), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(841), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [6008] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1328), 1,
      sym_integer_literal,
    ACTIONS(1330), 1,
      anon_sym_RBRACE,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(2806), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1326), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(841), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [6090] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1328), 1,
      sym_integer_literal,
    ACTIONS(1332), 1,
      anon_sym_RBRACE,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(2806), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1326), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(841), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [6172] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1328), 1,
      sym_integer_literal,
    ACTIONS(1334), 1,
      anon_sym_RBRACE,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(2806), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1326), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(841), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [6254] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1338), 13,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      aux_sym_identifier_token2,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1336), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE2,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [6304] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1340), 1,
      anon_sym_COMMA,
    ACTIONS(1344), 1,
      sym_integer_literal,
    ACTIONS(1346), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1342), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(658), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [6386] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1328), 1,
      sym_integer_literal,
    ACTIONS(1348), 1,
      anon_sym_RBRACE,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(2806), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1326), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(841), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [6468] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1322), 15,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      aux_sym_identifier_token2,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1320), 26,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_LBRACE2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [6518] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1328), 1,
      sym_integer_literal,
    ACTIONS(1350), 1,
      anon_sym_RBRACE,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(2806), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1326), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(841), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [6600] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1352), 1,
      anon_sym_COMMA,
    ACTIONS(1356), 1,
      sym_integer_literal,
    ACTIONS(1358), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1354), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(665), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [6682] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1328), 1,
      sym_integer_literal,
    ACTIONS(1360), 1,
      anon_sym_RBRACE,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(2806), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1326), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(841), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [6764] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1328), 1,
      sym_integer_literal,
    ACTIONS(1362), 1,
      anon_sym_RBRACE,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(2806), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1326), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(841), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [6846] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1338), 15,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      aux_sym_identifier_token2,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1336), 26,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_LBRACE2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [6896] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1364), 1,
      anon_sym_COMMA,
    ACTIONS(1368), 1,
      sym_integer_literal,
    ACTIONS(1370), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1366), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(674), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [6978] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1328), 1,
      sym_integer_literal,
    ACTIONS(1372), 1,
      anon_sym_RBRACE,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(2806), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1326), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(841), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [7060] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1328), 1,
      sym_integer_literal,
    ACTIONS(1374), 1,
      anon_sym_RBRACE,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(2806), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1326), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(841), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [7142] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1240), 1,
      anon_sym_COMMA,
    ACTIONS(1378), 1,
      sym_integer_literal,
    ACTIONS(1380), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1376), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(655), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [7224] = 18,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1384), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1158), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1382), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(791), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [7304] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1386), 1,
      anon_sym_COLON,
    ACTIONS(1390), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1388), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(783), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [7383] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1392), 1,
      anon_sym_RPAREN,
    ACTIONS(1396), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1394), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(649), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [7462] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1400), 1,
      sym_integer_literal,
    ACTIONS(1402), 1,
      anon_sym_DASH_GT,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(647), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1398), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(883), 20,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [7543] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1404), 1,
      anon_sym_RPAREN,
    ACTIONS(1408), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1406), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(678), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [7622] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1412), 1,
      sym_integer_literal,
    ACTIONS(1414), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1410), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(635), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [7701] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1416), 1,
      anon_sym_RPAREN,
    ACTIONS(1420), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1418), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(659), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [7780] = 18,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(940), 1,
      sym_integer_literal,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    STATE(157), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(938), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(337), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [7859] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1412), 1,
      sym_integer_literal,
    ACTIONS(1422), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1410), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(635), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [7938] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1426), 1,
      sym_integer_literal,
    ACTIONS(1428), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1424), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(838), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [8017] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1322), 15,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      aux_sym_identifier_token2,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1320), 25,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [8066] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1432), 1,
      sym_integer_literal,
    ACTIONS(1434), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1430), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(918), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [8145] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1412), 1,
      sym_integer_literal,
    ACTIONS(1436), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1410), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(635), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [8224] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1440), 1,
      sym_integer_literal,
    ACTIONS(1442), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1438), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(843), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [8303] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1444), 1,
      anon_sym_RPAREN,
    ACTIONS(1448), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1446), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(663), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [8382] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1450), 1,
      anon_sym_COLON,
    ACTIONS(1454), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1452), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(816), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [8461] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1412), 1,
      sym_integer_literal,
    ACTIONS(1456), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1410), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(635), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [8540] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1458), 1,
      anon_sym_RPAREN,
    ACTIONS(1462), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1460), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(668), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [8619] = 5,
    ACTIONS(1464), 1,
      aux_sym_argument_token1,
    ACTIONS(1466), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1318), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1312), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [8672] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1412), 1,
      sym_integer_literal,
    ACTIONS(1468), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1410), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(635), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [8751] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1472), 1,
      sym_integer_literal,
    ACTIONS(1474), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1470), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(856), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [8830] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1478), 1,
      sym_integer_literal,
    ACTIONS(1480), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1476), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(911), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [8909] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1412), 1,
      sym_integer_literal,
    ACTIONS(1482), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1410), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(635), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [8988] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1412), 1,
      sym_integer_literal,
    ACTIONS(1484), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1410), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(635), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [9067] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1488), 1,
      sym_integer_literal,
    ACTIONS(1490), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1486), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(858), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [9146] = 20,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1142), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(835), 1,
      sym_field_expression,
    STATE(1873), 1,
      sym_function_declaration,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1140), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(844), 4,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
    STATE(939), 16,
      sym_scope_dict,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [9229] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1338), 15,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      aux_sym_identifier_token2,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1336), 25,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [9278] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1412), 1,
      sym_integer_literal,
    ACTIONS(1492), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1410), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(635), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [9357] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1494), 1,
      anon_sym_RPAREN,
    ACTIONS(1498), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1496), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(640), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [9436] = 18,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1128), 1,
      sym_integer_literal,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    STATE(183), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1126), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(484), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [9515] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1412), 1,
      sym_integer_literal,
    ACTIONS(1500), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1410), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(635), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [9594] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1504), 1,
      sym_integer_literal,
    ACTIONS(1506), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1502), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(868), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [9673] = 18,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1128), 1,
      sym_integer_literal,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    STATE(174), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1126), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(484), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [9752] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1328), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(2806), 1,
      sym_dictionnary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1326), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(841), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [9831] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1412), 1,
      sym_integer_literal,
    ACTIONS(1508), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1410), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(635), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [9910] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1512), 1,
      sym_integer_literal,
    ACTIONS(1514), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1510), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(870), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [9989] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1516), 1,
      anon_sym_RPAREN,
    ACTIONS(1520), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1518), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(680), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [10068] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1524), 1,
      sym_integer_literal,
    ACTIONS(1526), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1522), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(875), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [10147] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1530), 1,
      sym_integer_literal,
    ACTIONS(1532), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1528), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(876), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [10226] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1534), 1,
      anon_sym_RPAREN,
    ACTIONS(1538), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1536), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(700), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [10305] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1540), 1,
      anon_sym_COLON,
    ACTIONS(1544), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1542), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(755), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [10384] = 18,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(940), 1,
      sym_integer_literal,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    STATE(153), 1,
      aux_sym_unlet_statement_repeat1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(938), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(337), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [10463] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1338), 13,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      aux_sym_identifier_token2,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1336), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE2,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [10512] = 20,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1142), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(835), 1,
      sym_field_expression,
    STATE(1866), 1,
      sym_function_declaration,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1140), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(844), 4,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
    STATE(939), 16,
      sym_scope_dict,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [10595] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1546), 1,
      anon_sym_COLON,
    ACTIONS(1550), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1548), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(778), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [10674] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1322), 13,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      aux_sym_identifier_token2,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1320), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE2,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [10723] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1554), 1,
      sym_integer_literal,
    ACTIONS(1556), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1552), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(925), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [10802] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1558), 1,
      anon_sym_COLON,
    ACTIONS(1562), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1560), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(788), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [10881] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1564), 1,
      anon_sym_RPAREN,
    ACTIONS(1568), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1566), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(656), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [10960] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1570), 1,
      anon_sym_COLON,
    ACTIONS(1574), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1572), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(794), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [11039] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1578), 1,
      sym_integer_literal,
    ACTIONS(1580), 1,
      anon_sym_RBRACK,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1576), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(853), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [11118] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1582), 1,
      anon_sym_RPAREN,
    ACTIONS(1586), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1584), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(672), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [11197] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1590), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1588), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(873), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [11273] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1594), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1592), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(692), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [11349] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1598), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1596), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(855), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [11425] = 17,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    ACTIONS(1602), 1,
      sym_integer_literal,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1600), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(717), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [11501] = 5,
    ACTIONS(1608), 1,
      aux_sym_identifier_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1604), 6,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(1606), 12,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1610), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [11553] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1412), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1410), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(635), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [11629] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1614), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1612), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(903), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [11705] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1618), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1616), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(915), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [11781] = 17,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    ACTIONS(1622), 1,
      sym_integer_literal,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1620), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(693), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [11857] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1624), 1,
      anon_sym_LBRACE,
    ACTIONS(1626), 1,
      aux_sym_identifier_token1,
    ACTIONS(1630), 1,
      sym_integer_literal,
    STATE(510), 1,
      sym__curly_braces_name_expression,
    STATE(527), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1628), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(589), 20,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [11935] = 17,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    ACTIONS(1634), 1,
      sym_integer_literal,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1632), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(701), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [12011] = 17,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    ACTIONS(1638), 1,
      sym_integer_literal,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1636), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(712), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [12087] = 17,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    ACTIONS(1642), 1,
      sym_integer_literal,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1640), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(713), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [12163] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1646), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1644), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(660), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [12239] = 17,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    ACTIONS(1650), 1,
      sym_integer_literal,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1648), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(709), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [12315] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1654), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1652), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(584), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [12391] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1630), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(586), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1628), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(589), 20,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [12469] = 17,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    ACTIONS(1658), 1,
      sym_integer_literal,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1656), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(652), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [12545] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1630), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1628), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(589), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [12621] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1662), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1660), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(601), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [12697] = 17,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    ACTIONS(1666), 1,
      sym_integer_literal,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1664), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(295), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [12773] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1670), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1668), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(599), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [12849] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1674), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1672), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(600), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [12925] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1678), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1676), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [12973] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1682), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1680), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(736), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [13049] = 7,
    ACTIONS(1688), 1,
      anon_sym_LPAREN,
    ACTIONS(1690), 1,
      anon_sym_DOT2,
    ACTIONS(1693), 1,
      anon_sym_LBRACK,
    ACTIONS(1695), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1686), 10,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1684), 25,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [13105] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1699), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1697), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [13153] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1703), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1701), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [13201] = 17,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    ACTIONS(1707), 1,
      sym_integer_literal,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1705), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(312), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [13277] = 18,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    ACTIONS(1634), 1,
      sym_integer_literal,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    STATE(699), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1632), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(701), 20,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [13355] = 17,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    ACTIONS(1711), 1,
      sym_integer_literal,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1709), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(313), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [13431] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1715), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1713), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(928), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [13507] = 17,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    ACTIONS(1719), 1,
      sym_integer_literal,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1717), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(316), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [13583] = 17,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    ACTIONS(1723), 1,
      sym_integer_literal,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1721), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(317), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [13659] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1727), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1725), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [13707] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1731), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1729), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(784), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [13783] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1735), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1733), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(763), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [13859] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1739), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1737), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [13907] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1743), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1741), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [13955] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1747), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1745), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14003] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1751), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1749), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14051] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1755), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1753), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14099] = 7,
    ACTIONS(1688), 1,
      anon_sym_LPAREN,
    ACTIONS(1693), 1,
      anon_sym_LBRACK,
    ACTIONS(1695), 1,
      anon_sym_DASH_GT,
    ACTIONS(1761), 1,
      anon_sym_DOT2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1759), 10,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1757), 25,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14155] = 8,
    ACTIONS(1688), 1,
      anon_sym_LPAREN,
    ACTIONS(1693), 1,
      anon_sym_LBRACK,
    ACTIONS(1695), 1,
      anon_sym_DASH_GT,
    ACTIONS(1766), 1,
      anon_sym_DOT2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1764), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1759), 10,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1757), 22,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14213] = 10,
    ACTIONS(1688), 1,
      anon_sym_LPAREN,
    ACTIONS(1693), 1,
      anon_sym_LBRACK,
    ACTIONS(1695), 1,
      anon_sym_DASH_GT,
    ACTIONS(1766), 1,
      anon_sym_DOT2,
    ACTIONS(1770), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1764), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1759), 8,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1757), 21,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14275] = 17,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    ACTIONS(1774), 1,
      sym_integer_literal,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1772), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(326), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [14351] = 13,
    ACTIONS(1688), 1,
      anon_sym_LPAREN,
    ACTIONS(1693), 1,
      anon_sym_LBRACK,
    ACTIONS(1695), 1,
      anon_sym_DASH_GT,
    ACTIONS(1766), 1,
      anon_sym_DOT2,
    ACTIONS(1770), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1778), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1764), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1759), 4,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1776), 4,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1780), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1757), 14,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_PIPE_PIPE,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14419] = 12,
    ACTIONS(1688), 1,
      anon_sym_LPAREN,
    ACTIONS(1693), 1,
      anon_sym_LBRACK,
    ACTIONS(1695), 1,
      anon_sym_DASH_GT,
    ACTIONS(1766), 1,
      anon_sym_DOT2,
    ACTIONS(1770), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1764), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1759), 4,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1776), 4,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1780), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1757), 15,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14485] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1784), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1782), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14533] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1788), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1786), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14581] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1792), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1790), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14629] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1796), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1794), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14677] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1800), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1798), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14725] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1804), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1802), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14773] = 17,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    ACTIONS(1808), 1,
      sym_integer_literal,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1806), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(331), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [14849] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1812), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1810), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14897] = 10,
    ACTIONS(1688), 1,
      anon_sym_LPAREN,
    ACTIONS(1693), 1,
      anon_sym_LBRACK,
    ACTIONS(1695), 1,
      anon_sym_DASH_GT,
    ACTIONS(1766), 1,
      anon_sym_DOT2,
    ACTIONS(1770), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1764), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1816), 8,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1814), 21,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [14959] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1820), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1818), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15007] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1824), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1822), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15055] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1828), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1826), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15103] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1832), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1830), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15151] = 14,
    ACTIONS(1688), 1,
      anon_sym_LPAREN,
    ACTIONS(1693), 1,
      anon_sym_LBRACK,
    ACTIONS(1695), 1,
      anon_sym_DASH_GT,
    ACTIONS(1766), 1,
      anon_sym_DOT2,
    ACTIONS(1770), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1778), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1838), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1764), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1776), 4,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1836), 4,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1780), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1834), 13,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15221] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1842), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1840), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15269] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1846), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1844), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15317] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1850), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1848), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15365] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1854), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1852), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15413] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1858), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1856), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15461] = 15,
    ACTIONS(1688), 1,
      anon_sym_LPAREN,
    ACTIONS(1693), 1,
      anon_sym_LBRACK,
    ACTIONS(1695), 1,
      anon_sym_DASH_GT,
    ACTIONS(1766), 1,
      anon_sym_DOT2,
    ACTIONS(1770), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1778), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1838), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1864), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1764), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1776), 4,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1862), 4,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1780), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1860), 12,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15533] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1868), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1866), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(707), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [15609] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1872), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1870), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15657] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1876), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1874), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15705] = 18,
    ACTIONS(920), 1,
      anon_sym_a_COLON,
    ACTIONS(922), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      aux_sym_identifier_token1,
    ACTIONS(926), 1,
      anon_sym_AMP,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(936), 1,
      anon_sym_BANG2,
    ACTIONS(942), 1,
      anon_sym_LBRACK,
    ACTIONS(944), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(946), 1,
      sym__scope_dict,
    ACTIONS(948), 1,
      sym_scope,
    ACTIONS(1711), 1,
      sym_integer_literal,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    STATE(343), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(930), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1709), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(313), 20,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [15783] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1880), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1878), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15831] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1884), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1882), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15879] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1888), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1886), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15927] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1892), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1890), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [15975] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1896), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1894), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [16023] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1900), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1898), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [16071] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1904), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1902), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [16119] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1908), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1906), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(931), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [16195] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1912), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1910), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(904), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [16271] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1916), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1914), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [16319] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1920), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1918), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [16367] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1924), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1922), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [16415] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1318), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1312), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [16463] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1928), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1926), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [16511] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1932), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1930), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(804), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [16587] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1936), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1934), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(727), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [16663] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1940), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1938), 28,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [16711] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1944), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(817), 2,
      sym_call_expression,
      sym_method_expression,
    ACTIONS(1942), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(942), 19,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [16789] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1948), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1946), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(807), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [16865] = 18,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1952), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    STATE(808), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(809), 20,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [16943] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1952), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(809), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [17019] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1956), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1954), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(593), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [17095] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1960), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1958), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(818), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [17171] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1964), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1962), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(819), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [17247] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1968), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1966), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(669), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [17323] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1972), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1970), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(913), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [17399] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1976), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1974), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(914), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [17475] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1980), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1978), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(793), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [17551] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1984), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1982), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(667), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [17627] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(1988), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1986), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(738), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [17703] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1944), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(728), 1,
      sym_call_expression,
    STATE(741), 1,
      sym_method_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1942), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(942), 19,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [17783] = 18,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1992), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(695), 2,
      sym_call_expression,
      sym_method_expression,
    ACTIONS(1990), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(947), 19,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [17861] = 17,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    ACTIONS(1996), 1,
      sym_integer_literal,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(696), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [17937] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(2000), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1998), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(797), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [18013] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(2004), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2002), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(729), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [18089] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1992), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(715), 1,
      sym_call_expression,
    STATE(718), 1,
      sym_method_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1990), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(947), 19,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [18169] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1944), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(742), 1,
      sym_call_expression,
    STATE(744), 1,
      sym_method_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1942), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(942), 19,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [18249] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(2008), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2006), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(726), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [18325] = 17,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    ACTIONS(2012), 1,
      sym_integer_literal,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2010), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(657), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [18401] = 17,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    ACTIONS(2016), 1,
      sym_integer_literal,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2014), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(691), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [18477] = 17,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    ACTIONS(2020), 1,
      sym_integer_literal,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2018), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(714), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [18553] = 19,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1992), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(722), 1,
      sym_call_expression,
    STATE(723), 1,
      sym_method_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1990), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(947), 19,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [18633] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2024), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2022), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(830), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [18709] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2028), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2026), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(777), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [18785] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2032), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2030), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(926), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [18861] = 17,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    ACTIONS(2036), 1,
      sym_integer_literal,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2034), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(643), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [18937] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2040), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2038), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(851), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [19013] = 17,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    ACTIONS(2044), 1,
      sym_integer_literal,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2042), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(500), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [19089] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2048), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2046), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(787), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [19165] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2052), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2050), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(932), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [19241] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2056), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2054), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(933), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [19317] = 17,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    ACTIONS(2060), 1,
      sym_integer_literal,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2058), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(462), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [19393] = 18,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    ACTIONS(2064), 1,
      sym_integer_literal,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    STATE(463), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2062), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(464), 20,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [19471] = 17,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    ACTIONS(2064), 1,
      sym_integer_literal,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2062), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(464), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [19547] = 17,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    ACTIONS(2068), 1,
      sym_integer_literal,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2066), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(466), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [19623] = 17,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    ACTIONS(2072), 1,
      sym_integer_literal,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2070), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(467), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [19699] = 17,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    ACTIONS(2076), 1,
      sym_integer_literal,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2074), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(475), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [19775] = 17,
    ACTIONS(1110), 1,
      anon_sym_a_COLON,
    ACTIONS(1112), 1,
      anon_sym_LBRACE,
    ACTIONS(1114), 1,
      aux_sym_identifier_token1,
    ACTIONS(1116), 1,
      anon_sym_AMP,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_DOLLAR,
    ACTIONS(1124), 1,
      anon_sym_BANG2,
    ACTIONS(1130), 1,
      anon_sym_LBRACK,
    ACTIONS(1132), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1134), 1,
      sym__scope_dict,
    ACTIONS(1136), 1,
      sym_scope,
    ACTIONS(2080), 1,
      sym_integer_literal,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2078), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(508), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [19851] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2084), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2082), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(828), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [19927] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2088), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2086), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(837), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [20003] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2092), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2090), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(865), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [20079] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2096), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2094), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(871), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [20155] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2100), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2098), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(877), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [20231] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2104), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2102), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(909), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [20307] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2108), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2106), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(924), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [20383] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2112), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2110), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(829), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [20459] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2116), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2114), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(831), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [20535] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2120), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2118), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(832), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [20611] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2124), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2122), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(833), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [20687] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2128), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2126), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(834), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [20763] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2132), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2130), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(836), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [20839] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2136), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2134), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(842), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [20915] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2140), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2138), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(845), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [20991] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2144), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2142), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(847), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [21067] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2148), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2146), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(848), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [21143] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2152), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2150), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(850), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [21219] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2156), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2154), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(852), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [21295] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2160), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2158), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(854), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [21371] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2164), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2162), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(857), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [21447] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2168), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2166), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(859), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [21523] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2172), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2170), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(861), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [21599] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2176), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2174), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(862), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [21675] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2180), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2178), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(863), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [21751] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2184), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2182), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(864), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [21827] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2188), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2186), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(866), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [21903] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2192), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2190), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(869), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [21979] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2196), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2194), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(874), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [22055] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2200), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2198), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(878), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [22131] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2204), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2202), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(879), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [22207] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2208), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2206), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(880), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [22283] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2212), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2210), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(935), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [22359] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2216), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2214), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(882), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [22435] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(1400), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1398), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(883), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [22511] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2220), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2218), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(884), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [22587] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2224), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2222), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(825), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [22663] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2228), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2226), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(885), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [22739] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2232), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2230), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(886), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [22815] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2236), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2234), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(887), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [22891] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2240), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2238), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(888), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [22967] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2244), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2242), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(889), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [23043] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2248), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2246), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(890), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [23119] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2252), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2250), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(891), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [23195] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2256), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2254), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(892), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [23271] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2260), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2258), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(893), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [23347] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2264), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2262), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(894), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [23423] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2268), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2266), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(895), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [23499] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2272), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2270), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(896), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [23575] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2276), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2274), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(897), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [23651] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2280), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2278), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(898), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [23727] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2284), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2282), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(899), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [23803] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2288), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2286), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(900), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [23879] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2292), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2290), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(901), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [23955] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2296), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2294), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(902), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [24031] = 17,
    ACTIONS(856), 1,
      anon_sym_LPAREN,
    ACTIONS(864), 1,
      anon_sym_BANG2,
    ACTIONS(874), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1002), 1,
      anon_sym_a_COLON,
    ACTIONS(1004), 1,
      anon_sym_LBRACE,
    ACTIONS(1008), 1,
      aux_sym_identifier_token1,
    ACTIONS(1010), 1,
      anon_sym_AMP,
    ACTIONS(1014), 1,
      anon_sym_DOLLAR,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      sym__scope_dict,
    ACTIONS(1026), 1,
      sym_scope,
    ACTIONS(2300), 1,
      sym_integer_literal,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(858), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2298), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(571), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [24107] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(2304), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2302), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(685), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [24183] = 17,
    ACTIONS(1254), 1,
      anon_sym_a_COLON,
    ACTIONS(1256), 1,
      anon_sym_LBRACE,
    ACTIONS(1258), 1,
      aux_sym_identifier_token1,
    ACTIONS(1260), 1,
      anon_sym_AMP,
    ACTIONS(1262), 1,
      anon_sym_LPAREN,
    ACTIONS(1266), 1,
      anon_sym_DOLLAR,
    ACTIONS(1268), 1,
      anon_sym_BANG2,
    ACTIONS(1274), 1,
      anon_sym_LBRACK,
    ACTIONS(1276), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1278), 1,
      sym__scope_dict,
    ACTIONS(1280), 1,
      sym_scope,
    ACTIONS(2308), 1,
      sym_integer_literal,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1264), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2306), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(686), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [24259] = 17,
    ACTIONS(1144), 1,
      anon_sym_a_COLON,
    ACTIONS(1146), 1,
      anon_sym_LBRACE,
    ACTIONS(1148), 1,
      aux_sym_identifier_token1,
    ACTIONS(1150), 1,
      anon_sym_AMP,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_DOLLAR,
    ACTIONS(1160), 1,
      anon_sym_BANG2,
    ACTIONS(1166), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_POUND_LBRACE,
    ACTIONS(1170), 1,
      sym__scope_dict,
    ACTIONS(1172), 1,
      sym_scope,
    ACTIONS(2312), 1,
      sym_integer_literal,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1154), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2310), 3,
      sym_string_literal,
      sym_float_literal,
      sym_register,
    STATE(689), 21,
      sym_scope_dict,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym__variable,
      sym__expression,
      sym_ternary_expression,
      sym_binary_operation,
      sym_unary_operation,
      sym_list,
      sym_index_expression,
      sym_slice_expression,
      sym_field_expression,
      sym_call_expression,
      sym_method_expression,
      sym_env_variable,
      sym_option,
      sym_dictionnary,
      sym_literal_dictionary,
      sym_lambda_expression,
  [24335] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1751), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1749), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [24382] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1747), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1745), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [24429] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1755), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1753), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [24476] = 7,
    ACTIONS(2314), 1,
      anon_sym_LPAREN,
    ACTIONS(2316), 1,
      anon_sym_DOT2,
    ACTIONS(2319), 1,
      anon_sym_LBRACK,
    ACTIONS(2321), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1759), 10,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1757), 24,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [24531] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1884), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1882), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [24578] = 8,
    ACTIONS(2314), 1,
      anon_sym_LPAREN,
    ACTIONS(2319), 1,
      anon_sym_LBRACK,
    ACTIONS(2321), 1,
      anon_sym_DASH_GT,
    ACTIONS(2325), 1,
      anon_sym_DOT2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2323), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1759), 10,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1757), 21,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [24635] = 10,
    ACTIONS(2314), 1,
      anon_sym_LPAREN,
    ACTIONS(2319), 1,
      anon_sym_LBRACK,
    ACTIONS(2321), 1,
      anon_sym_DASH_GT,
    ACTIONS(2325), 1,
      anon_sym_DOT2,
    ACTIONS(2329), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2327), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2323), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1759), 8,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1757), 20,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [24696] = 13,
    ACTIONS(2314), 1,
      anon_sym_LPAREN,
    ACTIONS(2319), 1,
      anon_sym_LBRACK,
    ACTIONS(2321), 1,
      anon_sym_DASH_GT,
    ACTIONS(2325), 1,
      anon_sym_DOT2,
    ACTIONS(2329), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2333), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2327), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2323), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1759), 4,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(2331), 4,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(2335), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1757), 13,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_PIPE_PIPE,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [24763] = 12,
    ACTIONS(2314), 1,
      anon_sym_LPAREN,
    ACTIONS(2319), 1,
      anon_sym_LBRACK,
    ACTIONS(2321), 1,
      anon_sym_DASH_GT,
    ACTIONS(2325), 1,
      anon_sym_DOT2,
    ACTIONS(2329), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2327), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2323), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1759), 4,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(2331), 4,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(2335), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1757), 14,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [24828] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1784), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1782), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [24875] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1788), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1786), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [24922] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1792), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1790), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [24969] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1796), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1794), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25016] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1800), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1798), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25063] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1804), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1802), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25110] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1812), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1810), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25157] = 10,
    ACTIONS(2314), 1,
      anon_sym_LPAREN,
    ACTIONS(2319), 1,
      anon_sym_LBRACK,
    ACTIONS(2321), 1,
      anon_sym_DASH_GT,
    ACTIONS(2325), 1,
      anon_sym_DOT2,
    ACTIONS(2329), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2327), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2323), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1816), 8,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1814), 20,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25218] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1888), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1886), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25265] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1892), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1890), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25312] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1820), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1818), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25359] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1824), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1822), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25406] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1828), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1826), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25453] = 5,
    ACTIONS(1608), 1,
      aux_sym_identifier_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1604), 5,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
    ACTIONS(1606), 12,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1610), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [25504] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1832), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1830), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25551] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1743), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1741), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25598] = 15,
    ACTIONS(2314), 1,
      anon_sym_LPAREN,
    ACTIONS(2319), 1,
      anon_sym_LBRACK,
    ACTIONS(2321), 1,
      anon_sym_DASH_GT,
    ACTIONS(2325), 1,
      anon_sym_DOT2,
    ACTIONS(2329), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2333), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2337), 1,
      anon_sym_QMARK,
    ACTIONS(2339), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2327), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2323), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1862), 4,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(2331), 4,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(2335), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1860), 11,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_DOLLAR,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25669] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1842), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1840), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25716] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1896), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1894), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25763] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1924), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1922), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25810] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1900), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1898), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25857] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1846), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1844), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25904] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1940), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1938), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25951] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1850), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1848), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [25998] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1904), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1902), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26045] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1854), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1852), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26092] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1858), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1856), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26139] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1928), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1926), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26186] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1916), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1914), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26233] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1920), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1918), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26280] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1678), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1676), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26327] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1872), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1870), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26374] = 7,
    ACTIONS(2314), 1,
      anon_sym_LPAREN,
    ACTIONS(2319), 1,
      anon_sym_LBRACK,
    ACTIONS(2321), 1,
      anon_sym_DASH_GT,
    ACTIONS(2341), 1,
      anon_sym_DOT2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1686), 10,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1684), 24,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26429] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1876), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1874), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26476] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1699), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1697), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26523] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1703), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1701), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26570] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1739), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1737), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26617] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1727), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1725), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26664] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1318), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1312), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26711] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1880), 11,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(1878), 27,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOLLAR,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      sym_float_literal,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26758] = 14,
    ACTIONS(2314), 1,
      anon_sym_LPAREN,
    ACTIONS(2319), 1,
      anon_sym_LBRACK,
    ACTIONS(2321), 1,
      anon_sym_DASH_GT,
    ACTIONS(2325), 1,
      anon_sym_DOT2,
    ACTIONS(2329), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2333), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2339), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2327), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2323), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1836), 4,
      aux_sym_identifier_token1,
      anon_sym_AMP,
      anon_sym_BANG2,
      sym_integer_literal,
    ACTIONS(2331), 4,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(2335), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(1834), 12,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_DOLLAR,
      sym_float_literal,
      sym_register,
      anon_sym_POUND_LBRACE,
  [26827] = 6,
    ACTIONS(2348), 1,
      anon_sym_custom,
    ACTIONS(2350), 1,
      anon_sym_customlist,
    STATE(1594), 1,
      sym__command_attribute_completion_behavior,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2346), 2,
      anon_sym_file2,
      anon_sym_tag,
    ACTIONS(2344), 32,
      anon_sym_arglist,
      anon_sym_augroup,
      anon_sym_buffer2,
      anon_sym_behave,
      anon_sym_color,
      anon_sym_command,
      anon_sym_compiler,
      anon_sym_dir,
      anon_sym_environment,
      anon_sym_even,
      anon_sym_expression,
      anon_sym_file_in_path,
      anon_sym_filetype,
      anon_sym_function,
      anon_sym_help,
      anon_sym_highlight,
      anon_sym_history,
      anon_sym_local,
      anon_sym_lua,
      anon_sym_mapclear,
      anon_sym_mapping,
      anon_sym_menu,
      anon_sym_messages,
      anon_sym_option,
      anon_sym_packadd,
      anon_sym_shellcmd,
      anon_sym_sign,
      anon_sym_syntax,
      anon_sym_syntime,
      anon_sym_tag_listfiles,
      anon_sym_user,
      anon_sym_var,
  [26879] = 6,
    ACTIONS(2352), 1,
      anon_sym_LBRACE2,
    ACTIONS(2354), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(511), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1064), 12,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1062), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [26930] = 6,
    ACTIONS(2352), 1,
      anon_sym_LBRACE2,
    ACTIONS(2356), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(512), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(904), 12,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(902), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [26981] = 6,
    ACTIONS(2358), 1,
      anon_sym_LBRACE2,
    ACTIONS(2361), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(512), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(912), 12,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(910), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [27032] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1322), 13,
      anon_sym_EQ,
      aux_sym_identifier_token2,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1320), 21,
      anon_sym_LBRACE2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [27075] = 8,
    ACTIONS(2364), 1,
      anon_sym_EQ,
    ACTIONS(2368), 1,
      anon_sym_EQ_LT_LT,
    STATE(382), 1,
      sym__let_operator,
    STATE(2575), 1,
      sym__let_heredoc,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2366), 7,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
    ACTIONS(2372), 10,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2370), 13,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [27128] = 8,
    ACTIONS(2374), 1,
      anon_sym_EQ,
    ACTIONS(2378), 1,
      anon_sym_EQ_LT_LT,
    STATE(376), 1,
      sym__let_operator,
    STATE(2798), 1,
      sym__let_heredoc,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2376), 7,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
    ACTIONS(2382), 10,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2380), 13,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [27181] = 8,
    ACTIONS(2374), 1,
      anon_sym_EQ,
    ACTIONS(2378), 1,
      anon_sym_EQ_LT_LT,
    STATE(376), 1,
      sym__let_operator,
    STATE(2798), 1,
      sym__let_heredoc,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2376), 7,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
    ACTIONS(2372), 10,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2370), 13,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [27234] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1338), 13,
      anon_sym_EQ,
      aux_sym_identifier_token2,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1336), 21,
      anon_sym_LBRACE2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [27277] = 30,
    ACTIONS(2388), 1,
      anon_sym_list,
    ACTIONS(2390), 1,
      anon_sym_clear,
    ACTIONS(2392), 1,
      anon_sym_case,
    ACTIONS(2394), 1,
      anon_sym_match,
    ACTIONS(2396), 1,
      anon_sym_spell,
    ACTIONS(2398), 1,
      anon_sym_foldlevel,
    ACTIONS(2400), 1,
      anon_sym_iskeyword,
    ACTIONS(2402), 1,
      anon_sym_conceal,
    ACTIONS(2404), 1,
      anon_sym_keyword,
    ACTIONS(2406), 1,
      anon_sym_region,
    ACTIONS(2408), 1,
      anon_sym_cluster,
    ACTIONS(2410), 1,
      anon_sym_include,
    ACTIONS(2412), 1,
      anon_sym_sync,
    STATE(2367), 1,
      sym__syn_case,
    STATE(2380), 1,
      sym__syn_enable,
    STATE(2387), 1,
      sym__syn_spell,
    STATE(2390), 1,
      sym__syn_foldlevel,
    STATE(2392), 1,
      sym__syn_iskeyword,
    STATE(2393), 1,
      sym__syn_conceal,
    STATE(2394), 1,
      sym__syn_keyword,
    STATE(2395), 1,
      sym__syn_match,
    STATE(2396), 1,
      sym__syn_region,
    STATE(2397), 1,
      sym__syn_cluster,
    STATE(2398), 1,
      sym__syn_include,
    STATE(2399), 1,
      sym__syn_sync,
    STATE(2400), 1,
      sym__syn_list,
    STATE(2401), 1,
      sym__syn_clear,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2386), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2384), 4,
      anon_sym_on,
      anon_sym_off,
      anon_sym_enable,
      anon_sym_reset,
  [27374] = 8,
    ACTIONS(2364), 1,
      anon_sym_EQ,
    ACTIONS(2368), 1,
      anon_sym_EQ_LT_LT,
    STATE(382), 1,
      sym__let_operator,
    STATE(2575), 1,
      sym__let_heredoc,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2366), 7,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
    ACTIONS(2382), 10,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2380), 13,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [27427] = 6,
    ACTIONS(2414), 1,
      anon_sym_LBRACE2,
    ACTIONS(2417), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(520), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(912), 6,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(910), 23,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [27475] = 6,
    ACTIONS(2420), 1,
      anon_sym_LBRACE2,
    ACTIONS(2422), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(523), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1064), 6,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1062), 23,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [27523] = 30,
    ACTIONS(2426), 1,
      anon_sym_list,
    ACTIONS(2428), 1,
      anon_sym_clear,
    ACTIONS(2430), 1,
      anon_sym_case,
    ACTIONS(2432), 1,
      anon_sym_match,
    ACTIONS(2434), 1,
      anon_sym_spell,
    ACTIONS(2436), 1,
      anon_sym_foldlevel,
    ACTIONS(2438), 1,
      anon_sym_iskeyword,
    ACTIONS(2440), 1,
      anon_sym_conceal,
    ACTIONS(2442), 1,
      anon_sym_keyword,
    ACTIONS(2444), 1,
      anon_sym_region,
    ACTIONS(2446), 1,
      anon_sym_cluster,
    ACTIONS(2448), 1,
      anon_sym_include,
    ACTIONS(2450), 1,
      anon_sym_sync,
    STATE(2784), 1,
      sym__syn_iskeyword,
    STATE(2785), 1,
      sym__syn_conceal,
    STATE(2794), 1,
      sym__syn_keyword,
    STATE(2796), 1,
      sym__syn_match,
    STATE(2797), 1,
      sym__syn_region,
    STATE(2800), 1,
      sym__syn_cluster,
    STATE(2802), 1,
      sym__syn_include,
    STATE(2803), 1,
      sym__syn_sync,
    STATE(2807), 1,
      sym__syn_list,
    STATE(2809), 1,
      sym__syn_clear,
    STATE(2812), 1,
      sym__syn_enable,
    STATE(2916), 1,
      sym__syn_case,
    STATE(2922), 1,
      sym__syn_spell,
    STATE(2950), 1,
      sym__syn_foldlevel,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2386), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2424), 4,
      anon_sym_on,
      anon_sym_off,
      anon_sym_enable,
      anon_sym_reset,
  [27619] = 6,
    ACTIONS(2420), 1,
      anon_sym_LBRACE2,
    ACTIONS(2452), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(520), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(904), 6,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(902), 23,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [27667] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1916), 11,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1914), 21,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [27708] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1892), 11,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1890), 21,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [27749] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1920), 11,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1918), 21,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [27790] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1884), 11,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1882), 21,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [27831] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1940), 11,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1938), 21,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [27872] = 5,
    ACTIONS(2454), 1,
      aux_sym_argument_token1,
    ACTIONS(2456), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1318), 7,
      aux_sym_identifier_token1,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1312), 23,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [27917] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1872), 11,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1870), 21,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [27958] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1900), 11,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1898), 21,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [27999] = 5,
    ACTIONS(2458), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2460), 8,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
    ACTIONS(1743), 10,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1741), 13,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [28044] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1876), 11,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1874), 21,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [28085] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1896), 11,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1894), 21,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [28126] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1928), 11,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1926), 21,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [28167] = 5,
    ACTIONS(2462), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2464), 8,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
    ACTIONS(1699), 10,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1697), 13,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [28212] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1904), 11,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1902), 21,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [28253] = 5,
    ACTIONS(2466), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2468), 8,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
    ACTIONS(1796), 10,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1794), 13,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [28298] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1888), 11,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1886), 21,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [28339] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1924), 11,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1922), 21,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [28380] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1880), 11,
      anon_sym_EQ,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_DOT2,
      anon_sym_PLUS,
      anon_sym_LT2,
      anon_sym_STAR2,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1878), 21,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [28421] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1338), 7,
      aux_sym_identifier_token2,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1336), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_LBRACE2,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [28461] = 5,
    ACTIONS(2470), 1,
      aux_sym_argument_token1,
    ACTIONS(2472), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1318), 6,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1312), 23,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [28505] = 5,
    ACTIONS(2454), 1,
      aux_sym_argument_token1,
    ACTIONS(2456), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1318), 7,
      aux_sym_identifier_token1,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1312), 22,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [28549] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1322), 7,
      aux_sym_identifier_token2,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1320), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_LBRACE2,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [28589] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1916), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1914), 25,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [28628] = 5,
    STATE(839), 1,
      sym__syn_pattern_offset,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2476), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2478), 7,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
    ACTIONS(2474), 20,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [28671] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1924), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1922), 25,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [28710] = 5,
    ACTIONS(1608), 1,
      aux_sym_identifier_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1604), 6,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2382), 6,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(2380), 17,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [28753] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2482), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(2480), 27,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
      anon_sym_end,
  [28792] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1920), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1918), 25,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [28831] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1318), 7,
      aux_sym_identifier_token1,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1312), 23,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [28870] = 6,
    ACTIONS(2484), 1,
      anon_sym_LBRACE2,
    ACTIONS(2487), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(553), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(912), 6,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(910), 20,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [28915] = 6,
    ACTIONS(2490), 1,
      anon_sym_LBRACE2,
    ACTIONS(2492), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(553), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(904), 6,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(902), 20,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [28960] = 6,
    ACTIONS(2490), 1,
      anon_sym_LBRACE2,
    ACTIONS(2494), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(554), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1064), 6,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1062), 20,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [29005] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1727), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1725), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29043] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1699), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1697), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29081] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1703), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1701), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29119] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1318), 7,
      aux_sym_identifier_token1,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1312), 22,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [29157] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1928), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1926), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29195] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1788), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1786), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29233] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1792), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1790), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29271] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1796), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1794), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29309] = 5,
    ACTIONS(1608), 1,
      aux_sym_identifier_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1604), 5,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
    ACTIONS(2382), 6,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(2380), 17,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [29351] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1940), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1938), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29389] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1800), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1798), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29427] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1804), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1802), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29465] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1678), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1676), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29503] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1318), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1312), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29541] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1812), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1810), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29579] = 10,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(1816), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1814), 16,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_RBRACK,
  [29631] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1888), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1886), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29669] = 13,
    ACTIONS(2514), 1,
      anon_sym_cchar,
    ACTIONS(2516), 1,
      anon_sym_contained,
    ACTIONS(2520), 1,
      anon_sym_contains,
    STATE(955), 1,
      sym__syn_pattern_offset,
    STATE(1000), 1,
      aux_sym__syn_match_repeat1,
    STATE(1050), 1,
      sym__syn_arguments_match,
    STATE(1061), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2518), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2510), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2512), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2522), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
    ACTIONS(2524), 7,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
  [29727] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1892), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1890), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29765] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1880), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1878), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29803] = 13,
    ACTIONS(2514), 1,
      anon_sym_cchar,
    ACTIONS(2516), 1,
      anon_sym_contained,
    ACTIONS(2520), 1,
      anon_sym_contains,
    STATE(944), 1,
      sym__syn_pattern_offset,
    STATE(980), 1,
      aux_sym__syn_match_repeat1,
    STATE(1050), 1,
      sym__syn_arguments_match,
    STATE(1061), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2518), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2526), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2512), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2522), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
    ACTIONS(2524), 7,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
  [29861] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1739), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1737), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29899] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1743), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1741), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29937] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1858), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1856), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [29975] = 6,
    ACTIONS(2528), 1,
      anon_sym_LBRACE2,
    ACTIONS(2530), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(582), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1064), 6,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1062), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [30019] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1751), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1749), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [30057] = 6,
    ACTIONS(2528), 1,
      anon_sym_LBRACE2,
    ACTIONS(2532), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(585), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(904), 6,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(902), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [30101] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1755), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1753), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [30139] = 7,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2534), 1,
      anon_sym_DOT2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1759), 4,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1757), 21,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_RBRACK,
  [30185] = 6,
    ACTIONS(2537), 1,
      anon_sym_LBRACE2,
    ACTIONS(2540), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(585), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(912), 6,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(910), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [30229] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1884), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1882), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [30267] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1820), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1818), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [30305] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1824), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1822), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [30343] = 8,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1759), 4,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1757), 18,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_RBRACK,
  [30391] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1828), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1826), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [30429] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1832), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1830), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [30467] = 10,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(1759), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1757), 16,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_RBRACK,
  [30519] = 13,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1834), 7,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [30577] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1842), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1840), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [30615] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1896), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1894), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [30653] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1900), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1898), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [30691] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1872), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1870), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [30729] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1846), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1844), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [30767] = 12,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
    ACTIONS(1757), 8,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
  [30823] = 11,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
    ACTIONS(1757), 9,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
  [30877] = 7,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2551), 1,
      anon_sym_DOT2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1686), 4,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1684), 21,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_RBRACK,
  [30923] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1850), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1848), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [30961] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1904), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1902), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [30999] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1784), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1782), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [31037] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1854), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1852), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [31075] = 5,
    STATE(951), 1,
      sym__syn_pattern_offset,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2476), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2554), 7,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
    ACTIONS(2474), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [31117] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1876), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1874), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [31155] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1747), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1745), 24,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_SEMI,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DASH_GT,
  [31193] = 5,
    ACTIONS(2556), 1,
      anon_sym_COMMA,
    STATE(611), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2560), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(2558), 23,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_start,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_add,
      anon_sym_remove,
      anon_sym_end,
  [31234] = 13,
    ACTIONS(2564), 1,
      anon_sym_cchar,
    ACTIONS(2566), 1,
      anon_sym_contained,
    ACTIONS(2570), 1,
      anon_sym_contains,
    STATE(973), 1,
      sym__syn_pattern_offset,
    STATE(1018), 1,
      aux_sym__syn_match_repeat1,
    STATE(1119), 1,
      sym__syn_arguments_match,
    STATE(1122), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2526), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2568), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2562), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2572), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
    ACTIONS(2574), 7,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
  [31291] = 5,
    ACTIONS(2556), 1,
      anon_sym_COMMA,
    STATE(613), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2578), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(2576), 23,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_start,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_add,
      anon_sym_remove,
      anon_sym_end,
  [31332] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2482), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2480), 26,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
      anon_sym_end,
  [31369] = 5,
    ACTIONS(2580), 1,
      anon_sym_COMMA,
    STATE(613), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2585), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(2583), 23,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_start,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_add,
      anon_sym_remove,
      anon_sym_end,
  [31410] = 5,
    ACTIONS(2587), 1,
      aux_sym_argument_token1,
    ACTIONS(2589), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1318), 6,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1312), 20,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [31451] = 13,
    ACTIONS(2564), 1,
      anon_sym_cchar,
    ACTIONS(2566), 1,
      anon_sym_contained,
    ACTIONS(2570), 1,
      anon_sym_contains,
    STATE(962), 1,
      sym__syn_pattern_offset,
    STATE(1014), 1,
      aux_sym__syn_match_repeat1,
    STATE(1119), 1,
      sym__syn_arguments_match,
    STATE(1122), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2510), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2568), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2562), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2572), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
    ACTIONS(2574), 7,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
  [31508] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1322), 7,
      aux_sym_identifier_token2,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1320), 21,
      anon_sym_LBRACE2,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [31545] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1338), 7,
      aux_sym_identifier_token2,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1336), 21,
      anon_sym_LBRACE2,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [31582] = 5,
    STATE(968), 1,
      sym__syn_pattern_offset,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2591), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(2478), 7,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
    ACTIONS(2593), 17,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [31623] = 18,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2603), 1,
      anon_sym_contains,
    ACTIONS(2607), 1,
      anon_sym_matchgroup,
    ACTIONS(2611), 1,
      anon_sym_skip,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(768), 1,
      sym__syn_region_skip,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(923), 1,
      aux_sym__syn_region_repeat1,
    STATE(2014), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2599), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [31689] = 6,
    ACTIONS(2615), 1,
      anon_sym_COMMA,
    ACTIONS(2617), 1,
      anon_sym_DASH_GT,
    STATE(2744), 1,
      aux_sym_parameters_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1606), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1610), 19,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
  [31731] = 17,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(2624), 1,
      anon_sym_SEMI,
    ACTIONS(2626), 1,
      anon_sym_RBRACK,
    STATE(2353), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [31795] = 18,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2603), 1,
      anon_sym_contains,
    ACTIONS(2607), 1,
      anon_sym_matchgroup,
    ACTIONS(2611), 1,
      anon_sym_skip,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(619), 1,
      aux_sym__syn_region_repeat1,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(762), 1,
      sym__syn_region_skip,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2115), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2599), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [31861] = 6,
    ACTIONS(2615), 1,
      anon_sym_COMMA,
    ACTIONS(2628), 1,
      anon_sym_DASH_GT,
    STATE(2505), 1,
      aux_sym_parameters_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1606), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1610), 19,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
  [31903] = 6,
    ACTIONS(2615), 1,
      anon_sym_COMMA,
    ACTIONS(2631), 1,
      anon_sym_DASH_GT,
    STATE(2745), 1,
      aux_sym_parameters_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1606), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1610), 19,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
  [31945] = 18,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2603), 1,
      anon_sym_contains,
    ACTIONS(2607), 1,
      anon_sym_matchgroup,
    ACTIONS(2611), 1,
      anon_sym_skip,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(626), 1,
      aux_sym__syn_region_repeat1,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(769), 1,
      sym__syn_region_skip,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2016), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2599), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [32011] = 18,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2603), 1,
      anon_sym_contains,
    ACTIONS(2607), 1,
      anon_sym_matchgroup,
    ACTIONS(2611), 1,
      anon_sym_skip,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(773), 1,
      sym__syn_region_skip,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(923), 1,
      aux_sym__syn_region_repeat1,
    STATE(2048), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2599), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [32077] = 18,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2603), 1,
      anon_sym_contains,
    ACTIONS(2607), 1,
      anon_sym_matchgroup,
    ACTIONS(2611), 1,
      anon_sym_skip,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(813), 1,
      sym__syn_region_skip,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(923), 1,
      aux_sym__syn_region_repeat1,
    STATE(2195), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2599), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [32143] = 18,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2603), 1,
      anon_sym_contains,
    ACTIONS(2607), 1,
      anon_sym_matchgroup,
    ACTIONS(2611), 1,
      anon_sym_skip,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(634), 1,
      aux_sym__syn_region_repeat1,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(814), 1,
      sym__syn_region_skip,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2171), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2599), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [32209] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1338), 7,
      aux_sym_identifier_token2,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1336), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_LBRACE2,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [32245] = 17,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2624), 1,
      anon_sym_SEMI,
    ACTIONS(2636), 1,
      anon_sym_COMMA,
    ACTIONS(2638), 1,
      anon_sym_RBRACK,
    STATE(2333), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [32309] = 5,
    ACTIONS(2640), 1,
      aux_sym_argument_token1,
    ACTIONS(2642), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1318), 6,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1312), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [32349] = 18,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2603), 1,
      anon_sym_contains,
    ACTIONS(2607), 1,
      anon_sym_matchgroup,
    ACTIONS(2611), 1,
      anon_sym_skip,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(627), 1,
      aux_sym__syn_region_repeat1,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(824), 1,
      sym__syn_region_skip,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2162), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2599), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [32415] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1322), 7,
      aux_sym_identifier_token2,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
      anon_sym_isnot,
    ACTIONS(1320), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_LBRACE2,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [32451] = 18,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2603), 1,
      anon_sym_contains,
    ACTIONS(2607), 1,
      anon_sym_matchgroup,
    ACTIONS(2611), 1,
      anon_sym_skip,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(823), 1,
      sym__syn_region_skip,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(923), 1,
      aux_sym__syn_region_repeat1,
    STATE(2136), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2599), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [32517] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2644), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [32575] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2585), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(2583), 24,
      anon_sym_COMMA,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_start,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_add,
      anon_sym_remove,
      anon_sym_end,
  [32611] = 5,
    STATE(994), 1,
      sym__syn_pattern_offset,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2646), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2478), 7,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
    ACTIONS(2648), 17,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [32651] = 6,
    ACTIONS(2615), 1,
      anon_sym_COMMA,
    ACTIONS(2650), 1,
      anon_sym_DASH_GT,
    STATE(2739), 1,
      aux_sym_parameters_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1606), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1610), 19,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
  [32693] = 6,
    ACTIONS(2615), 1,
      anon_sym_COMMA,
    ACTIONS(2653), 1,
      anon_sym_DASH_GT,
    STATE(2742), 1,
      aux_sym_parameters_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1606), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1610), 19,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
  [32735] = 16,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(2656), 1,
      anon_sym_RPAREN,
    STATE(2644), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [32796] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1820), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1818), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [32831] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1824), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1822), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [32866] = 14,
    ACTIONS(2658), 1,
      anon_sym_QMARK,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2664), 1,
      anon_sym_DOT2,
    ACTIONS(2672), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2674), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2676), 1,
      anon_sym_DASH,
    ACTIONS(2680), 1,
      anon_sym_LBRACK,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2666), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2662), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2668), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2670), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2678), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [32923] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1828), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1826), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [32958] = 16,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2684), 1,
      anon_sym_COMMA,
    ACTIONS(2686), 1,
      anon_sym_RBRACK,
    STATE(2536), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [33019] = 14,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(651), 1,
      aux_sym__syn_region_repeat1,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2688), 4,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_end,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [33076] = 6,
    ACTIONS(2615), 1,
      anon_sym_COMMA,
    ACTIONS(2696), 1,
      anon_sym_DASH_GT,
    STATE(2709), 1,
      aux_sym_parameters_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1606), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1610), 18,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
  [33117] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1832), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1830), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [33152] = 16,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(2699), 1,
      anon_sym_RPAREN,
    STATE(2553), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [33213] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1318), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1312), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [33248] = 14,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(662), 1,
      aux_sym__syn_region_repeat1,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2701), 4,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_end,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [33305] = 13,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2664), 1,
      anon_sym_DOT2,
    ACTIONS(2672), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2674), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2676), 1,
      anon_sym_DASH,
    ACTIONS(2680), 1,
      anon_sym_LBRACK,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2666), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2662), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2668), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1834), 4,
      anon_sym_QMARK,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2678), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [33360] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1784), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1782), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [33395] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1928), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1926), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [33430] = 16,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2636), 1,
      anon_sym_COMMA,
    ACTIONS(2703), 1,
      anon_sym_RBRACK,
    STATE(2515), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [33491] = 16,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(2705), 1,
      anon_sym_RPAREN,
    STATE(2569), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [33552] = 14,
    ACTIONS(2658), 1,
      anon_sym_QMARK,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2664), 1,
      anon_sym_DOT2,
    ACTIONS(2672), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2674), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2676), 1,
      anon_sym_DASH,
    ACTIONS(2680), 1,
      anon_sym_LBRACK,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2666), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2662), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2668), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2707), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2678), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [33609] = 16,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2709), 1,
      anon_sym_COMMA,
    ACTIONS(2711), 1,
      anon_sym_RBRACK,
    STATE(2583), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [33670] = 16,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(2713), 1,
      anon_sym_RPAREN,
    STATE(2590), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [33731] = 15,
    ACTIONS(2715), 1,
      anon_sym_QMARK,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2727), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    STATE(13), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2739), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [33790] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1842), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1840), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [33825] = 14,
    ACTIONS(2746), 1,
      anon_sym_cchar,
    ACTIONS(2755), 1,
      anon_sym_contains,
    ACTIONS(2761), 1,
      anon_sym_matchgroup,
    STATE(662), 1,
      aux_sym__syn_region_repeat1,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2743), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2749), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2764), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2741), 4,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_end,
    ACTIONS(2752), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2758), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [33882] = 16,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(2767), 1,
      anon_sym_RPAREN,
    STATE(2594), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [33943] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1846), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1844), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [33978] = 16,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2769), 1,
      anon_sym_COMMA,
    ACTIONS(2771), 1,
      anon_sym_RBRACK,
    STATE(2615), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [34039] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1747), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1745), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [34074] = 15,
    ACTIONS(2715), 1,
      anon_sym_QMARK,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2727), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    STATE(26), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2773), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [34133] = 16,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(2775), 1,
      anon_sym_RPAREN,
    STATE(2622), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [34194] = 15,
    ACTIONS(2715), 1,
      anon_sym_QMARK,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2727), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    STATE(5), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2777), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [34253] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1850), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1848), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [34288] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1854), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1852), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [34323] = 16,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(2779), 1,
      anon_sym_RPAREN,
    STATE(2627), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [34384] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1858), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1856), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [34419] = 16,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2781), 1,
      anon_sym_COMMA,
    ACTIONS(2783), 1,
      anon_sym_RBRACK,
    STATE(2637), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [34480] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1727), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1725), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [34515] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1940), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1938), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [34550] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1743), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1741), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [34585] = 16,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(2785), 1,
      anon_sym_RPAREN,
    STATE(2619), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [34646] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1751), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1749), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [34681] = 16,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(2787), 1,
      anon_sym_RPAREN,
    STATE(2648), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [34742] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1788), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1786), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [34777] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1792), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1790), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [34812] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1796), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1794), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [34847] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1920), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1918), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [34882] = 15,
    ACTIONS(2715), 1,
      anon_sym_QMARK,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2727), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    STATE(43), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2789), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [34941] = 15,
    ACTIONS(2715), 1,
      anon_sym_QMARK,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2727), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    STATE(7), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2791), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [35000] = 14,
    ACTIONS(2658), 1,
      anon_sym_QMARK,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2664), 1,
      anon_sym_DOT2,
    ACTIONS(2672), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2674), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2676), 1,
      anon_sym_DASH,
    ACTIONS(2680), 1,
      anon_sym_LBRACK,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2666), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2662), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2668), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2793), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2678), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [35057] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1872), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1870), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [35092] = 14,
    ACTIONS(2658), 1,
      anon_sym_QMARK,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2664), 1,
      anon_sym_DOT2,
    ACTIONS(2672), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2674), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2676), 1,
      anon_sym_DASH,
    ACTIONS(2680), 1,
      anon_sym_LBRACK,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2666), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2662), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2668), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2795), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2678), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [35149] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1876), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1874), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [35184] = 14,
    ACTIONS(2658), 1,
      anon_sym_QMARK,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2664), 1,
      anon_sym_DOT2,
    ACTIONS(2672), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2674), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2676), 1,
      anon_sym_DASH,
    ACTIONS(2680), 1,
      anon_sym_LBRACK,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2666), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2662), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2668), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2797), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2678), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [35241] = 15,
    ACTIONS(2715), 1,
      anon_sym_QMARK,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2727), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    STATE(50), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2799), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [35300] = 7,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2680), 1,
      anon_sym_LBRACK,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(2801), 1,
      anon_sym_DOT2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1759), 4,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1757), 18,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [35343] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1880), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1878), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [35378] = 4,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2804), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2372), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2370), 18,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [35415] = 14,
    ACTIONS(2658), 1,
      anon_sym_QMARK,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2664), 1,
      anon_sym_DOT2,
    ACTIONS(2672), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2674), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2676), 1,
      anon_sym_DASH,
    ACTIONS(2680), 1,
      anon_sym_LBRACK,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2666), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2662), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2668), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2806), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2678), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [35472] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1739), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1737), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [35507] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1800), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1798), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [35542] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1884), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1882), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [35577] = 16,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(2808), 1,
      anon_sym_RPAREN,
    STATE(2450), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [35638] = 8,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2664), 1,
      anon_sym_DOT2,
    ACTIONS(2680), 1,
      anon_sym_LBRACK,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2662), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1759), 4,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1757), 15,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [35683] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1888), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1886), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [35718] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1892), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1890), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [35753] = 10,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2664), 1,
      anon_sym_DOT2,
    ACTIONS(2676), 1,
      anon_sym_DASH,
    ACTIONS(2680), 1,
      anon_sym_LBRACK,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2666), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(1759), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2662), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1757), 13,
      anon_sym_QMARK,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [35802] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1804), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1802), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [35837] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1812), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1810), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [35872] = 15,
    ACTIONS(2715), 1,
      anon_sym_QMARK,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2727), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    STATE(22), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2810), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [35931] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1896), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1894), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [35966] = 10,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2664), 1,
      anon_sym_DOT2,
    ACTIONS(2676), 1,
      anon_sym_DASH,
    ACTIONS(2680), 1,
      anon_sym_LBRACK,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2666), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(1816), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2662), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1814), 13,
      anon_sym_QMARK,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [36015] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1900), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1898), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [36050] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1904), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1902), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [36085] = 12,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2664), 1,
      anon_sym_DOT2,
    ACTIONS(2674), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2676), 1,
      anon_sym_DASH,
    ACTIONS(2680), 1,
      anon_sym_LBRACK,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2666), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2662), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2668), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1757), 5,
      anon_sym_QMARK,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_PIPE_PIPE,
    ACTIONS(2678), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [36138] = 11,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2664), 1,
      anon_sym_DOT2,
    ACTIONS(2676), 1,
      anon_sym_DASH,
    ACTIONS(2680), 1,
      anon_sym_LBRACK,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2666), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2662), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2668), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1757), 6,
      anon_sym_QMARK,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(2678), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [36189] = 14,
    ACTIONS(2658), 1,
      anon_sym_QMARK,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2664), 1,
      anon_sym_DOT2,
    ACTIONS(2672), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2674), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2676), 1,
      anon_sym_DASH,
    ACTIONS(2680), 1,
      anon_sym_LBRACK,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2666), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2662), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2668), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2812), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2678), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [36246] = 4,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2814), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2372), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2370), 18,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [36283] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1678), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1676), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [36318] = 7,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2680), 1,
      anon_sym_LBRACK,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(2816), 1,
      anon_sym_DOT2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1686), 4,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1684), 18,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [36361] = 4,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2814), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2372), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2370), 18,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [36398] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1699), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1697), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [36433] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1703), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1701), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [36468] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1916), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1914), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [36503] = 4,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2819), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2372), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2370), 18,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [36540] = 4,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2819), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2372), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2370), 18,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [36577] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1924), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1922), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [36612] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1755), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1753), 21,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [36647] = 13,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2727), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(1834), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [36701] = 14,
    ACTIONS(2715), 1,
      anon_sym_QMARK,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2727), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2707), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [36757] = 4,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2814), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2372), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2370), 18,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [36793] = 14,
    ACTIONS(2715), 1,
      anon_sym_QMARK,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2727), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2812), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [36849] = 19,
    ACTIONS(2823), 1,
      anon_sym_NONE,
    ACTIONS(2825), 1,
      anon_sym_term,
    ACTIONS(2827), 1,
      anon_sym_cterm,
    ACTIONS(2833), 1,
      anon_sym_gui,
    ACTIONS(2837), 1,
      anon_sym_font,
    ACTIONS(2839), 1,
      anon_sym_blend,
    STATE(1194), 1,
      sym__hl_key_cterm,
    STATE(1195), 1,
      sym__hl_key_start_stop,
    STATE(1196), 1,
      sym__hl_key_ctermfg_ctermbg,
    STATE(1197), 1,
      sym__hl_key_gui,
    STATE(1198), 1,
      sym__hl_key_gui_color,
    STATE(1199), 1,
      sym__hl_key_font,
    STATE(1200), 1,
      sym__hl_key_blend,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2829), 2,
      anon_sym_start,
      anon_sym_stop,
    ACTIONS(2831), 2,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
    STATE(867), 2,
      sym_hl_attribute,
      aux_sym__hl_body_keys_repeat1,
    ACTIONS(2821), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2835), 3,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
  [36915] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1788), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1786), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [36949] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1792), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1790), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [36983] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1796), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1794), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37017] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1800), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1798), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37051] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1804), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1802), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37085] = 14,
    ACTIONS(2715), 1,
      anon_sym_QMARK,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2727), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2806), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [37141] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1812), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1810), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37175] = 10,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(1816), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1814), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [37223] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1888), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1886), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37257] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1892), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1890), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37291] = 4,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2814), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2372), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2370), 18,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37327] = 4,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2819), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2372), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2370), 18,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37363] = 15,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2841), 1,
      anon_sym_COLON,
    ACTIONS(2843), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [37421] = 4,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2819), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2372), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2370), 18,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37457] = 14,
    ACTIONS(2848), 1,
      anon_sym_cchar,
    ACTIONS(2857), 1,
      anon_sym_contains,
    ACTIONS(2863), 1,
      anon_sym_matchgroup,
    STATE(745), 1,
      aux_sym__syn_region_repeat1,
    STATE(992), 1,
      sym__syn_arguments_keyword,
    STATE(996), 1,
      sym__syn_arguments_match,
    STATE(998), 1,
      sym__syn_arguments_region,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2845), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2851), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2866), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2741), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_end,
    ACTIONS(2854), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2860), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [37513] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1820), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1818), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37547] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1824), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1822), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37581] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1828), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1826), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37615] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1832), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1830), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37649] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1842), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1840), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37683] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1896), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1894), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37717] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1900), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1898), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37751] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1846), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1844), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37785] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1916), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1914), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37819] = 15,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2869), 1,
      anon_sym_COLON,
    ACTIONS(2871), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [37877] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1920), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1918), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37911] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1924), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1922), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37945] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1678), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1676), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [37979] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1872), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1870), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [38013] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1850), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1848), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [38047] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1904), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1902), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [38081] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2613), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(767), 1,
      aux_sym__syn_region_repeat1,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2010), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [38141] = 7,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(2873), 1,
      anon_sym_DOT2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1686), 4,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1684), 17,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [38183] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1876), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1874), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [38217] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1854), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1852), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [38251] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1699), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1697), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [38285] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2613), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(662), 1,
      aux_sym__syn_region_repeat1,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2044), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [38345] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2613), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(771), 1,
      aux_sym__syn_region_repeat1,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2046), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [38405] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2613), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(772), 1,
      aux_sym__syn_region_repeat1,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2047), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [38465] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1703), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1701), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [38499] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2613), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(662), 1,
      aux_sym__syn_region_repeat1,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2058), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [38559] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2613), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(662), 1,
      aux_sym__syn_region_repeat1,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2060), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [38619] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2613), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(774), 1,
      aux_sym__syn_region_repeat1,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2061), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [38679] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2613), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(662), 1,
      aux_sym__syn_region_repeat1,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2069), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [38739] = 15,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2841), 1,
      anon_sym_COLON,
    ACTIONS(2876), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [38797] = 5,
    ACTIONS(2878), 1,
      anon_sym_COMMA,
    STATE(776), 1,
      aux_sym__syn_match_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2883), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(2881), 20,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [38835] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2885), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [38891] = 15,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2887), 1,
      anon_sym_COLON,
    ACTIONS(2889), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [38949] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1858), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1856), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [38983] = 15,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2841), 1,
      anon_sym_COLON,
    ACTIONS(2891), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [39041] = 15,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2841), 1,
      anon_sym_COLON,
    ACTIONS(2893), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [39099] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1928), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1926), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [39133] = 15,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2895), 1,
      anon_sym_COLON,
    ACTIONS(2897), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [39191] = 14,
    ACTIONS(2715), 1,
      anon_sym_QMARK,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2727), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2670), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [39247] = 15,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2841), 1,
      anon_sym_COLON,
    ACTIONS(2899), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [39305] = 14,
    ACTIONS(2903), 1,
      anon_sym_cchar,
    ACTIONS(2909), 1,
      anon_sym_contains,
    ACTIONS(2913), 1,
      anon_sym_matchgroup,
    STATE(812), 1,
      aux_sym__syn_region_repeat1,
    STATE(992), 1,
      sym__syn_arguments_keyword,
    STATE(996), 1,
      sym__syn_arguments_match,
    STATE(998), 1,
      sym__syn_arguments_region,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2901), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2905), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2915), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2688), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_end,
    ACTIONS(2907), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2911), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [39361] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2917), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [39417] = 15,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2919), 1,
      anon_sym_COLON,
    ACTIONS(2921), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [39475] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2634), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(662), 1,
      aux_sym__syn_region_repeat1,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2192), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [39535] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1940), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1938), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [39569] = 14,
    ACTIONS(2715), 1,
      anon_sym_QMARK,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2727), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2793), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [39625] = 15,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2841), 1,
      anon_sym_COLON,
    ACTIONS(2923), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [39683] = 14,
    ACTIONS(2715), 1,
      anon_sym_QMARK,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2727), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2797), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [39739] = 15,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2925), 1,
      anon_sym_COLON,
    ACTIONS(2927), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [39797] = 15,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2841), 1,
      anon_sym_COLON,
    ACTIONS(2929), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [39855] = 15,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2841), 1,
      anon_sym_COLON,
    ACTIONS(2931), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [39913] = 14,
    ACTIONS(2715), 1,
      anon_sym_QMARK,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2727), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2795), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [39969] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1318), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1312), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [40003] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1727), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1725), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [40037] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1880), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1878), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [40071] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1739), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1737), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [40105] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1743), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1741), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [40139] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1747), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1745), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [40173] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2933), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [40229] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1751), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1749), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [40263] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1755), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1753), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [40297] = 7,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(2935), 1,
      anon_sym_DOT2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1759), 4,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1757), 17,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [40339] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1884), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1882), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [40373] = 8,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1759), 4,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1757), 14,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [40417] = 10,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(1759), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(1757), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [40465] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2634), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(662), 1,
      aux_sym__syn_region_repeat1,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2181), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [40525] = 14,
    ACTIONS(2903), 1,
      anon_sym_cchar,
    ACTIONS(2909), 1,
      anon_sym_contains,
    ACTIONS(2913), 1,
      anon_sym_matchgroup,
    STATE(745), 1,
      aux_sym__syn_region_repeat1,
    STATE(992), 1,
      sym__syn_arguments_keyword,
    STATE(996), 1,
      sym__syn_arguments_match,
    STATE(998), 1,
      sym__syn_arguments_region,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2901), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2905), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2915), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2701), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_end,
    ACTIONS(2907), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2911), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [40581] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2634), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(821), 1,
      aux_sym__syn_region_repeat1,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2122), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [40641] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2634), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(822), 1,
      aux_sym__syn_region_repeat1,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2168), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [40701] = 3,
    ACTIONS(2482), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2480), 24,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
  [40735] = 15,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2938), 1,
      anon_sym_COLON,
    ACTIONS(2940), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [40793] = 4,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2804), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2372), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2370), 18,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [40829] = 12,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1757), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [40881] = 11,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2721), 1,
      anon_sym_DOT2,
    ACTIONS(2731), 1,
      anon_sym_DASH,
    ACTIONS(2735), 1,
      anon_sym_LBRACK,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2723), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2719), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2725), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1757), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(2733), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [40931] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1784), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(1782), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_QMARK,
      anon_sym_LPAREN,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [40965] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2634), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(662), 1,
      aux_sym__syn_region_repeat1,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2166), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [41025] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2634), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(662), 1,
      aux_sym__syn_region_repeat1,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2179), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [41085] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2634), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(789), 1,
      aux_sym__syn_region_repeat1,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2184), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [41145] = 16,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(2634), 1,
      anon_sym_end,
    ACTIONS(2692), 1,
      anon_sym_contains,
    ACTIONS(2694), 1,
      anon_sym_matchgroup,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(811), 1,
      aux_sym__syn_region_repeat1,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(2146), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(2690), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [41205] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2942), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [41260] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2946), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(2944), 21,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_start,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [41293] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2950), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(2948), 21,
      anon_sym_COMMA,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [41326] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2952), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [41381] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2954), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [41436] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2956), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [41491] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2958), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [41546] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2960), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [41601] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2962), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [41656] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2964), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [41711] = 5,
    ACTIONS(2966), 1,
      anon_sym_LPAREN,
    STATE(2116), 1,
      sym_parameters,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2372), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2370), 17,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [41748] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2968), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [41803] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2970), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [41858] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2972), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [41913] = 5,
    ACTIONS(2974), 1,
      anon_sym_COMMA,
    STATE(840), 1,
      aux_sym__syn_match_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2978), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2976), 20,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [41950] = 5,
    ACTIONS(2974), 1,
      anon_sym_COMMA,
    STATE(776), 1,
      aux_sym__syn_match_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2982), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2980), 20,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [41987] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2841), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [42042] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2984), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [42097] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2986), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [42152] = 5,
    ACTIONS(2966), 1,
      anon_sym_LPAREN,
    STATE(2116), 1,
      sym_parameters,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2382), 5,
      anon_sym_DOT2,
      anon_sym_LT2,
      anon_sym_DASH,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2380), 17,
      anon_sym_QMARK,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_PLUS,
      anon_sym_STAR2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
  [42189] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2988), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [42244] = 5,
    ACTIONS(2992), 1,
      sym_hl_group,
    STATE(906), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2990), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2994), 19,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [42281] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2996), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [42336] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2998), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [42391] = 19,
    ACTIONS(3000), 1,
      anon_sym_NONE,
    ACTIONS(3002), 1,
      anon_sym_term,
    ACTIONS(3004), 1,
      anon_sym_cterm,
    ACTIONS(3010), 1,
      anon_sym_gui,
    ACTIONS(3014), 1,
      anon_sym_font,
    ACTIONS(3016), 1,
      anon_sym_blend,
    STATE(1304), 1,
      sym__hl_key_cterm,
    STATE(1305), 1,
      sym__hl_key_start_stop,
    STATE(1310), 1,
      sym__hl_key_ctermfg_ctermbg,
    STATE(1313), 1,
      sym__hl_key_gui,
    STATE(1319), 1,
      sym__hl_key_gui_color,
    STATE(1327), 1,
      sym__hl_key_font,
    STATE(1328), 1,
      sym__hl_key_blend,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2821), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3006), 2,
      anon_sym_start,
      anon_sym_stop,
    ACTIONS(3008), 2,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
    STATE(953), 2,
      sym_hl_attribute,
      aux_sym__hl_body_keys_repeat1,
    ACTIONS(3012), 3,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
  [42456] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3018), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [42511] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3020), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [42566] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3022), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [42621] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3024), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [42676] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3026), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [42731] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3028), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [42786] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3030), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [42841] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3032), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [42896] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3034), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [42951] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3036), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43006] = 15,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(3038), 1,
      anon_sym_start,
    ACTIONS(3042), 1,
      anon_sym_contains,
    ACTIONS(3044), 1,
      anon_sym_matchgroup,
    STATE(632), 1,
      sym__syn_region_start,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(929), 1,
      aux_sym__syn_region_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(3040), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [43063] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2891), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43118] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3046), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43173] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3048), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43228] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3050), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43283] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3052), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43338] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3054), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43393] = 18,
    ACTIONS(2825), 1,
      anon_sym_term,
    ACTIONS(2827), 1,
      anon_sym_cterm,
    ACTIONS(2833), 1,
      anon_sym_gui,
    ACTIONS(2837), 1,
      anon_sym_font,
    ACTIONS(2839), 1,
      anon_sym_blend,
    STATE(1194), 1,
      sym__hl_key_cterm,
    STATE(1195), 1,
      sym__hl_key_start_stop,
    STATE(1196), 1,
      sym__hl_key_ctermfg_ctermbg,
    STATE(1197), 1,
      sym__hl_key_gui,
    STATE(1198), 1,
      sym__hl_key_gui_color,
    STATE(1199), 1,
      sym__hl_key_font,
    STATE(1200), 1,
      sym__hl_key_blend,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2829), 2,
      anon_sym_start,
      anon_sym_stop,
    ACTIONS(2831), 2,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
    STATE(907), 2,
      sym_hl_attribute,
      aux_sym__hl_body_keys_repeat1,
    ACTIONS(2835), 3,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
    ACTIONS(3056), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [43456] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3058), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43511] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3060), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43566] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3062), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43621] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3064), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43676] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3068), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(3066), 21,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_start,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [43709] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2843), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43764] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3070), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43819] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3072), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43874] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3074), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43929] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3076), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [43984] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3078), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44039] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3080), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44094] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2876), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44149] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3084), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(3082), 21,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_start,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [44182] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3086), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44237] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3088), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44292] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2899), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44347] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3090), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44402] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3092), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44457] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3094), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44512] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3096), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44567] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3098), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44622] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3100), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44677] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2923), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44732] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3102), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44787] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2929), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44842] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3104), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44897] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3106), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [44952] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3108), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [45007] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3110), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [45062] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3112), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [45117] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3114), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [45172] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3116), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [45227] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3118), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [45282] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3120), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [45337] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3122), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [45392] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3124), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [45447] = 18,
    ACTIONS(2825), 1,
      anon_sym_term,
    ACTIONS(2827), 1,
      anon_sym_cterm,
    ACTIONS(2833), 1,
      anon_sym_gui,
    ACTIONS(2837), 1,
      anon_sym_font,
    ACTIONS(2839), 1,
      anon_sym_blend,
    STATE(1194), 1,
      sym__hl_key_cterm,
    STATE(1195), 1,
      sym__hl_key_start_stop,
    STATE(1196), 1,
      sym__hl_key_ctermfg_ctermbg,
    STATE(1197), 1,
      sym__hl_key_gui,
    STATE(1198), 1,
      sym__hl_key_gui_color,
    STATE(1199), 1,
      sym__hl_key_font,
    STATE(1200), 1,
      sym__hl_key_blend,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2829), 2,
      anon_sym_start,
      anon_sym_stop,
    ACTIONS(2831), 2,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
    STATE(907), 2,
      sym_hl_attribute,
      aux_sym__hl_body_keys_repeat1,
    ACTIONS(2835), 3,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
    ACTIONS(3126), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [45510] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3130), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(3128), 21,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_start,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [45543] = 18,
    ACTIONS(3134), 1,
      anon_sym_term,
    ACTIONS(3137), 1,
      anon_sym_cterm,
    ACTIONS(3146), 1,
      anon_sym_gui,
    ACTIONS(3152), 1,
      anon_sym_font,
    ACTIONS(3155), 1,
      anon_sym_blend,
    STATE(1194), 1,
      sym__hl_key_cterm,
    STATE(1195), 1,
      sym__hl_key_start_stop,
    STATE(1196), 1,
      sym__hl_key_ctermfg_ctermbg,
    STATE(1197), 1,
      sym__hl_key_gui,
    STATE(1198), 1,
      sym__hl_key_gui_color,
    STATE(1199), 1,
      sym__hl_key_font,
    STATE(1200), 1,
      sym__hl_key_blend,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3140), 2,
      anon_sym_start,
      anon_sym_stop,
    ACTIONS(3143), 2,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
    STATE(907), 2,
      sym_hl_attribute,
      aux_sym__hl_body_keys_repeat1,
    ACTIONS(3132), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(3149), 3,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
  [45606] = 15,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(3038), 1,
      anon_sym_start,
    ACTIONS(3042), 1,
      anon_sym_contains,
    ACTIONS(3044), 1,
      anon_sym_matchgroup,
    STATE(622), 1,
      sym__syn_region_start,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(910), 1,
      aux_sym__syn_region_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(3040), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [45663] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3158), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [45718] = 15,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(3038), 1,
      anon_sym_start,
    ACTIONS(3042), 1,
      anon_sym_contains,
    ACTIONS(3044), 1,
      anon_sym_matchgroup,
    STATE(625), 1,
      sym__syn_region_start,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(937), 1,
      aux_sym__syn_region_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(3040), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [45775] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3160), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [45830] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3164), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(3162), 21,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_start,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [45863] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3166), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [45918] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3168), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [45973] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3170), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [46028] = 3,
    ACTIONS(2482), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2480), 23,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
  [46061] = 5,
    ACTIONS(2992), 1,
      sym_hl_group,
    STATE(919), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3172), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(3174), 19,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [46098] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3176), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [46153] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3180), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(3178), 21,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_start,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [46186] = 6,
    ACTIONS(3182), 1,
      anon_sym_LBRACE2,
    ACTIONS(3185), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(912), 2,
      anon_sym_EQ,
      sym_command_name,
    STATE(920), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(910), 18,
      anon_sym_EQ_LT_LT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LPAREN2,
      anon_sym_DASH_GT,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [46225] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3190), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(3188), 21,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_start,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [46258] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3194), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(3192), 21,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_start,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [46291] = 15,
    ACTIONS(2741), 1,
      anon_sym_end,
    ACTIONS(2746), 1,
      anon_sym_cchar,
    ACTIONS(3199), 1,
      anon_sym_contains,
    ACTIONS(3202), 1,
      anon_sym_matchgroup,
    ACTIONS(3205), 1,
      anon_sym_skip,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(923), 1,
      aux_sym__syn_region_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2743), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2764), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(3196), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2752), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2758), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [46348] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3207), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [46403] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3209), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [46458] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3211), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [46513] = 5,
    ACTIONS(2992), 1,
      sym_hl_group,
    STATE(921), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3213), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(3215), 19,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [46550] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3217), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [46605] = 15,
    ACTIONS(2597), 1,
      anon_sym_cchar,
    ACTIONS(3038), 1,
      anon_sym_start,
    ACTIONS(3042), 1,
      anon_sym_contains,
    ACTIONS(3044), 1,
      anon_sym_matchgroup,
    STATE(628), 1,
      sym__syn_region_start,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(937), 1,
      aux_sym__syn_region_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2595), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2609), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(3040), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2601), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2605), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [46662] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3221), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(3219), 21,
      anon_sym_COMMA,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [46695] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3223), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [46750] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3225), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [46805] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3227), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [46860] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3231), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(3229), 21,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_start,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [46893] = 14,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3233), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [46948] = 5,
    ACTIONS(3235), 1,
      anon_sym_COMMA,
    STATE(956), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2578), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2576), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [46984] = 14,
    ACTIONS(2741), 1,
      anon_sym_start,
    ACTIONS(2746), 1,
      anon_sym_cchar,
    ACTIONS(3240), 1,
      anon_sym_contains,
    ACTIONS(3243), 1,
      anon_sym_matchgroup,
    STATE(826), 1,
      sym__syn_arguments_keyword,
    STATE(872), 1,
      sym__syn_arguments_region,
    STATE(881), 1,
      sym__syn_arguments_match,
    STATE(937), 1,
      aux_sym__syn_region_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2743), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2764), 2,
      anon_sym_oneline,
      anon_sym_concealends,
    ACTIONS(3237), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2752), 4,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2758), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [47038] = 5,
    ACTIONS(3246), 1,
      anon_sym_COMMA,
    STATE(938), 1,
      aux_sym__syn_match_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2883), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2881), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [47074] = 13,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [47126] = 5,
    ACTIONS(3249), 1,
      sym_hl_group,
    STATE(987), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3172), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3174), 19,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [47162] = 18,
    ACTIONS(3002), 1,
      anon_sym_term,
    ACTIONS(3004), 1,
      anon_sym_cterm,
    ACTIONS(3010), 1,
      anon_sym_gui,
    ACTIONS(3014), 1,
      anon_sym_font,
    ACTIONS(3016), 1,
      anon_sym_blend,
    STATE(1304), 1,
      sym__hl_key_cterm,
    STATE(1305), 1,
      sym__hl_key_start_stop,
    STATE(1310), 1,
      sym__hl_key_ctermfg_ctermbg,
    STATE(1313), 1,
      sym__hl_key_gui,
    STATE(1319), 1,
      sym__hl_key_gui_color,
    STATE(1327), 1,
      sym__hl_key_font,
    STATE(1328), 1,
      sym__hl_key_blend,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3006), 2,
      anon_sym_start,
      anon_sym_stop,
    ACTIONS(3008), 2,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
    ACTIONS(3126), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(952), 2,
      sym_hl_attribute,
      aux_sym__hl_body_keys_repeat1,
    ACTIONS(3012), 3,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
  [47224] = 13,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2737), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [47276] = 13,
    ACTIONS(2514), 1,
      anon_sym_cchar,
    ACTIONS(2516), 1,
      anon_sym_contained,
    ACTIONS(2520), 1,
      anon_sym_contains,
    ACTIONS(3251), 1,
      anon_sym_COMMA,
    STATE(993), 1,
      aux_sym__syn_match_repeat1,
    STATE(1007), 1,
      aux_sym__syn_match_repeat2,
    STATE(1050), 1,
      sym__syn_arguments_match,
    STATE(1061), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2518), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3253), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2512), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2522), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [47328] = 13,
    ACTIONS(2514), 1,
      anon_sym_cchar,
    ACTIONS(2516), 1,
      anon_sym_contained,
    ACTIONS(2520), 1,
      anon_sym_contains,
    ACTIONS(3251), 1,
      anon_sym_COMMA,
    STATE(958), 1,
      aux_sym__syn_match_repeat2,
    STATE(977), 1,
      aux_sym__syn_match_repeat1,
    STATE(1050), 1,
      sym__syn_arguments_match,
    STATE(1061), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2518), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3255), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2512), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2522), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [47380] = 5,
    ACTIONS(3257), 1,
      anon_sym_COMMA,
    STATE(938), 1,
      aux_sym__syn_match_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2982), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2980), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [47416] = 5,
    ACTIONS(3249), 1,
      sym_hl_group,
    STATE(978), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2990), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2994), 19,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [47452] = 13,
    ACTIONS(2500), 1,
      anon_sym_DOT2,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2506), 1,
      anon_sym_LBRACK,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(2660), 1,
      anon_sym_LPAREN,
    ACTIONS(2682), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [47504] = 6,
    ACTIONS(3259), 1,
      anon_sym_LBRACE2,
    ACTIONS(3261), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1064), 2,
      anon_sym_EQ,
      sym_command_name,
    STATE(949), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1062), 17,
      anon_sym_EQ_LT_LT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_DASH_GT,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [47542] = 6,
    ACTIONS(3259), 1,
      anon_sym_LBRACE2,
    ACTIONS(3263), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(904), 2,
      anon_sym_EQ,
      sym_command_name,
    STATE(920), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(902), 17,
      anon_sym_EQ_LT_LT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_DASH_GT,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [47580] = 5,
    ACTIONS(3249), 1,
      sym_hl_group,
    STATE(995), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3213), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3215), 19,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [47616] = 5,
    ACTIONS(3257), 1,
      anon_sym_COMMA,
    STATE(945), 1,
      aux_sym__syn_match_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2978), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2976), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [47652] = 18,
    ACTIONS(3265), 1,
      anon_sym_term,
    ACTIONS(3268), 1,
      anon_sym_cterm,
    ACTIONS(3277), 1,
      anon_sym_gui,
    ACTIONS(3283), 1,
      anon_sym_font,
    ACTIONS(3286), 1,
      anon_sym_blend,
    STATE(1304), 1,
      sym__hl_key_cterm,
    STATE(1305), 1,
      sym__hl_key_start_stop,
    STATE(1310), 1,
      sym__hl_key_ctermfg_ctermbg,
    STATE(1313), 1,
      sym__hl_key_gui,
    STATE(1319), 1,
      sym__hl_key_gui_color,
    STATE(1327), 1,
      sym__hl_key_font,
    STATE(1328), 1,
      sym__hl_key_blend,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3132), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3271), 2,
      anon_sym_start,
      anon_sym_stop,
    ACTIONS(3274), 2,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
    STATE(952), 2,
      sym_hl_attribute,
      aux_sym__hl_body_keys_repeat1,
    ACTIONS(3280), 3,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
  [47714] = 18,
    ACTIONS(3002), 1,
      anon_sym_term,
    ACTIONS(3004), 1,
      anon_sym_cterm,
    ACTIONS(3010), 1,
      anon_sym_gui,
    ACTIONS(3014), 1,
      anon_sym_font,
    ACTIONS(3016), 1,
      anon_sym_blend,
    STATE(1304), 1,
      sym__hl_key_cterm,
    STATE(1305), 1,
      sym__hl_key_start_stop,
    STATE(1310), 1,
      sym__hl_key_ctermfg_ctermbg,
    STATE(1313), 1,
      sym__hl_key_gui,
    STATE(1319), 1,
      sym__hl_key_gui_color,
    STATE(1327), 1,
      sym__hl_key_font,
    STATE(1328), 1,
      sym__hl_key_blend,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3006), 2,
      anon_sym_start,
      anon_sym_stop,
    ACTIONS(3008), 2,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
    ACTIONS(3056), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(952), 2,
      sym_hl_attribute,
      aux_sym__hl_body_keys_repeat1,
    ACTIONS(3012), 3,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
  [47776] = 5,
    ACTIONS(3235), 1,
      anon_sym_COMMA,
    STATE(936), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2560), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2558), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [47812] = 13,
    ACTIONS(2514), 1,
      anon_sym_cchar,
    ACTIONS(2516), 1,
      anon_sym_contained,
    ACTIONS(2520), 1,
      anon_sym_contains,
    ACTIONS(3251), 1,
      anon_sym_COMMA,
    STATE(943), 1,
      aux_sym__syn_match_repeat2,
    STATE(984), 1,
      aux_sym__syn_match_repeat1,
    STATE(1050), 1,
      sym__syn_arguments_match,
    STATE(1061), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2518), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3289), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2512), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2522), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [47864] = 5,
    ACTIONS(3291), 1,
      anon_sym_COMMA,
    STATE(956), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2585), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2583), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [47900] = 13,
    ACTIONS(2496), 1,
      anon_sym_LPAREN,
    ACTIONS(2504), 1,
      anon_sym_DASH,
    ACTIONS(2508), 1,
      anon_sym_DASH_GT,
    ACTIONS(2545), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2547), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2620), 1,
      anon_sym_QMARK,
    ACTIONS(3294), 1,
      anon_sym_DOT2,
    ACTIONS(3296), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2502), 2,
      anon_sym_PLUS,
      anon_sym_DOT_DOT,
    ACTIONS(2498), 3,
      anon_sym_PERCENT,
      anon_sym_SLASH,
      anon_sym_STAR2,
    ACTIONS(2543), 3,
      anon_sym_LT2,
      anon_sym_GT2,
      anon_sym_is,
    ACTIONS(2549), 7,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_isnot,
  [47952] = 13,
    ACTIONS(2514), 1,
      anon_sym_cchar,
    ACTIONS(2516), 1,
      anon_sym_contained,
    ACTIONS(2520), 1,
      anon_sym_contains,
    ACTIONS(3251), 1,
      anon_sym_COMMA,
    STATE(997), 1,
      aux_sym__syn_match_repeat1,
    STATE(1007), 1,
      aux_sym__syn_match_repeat2,
    STATE(1050), 1,
      sym__syn_arguments_match,
    STATE(1061), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2518), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3298), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2512), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2522), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [48004] = 8,
    ACTIONS(756), 1,
      anon_sym_LT,
    ACTIONS(758), 1,
      anon_sym_BSLASH2,
    ACTIONS(3302), 1,
      aux_sym__bang_filter_command_argument_token3,
    STATE(963), 1,
      aux_sym__map_lhs_repeat1,
    STATE(1019), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3304), 4,
      aux_sym_identifier_token1,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_integer_literal,
    ACTIONS(3300), 13,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_AMP,
      anon_sym_LPAREN,
      anon_sym_DOLLAR,
      anon_sym_BANG2,
      sym_float_literal,
      anon_sym_LBRACK,
      sym_register,
      anon_sym_POUND_LBRACE,
  [48045] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1322), 2,
      anon_sym_EQ,
      sym_command_name,
    ACTIONS(1320), 20,
      anon_sym_LBRACE2,
      aux_sym_identifier_token2,
      anon_sym_EQ_LT_LT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LPAREN2,
      anon_sym_DASH_GT,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [48076] = 4,
    ACTIONS(2992), 1,
      sym_hl_group,
    STATE(921), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3215), 20,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_skip,
      anon_sym_end,
  [48109] = 13,
    ACTIONS(2564), 1,
      anon_sym_cchar,
    ACTIONS(2566), 1,
      anon_sym_contained,
    ACTIONS(2570), 1,
      anon_sym_contains,
    ACTIONS(3306), 1,
      anon_sym_COMMA,
    STATE(972), 1,
      aux_sym__syn_match_repeat2,
    STATE(1021), 1,
      aux_sym__syn_match_repeat1,
    STATE(1119), 1,
      sym__syn_arguments_match,
    STATE(1122), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2568), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3289), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2562), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2572), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [48160] = 8,
    ACTIONS(3310), 1,
      aux_sym__bang_filter_command_argument_token3,
    ACTIONS(3315), 1,
      anon_sym_LT,
    ACTIONS(3318), 1,
      anon_sym_BSLASH2,
    STATE(963), 1,
      aux_sym__map_lhs_repeat1,
    STATE(1019), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3313), 4,
      aux_sym_identifier_token1,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_integer_literal,
    ACTIONS(3308), 13,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_AMP,
      anon_sym_LPAREN,
      anon_sym_DOLLAR,
      anon_sym_BANG2,
      sym_float_literal,
      anon_sym_LBRACK,
      sym_register,
      anon_sym_POUND_LBRACE,
  [48201] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2950), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2948), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_COMMA,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [48232] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3221), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(3219), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_COMMA,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [48263] = 4,
    ACTIONS(2992), 1,
      sym_hl_group,
    STATE(919), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3174), 20,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_skip,
      anon_sym_end,
  [48296] = 13,
    ACTIONS(2564), 1,
      anon_sym_cchar,
    ACTIONS(2566), 1,
      anon_sym_contained,
    ACTIONS(2570), 1,
      anon_sym_contains,
    ACTIONS(3306), 1,
      anon_sym_COMMA,
    STATE(1022), 1,
      aux_sym__syn_match_repeat1,
    STATE(1028), 1,
      aux_sym__syn_match_repeat2,
    STATE(1119), 1,
      sym__syn_arguments_match,
    STATE(1122), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2568), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3298), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2562), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2572), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [48347] = 5,
    ACTIONS(2974), 1,
      anon_sym_COMMA,
    STATE(976), 1,
      aux_sym__syn_match_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3321), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(3323), 17,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [48382] = 4,
    ACTIONS(2992), 1,
      sym_hl_group,
    STATE(906), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2994), 20,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_skip,
      anon_sym_end,
  [48415] = 8,
    ACTIONS(746), 1,
      aux_sym__bang_filter_command_argument_token3,
    ACTIONS(756), 1,
      anon_sym_LT,
    ACTIONS(758), 1,
      anon_sym_BSLASH2,
    STATE(959), 1,
      aux_sym__map_lhs_repeat1,
    STATE(1019), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(748), 4,
      aux_sym_identifier_token1,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_integer_literal,
    ACTIONS(744), 13,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_AMP,
      anon_sym_LPAREN,
      anon_sym_DOLLAR,
      anon_sym_BANG2,
      sym_float_literal,
      anon_sym_LBRACK,
      sym_register,
      anon_sym_POUND_LBRACE,
  [48456] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2585), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2583), 20,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_COMMA,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [48487] = 13,
    ACTIONS(2564), 1,
      anon_sym_cchar,
    ACTIONS(2566), 1,
      anon_sym_contained,
    ACTIONS(2570), 1,
      anon_sym_contains,
    ACTIONS(3306), 1,
      anon_sym_COMMA,
    STATE(1024), 1,
      aux_sym__syn_match_repeat1,
    STATE(1028), 1,
      aux_sym__syn_match_repeat2,
    STATE(1119), 1,
      sym__syn_arguments_match,
    STATE(1122), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2568), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3253), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2562), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2572), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [48538] = 13,
    ACTIONS(2564), 1,
      anon_sym_cchar,
    ACTIONS(2566), 1,
      anon_sym_contained,
    ACTIONS(2570), 1,
      anon_sym_contains,
    ACTIONS(3306), 1,
      anon_sym_COMMA,
    STATE(967), 1,
      aux_sym__syn_match_repeat2,
    STATE(1006), 1,
      aux_sym__syn_match_repeat1,
    STATE(1119), 1,
      sym__syn_arguments_match,
    STATE(1122), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2568), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3255), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2562), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2572), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [48589] = 8,
    ACTIONS(756), 1,
      anon_sym_LT,
    ACTIONS(758), 1,
      anon_sym_BSLASH2,
    ACTIONS(3325), 1,
      aux_sym__bang_filter_command_argument_token3,
    STATE(975), 1,
      aux_sym__map_lhs_repeat1,
    STATE(1019), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3304), 4,
      aux_sym_identifier_token1,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_integer_literal,
    ACTIONS(3300), 13,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_AMP,
      anon_sym_LPAREN,
      anon_sym_DOLLAR,
      anon_sym_BANG2,
      sym_float_literal,
      anon_sym_LBRACK,
      sym_register,
      anon_sym_POUND_LBRACE,
  [48630] = 8,
    ACTIONS(756), 1,
      anon_sym_LT,
    ACTIONS(758), 1,
      anon_sym_BSLASH2,
    ACTIONS(3302), 1,
      aux_sym__bang_filter_command_argument_token3,
    STATE(963), 1,
      aux_sym__map_lhs_repeat1,
    STATE(1019), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3329), 4,
      aux_sym_identifier_token1,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_integer_literal,
    ACTIONS(3327), 13,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_AMP,
      anon_sym_LPAREN,
      anon_sym_DOLLAR,
      anon_sym_BANG2,
      sym_float_literal,
      anon_sym_LBRACK,
      sym_register,
      anon_sym_POUND_LBRACE,
  [48671] = 5,
    ACTIONS(2974), 1,
      anon_sym_COMMA,
    STATE(776), 1,
      aux_sym__syn_match_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3331), 3,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_skip,
    ACTIONS(3333), 17,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [48706] = 11,
    ACTIONS(2514), 1,
      anon_sym_cchar,
    ACTIONS(2516), 1,
      anon_sym_contained,
    ACTIONS(2520), 1,
      anon_sym_contains,
    STATE(1002), 1,
      aux_sym__syn_match_repeat1,
    STATE(1050), 1,
      sym__syn_arguments_match,
    STATE(1061), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2518), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3298), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2512), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2522), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [48752] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3130), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(3128), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [48782] = 17,
    ACTIONS(3002), 1,
      anon_sym_term,
    ACTIONS(3004), 1,
      anon_sym_cterm,
    ACTIONS(3010), 1,
      anon_sym_gui,
    ACTIONS(3014), 1,
      anon_sym_font,
    ACTIONS(3016), 1,
      anon_sym_blend,
    STATE(1304), 1,
      sym__hl_key_cterm,
    STATE(1305), 1,
      sym__hl_key_start_stop,
    STATE(1310), 1,
      sym__hl_key_ctermfg_ctermbg,
    STATE(1313), 1,
      sym__hl_key_gui,
    STATE(1319), 1,
      sym__hl_key_gui_color,
    STATE(1327), 1,
      sym__hl_key_font,
    STATE(1328), 1,
      sym__hl_key_blend,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3006), 2,
      anon_sym_start,
      anon_sym_stop,
    ACTIONS(3008), 2,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
    STATE(941), 2,
      sym_hl_attribute,
      aux_sym__hl_body_keys_repeat1,
    ACTIONS(3012), 3,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
  [48840] = 11,
    ACTIONS(2514), 1,
      anon_sym_cchar,
    ACTIONS(2516), 1,
      anon_sym_contained,
    ACTIONS(2520), 1,
      anon_sym_contains,
    STATE(1002), 1,
      aux_sym__syn_match_repeat1,
    STATE(1050), 1,
      sym__syn_arguments_match,
    STATE(1061), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2518), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3335), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2512), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2522), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [48886] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3231), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(3229), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [48916] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1338), 2,
      anon_sym_EQ,
      sym_command_name,
    ACTIONS(1336), 19,
      anon_sym_LBRACE2,
      aux_sym_identifier_token2,
      anon_sym_EQ_LT_LT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_DASH_GT,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [48946] = 5,
    ACTIONS(2585), 1,
      anon_sym_contained,
    ACTIONS(3337), 1,
      anon_sym_COMMA,
    STATE(983), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2583), 18,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_add,
      anon_sym_remove,
  [48980] = 11,
    ACTIONS(2514), 1,
      anon_sym_cchar,
    ACTIONS(2516), 1,
      anon_sym_contained,
    ACTIONS(2520), 1,
      anon_sym_contains,
    STATE(1002), 1,
      aux_sym__syn_match_repeat1,
    STATE(1050), 1,
      sym__syn_arguments_match,
    STATE(1061), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2518), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3253), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2512), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2522), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [49026] = 5,
    ACTIONS(2560), 1,
      anon_sym_contained,
    ACTIONS(3340), 1,
      anon_sym_COMMA,
    STATE(988), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2558), 18,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_add,
      anon_sym_remove,
  [49060] = 17,
    ACTIONS(2825), 1,
      anon_sym_term,
    ACTIONS(2827), 1,
      anon_sym_cterm,
    ACTIONS(2833), 1,
      anon_sym_gui,
    ACTIONS(2837), 1,
      anon_sym_font,
    ACTIONS(2839), 1,
      anon_sym_blend,
    STATE(1194), 1,
      sym__hl_key_cterm,
    STATE(1195), 1,
      sym__hl_key_start_stop,
    STATE(1196), 1,
      sym__hl_key_ctermfg_ctermbg,
    STATE(1197), 1,
      sym__hl_key_gui,
    STATE(1198), 1,
      sym__hl_key_gui_color,
    STATE(1199), 1,
      sym__hl_key_font,
    STATE(1200), 1,
      sym__hl_key_blend,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2829), 2,
      anon_sym_start,
      anon_sym_stop,
    ACTIONS(2831), 2,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
    STATE(905), 2,
      sym_hl_attribute,
      aux_sym__hl_body_keys_repeat1,
    ACTIONS(2835), 3,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
  [49118] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3180), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(3178), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [49148] = 5,
    ACTIONS(2578), 1,
      anon_sym_contained,
    ACTIONS(3340), 1,
      anon_sym_COMMA,
    STATE(983), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2576), 18,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_add,
      anon_sym_remove,
  [49182] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3194), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(3192), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [49212] = 5,
    ACTIONS(2974), 1,
      anon_sym_COMMA,
    STATE(776), 1,
      aux_sym__syn_match_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3342), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(3344), 17,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [49246] = 4,
    ACTIONS(2992), 1,
      sym_hl_group,
    STATE(919), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3174), 19,
      anon_sym_start,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
  [49278] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2946), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(2944), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [49308] = 11,
    ACTIONS(2514), 1,
      anon_sym_cchar,
    ACTIONS(2516), 1,
      anon_sym_contained,
    ACTIONS(2520), 1,
      anon_sym_contains,
    STATE(1002), 1,
      aux_sym__syn_match_repeat1,
    STATE(1050), 1,
      sym__syn_arguments_match,
    STATE(1061), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2518), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3346), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2512), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2522), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [49354] = 5,
    ACTIONS(2974), 1,
      anon_sym_COMMA,
    STATE(990), 1,
      aux_sym__syn_match_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3348), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(3350), 17,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [49388] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3190), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(3188), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [49418] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3084), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(3082), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [49448] = 11,
    ACTIONS(2514), 1,
      anon_sym_cchar,
    ACTIONS(2516), 1,
      anon_sym_contained,
    ACTIONS(2520), 1,
      anon_sym_contains,
    STATE(1002), 1,
      aux_sym__syn_match_repeat1,
    STATE(1050), 1,
      sym__syn_arguments_match,
    STATE(1061), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2518), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3352), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2512), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2522), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [49494] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3068), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(3066), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [49524] = 4,
    ACTIONS(2992), 1,
      sym_hl_group,
    STATE(906), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2994), 19,
      anon_sym_start,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
  [49556] = 11,
    ACTIONS(2514), 1,
      anon_sym_cchar,
    ACTIONS(2516), 1,
      anon_sym_contained,
    ACTIONS(2520), 1,
      anon_sym_contains,
    STATE(1002), 1,
      aux_sym__syn_match_repeat1,
    STATE(1050), 1,
      sym__syn_arguments_match,
    STATE(1061), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2518), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2526), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2512), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2522), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [49602] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3164), 2,
      anon_sym_conceal,
      anon_sym_contained,
    ACTIONS(3162), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
      anon_sym_end,
  [49632] = 11,
    ACTIONS(3359), 1,
      anon_sym_cchar,
    ACTIONS(3362), 1,
      anon_sym_contained,
    ACTIONS(3368), 1,
      anon_sym_contains,
    STATE(1002), 1,
      aux_sym__syn_match_repeat1,
    STATE(1050), 1,
      sym__syn_arguments_match,
    STATE(1061), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3365), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3354), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(3356), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(3371), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [49678] = 4,
    ACTIONS(2992), 1,
      sym_hl_group,
    STATE(921), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3215), 19,
      anon_sym_start,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_matchgroup,
      anon_sym_oneline,
      anon_sym_concealends,
  [49710] = 12,
    ACTIONS(3376), 1,
      anon_sym_cchar,
    ACTIONS(3378), 1,
      anon_sym_contained,
    ACTIONS(3382), 1,
      anon_sym_contains,
    ACTIONS(3386), 1,
      sym__separator_first,
    STATE(610), 1,
      sym__syn_hl_pattern,
    STATE(1027), 1,
      aux_sym__syn_match_repeat1,
    STATE(1137), 1,
      sym__syn_arguments_keyword,
    STATE(1138), 1,
      sym__syn_arguments_match,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3380), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3374), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(3384), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [49757] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3390), 5,
      aux_sym__bang_filter_command_argument_token3,
      aux_sym_identifier_token1,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_integer_literal,
    ACTIONS(3388), 15,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_AMP,
      anon_sym_LPAREN,
      anon_sym_DOLLAR,
      anon_sym_LT,
      anon_sym_BSLASH2,
      anon_sym_BANG2,
      sym_float_literal,
      anon_sym_LBRACK,
      sym_register,
      anon_sym_POUND_LBRACE,
  [49786] = 11,
    ACTIONS(2564), 1,
      anon_sym_cchar,
    ACTIONS(2566), 1,
      anon_sym_contained,
    ACTIONS(2570), 1,
      anon_sym_contains,
    STATE(1013), 1,
      aux_sym__syn_match_repeat1,
    STATE(1119), 1,
      sym__syn_arguments_match,
    STATE(1122), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2568), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3298), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2562), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2572), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [49831] = 5,
    ACTIONS(2883), 1,
      anon_sym_contained,
    ACTIONS(3392), 1,
      anon_sym_COMMA,
    STATE(1007), 1,
      aux_sym__syn_match_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2881), 17,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [49864] = 5,
    ACTIONS(2560), 1,
      anon_sym_contained,
    ACTIONS(3395), 1,
      anon_sym_COMMA,
    STATE(1015), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2558), 17,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [49897] = 5,
    ACTIONS(3397), 1,
      sym_hl_group,
    STATE(1062), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2990), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2994), 15,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [49930] = 5,
    ACTIONS(3397), 1,
      sym_hl_group,
    STATE(1065), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3213), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(3215), 15,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [49963] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3401), 5,
      aux_sym__bang_filter_command_argument_token3,
      aux_sym_identifier_token1,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_integer_literal,
    ACTIONS(3399), 15,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_AMP,
      anon_sym_LPAREN,
      anon_sym_DOLLAR,
      anon_sym_LT,
      anon_sym_BSLASH2,
      anon_sym_BANG2,
      sym_float_literal,
      anon_sym_LBRACK,
      sym_register,
      anon_sym_POUND_LBRACE,
  [49992] = 12,
    ACTIONS(3376), 1,
      anon_sym_cchar,
    ACTIONS(3378), 1,
      anon_sym_contained,
    ACTIONS(3382), 1,
      anon_sym_contains,
    ACTIONS(3403), 1,
      sym__separator_first,
    STATE(573), 1,
      sym__syn_hl_pattern,
    STATE(1020), 1,
      aux_sym__syn_match_repeat1,
    STATE(1137), 1,
      sym__syn_arguments_keyword,
    STATE(1138), 1,
      sym__syn_arguments_match,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3380), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3374), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(3384), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [50039] = 11,
    ACTIONS(3408), 1,
      anon_sym_cchar,
    ACTIONS(3411), 1,
      anon_sym_contained,
    ACTIONS(3417), 1,
      anon_sym_contains,
    STATE(1013), 1,
      aux_sym__syn_match_repeat1,
    STATE(1119), 1,
      sym__syn_arguments_match,
    STATE(1122), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3354), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3414), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3405), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(3420), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [50084] = 11,
    ACTIONS(2564), 1,
      anon_sym_cchar,
    ACTIONS(2566), 1,
      anon_sym_contained,
    ACTIONS(2570), 1,
      anon_sym_contains,
    STATE(1013), 1,
      aux_sym__syn_match_repeat1,
    STATE(1119), 1,
      sym__syn_arguments_match,
    STATE(1122), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2526), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2568), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(2562), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2572), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [50129] = 5,
    ACTIONS(2578), 1,
      anon_sym_contained,
    ACTIONS(3395), 1,
      anon_sym_COMMA,
    STATE(1016), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2576), 17,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [50162] = 5,
    ACTIONS(2585), 1,
      anon_sym_contained,
    ACTIONS(3423), 1,
      anon_sym_COMMA,
    STATE(1016), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2583), 17,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [50195] = 3,
    ACTIONS(2585), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2583), 19,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_COMMA,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
      anon_sym_add,
      anon_sym_remove,
  [50224] = 11,
    ACTIONS(2564), 1,
      anon_sym_cchar,
    ACTIONS(2566), 1,
      anon_sym_contained,
    ACTIONS(2570), 1,
      anon_sym_contains,
    STATE(1013), 1,
      aux_sym__syn_match_repeat1,
    STATE(1119), 1,
      sym__syn_arguments_match,
    STATE(1122), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2568), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3335), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2562), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2572), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [50269] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3428), 5,
      aux_sym__bang_filter_command_argument_token3,
      aux_sym_identifier_token1,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_integer_literal,
    ACTIONS(3426), 15,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_AMP,
      anon_sym_LPAREN,
      anon_sym_DOLLAR,
      anon_sym_LT,
      anon_sym_BSLASH2,
      anon_sym_BANG2,
      sym_float_literal,
      anon_sym_LBRACK,
      sym_register,
      anon_sym_POUND_LBRACE,
  [50298] = 12,
    ACTIONS(3376), 1,
      anon_sym_cchar,
    ACTIONS(3378), 1,
      anon_sym_contained,
    ACTIONS(3382), 1,
      anon_sym_contains,
    ACTIONS(3403), 1,
      sym__separator_first,
    STATE(576), 1,
      sym__syn_hl_pattern,
    STATE(1027), 1,
      aux_sym__syn_match_repeat1,
    STATE(1137), 1,
      sym__syn_arguments_keyword,
    STATE(1138), 1,
      sym__syn_arguments_match,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3380), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3374), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(3384), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [50345] = 11,
    ACTIONS(2564), 1,
      anon_sym_cchar,
    ACTIONS(2566), 1,
      anon_sym_contained,
    ACTIONS(2570), 1,
      anon_sym_contains,
    STATE(1013), 1,
      aux_sym__syn_match_repeat1,
    STATE(1119), 1,
      sym__syn_arguments_match,
    STATE(1122), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2568), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3253), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2562), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2572), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [50390] = 11,
    ACTIONS(2564), 1,
      anon_sym_cchar,
    ACTIONS(2566), 1,
      anon_sym_contained,
    ACTIONS(2570), 1,
      anon_sym_contains,
    STATE(1013), 1,
      aux_sym__syn_match_repeat1,
    STATE(1119), 1,
      sym__syn_arguments_match,
    STATE(1122), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2568), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3352), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2562), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2572), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [50435] = 12,
    ACTIONS(3376), 1,
      anon_sym_cchar,
    ACTIONS(3378), 1,
      anon_sym_contained,
    ACTIONS(3382), 1,
      anon_sym_contains,
    ACTIONS(3386), 1,
      sym__separator_first,
    STATE(615), 1,
      sym__syn_hl_pattern,
    STATE(1004), 1,
      aux_sym__syn_match_repeat1,
    STATE(1137), 1,
      sym__syn_arguments_keyword,
    STATE(1138), 1,
      sym__syn_arguments_match,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3380), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3374), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(3384), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [50482] = 11,
    ACTIONS(2564), 1,
      anon_sym_cchar,
    ACTIONS(2566), 1,
      anon_sym_contained,
    ACTIONS(2570), 1,
      anon_sym_contains,
    STATE(1013), 1,
      aux_sym__syn_match_repeat1,
    STATE(1119), 1,
      sym__syn_arguments_match,
    STATE(1122), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2568), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3346), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2562), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(2572), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [50527] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3313), 5,
      aux_sym__bang_filter_command_argument_token3,
      aux_sym_identifier_token1,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_integer_literal,
    ACTIONS(3308), 15,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_AMP,
      anon_sym_LPAREN,
      anon_sym_DOLLAR,
      anon_sym_LT,
      anon_sym_BSLASH2,
      anon_sym_BANG2,
      sym_float_literal,
      anon_sym_LBRACK,
      sym_register,
      anon_sym_POUND_LBRACE,
  [50556] = 11,
    ACTIONS(3430), 1,
      anon_sym_BSLASH,
    ACTIONS(3436), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(3438), 1,
      anon_sym_LBRACK,
    ACTIONS(3440), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1788), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1035), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1049), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3434), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_PIPE,
    ACTIONS(3442), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3432), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
  [50600] = 11,
    ACTIONS(3354), 1,
      sym__separator_first,
    ACTIONS(3447), 1,
      anon_sym_cchar,
    ACTIONS(3450), 1,
      anon_sym_contained,
    ACTIONS(3456), 1,
      anon_sym_contains,
    STATE(1027), 1,
      aux_sym__syn_match_repeat1,
    STATE(1137), 1,
      sym__syn_arguments_keyword,
    STATE(1138), 1,
      sym__syn_arguments_match,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3453), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(3444), 5,
      anon_sym_conceal,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
    ACTIONS(3459), 5,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [50644] = 5,
    ACTIONS(2883), 1,
      anon_sym_contained,
    ACTIONS(3462), 1,
      anon_sym_COMMA,
    STATE(1028), 1,
      aux_sym__syn_match_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2881), 16,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [50676] = 13,
    ACTIONS(3465), 1,
      anon_sym_a_COLON,
    ACTIONS(3467), 1,
      anon_sym_LBRACE,
    ACTIONS(3469), 1,
      aux_sym_identifier_token1,
    ACTIONS(3473), 1,
      anon_sym_LBRACK,
    ACTIONS(3475), 1,
      sym__scope_dict,
    ACTIONS(3477), 1,
      sym_scope,
    STATE(1346), 1,
      sym__curly_braces_name_expression,
    STATE(1765), 1,
      sym_identifier,
    STATE(2662), 1,
      sym__const_assignment,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3471), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(1435), 3,
      sym_scope_dict,
      sym__assignment_variable,
      aux_sym_let_statement_repeat1,
    STATE(2506), 4,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym_list_assignment,
  [50724] = 5,
    STATE(1295), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3481), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3483), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 10,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [50756] = 11,
    ACTIONS(3485), 1,
      anon_sym_BSLASH,
    ACTIONS(3487), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(3489), 1,
      anon_sym_LBRACK,
    ACTIONS(3491), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1774), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1030), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1048), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3434), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_PIPE,
    ACTIONS(3493), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3432), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
  [50800] = 7,
    ACTIONS(3495), 1,
      anon_sym_BSLASH,
    ACTIONS(3502), 1,
      anon_sym_LBRACK,
    ACTIONS(3505), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1032), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3500), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [50836] = 5,
    ACTIONS(3508), 1,
      anon_sym_LT,
    ACTIONS(3512), 1,
      aux_sym__hl_term_list_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1034), 2,
      sym__immediate_keycode,
      aux_sym__hl_term_list,
    ACTIONS(3510), 15,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_cterm,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_gui,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [50868] = 5,
    ACTIONS(3514), 1,
      anon_sym_LT,
    ACTIONS(3519), 1,
      aux_sym__hl_term_list_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1034), 2,
      sym__immediate_keycode,
      aux_sym__hl_term_list,
    ACTIONS(3517), 15,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_cterm,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_gui,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [50900] = 5,
    STATE(1285), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3481), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3522), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 10,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [50932] = 7,
    ACTIONS(3524), 1,
      anon_sym_BSLASH,
    ACTIONS(3527), 1,
      anon_sym_LBRACK,
    ACTIONS(3530), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1036), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3500), 11,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [50968] = 3,
    ACTIONS(3221), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3219), 18,
      anon_sym_COMMA,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [50996] = 3,
    ACTIONS(2950), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2948), 18,
      anon_sym_COMMA,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [51024] = 5,
    ACTIONS(3533), 1,
      sym_hl_group,
    STATE(1099), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3213), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3215), 15,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [51056] = 3,
    ACTIONS(2585), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2583), 18,
      anon_sym_COMMA,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [51084] = 5,
    STATE(1292), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3481), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3535), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 12,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [51116] = 11,
    ACTIONS(3537), 1,
      anon_sym_BSLASH,
    ACTIONS(3539), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(3541), 1,
      anon_sym_LBRACK,
    ACTIONS(3543), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1762), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3432), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    STATE(1041), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1070), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3545), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3434), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [51160] = 7,
    ACTIONS(3547), 1,
      anon_sym_BSLASH,
    ACTIONS(3550), 1,
      anon_sym_LBRACK,
    ACTIONS(3553), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1043), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3500), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [51196] = 5,
    STATE(1299), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3481), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3556), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 12,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [51228] = 11,
    ACTIONS(3558), 1,
      anon_sym_BSLASH,
    ACTIONS(3560), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(3562), 1,
      anon_sym_LBRACK,
    ACTIONS(3564), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1784), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3432), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    STATE(1044), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1078), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3566), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3434), 5,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [51272] = 7,
    ACTIONS(3568), 1,
      anon_sym_BSLASH,
    ACTIONS(3571), 1,
      anon_sym_LBRACK,
    ACTIONS(3574), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1046), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3500), 13,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [51308] = 5,
    ACTIONS(3533), 1,
      sym_hl_group,
    STATE(1093), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2990), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2994), 15,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [51340] = 9,
    ACTIONS(3577), 1,
      anon_sym_BSLASH,
    ACTIONS(3584), 1,
      anon_sym_LBRACK,
    ACTIONS(3587), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1030), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1048), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3590), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3580), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3582), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
  [51379] = 9,
    ACTIONS(3593), 1,
      anon_sym_BSLASH,
    ACTIONS(3596), 1,
      anon_sym_LBRACK,
    ACTIONS(3599), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1035), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1049), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3602), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3580), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3582), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
  [51418] = 3,
    ACTIONS(3607), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3605), 17,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [51445] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3611), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3609), 14,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [51472] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3615), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3613), 14,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [51499] = 9,
    ACTIONS(3430), 1,
      anon_sym_BSLASH,
    ACTIONS(3438), 1,
      anon_sym_LBRACK,
    ACTIONS(3440), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1035), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1049), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3442), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3617), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3619), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
  [51538] = 6,
    ACTIONS(3621), 1,
      anon_sym_LT,
    ACTIONS(3624), 1,
      aux_sym__hl_term_list_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3627), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1054), 2,
      sym__immediate_keycode,
      aux_sym__hl_term_list,
    ACTIONS(3517), 12,
      anon_sym_term,
      anon_sym_cterm,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_gui,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [51571] = 5,
    ACTIONS(2578), 1,
      anon_sym_contained,
    ACTIONS(3629), 1,
      anon_sym_COMMA,
    STATE(1058), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2576), 15,
      sym__separator_first,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [51602] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3500), 14,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [51629] = 8,
    ACTIONS(3633), 1,
      aux_sym_argument_token2,
    ACTIONS(3635), 1,
      anon_sym_SLASH,
    ACTIONS(3637), 1,
      anon_sym_BSLASH2,
    ACTIONS(3639), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1366), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1693), 3,
      sym__plus_cmd_number,
      sym__plus_cmd_command,
      sym__plus_cmd_pattern,
    ACTIONS(3631), 10,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [51666] = 5,
    ACTIONS(2585), 1,
      anon_sym_contained,
    ACTIONS(3641), 1,
      anon_sym_COMMA,
    STATE(1058), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2583), 15,
      sym__separator_first,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [51697] = 13,
    ACTIONS(3473), 1,
      anon_sym_LBRACK,
    ACTIONS(3477), 1,
      sym_scope,
    ACTIONS(3644), 1,
      anon_sym_a_COLON,
    ACTIONS(3646), 1,
      anon_sym_LBRACE,
    ACTIONS(3648), 1,
      aux_sym_identifier_token1,
    ACTIONS(3650), 1,
      sym__scope_dict,
    STATE(1480), 1,
      sym__curly_braces_name_expression,
    STATE(1797), 1,
      sym_identifier,
    STATE(2849), 1,
      sym__const_assignment,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3471), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1560), 3,
      sym_scope_dict,
      sym__assignment_variable,
      aux_sym_let_statement_repeat1,
    STATE(2485), 4,
      sym_scoped_identifier,
      sym_argument,
      sym__ident,
      sym_list_assignment,
  [51744] = 3,
    ACTIONS(3194), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3192), 17,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [51771] = 3,
    ACTIONS(2946), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2944), 17,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [51798] = 3,
    ACTIONS(3130), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3128), 17,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [51825] = 5,
    ACTIONS(2560), 1,
      anon_sym_contained,
    ACTIONS(3629), 1,
      anon_sym_COMMA,
    STATE(1055), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2558), 15,
      sym__separator_first,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [51856] = 3,
    ACTIONS(2950), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2948), 17,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_COMMA,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [51883] = 3,
    ACTIONS(3190), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3188), 17,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [51910] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3611), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3609), 14,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [51937] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3615), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3613), 14,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [51964] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3500), 16,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [51991] = 9,
    ACTIONS(3485), 1,
      anon_sym_BSLASH,
    ACTIONS(3489), 1,
      anon_sym_LBRACK,
    ACTIONS(3491), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1030), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1048), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3493), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3617), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3619), 4,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
  [52030] = 9,
    ACTIONS(3652), 1,
      anon_sym_BSLASH,
    ACTIONS(3655), 1,
      anon_sym_LBRACK,
    ACTIONS(3658), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3580), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    STATE(1041), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1070), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3661), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3582), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [52069] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3611), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3609), 16,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [52096] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3615), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3613), 16,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [52123] = 9,
    ACTIONS(3537), 1,
      anon_sym_BSLASH,
    ACTIONS(3541), 1,
      anon_sym_LBRACK,
    ACTIONS(3543), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    STATE(1041), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1070), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3545), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3619), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [52162] = 3,
    ACTIONS(3221), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3219), 17,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_COMMA,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [52189] = 12,
    ACTIONS(3664), 1,
      anon_sym_BANG,
    ACTIONS(3668), 1,
      sym_command_name,
    ACTIONS(3670), 1,
      anon_sym_DASHnargs,
    ACTIONS(3672), 1,
      anon_sym_DASHcomplete,
    ACTIONS(3674), 1,
      anon_sym_DASHrange,
    ACTIONS(3676), 1,
      anon_sym_DASHcount,
    ACTIONS(3678), 1,
      anon_sym_DASHaddr,
    STATE(1128), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1402), 2,
      sym_command_attribute,
      aux_sym_command_statement_repeat1,
    ACTIONS(3666), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(3680), 5,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [52234] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3500), 16,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [52261] = 13,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3684), 1,
      anon_sym_BANG,
    ACTIONS(3686), 1,
      anon_sym_PLUS,
    ACTIONS(3690), 1,
      anon_sym_POUND,
    ACTIONS(3696), 1,
      anon_sym_PLUS_PLUS,
    STATE(1135), 1,
      sym_bang,
    STATE(2461), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1139), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1383), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(3688), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [52308] = 9,
    ACTIONS(3698), 1,
      anon_sym_BSLASH,
    ACTIONS(3701), 1,
      anon_sym_LBRACK,
    ACTIONS(3704), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3580), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    STATE(1044), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1078), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3707), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3582), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [52347] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3611), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3609), 16,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [52374] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3615), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3613), 16,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [52401] = 9,
    ACTIONS(3558), 1,
      anon_sym_BSLASH,
    ACTIONS(3562), 1,
      anon_sym_LBRACK,
    ACTIONS(3564), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    STATE(1044), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1078), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3566), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3619), 6,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [52440] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3500), 14,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [52467] = 6,
    ACTIONS(3710), 1,
      anon_sym_LT,
    ACTIONS(3712), 1,
      aux_sym__hl_term_list_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3714), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1054), 2,
      sym__immediate_keycode,
      aux_sym__hl_term_list,
    ACTIONS(3510), 12,
      anon_sym_term,
      anon_sym_cterm,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_gui,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [52500] = 5,
    ACTIONS(3213), 1,
      sym__separator_first,
    ACTIONS(3716), 1,
      sym_hl_group,
    STATE(1159), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3215), 15,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [52531] = 5,
    ACTIONS(2990), 1,
      sym__separator_first,
    ACTIONS(3716), 1,
      sym_hl_group,
    STATE(1142), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2994), 15,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [52562] = 3,
    ACTIONS(3164), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3162), 17,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [52589] = 7,
    ACTIONS(3718), 1,
      anon_sym_BSLASH,
    ACTIONS(3721), 1,
      anon_sym_LBRACK,
    ACTIONS(3724), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1087), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3500), 11,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [52623] = 12,
    ACTIONS(3670), 1,
      anon_sym_DASHnargs,
    ACTIONS(3672), 1,
      anon_sym_DASHcomplete,
    ACTIONS(3674), 1,
      anon_sym_DASHrange,
    ACTIONS(3676), 1,
      anon_sym_DASHcount,
    ACTIONS(3678), 1,
      anon_sym_DASHaddr,
    ACTIONS(3727), 1,
      anon_sym_BANG,
    ACTIONS(3729), 1,
      sym_command_name,
    STATE(1233), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3666), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1388), 2,
      sym_command_attribute,
      aux_sym_command_statement_repeat1,
    ACTIONS(3680), 5,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [52667] = 5,
    ACTIONS(3731), 1,
      anon_sym_COMMA,
    STATE(1089), 1,
      aux_sym__hl_attr_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3736), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(3734), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [52697] = 5,
    STATE(1417), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3481), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3738), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [52727] = 11,
    ACTIONS(3434), 1,
      anon_sym_BSLASH_PIPE,
    ACTIONS(3740), 1,
      anon_sym_BSLASH,
    ACTIONS(3742), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(3744), 1,
      anon_sym_LBRACK,
    ACTIONS(3746), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1977), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1090), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1170), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3748), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3432), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
  [52769] = 7,
    ACTIONS(3750), 1,
      anon_sym_BSLASH,
    ACTIONS(3753), 1,
      anon_sym_LBRACK,
    ACTIONS(3756), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1092), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3500), 9,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [52803] = 3,
    ACTIONS(3130), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3128), 16,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [52829] = 12,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3759), 1,
      anon_sym_BANG,
    ACTIONS(3761), 1,
      anon_sym_PLUS,
    ACTIONS(3765), 1,
      anon_sym_PLUS_PLUS,
    STATE(1191), 1,
      sym_bang,
    STATE(2471), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1192), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1453), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(3763), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [52873] = 9,
    ACTIONS(3767), 1,
      aux_sym_argument_token2,
    ACTIONS(3769), 1,
      anon_sym_SLASH,
    ACTIONS(3771), 1,
      anon_sym_BSLASH2,
    ACTIONS(3773), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1440), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3775), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1753), 3,
      sym__plus_cmd_number,
      sym__plus_cmd_command,
      sym__plus_cmd_pattern,
    ACTIONS(3631), 7,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [52911] = 3,
    ACTIONS(2585), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2583), 16,
      sym__separator_first,
      anon_sym_COMMA,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [52937] = 3,
    ACTIONS(3164), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3162), 16,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [52963] = 5,
    ACTIONS(3777), 1,
      anon_sym_COMMA,
    STATE(1105), 1,
      aux_sym__hl_attr_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3781), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(3779), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [52993] = 3,
    ACTIONS(3190), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3188), 16,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [53019] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3785), 4,
      aux_sym_identifier_token1,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_integer_literal,
    ACTIONS(3783), 13,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_AMP,
      anon_sym_LPAREN,
      anon_sym_DOLLAR,
      anon_sym_BANG2,
      sym_float_literal,
      anon_sym_LBRACK,
      sym_register,
      anon_sym_POUND_LBRACE,
  [53045] = 8,
    ACTIONS(3787), 1,
      aux_sym_argument_token2,
    ACTIONS(3789), 1,
      anon_sym_SLASH,
    ACTIONS(3791), 1,
      anon_sym_BSLASH2,
    ACTIONS(3793), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1412), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1704), 3,
      sym__plus_cmd_number,
      sym__plus_cmd_command,
      sym__plus_cmd_pattern,
    ACTIONS(3631), 9,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [53081] = 3,
    ACTIONS(3194), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3192), 16,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [53107] = 7,
    ACTIONS(3795), 1,
      anon_sym_BSLASH,
    ACTIONS(3798), 1,
      anon_sym_LBRACK,
    ACTIONS(3801), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1103), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3500), 9,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [53141] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(742), 4,
      aux_sym_identifier_token1,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_integer_literal,
    ACTIONS(740), 13,
      sym__scope_dict,
      sym_scope,
      sym_string_literal,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_AMP,
      anon_sym_LPAREN,
      anon_sym_DOLLAR,
      anon_sym_BANG2,
      sym_float_literal,
      anon_sym_LBRACK,
      sym_register,
      anon_sym_POUND_LBRACE,
  [53167] = 5,
    ACTIONS(3777), 1,
      anon_sym_COMMA,
    STATE(1089), 1,
      aux_sym__hl_attr_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3806), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(3804), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [53197] = 5,
    STATE(1427), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3481), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3808), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 10,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [53227] = 11,
    ACTIONS(3810), 1,
      anon_sym_BSLASH,
    ACTIONS(3812), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(3814), 1,
      anon_sym_LBRACK,
    ACTIONS(3816), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1931), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3432), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1106), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1129), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3434), 3,
      anon_sym_BSLASH_PIPE,
      anon_sym_minlines,
      anon_sym_maxlines,
    ACTIONS(3818), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [53269] = 7,
    ACTIONS(3820), 1,
      anon_sym_BSLASH,
    ACTIONS(3823), 1,
      anon_sym_LBRACK,
    ACTIONS(3826), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1108), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3500), 11,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [53303] = 4,
    STATE(1432), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3829), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [53331] = 10,
    ACTIONS(3831), 1,
      anon_sym_BSLASH,
    ACTIONS(3833), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(3835), 1,
      anon_sym_LBRACK,
    ACTIONS(3837), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1976), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1109), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1146), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3839), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3434), 5,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_minlines,
      anon_sym_maxlines,
  [53371] = 6,
    ACTIONS(3841), 1,
      anon_sym_BSLASH,
    ACTIONS(3844), 1,
      anon_sym_LBRACK,
    ACTIONS(3847), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1111), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3500), 13,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [53403] = 5,
    STATE(1442), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3481), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3850), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 10,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [53433] = 11,
    ACTIONS(3852), 1,
      anon_sym_BSLASH,
    ACTIONS(3854), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(3856), 1,
      anon_sym_LBRACK,
    ACTIONS(3858), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1942), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3432), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    STATE(1112), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1154), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3434), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(3860), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [53475] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3401), 17,
      anon_sym_LT,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_cterm,
      aux_sym__hl_term_list_token1,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_gui,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [53499] = 5,
    STATE(1452), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3481), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3862), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 10,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [53529] = 11,
    ACTIONS(3864), 1,
      anon_sym_BSLASH,
    ACTIONS(3866), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(3868), 1,
      anon_sym_LBRACK,
    ACTIONS(3870), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1981), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3432), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    STATE(1115), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1162), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3434), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(3872), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [53571] = 13,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3876), 1,
      anon_sym_BANG,
    ACTIONS(3878), 1,
      anon_sym_PLUS,
    ACTIONS(3880), 1,
      anon_sym_POUND,
    ACTIONS(3886), 1,
      anon_sym_PLUS_PLUS,
    STATE(1216), 1,
      sym_bang,
    STATE(2956), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3688), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1217), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1536), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [53617] = 7,
    ACTIONS(3888), 1,
      anon_sym_BSLASH,
    ACTIONS(3891), 1,
      anon_sym_LBRACK,
    ACTIONS(3894), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1118), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3500), 11,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [53651] = 3,
    ACTIONS(3607), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3605), 16,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [53677] = 5,
    STATE(1507), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3481), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3897), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [53707] = 11,
    ACTIONS(3434), 1,
      anon_sym_BSLASH_PIPE,
    ACTIONS(3899), 1,
      anon_sym_BSLASH,
    ACTIONS(3901), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(3903), 1,
      anon_sym_LBRACK,
    ACTIONS(3905), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1908), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1120), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1143), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3907), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3432), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
  [53749] = 3,
    ACTIONS(2946), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2944), 16,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [53775] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3500), 14,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [53800] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3615), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3613), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [53825] = 9,
    ACTIONS(3740), 1,
      anon_sym_BSLASH,
    ACTIONS(3744), 1,
      anon_sym_LBRACK,
    ACTIONS(3746), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3619), 2,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
    STATE(1090), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1170), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3748), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3617), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
  [53862] = 12,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3909), 1,
      anon_sym_BANG,
    ACTIONS(3911), 1,
      anon_sym_PLUS,
    ACTIONS(3913), 1,
      anon_sym_PLUS_PLUS,
    STATE(1293), 1,
      sym_bang,
    STATE(2762), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3763), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1296), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1617), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [53905] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3500), 14,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [53930] = 10,
    ACTIONS(3670), 1,
      anon_sym_DASHnargs,
    ACTIONS(3672), 1,
      anon_sym_DASHcomplete,
    ACTIONS(3674), 1,
      anon_sym_DASHrange,
    ACTIONS(3676), 1,
      anon_sym_DASHcount,
    ACTIONS(3678), 1,
      anon_sym_DASHaddr,
    ACTIONS(3917), 1,
      sym_command_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1403), 2,
      sym_command_attribute,
      aux_sym_command_statement_repeat1,
    ACTIONS(3915), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(3680), 5,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [53969] = 9,
    ACTIONS(3919), 1,
      anon_sym_BSLASH,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(3925), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3580), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1106), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1129), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3928), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3582), 4,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_minlines,
      anon_sym_maxlines,
  [54006] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3611), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3609), 14,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [54031] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3615), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3613), 14,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [54056] = 9,
    ACTIONS(3810), 1,
      anon_sym_BSLASH,
    ACTIONS(3814), 1,
      anon_sym_LBRACK,
    ACTIONS(3816), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1106), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1129), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3818), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3619), 4,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_minlines,
      anon_sym_maxlines,
  [54093] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3399), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3401), 14,
      anon_sym_LT,
      anon_sym_term,
      anon_sym_cterm,
      aux_sym__hl_term_list_token1,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_gui,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [54118] = 3,
    ACTIONS(3164), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3162), 15,
      sym__separator_first,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [54143] = 11,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3686), 1,
      anon_sym_PLUS,
    ACTIONS(3696), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(3933), 1,
      anon_sym_POUND,
    STATE(2377), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1160), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1365), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(3931), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [54184] = 3,
    ACTIONS(3194), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3192), 15,
      sym__separator_first,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [54209] = 3,
    ACTIONS(2946), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2944), 15,
      sym__separator_first,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [54234] = 3,
    ACTIONS(3607), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3605), 15,
      sym__separator_first,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [54259] = 11,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3686), 1,
      anon_sym_PLUS,
    ACTIONS(3696), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(3933), 1,
      anon_sym_POUND,
    STATE(2377), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1365), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    STATE(1375), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    ACTIONS(3931), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [54300] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3736), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(3734), 14,
      anon_sym_COMMA,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [54325] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3500), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [54350] = 3,
    ACTIONS(3130), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3128), 15,
      sym__separator_first,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [54375] = 9,
    ACTIONS(3935), 1,
      anon_sym_BSLASH,
    ACTIONS(3938), 1,
      anon_sym_LBRACK,
    ACTIONS(3941), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3582), 2,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
    STATE(1120), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1143), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3944), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3580), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
  [54412] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3500), 16,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [54435] = 12,
    ACTIONS(3810), 1,
      anon_sym_BSLASH,
    ACTIONS(3814), 1,
      anon_sym_LBRACK,
    ACTIONS(3816), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1171), 1,
      aux_sym__syn_sync_repeat1,
    STATE(1817), 1,
      sym__syn_sync_lines,
    STATE(2009), 1,
      sym_pattern,
    STATE(2076), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3947), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
    STATE(1106), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1107), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3818), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [54478] = 8,
    ACTIONS(3949), 1,
      anon_sym_BSLASH,
    ACTIONS(3952), 1,
      anon_sym_LBRACK,
    ACTIONS(3955), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1109), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1146), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3958), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3582), 6,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_minlines,
      anon_sym_maxlines,
  [54513] = 5,
    ACTIONS(3961), 1,
      anon_sym_COMMA,
    STATE(1169), 1,
      aux_sym__hl_attr_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3806), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(3804), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [54542] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3613), 16,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [54565] = 8,
    ACTIONS(3831), 1,
      anon_sym_BSLASH,
    ACTIONS(3835), 1,
      anon_sym_LBRACK,
    ACTIONS(3837), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1109), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1146), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3839), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3619), 6,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_minlines,
      anon_sym_maxlines,
  [54600] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3611), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3609), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [54625] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3615), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3613), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [54650] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3500), 14,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [54675] = 9,
    ACTIONS(3899), 1,
      anon_sym_BSLASH,
    ACTIONS(3903), 1,
      anon_sym_LBRACK,
    ACTIONS(3905), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3619), 2,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
    STATE(1120), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1143), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3907), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3617), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
  [54712] = 9,
    ACTIONS(3963), 1,
      anon_sym_BSLASH,
    ACTIONS(3966), 1,
      anon_sym_LBRACK,
    ACTIONS(3969), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3580), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    STATE(1112), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1154), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3972), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3582), 4,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [54749] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3611), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3609), 14,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [54774] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3615), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(3613), 14,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [54799] = 9,
    ACTIONS(3852), 1,
      anon_sym_BSLASH,
    ACTIONS(3856), 1,
      anon_sym_LBRACK,
    ACTIONS(3858), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    STATE(1112), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1154), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3860), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3619), 4,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [54836] = 9,
    ACTIONS(3975), 1,
      aux_sym_argument_token2,
    ACTIONS(3977), 1,
      anon_sym_SLASH,
    ACTIONS(3979), 1,
      anon_sym_BSLASH2,
    ACTIONS(3981), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1629), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3775), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1877), 3,
      sym__plus_cmd_number,
      sym__plus_cmd_command,
      sym__plus_cmd_pattern,
    ACTIONS(3631), 6,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [54873] = 3,
    ACTIONS(3190), 1,
      anon_sym_contained,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3188), 15,
      sym__separator_first,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      anon_sym_contains,
      anon_sym_fold,
      anon_sym_display,
      anon_sym_extend,
      anon_sym_keepend,
      anon_sym_excludenl,
  [54898] = 11,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3686), 1,
      anon_sym_PLUS,
    ACTIONS(3696), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(3985), 1,
      anon_sym_POUND,
    STATE(2482), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1356), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    STATE(1375), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    ACTIONS(3983), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [54939] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3500), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [54964] = 9,
    ACTIONS(3987), 1,
      anon_sym_BSLASH,
    ACTIONS(3990), 1,
      anon_sym_LBRACK,
    ACTIONS(3993), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3580), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    STATE(1115), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1162), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3996), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3582), 4,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [55001] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3611), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3609), 14,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [55026] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3615), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3613), 14,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [55051] = 9,
    ACTIONS(3864), 1,
      anon_sym_BSLASH,
    ACTIONS(3868), 1,
      anon_sym_LBRACK,
    ACTIONS(3870), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    STATE(1115), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1162), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3872), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3619), 4,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [55088] = 12,
    ACTIONS(3831), 1,
      anon_sym_BSLASH,
    ACTIONS(3835), 1,
      anon_sym_LBRACK,
    ACTIONS(3837), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1167), 1,
      aux_sym__syn_sync_repeat1,
    STATE(1817), 1,
      sym__syn_sync_lines,
    STATE(1901), 1,
      sym_pattern,
    STATE(2106), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3947), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
    STATE(1109), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1110), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3839), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [55131] = 12,
    ACTIONS(3831), 1,
      anon_sym_BSLASH,
    ACTIONS(3835), 1,
      anon_sym_LBRACK,
    ACTIONS(3837), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1662), 1,
      aux_sym__syn_sync_repeat1,
    STATE(1817), 1,
      sym__syn_sync_lines,
    STATE(1938), 1,
      sym_pattern,
    STATE(2106), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3947), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
    STATE(1109), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1110), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3839), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [55174] = 5,
    ACTIONS(3961), 1,
      anon_sym_COMMA,
    STATE(1147), 1,
      aux_sym__hl_attr_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3781), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(3779), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [55203] = 5,
    ACTIONS(3999), 1,
      anon_sym_COMMA,
    STATE(1169), 1,
      aux_sym__hl_attr_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3736), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(3734), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [55232] = 9,
    ACTIONS(4002), 1,
      anon_sym_BSLASH,
    ACTIONS(4005), 1,
      anon_sym_LBRACK,
    ACTIONS(4008), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3582), 2,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
    STATE(1090), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1170), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4011), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3580), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
  [55269] = 12,
    ACTIONS(3810), 1,
      anon_sym_BSLASH,
    ACTIONS(3814), 1,
      anon_sym_LBRACK,
    ACTIONS(3816), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1662), 1,
      aux_sym__syn_sync_repeat1,
    STATE(1817), 1,
      sym__syn_sync_lines,
    STATE(1990), 1,
      sym_pattern,
    STATE(2076), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3947), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
    STATE(1106), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1107), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3818), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [55312] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3611), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(3609), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [55337] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3609), 16,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [55360] = 11,
    ACTIONS(3434), 1,
      anon_sym_BSLASH_PIPE,
    ACTIONS(4014), 1,
      anon_sym_BSLASH,
    ACTIONS(4016), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(4018), 1,
      anon_sym_LBRACK,
    ACTIONS(4020), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2190), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3432), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1219), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1236), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4022), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [55400] = 5,
    ACTIONS(4024), 1,
      anon_sym_COMMA,
    STATE(1180), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2558), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2560), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [55428] = 8,
    ACTIONS(4031), 1,
      anon_sym_cchar,
    ACTIONS(4037), 1,
      aux_sym__syn_keyword_token1,
    STATE(1176), 1,
      aux_sym__syn_keyword_repeat2,
    STATE(1362), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4034), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(4026), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4028), 6,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
  [55462] = 8,
    ACTIONS(4044), 1,
      anon_sym_cchar,
    ACTIONS(4048), 1,
      aux_sym__syn_keyword_token1,
    STATE(1176), 1,
      aux_sym__syn_keyword_repeat2,
    STATE(1362), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4046), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(4040), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4042), 6,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
  [55496] = 14,
    ACTIONS(4050), 1,
      anon_sym_LBRACE,
    ACTIONS(4052), 1,
      aux_sym_identifier_token1,
    ACTIONS(4054), 1,
      anon_sym_BANG,
    ACTIONS(4058), 1,
      sym_au_event,
    ACTIONS(4060), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(1360), 1,
      sym_bang,
    STATE(1717), 1,
      sym__curly_braces_name_expression,
    STATE(1893), 1,
      sym__augroup_name,
    STATE(2183), 1,
      sym_identifier,
    STATE(2197), 1,
      sym_au_event_list,
    STATE(2697), 1,
      sym__autocmd_pattern,
    STATE(2698), 1,
      sym__autocmd_command,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4056), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [55542] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4064), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4062), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [55566] = 5,
    ACTIONS(4024), 1,
      anon_sym_COMMA,
    STATE(1181), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2576), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2578), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [55594] = 5,
    ACTIONS(4066), 1,
      anon_sym_COMMA,
    STATE(1181), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2583), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2585), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [55622] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3736), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(3734), 13,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_COMMA,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [55646] = 10,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3761), 1,
      anon_sym_PLUS,
    ACTIONS(3765), 1,
      anon_sym_PLUS_PLUS,
    STATE(2468), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1189), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1443), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(4069), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [55684] = 5,
    ACTIONS(4078), 1,
      sym__wincmd,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4075), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(4073), 4,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4071), 8,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      sym_command_name,
  [55712] = 9,
    ACTIONS(4080), 1,
      anon_sym_QMARK,
    ACTIONS(4084), 1,
      anon_sym_SLASH,
    ACTIONS(4086), 1,
      anon_sym_DOT2,
    ACTIONS(4088), 1,
      anon_sym_PLUS,
    ACTIONS(4090), 1,
      anon_sym_DOLLAR,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4082), 2,
      sym_mark,
      sym_integer_literal,
    ACTIONS(4092), 3,
      anon_sym_BSLASH_SLASH,
      anon_sym_BSLASH_QMARK,
      anon_sym_BSLASH_AMP,
    STATE(2465), 5,
      sym__range_marker,
      sym_current_line,
      sym_next_line,
      sym_last_line,
      sym_previous_pattern,
  [55748] = 9,
    ACTIONS(493), 1,
      anon_sym_DOT2,
    ACTIONS(495), 1,
      anon_sym_PLUS,
    ACTIONS(497), 1,
      anon_sym_DOLLAR,
    ACTIONS(4094), 1,
      anon_sym_QMARK,
    ACTIONS(4098), 1,
      anon_sym_SLASH,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4096), 2,
      sym_mark,
      sym_integer_literal,
    ACTIONS(499), 3,
      anon_sym_BSLASH_SLASH,
      anon_sym_BSLASH_QMARK,
      anon_sym_BSLASH_AMP,
    STATE(1818), 5,
      sym__complete_range_marker,
      sym_current_line,
      sym_next_line,
      sym_last_line,
      sym_previous_pattern,
  [55784] = 11,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3878), 1,
      anon_sym_PLUS,
    ACTIONS(3886), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(4100), 1,
      anon_sym_POUND,
    STATE(2960), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(3983), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1445), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1487), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [55824] = 7,
    ACTIONS(4102), 1,
      anon_sym_BSLASH,
    ACTIONS(4105), 1,
      anon_sym_LBRACK,
    ACTIONS(4108), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1188), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3500), 9,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [55856] = 10,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3761), 1,
      anon_sym_PLUS,
    ACTIONS(3765), 1,
      anon_sym_PLUS_PLUS,
    STATE(2381), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1414), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1429), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(4111), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [55894] = 4,
    STATE(1168), 1,
      sym__hl_none,
    STATE(1318), 1,
      sym__hl_attr_list,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4113), 13,
      anon_sym_NONE2,
      anon_sym_bold,
      anon_sym_underline,
      anon_sym_undercurl,
      anon_sym_underdouble,
      anon_sym_underdotted,
      anon_sym_underdashed,
      anon_sym_strikethrough,
      anon_sym_reverse,
      anon_sym_inverse,
      anon_sym_italic,
      anon_sym_standout,
      anon_sym_nocombine,
  [55920] = 10,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3761), 1,
      anon_sym_PLUS,
    ACTIONS(3765), 1,
      anon_sym_PLUS_PLUS,
    STATE(2384), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1210), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1517), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(4115), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [55958] = 10,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3761), 1,
      anon_sym_PLUS,
    ACTIONS(3765), 1,
      anon_sym_PLUS_PLUS,
    STATE(2384), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1414), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1517), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(4115), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [55996] = 4,
    STATE(1168), 1,
      sym__hl_none,
    STATE(1322), 1,
      sym__hl_attr_list,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4113), 13,
      anon_sym_NONE2,
      anon_sym_bold,
      anon_sym_underline,
      anon_sym_undercurl,
      anon_sym_underdouble,
      anon_sym_underdotted,
      anon_sym_underdashed,
      anon_sym_strikethrough,
      anon_sym_reverse,
      anon_sym_inverse,
      anon_sym_italic,
      anon_sym_standout,
      anon_sym_nocombine,
  [56022] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4119), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4117), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [56046] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4119), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4117), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [56070] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4119), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4117), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [56094] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4119), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4117), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [56118] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4119), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4117), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [56142] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4119), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4117), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [56166] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4119), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4117), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [56190] = 6,
    ACTIONS(4125), 1,
      anon_sym_text,
    STATE(1205), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4127), 2,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4121), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4123), 8,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [56220] = 7,
    ACTIONS(4129), 1,
      anon_sym_BSLASH,
    ACTIONS(4133), 1,
      anon_sym_text,
    STATE(1732), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4135), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token3,
    ACTIONS(4137), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(4131), 8,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [56252] = 10,
    ACTIONS(4139), 1,
      anon_sym_BSLASH,
    ACTIONS(4141), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4145), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2148), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1234), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1283), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3434), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4147), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [56290] = 6,
    ACTIONS(4153), 1,
      anon_sym_text,
    STATE(1207), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4155), 2,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4149), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4151), 8,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [56320] = 6,
    ACTIONS(4153), 1,
      anon_sym_text,
    STATE(1208), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4159), 2,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4157), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4151), 8,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [56350] = 6,
    ACTIONS(4161), 1,
      anon_sym_BSLASH,
    ACTIONS(4164), 1,
      anon_sym_LBRACK,
    ACTIONS(4167), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1206), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3500), 11,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [56380] = 6,
    ACTIONS(4172), 1,
      anon_sym_text,
    STATE(1208), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4159), 2,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4157), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4170), 8,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [56410] = 6,
    ACTIONS(4179), 1,
      anon_sym_text,
    STATE(1208), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4181), 2,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4174), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4177), 8,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [56440] = 5,
    STATE(1212), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4186), 2,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4184), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4123), 9,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [56468] = 10,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3761), 1,
      anon_sym_PLUS,
    ACTIONS(3765), 1,
      anon_sym_PLUS_PLUS,
    STATE(2488), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1414), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1433), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(4188), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [56506] = 5,
    STATE(1213), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4192), 2,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4190), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4151), 9,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [56534] = 5,
    STATE(1214), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4196), 2,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4194), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4151), 9,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [56562] = 5,
    STATE(1214), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4196), 2,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4194), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4170), 9,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [56590] = 5,
    STATE(1214), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4201), 2,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4198), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4177), 9,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [56618] = 8,
    ACTIONS(4044), 1,
      anon_sym_cchar,
    ACTIONS(4206), 1,
      aux_sym__syn_keyword_token1,
    STATE(1228), 1,
      aux_sym__syn_keyword_repeat2,
    STATE(1362), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4046), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(4204), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4042), 6,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
  [56652] = 11,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3878), 1,
      anon_sym_PLUS,
    ACTIONS(3886), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(4208), 1,
      anon_sym_POUND,
    STATE(2831), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(3931), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1187), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1444), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [56692] = 11,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3878), 1,
      anon_sym_PLUS,
    ACTIONS(3886), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(4208), 1,
      anon_sym_POUND,
    STATE(2831), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(3931), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1444), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    STATE(1445), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
  [56732] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4212), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4210), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [56756] = 5,
    STATE(1671), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3481), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4214), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [56784] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4218), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4216), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [56808] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4222), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4220), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [56832] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4226), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4224), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [56856] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4230), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4228), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [56880] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4234), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4232), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [56904] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4238), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4236), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [56928] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4242), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4240), 13,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [56952] = 5,
    ACTIONS(4244), 1,
      sym_hl_group,
    STATE(1338), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3213), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(3215), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [56980] = 8,
    ACTIONS(4044), 1,
      anon_sym_cchar,
    ACTIONS(4048), 1,
      aux_sym__syn_keyword_token1,
    STATE(1176), 1,
      aux_sym__syn_keyword_repeat2,
    STATE(1362), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4046), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(4246), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4042), 6,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
  [57014] = 8,
    ACTIONS(4044), 1,
      anon_sym_cchar,
    ACTIONS(4248), 1,
      aux_sym__syn_keyword_token1,
    STATE(1177), 1,
      aux_sym__syn_keyword_repeat2,
    STATE(1362), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4046), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(4246), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4042), 6,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
  [57048] = 9,
    ACTIONS(4250), 1,
      anon_sym_QMARK,
    ACTIONS(4254), 1,
      anon_sym_SLASH,
    ACTIONS(4256), 1,
      anon_sym_DOT2,
    ACTIONS(4258), 1,
      anon_sym_PLUS,
    ACTIONS(4260), 1,
      anon_sym_DOLLAR,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4252), 2,
      sym_mark,
      sym_integer_literal,
    ACTIONS(4262), 3,
      anon_sym_BSLASH_SLASH,
      anon_sym_BSLASH_QMARK,
      anon_sym_BSLASH_AMP,
    STATE(2323), 5,
      sym__range_marker,
      sym_current_line,
      sym_next_line,
      sym_last_line,
      sym_previous_pattern,
  [57084] = 4,
    STATE(1098), 1,
      sym__hl_none,
    STATE(1218), 1,
      sym__hl_attr_list,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4264), 13,
      anon_sym_NONE2,
      anon_sym_bold,
      anon_sym_underline,
      anon_sym_undercurl,
      anon_sym_underdouble,
      anon_sym_underdotted,
      anon_sym_underdashed,
      anon_sym_strikethrough,
      anon_sym_reverse,
      anon_sym_inverse,
      anon_sym_italic,
      anon_sym_standout,
      anon_sym_nocombine,
  [57110] = 4,
    STATE(1098), 1,
      sym__hl_none,
    STATE(1222), 1,
      sym__hl_attr_list,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4264), 13,
      anon_sym_NONE2,
      anon_sym_bold,
      anon_sym_underline,
      anon_sym_undercurl,
      anon_sym_underdouble,
      anon_sym_underdotted,
      anon_sym_underdashed,
      anon_sym_strikethrough,
      anon_sym_reverse,
      anon_sym_inverse,
      anon_sym_italic,
      anon_sym_standout,
      anon_sym_nocombine,
  [57136] = 10,
    ACTIONS(3670), 1,
      anon_sym_DASHnargs,
    ACTIONS(3672), 1,
      anon_sym_DASHcomplete,
    ACTIONS(3674), 1,
      anon_sym_DASHrange,
    ACTIONS(3676), 1,
      anon_sym_DASHcount,
    ACTIONS(3678), 1,
      anon_sym_DASHaddr,
    ACTIONS(4266), 1,
      sym_command_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3915), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1397), 2,
      sym_command_attribute,
      aux_sym_command_statement_repeat1,
    ACTIONS(3680), 5,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [57174] = 4,
    STATE(1653), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4268), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 10,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [57200] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4270), 14,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      sym_command_name,
  [57221] = 9,
    ACTIONS(4272), 1,
      anon_sym_BSLASH,
    ACTIONS(4275), 1,
      anon_sym_LBRACK,
    ACTIONS(4278), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3580), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3582), 2,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
    STATE(1219), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1236), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4281), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [57256] = 7,
    ACTIONS(3498), 1,
      sym__separator,
    ACTIONS(4284), 1,
      anon_sym_BSLASH,
    ACTIONS(4287), 1,
      anon_sym_LBRACK,
    ACTIONS(4290), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1237), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3500), 9,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [57287] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4064), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4062), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [57310] = 6,
    STATE(1244), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4293), 2,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token7,
    ACTIONS(4123), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4295), 3,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4125), 5,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [57339] = 4,
    STATE(1710), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4297), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 9,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_RPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [57364] = 10,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4301), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2315), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3434), 2,
      anon_sym_BSLASH_PIPE,
      anon_sym_BSLASH_RPAREN,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1336), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [57401] = 14,
    ACTIONS(4309), 1,
      anon_sym_LBRACE,
    ACTIONS(4311), 1,
      aux_sym_identifier_token1,
    ACTIONS(4313), 1,
      anon_sym_BANG,
    ACTIONS(4315), 1,
      sym_au_event,
    ACTIONS(4317), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(1494), 1,
      sym_bang,
    STATE(1839), 1,
      sym__curly_braces_name_expression,
    STATE(1988), 1,
      sym__augroup_name,
    STATE(2287), 1,
      sym_identifier,
    STATE(2366), 1,
      sym_au_event_list,
    STATE(2943), 1,
      sym__autocmd_pattern,
    STATE(2944), 1,
      sym__autocmd_command,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4319), 2,
      sym__newline_or_pipe,
      sym_comment,
  [57446] = 6,
    STATE(1247), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4321), 2,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token7,
    ACTIONS(4151), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4323), 3,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4153), 5,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [57475] = 6,
    STATE(1248), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4325), 2,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token7,
    ACTIONS(4151), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4327), 3,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4153), 5,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [57504] = 6,
    ACTIONS(4329), 1,
      anon_sym_BSLASH,
    ACTIONS(4332), 1,
      anon_sym_LBRACK,
    ACTIONS(4335), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1245), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3500), 10,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_RPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [57533] = 8,
    ACTIONS(4338), 1,
      aux_sym_argument_token2,
    ACTIONS(4340), 1,
      anon_sym_SLASH,
    ACTIONS(4342), 1,
      anon_sym_BSLASH2,
    ACTIONS(4344), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1722), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2032), 3,
      sym__plus_cmd_number,
      sym__plus_cmd_command,
      sym__plus_cmd_pattern,
    ACTIONS(3631), 6,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [57566] = 6,
    STATE(1248), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4325), 2,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token7,
    ACTIONS(4170), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4327), 3,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4172), 5,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [57595] = 6,
    STATE(1248), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4346), 2,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token7,
    ACTIONS(4177), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4349), 3,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4179), 5,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [57624] = 5,
    ACTIONS(4352), 1,
      sym_hl_group,
    STATE(1513), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3213), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3215), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [57651] = 5,
    ACTIONS(4354), 1,
      anon_sym_COMMA,
    STATE(1252), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2558), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2560), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [57678] = 10,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3911), 1,
      anon_sym_PLUS,
    ACTIONS(3913), 1,
      anon_sym_PLUS_PLUS,
    STATE(2834), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4069), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1290), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1598), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [57715] = 5,
    ACTIONS(4354), 1,
      anon_sym_COMMA,
    STATE(1253), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2576), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2578), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [57742] = 5,
    ACTIONS(4356), 1,
      anon_sym_COMMA,
    STATE(1253), 1,
      aux_sym_hl_groups_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2583), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(2585), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [57769] = 8,
    ACTIONS(4362), 1,
      anon_sym_cchar,
    ACTIONS(4368), 1,
      aux_sym__syn_keyword_token1,
    STATE(1254), 1,
      aux_sym__syn_keyword_repeat2,
    STATE(1516), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4026), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4365), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(4359), 6,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
  [57802] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4371), 14,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      sym_command_name,
  [57823] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4373), 14,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      sym_command_name,
  [57844] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4375), 14,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      sym_command_name,
  [57865] = 8,
    ACTIONS(4379), 1,
      anon_sym_cchar,
    ACTIONS(4383), 1,
      aux_sym__syn_keyword_token1,
    STATE(1254), 1,
      aux_sym__syn_keyword_repeat2,
    STATE(1516), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4040), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4381), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(4377), 6,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
  [57898] = 5,
    ACTIONS(4385), 1,
      sym__wincmd,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4075), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(4073), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
    ACTIONS(4071), 8,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      sym_command_name,
  [57925] = 8,
    ACTIONS(4379), 1,
      anon_sym_cchar,
    ACTIONS(4387), 1,
      aux_sym__syn_keyword_token1,
    STATE(1330), 1,
      aux_sym__syn_keyword_repeat2,
    STATE(1516), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4204), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4381), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(4377), 6,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
  [57958] = 11,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(4389), 1,
      anon_sym_BANG,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    STATE(1422), 1,
      sym_bang,
    STATE(2926), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1425), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1768), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [57997] = 10,
    ACTIONS(4395), 1,
      anon_sym_BANG,
    ACTIONS(4399), 1,
      sym_hl_group,
    ACTIONS(4401), 1,
      anon_sym_link,
    ACTIONS(4403), 1,
      anon_sym_clear,
    ACTIONS(4405), 1,
      sym__default,
    STATE(1510), 1,
      sym_bang,
    STATE(2369), 1,
      sym__hl_body_link,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4397), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(2370), 4,
      sym__hl_body_clear,
      sym__hl_body_none,
      sym__hl_body_keys,
      sym__hl_body,
  [58034] = 10,
    ACTIONS(4014), 1,
      anon_sym_BSLASH,
    ACTIONS(4018), 1,
      anon_sym_LBRACK,
    ACTIONS(4407), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2288), 1,
      sym__pattern_branch,
    STATE(2934), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4409), 2,
      anon_sym_grouphere,
      anon_sym_groupthere,
    STATE(1174), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1219), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(4022), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [58071] = 6,
    ACTIONS(4125), 1,
      anon_sym_text,
    STATE(1266), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4413), 2,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4411), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4123), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [58100] = 6,
    ACTIONS(4153), 1,
      anon_sym_text,
    STATE(1268), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4417), 2,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4415), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4151), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [58129] = 6,
    ACTIONS(4153), 1,
      anon_sym_text,
    STATE(1269), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4421), 2,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4419), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4151), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [58158] = 3,
    STATE(1182), 1,
      sym__hl_none,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4423), 13,
      anon_sym_NONE2,
      anon_sym_bold,
      anon_sym_underline,
      anon_sym_undercurl,
      anon_sym_underdouble,
      anon_sym_underdotted,
      anon_sym_underdashed,
      anon_sym_strikethrough,
      anon_sym_reverse,
      anon_sym_inverse,
      anon_sym_italic,
      anon_sym_standout,
      anon_sym_nocombine,
  [58181] = 6,
    ACTIONS(4172), 1,
      anon_sym_text,
    STATE(1269), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4421), 2,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4419), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4170), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [58210] = 6,
    ACTIONS(4179), 1,
      anon_sym_text,
    STATE(1269), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4428), 2,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4425), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4177), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [58239] = 5,
    STATE(1274), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4433), 2,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4431), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4123), 8,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [58266] = 5,
    ACTIONS(3481), 1,
      anon_sym_QMARK2,
    STATE(1759), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4435), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [58293] = 11,
    ACTIONS(3432), 1,
      anon_sym_QMARK2,
    ACTIONS(3434), 1,
      anon_sym_BSLASH_PIPE,
    ACTIONS(4437), 1,
      anon_sym_BSLASH,
    ACTIONS(4439), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(4441), 1,
      anon_sym_LBRACK,
    ACTIONS(4443), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2306), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1271), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1382), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4445), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [58332] = 5,
    STATE(1276), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4449), 2,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4447), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4151), 8,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [58359] = 5,
    STATE(1277), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4453), 2,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4451), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4151), 8,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [58386] = 7,
    ACTIONS(3498), 1,
      anon_sym_QMARK2,
    ACTIONS(4455), 1,
      anon_sym_BSLASH,
    ACTIONS(4458), 1,
      anon_sym_LBRACK,
    ACTIONS(4461), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1275), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3500), 9,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [58417] = 5,
    STATE(1277), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4453), 2,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4451), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4170), 8,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [58444] = 5,
    STATE(1277), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4467), 2,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4464), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4177), 8,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [58471] = 7,
    ACTIONS(4133), 1,
      anon_sym_text,
    ACTIONS(4470), 1,
      anon_sym_BSLASH,
    STATE(1865), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4472), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token3,
    ACTIONS(4474), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(4131), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [58502] = 11,
    ACTIONS(3432), 1,
      anon_sym_SLASH2,
    ACTIONS(3434), 1,
      anon_sym_BSLASH_PIPE,
    ACTIONS(4476), 1,
      anon_sym_BSLASH,
    ACTIONS(4478), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(4480), 1,
      anon_sym_LBRACK,
    ACTIONS(4482), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2307), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1332), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1393), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4484), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [58541] = 7,
    ACTIONS(3498), 1,
      anon_sym_SLASH2,
    ACTIONS(4486), 1,
      anon_sym_BSLASH,
    ACTIONS(4489), 1,
      anon_sym_LBRACK,
    ACTIONS(4492), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1280), 1,
      aux_sym__pattern_ordinary_atom,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3500), 9,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [58572] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3500), 14,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [58593] = 11,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(4389), 1,
      anon_sym_BANG,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    STATE(1505), 1,
      sym_bang,
    STATE(2749), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1465), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1776), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [58632] = 8,
    ACTIONS(4495), 1,
      anon_sym_BSLASH,
    ACTIONS(4498), 1,
      anon_sym_LBRACK,
    ACTIONS(4501), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1234), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1283), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4504), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3582), 4,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [58665] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4509), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(4507), 10,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [58688] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4513), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(4511), 10,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [58711] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3609), 14,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [58732] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3613), 14,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [58753] = 8,
    ACTIONS(4139), 1,
      anon_sym_BSLASH,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4145), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1234), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1283), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4147), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
    ACTIONS(3619), 4,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [58786] = 4,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4075), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(4073), 4,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4071), 8,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      sym_command_name,
  [58811] = 10,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3911), 1,
      anon_sym_PLUS,
    ACTIONS(3913), 1,
      anon_sym_PLUS_PLUS,
    STATE(2872), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4111), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1555), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    STATE(1630), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
  [58848] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4509), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(4507), 12,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [58871] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4513), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(4511), 12,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [58894] = 10,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3911), 1,
      anon_sym_PLUS,
    ACTIONS(3913), 1,
      anon_sym_PLUS_PLUS,
    STATE(2874), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4115), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1303), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1556), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [58931] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4509), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(4507), 10,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [58954] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4513), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(4511), 10,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [58977] = 10,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3911), 1,
      anon_sym_PLUS,
    ACTIONS(3913), 1,
      anon_sym_PLUS_PLUS,
    STATE(2874), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4115), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1556), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    STATE(1630), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
  [59014] = 4,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4519), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(4517), 4,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4515), 8,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      sym_command_name,
  [59039] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4509), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(4507), 12,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [59062] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4513), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(4511), 12,
      anon_sym_BSLASH,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [59085] = 10,
    ACTIONS(4139), 1,
      anon_sym_BSLASH,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4145), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2292), 1,
      sym__pattern_branch,
    STATE(2605), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4522), 2,
      anon_sym_grouphere,
      anon_sym_groupthere,
    STATE(1203), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1234), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(4147), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [59122] = 10,
    ACTIONS(4526), 1,
      anon_sym_BSLASH,
    ACTIONS(4528), 1,
      anon_sym_BANG,
    STATE(1520), 1,
      sym_bang,
    STATE(1773), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1898), 1,
      sym_filename,
    STATE(1936), 1,
      sym__runtime_where,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4530), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token3,
    ACTIONS(4532), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(4524), 4,
      anon_sym_START,
      anon_sym_OPT,
      anon_sym_PACK,
      anon_sym_ALL,
  [59159] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2583), 4,
      anon_sym_COMMA,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(2585), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [59182] = 10,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3911), 1,
      anon_sym_PLUS,
    ACTIONS(3913), 1,
      anon_sym_PLUS_PLUS,
    STATE(2974), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4188), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1621), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    STATE(1630), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
  [59219] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4119), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4117), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [59242] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4119), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4117), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [59265] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(740), 14,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [59286] = 10,
    ACTIONS(4528), 1,
      anon_sym_BANG,
    ACTIONS(4534), 1,
      anon_sym_BSLASH,
    STATE(1479), 1,
      sym_bang,
    STATE(1683), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1831), 1,
      sym_filename,
    STATE(1956), 1,
      sym__runtime_where,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4536), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token3,
    ACTIONS(4538), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(4524), 4,
      anon_sym_START,
      anon_sym_OPT,
      anon_sym_PACK,
      anon_sym_ALL,
  [59323] = 11,
    ACTIONS(4389), 1,
      anon_sym_BANG,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    STATE(1421), 1,
      sym_bang,
    STATE(2464), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1423), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1770), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [59362] = 11,
    ACTIONS(4389), 1,
      anon_sym_BANG,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    STATE(1456), 1,
      sym_bang,
    STATE(2474), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1457), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1786), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [59401] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4119), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4117), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [59424] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3498), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3500), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [59447] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3611), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3609), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [59470] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4119), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4117), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [59493] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3615), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3613), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [59516] = 9,
    ACTIONS(4014), 1,
      anon_sym_BSLASH,
    ACTIONS(4018), 1,
      anon_sym_LBRACK,
    ACTIONS(4020), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3619), 2,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
    STATE(1219), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1236), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4022), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [59551] = 5,
    ACTIONS(3481), 1,
      sym__separator,
    STATE(1760), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4542), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [59578] = 11,
    ACTIONS(3432), 1,
      sym__separator,
    ACTIONS(3434), 1,
      anon_sym_BSLASH_PIPE,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4546), 1,
      anon_sym_BSLASH_AMP,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2310), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1384), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [59617] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4212), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4210), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [59640] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4119), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4117), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [59663] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4218), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4216), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [59686] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4222), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4220), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [59709] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4226), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4224), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [59732] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4230), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4228), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [59755] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4234), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4232), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [59778] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4238), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4236), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [59801] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4242), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4240), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [59824] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4119), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4117), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [59847] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4119), 2,
      anon_sym_cterm,
      anon_sym_gui,
    ACTIONS(4117), 12,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_term,
      anon_sym_start,
      anon_sym_stop,
      anon_sym_ctermfg,
      anon_sym_ctermbg,
      anon_sym_guifg,
      anon_sym_guibg,
      anon_sym_guisp,
      anon_sym_font,
      anon_sym_blend,
  [59870] = 3,
    STATE(1140), 1,
      sym__hl_none,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4554), 13,
      anon_sym_NONE2,
      anon_sym_bold,
      anon_sym_underline,
      anon_sym_undercurl,
      anon_sym_underdouble,
      anon_sym_underdotted,
      anon_sym_underdashed,
      anon_sym_strikethrough,
      anon_sym_reverse,
      anon_sym_inverse,
      anon_sym_italic,
      anon_sym_standout,
      anon_sym_nocombine,
  [59893] = 8,
    ACTIONS(4379), 1,
      anon_sym_cchar,
    ACTIONS(4383), 1,
      aux_sym__syn_keyword_token1,
    STATE(1254), 1,
      aux_sym__syn_keyword_repeat2,
    STATE(1516), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4246), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4381), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(4377), 6,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
  [59926] = 8,
    ACTIONS(4379), 1,
      anon_sym_cchar,
    ACTIONS(4556), 1,
      aux_sym__syn_keyword_token1,
    STATE(1258), 1,
      aux_sym__syn_keyword_repeat2,
    STATE(1516), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4246), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4381), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(4377), 6,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
  [59959] = 5,
    ACTIONS(3481), 1,
      anon_sym_SLASH2,
    STATE(1711), 1,
      sym_pattern_multi,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4558), 4,
      anon_sym_STAR2,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
    ACTIONS(3479), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [59986] = 6,
    ACTIONS(4560), 1,
      anon_sym_LBRACE2,
    ACTIONS(4563), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1333), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(910), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(912), 6,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [60014] = 6,
    STATE(1339), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4153), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(4566), 2,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token7,
    ACTIONS(4568), 3,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4151), 5,
      sym_string_literal,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [60042] = 10,
    ACTIONS(4570), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(4572), 1,
      anon_sym_BSLASH,
    ACTIONS(4576), 1,
      anon_sym_LTexpr_GT,
    ACTIONS(4578), 1,
      anon_sym_LT2,
    STATE(1389), 1,
      aux_sym_map_statement_repeat1,
    STATE(1775), 1,
      sym_keycode,
    STATE(1910), 1,
      sym__map_lhs,
    STATE(2754), 1,
      sym__map_definition,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4574), 5,
      anon_sym_LTbuffer_GT,
      anon_sym_LTnowait_GT,
      anon_sym_LTsilent_GT,
      anon_sym_LTunique_GT,
      anon_sym_LTscript_GT,
  [60078] = 8,
    ACTIONS(4580), 1,
      anon_sym_BSLASH,
    ACTIONS(4583), 1,
      anon_sym_LBRACK,
    ACTIONS(4586), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1336), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3582), 3,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(4589), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [60110] = 6,
    STATE(1339), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4172), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(4566), 2,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token7,
    ACTIONS(4568), 3,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4170), 5,
      sym_string_literal,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [60138] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3188), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(3190), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [60160] = 6,
    STATE(1339), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4179), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(4592), 2,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token7,
    ACTIONS(4595), 3,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4177), 5,
      sym_string_literal,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [60188] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4375), 13,
      sym__newline_or_pipe,
      sym_comment,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      sym_command_name,
  [60208] = 3,
    ACTIONS(1916), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1914), 12,
      anon_sym_EQ_LT_LT,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [60230] = 3,
    ACTIONS(1920), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1918), 12,
      anon_sym_EQ_LT_LT,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [60252] = 3,
    ACTIONS(1924), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1922), 12,
      anon_sym_EQ_LT_LT,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [60274] = 3,
    ACTIONS(3615), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3613), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [60296] = 9,
    ACTIONS(3617), 1,
      sym__separator,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3619), 2,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1384), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [60330] = 6,
    ACTIONS(4598), 1,
      anon_sym_LBRACE2,
    ACTIONS(4600), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1348), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1064), 3,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
    ACTIONS(1062), 6,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_EQ_LT_LT,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [60358] = 10,
    ACTIONS(4602), 1,
      anon_sym_BANG,
    ACTIONS(4604), 1,
      sym_hl_group,
    ACTIONS(4606), 1,
      anon_sym_link,
    ACTIONS(4608), 1,
      anon_sym_clear,
    ACTIONS(4610), 1,
      sym__default,
    STATE(1568), 1,
      sym_bang,
    STATE(2851), 1,
      sym__hl_body_link,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4397), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(2857), 4,
      sym__hl_body_clear,
      sym__hl_body_none,
      sym__hl_body_keys,
      sym__hl_body,
  [60394] = 6,
    ACTIONS(4598), 1,
      anon_sym_LBRACE2,
    ACTIONS(4612), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1351), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(904), 3,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
    ACTIONS(902), 6,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_EQ_LT_LT,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [60422] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4371), 13,
      sym__newline_or_pipe,
      sym_comment,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      sym_command_name,
  [60442] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3609), 13,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_RPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [60462] = 6,
    ACTIONS(4614), 1,
      anon_sym_LBRACE2,
    ACTIONS(4617), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1351), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(912), 3,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
    ACTIONS(910), 6,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_EQ_LT_LT,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [60490] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3162), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(3164), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [60512] = 6,
    ACTIONS(4622), 1,
      aux_sym_filename_token7,
    STATE(1354), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4151), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4620), 4,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4153), 5,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [60540] = 6,
    ACTIONS(4626), 1,
      aux_sym_filename_token7,
    STATE(1355), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4170), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4624), 4,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4172), 5,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [60568] = 6,
    ACTIONS(4631), 1,
      aux_sym_filename_token7,
    STATE(1355), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4177), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4628), 4,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4179), 5,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [60596] = 9,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(4634), 1,
      anon_sym_PLUS,
    ACTIONS(4638), 1,
      anon_sym_POUND,
    STATE(2656), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1522), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(4636), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [60630] = 6,
    ACTIONS(4626), 1,
      aux_sym_filename_token7,
    STATE(1355), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4151), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4624), 4,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4153), 5,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [60658] = 11,
    ACTIONS(4642), 1,
      anon_sym_detect,
    ACTIONS(4644), 1,
      anon_sym_plugin,
    ACTIONS(4646), 1,
      anon_sym_indent,
    STATE(2443), 1,
      sym__filetype_state,
    STATE(2444), 1,
      sym__filetype_enable,
    STATE(2445), 1,
      sym__filetype_detect,
    STATE(2447), 1,
      sym__filetype_plugin,
    STATE(2449), 1,
      sym__filetype_indent,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4640), 2,
      anon_sym_on,
      anon_sym_off,
    ACTIONS(4648), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [60696] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3613), 13,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_RPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [60716] = 12,
    ACTIONS(4050), 1,
      anon_sym_LBRACE,
    ACTIONS(4052), 1,
      aux_sym_identifier_token1,
    ACTIONS(4058), 1,
      sym_au_event,
    ACTIONS(4060), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(1717), 1,
      sym__curly_braces_name_expression,
    STATE(1803), 1,
      sym__augroup_name,
    STATE(2163), 1,
      sym_au_event_list,
    STATE(2183), 1,
      sym_identifier,
    STATE(2599), 1,
      sym__autocmd_pattern,
    STATE(2600), 1,
      sym__autocmd_command,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4650), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [60756] = 4,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4075), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(4073), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
    ACTIONS(4071), 8,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      sym_command_name,
  [60780] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4652), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4654), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [60802] = 8,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1336), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3619), 3,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [60834] = 6,
    ACTIONS(4658), 1,
      aux_sym_filename_token7,
    STATE(1357), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4123), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4656), 4,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4125), 5,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [60862] = 9,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3985), 1,
      anon_sym_POUND,
    ACTIONS(4634), 1,
      anon_sym_PLUS,
    STATE(2482), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1522), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(3983), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [60896] = 5,
    ACTIONS(3637), 1,
      anon_sym_BSLASH2,
    ACTIONS(3639), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1399), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4660), 10,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [60922] = 6,
    ACTIONS(4662), 1,
      anon_sym_LBRACE2,
    ACTIONS(4664), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1368), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1062), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(1064), 6,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [60950] = 6,
    ACTIONS(4662), 1,
      anon_sym_LBRACE2,
    ACTIONS(4666), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1404), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(902), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(904), 6,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [60978] = 6,
    STATE(1337), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4153), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(4668), 2,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token7,
    ACTIONS(4670), 3,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4151), 5,
      sym_string_literal,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [61006] = 6,
    ACTIONS(4672), 1,
      anon_sym_LBRACE2,
    ACTIONS(4674), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1371), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1062), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(1064), 6,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [61034] = 6,
    ACTIONS(4672), 1,
      anon_sym_LBRACE2,
    ACTIONS(4676), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1333), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(902), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(904), 6,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [61062] = 3,
    ACTIONS(3611), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3609), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [61084] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(740), 13,
      sym__newline_or_pipe,
      sym_comment,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [61104] = 10,
    ACTIONS(4570), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(4572), 1,
      anon_sym_BSLASH,
    ACTIONS(4578), 1,
      anon_sym_LT2,
    ACTIONS(4680), 1,
      anon_sym_LTexpr_GT,
    STATE(1378), 1,
      aux_sym_map_statement_repeat1,
    STATE(1775), 1,
      sym_keycode,
    STATE(1948), 1,
      sym__map_lhs,
    STATE(2719), 1,
      sym__map_definition,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4678), 5,
      anon_sym_LTbuffer_GT,
      anon_sym_LTnowait_GT,
      anon_sym_LTsilent_GT,
      anon_sym_LTunique_GT,
      anon_sym_LTscript_GT,
  [61140] = 5,
    ACTIONS(4686), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1375), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    ACTIONS(4682), 4,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4684), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [61166] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4373), 13,
      sym__newline_or_pipe,
      sym_comment,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      sym_command_name,
  [61186] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2583), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_COMMA,
    ACTIONS(2585), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [61208] = 10,
    ACTIONS(4570), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(4572), 1,
      anon_sym_BSLASH,
    ACTIONS(4578), 1,
      anon_sym_LT2,
    ACTIONS(4680), 1,
      anon_sym_LTexpr_GT,
    STATE(1656), 1,
      aux_sym_map_statement_repeat1,
    STATE(1775), 1,
      sym_keycode,
    STATE(1948), 1,
      sym__map_lhs,
    STATE(2650), 1,
      sym__map_definition,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4689), 5,
      anon_sym_LTbuffer_GT,
      anon_sym_LTnowait_GT,
      anon_sym_LTsilent_GT,
      anon_sym_LTunique_GT,
      anon_sym_LTscript_GT,
  [61244] = 3,
    ACTIONS(3498), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3500), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [61266] = 3,
    ACTIONS(3498), 1,
      anon_sym_QMARK2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3500), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [61288] = 4,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4519), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(4517), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
    ACTIONS(4515), 8,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      sym_command_name,
  [61312] = 9,
    ACTIONS(3580), 1,
      anon_sym_QMARK2,
    ACTIONS(4691), 1,
      anon_sym_BSLASH,
    ACTIONS(4694), 1,
      anon_sym_LBRACK,
    ACTIONS(4697), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3582), 2,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
    STATE(1271), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1382), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4700), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [61346] = 9,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3933), 1,
      anon_sym_POUND,
    ACTIONS(4634), 1,
      anon_sym_PLUS,
    STATE(2377), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1522), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(3931), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [61380] = 9,
    ACTIONS(3580), 1,
      sym__separator,
    ACTIONS(4703), 1,
      anon_sym_BSLASH,
    ACTIONS(4706), 1,
      anon_sym_LBRACK,
    ACTIONS(4709), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3582), 2,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1384), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4712), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [61414] = 3,
    ACTIONS(3611), 1,
      anon_sym_QMARK2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3609), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [61436] = 3,
    ACTIONS(3615), 1,
      anon_sym_QMARK2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3613), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [61458] = 9,
    ACTIONS(3617), 1,
      anon_sym_QMARK2,
    ACTIONS(4437), 1,
      anon_sym_BSLASH,
    ACTIONS(4441), 1,
      anon_sym_LBRACK,
    ACTIONS(4443), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3619), 2,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
    STATE(1271), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1382), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4445), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [61492] = 9,
    ACTIONS(3670), 1,
      anon_sym_DASHnargs,
    ACTIONS(3672), 1,
      anon_sym_DASHcomplete,
    ACTIONS(3674), 1,
      anon_sym_DASHrange,
    ACTIONS(3676), 1,
      anon_sym_DASHcount,
    ACTIONS(3678), 1,
      anon_sym_DASHaddr,
    ACTIONS(4715), 1,
      sym_command_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1398), 2,
      sym_command_attribute,
      aux_sym_command_statement_repeat1,
    ACTIONS(3680), 5,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [61526] = 10,
    ACTIONS(4570), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(4572), 1,
      anon_sym_BSLASH,
    ACTIONS(4576), 1,
      anon_sym_LTexpr_GT,
    ACTIONS(4578), 1,
      anon_sym_LT2,
    STATE(1656), 1,
      aux_sym_map_statement_repeat1,
    STATE(1775), 1,
      sym_keycode,
    STATE(1910), 1,
      sym__map_lhs,
    STATE(2961), 1,
      sym__map_definition,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4689), 5,
      anon_sym_LTbuffer_GT,
      anon_sym_LTnowait_GT,
      anon_sym_LTsilent_GT,
      anon_sym_LTunique_GT,
      anon_sym_LTscript_GT,
  [61562] = 5,
    ACTIONS(3637), 1,
      anon_sym_BSLASH2,
    ACTIONS(3639), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1399), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4717), 10,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [61588] = 3,
    ACTIONS(3498), 1,
      anon_sym_SLASH2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3500), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [61610] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4270), 13,
      sym__newline_or_pipe,
      sym_comment,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      sym_command_name,
  [61630] = 9,
    ACTIONS(3580), 1,
      anon_sym_SLASH2,
    ACTIONS(4719), 1,
      anon_sym_BSLASH,
    ACTIONS(4722), 1,
      anon_sym_LBRACK,
    ACTIONS(4725), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3582), 2,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
    STATE(1332), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1393), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4728), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [61664] = 3,
    ACTIONS(3611), 1,
      anon_sym_SLASH2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3609), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [61686] = 3,
    ACTIONS(3615), 1,
      anon_sym_SLASH2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3613), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [61708] = 9,
    ACTIONS(3617), 1,
      anon_sym_SLASH2,
    ACTIONS(4476), 1,
      anon_sym_BSLASH,
    ACTIONS(4480), 1,
      anon_sym_LBRACK,
    ACTIONS(4482), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3619), 2,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
    STATE(1332), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1393), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4484), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [61742] = 9,
    ACTIONS(3670), 1,
      anon_sym_DASHnargs,
    ACTIONS(3672), 1,
      anon_sym_DASHcomplete,
    ACTIONS(3674), 1,
      anon_sym_DASHrange,
    ACTIONS(3676), 1,
      anon_sym_DASHcount,
    ACTIONS(3678), 1,
      anon_sym_DASHaddr,
    ACTIONS(4731), 1,
      sym_command_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1398), 2,
      sym_command_attribute,
      aux_sym_command_statement_repeat1,
    ACTIONS(3680), 5,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [61776] = 9,
    ACTIONS(4733), 1,
      sym_command_name,
    ACTIONS(4735), 1,
      anon_sym_DASHnargs,
    ACTIONS(4738), 1,
      anon_sym_DASHcomplete,
    ACTIONS(4741), 1,
      anon_sym_DASHrange,
    ACTIONS(4744), 1,
      anon_sym_DASHcount,
    ACTIONS(4747), 1,
      anon_sym_DASHaddr,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1398), 2,
      sym_command_attribute,
      aux_sym_command_statement_repeat1,
    ACTIONS(4750), 5,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [61810] = 5,
    ACTIONS(4755), 1,
      anon_sym_BSLASH2,
    ACTIONS(4758), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1399), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4753), 10,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [61836] = 6,
    STATE(1334), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4125), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(4761), 2,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token7,
    ACTIONS(4763), 3,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4123), 5,
      sym_string_literal,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [61864] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3500), 13,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_STAR2,
      anon_sym_LBRACK,
      aux_sym_pattern_multi_token1,
      aux_sym_pattern_multi_token2,
      aux_sym_pattern_multi_token3,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_RPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [61884] = 9,
    ACTIONS(3670), 1,
      anon_sym_DASHnargs,
    ACTIONS(3672), 1,
      anon_sym_DASHcomplete,
    ACTIONS(3674), 1,
      anon_sym_DASHrange,
    ACTIONS(3676), 1,
      anon_sym_DASHcount,
    ACTIONS(3678), 1,
      anon_sym_DASHaddr,
    ACTIONS(4765), 1,
      sym_command_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1398), 2,
      sym_command_attribute,
      aux_sym_command_statement_repeat1,
    ACTIONS(3680), 5,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [61918] = 9,
    ACTIONS(3670), 1,
      anon_sym_DASHnargs,
    ACTIONS(3672), 1,
      anon_sym_DASHcomplete,
    ACTIONS(3674), 1,
      anon_sym_DASHrange,
    ACTIONS(3676), 1,
      anon_sym_DASHcount,
    ACTIONS(3678), 1,
      anon_sym_DASHaddr,
    ACTIONS(4767), 1,
      sym_command_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1398), 2,
      sym_command_attribute,
      aux_sym_command_statement_repeat1,
    ACTIONS(3680), 5,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [61952] = 6,
    ACTIONS(4769), 1,
      anon_sym_LBRACE2,
    ACTIONS(4772), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1404), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(910), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(912), 6,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [61980] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(3010), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [62013] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4775), 12,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
      aux_sym__plus_cmd_arg_token1,
  [62032] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(3138), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [62065] = 6,
    ACTIONS(4777), 1,
      anon_sym_LBRACE2,
    ACTIONS(4779), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1446), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(904), 3,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
    ACTIONS(902), 5,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_EQ_LT_LT,
  [62092] = 6,
    ACTIONS(4783), 1,
      aux_sym_filename_token7,
    STATE(1410), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4172), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(4170), 4,
      sym__newline_or_pipe,
      sym_string_literal,
      sym_comment,
      anon_sym_BANG,
    ACTIONS(4781), 4,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
  [62119] = 6,
    ACTIONS(4788), 1,
      aux_sym_filename_token7,
    STATE(1410), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4179), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(4177), 4,
      sym__newline_or_pipe,
      sym_string_literal,
      sym_comment,
      anon_sym_BANG,
    ACTIONS(4785), 4,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
  [62146] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1928), 5,
      anon_sym_AMP,
      anon_sym_QMARK,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(1926), 7,
      anon_sym_BANG,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [62167] = 5,
    ACTIONS(3791), 1,
      anon_sym_BSLASH2,
    ACTIONS(3793), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1501), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4660), 9,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [62192] = 10,
    ACTIONS(4791), 1,
      aux_sym_option_name_token1,
    ACTIONS(4793), 1,
      anon_sym_t_,
    ACTIONS(4795), 1,
      anon_sym_all,
    ACTIONS(4797), 1,
      anon_sym_all_AMP,
    ACTIONS(4799), 1,
      sym__no,
    ACTIONS(4801), 1,
      sym__inv,
    STATE(1449), 1,
      sym_option_name,
    STATE(2238), 1,
      sym_set_item,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1549), 4,
      sym_no_option,
      sym_inv_option,
      sym_default_option,
      sym__set_option,
  [62227] = 5,
    ACTIONS(4803), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1414), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    ACTIONS(4682), 4,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4684), 5,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [62252] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4509), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(4507), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [62273] = 9,
    ACTIONS(4139), 1,
      anon_sym_BSLASH,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4806), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2292), 1,
      sym__pattern_branch,
    STATE(2519), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1203), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1234), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(4147), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [62306] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4513), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(4511), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [62327] = 10,
    ACTIONS(4808), 1,
      aux_sym_option_name_token1,
    ACTIONS(4810), 1,
      anon_sym_t_,
    ACTIONS(4812), 1,
      anon_sym_all,
    ACTIONS(4814), 1,
      anon_sym_all_AMP,
    ACTIONS(4816), 1,
      sym__no,
    ACTIONS(4818), 1,
      sym__inv,
    STATE(1624), 1,
      sym_option_name,
    STATE(2345), 1,
      sym_set_item,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1687), 4,
      sym_no_option,
      sym_inv_option,
      sym_default_option,
      sym__set_option,
  [62362] = 10,
    ACTIONS(4808), 1,
      aux_sym_option_name_token1,
    ACTIONS(4810), 1,
      anon_sym_t_,
    ACTIONS(4812), 1,
      anon_sym_all,
    ACTIONS(4814), 1,
      anon_sym_all_AMP,
    ACTIONS(4816), 1,
      sym__no,
    ACTIONS(4818), 1,
      sym__inv,
    STATE(1624), 1,
      sym_option_name,
    STATE(2355), 1,
      sym_set_item,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1687), 4,
      sym_no_option,
      sym_inv_option,
      sym_default_option,
      sym__set_option,
  [62397] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1940), 5,
      anon_sym_AMP,
      anon_sym_QMARK,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(1938), 7,
      anon_sym_BANG,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [62418] = 9,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    STATE(2378), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1428), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1731), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [62451] = 9,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    STATE(2896), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1454), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1707), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [62484] = 9,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    STATE(2378), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1730), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1731), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [62517] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4509), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4507), 10,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [62538] = 9,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    STATE(2896), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1707), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    STATE(1730), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
  [62571] = 9,
    ACTIONS(4014), 1,
      anon_sym_BSLASH,
    ACTIONS(4018), 1,
      anon_sym_LBRACK,
    ACTIONS(4020), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2288), 1,
      sym__pattern_branch,
    STATE(2773), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1174), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1219), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(4022), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [62604] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4513), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4511), 10,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [62625] = 9,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    STATE(2486), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1724), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    STATE(1730), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
  [62658] = 8,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(4820), 1,
      anon_sym_PLUS,
    STATE(2487), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1566), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(4822), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [62689] = 10,
    ACTIONS(4808), 1,
      aux_sym_option_name_token1,
    ACTIONS(4810), 1,
      anon_sym_t_,
    ACTIONS(4812), 1,
      anon_sym_all,
    ACTIONS(4814), 1,
      anon_sym_all_AMP,
    ACTIONS(4816), 1,
      sym__no,
    ACTIONS(4818), 1,
      sym__inv,
    STATE(1624), 1,
      sym_option_name,
    STATE(2375), 1,
      sym_set_item,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1687), 4,
      sym_no_option,
      sym_inv_option,
      sym_default_option,
      sym__set_option,
  [62724] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4507), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [62743] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4511), 12,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [62762] = 8,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(4820), 1,
      anon_sym_PLUS,
    STATE(2659), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1566), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(4824), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [62793] = 9,
    ACTIONS(4014), 1,
      anon_sym_BSLASH,
    ACTIONS(4018), 1,
      anon_sym_LBRACK,
    ACTIONS(4020), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2288), 1,
      sym__pattern_branch,
    STATE(2825), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1174), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1219), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(4022), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [62826] = 7,
    ACTIONS(3467), 1,
      anon_sym_LBRACE,
    ACTIONS(3469), 1,
      aux_sym_identifier_token1,
    STATE(1346), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3475), 2,
      sym__scope_dict,
      anon_sym_a_COLON,
    ACTIONS(4826), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(1502), 4,
      sym_scope_dict,
      sym_identifier,
      sym__assignment_variable,
      aux_sym_let_statement_repeat1,
  [62855] = 9,
    ACTIONS(4014), 1,
      anon_sym_BSLASH,
    ACTIONS(4018), 1,
      anon_sym_LBRACK,
    ACTIONS(4020), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2288), 1,
      sym__pattern_branch,
    STATE(2810), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1174), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1219), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(4022), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [62888] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(3187), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [62921] = 9,
    ACTIONS(4476), 1,
      anon_sym_BSLASH,
    ACTIONS(4480), 1,
      anon_sym_LBRACK,
    ACTIONS(4828), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2596), 1,
      sym__pattern_branch,
    STATE(2993), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1279), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1332), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(4484), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [62954] = 7,
    ACTIONS(4832), 1,
      sym__hl_color_nr,
    ACTIONS(4834), 1,
      anon_sym_SQUOTE,
    ACTIONS(4836), 1,
      aux_sym_color_token1,
    STATE(1320), 1,
      sym_color,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1321), 2,
      sym__hl_none,
      sym__hl_quoted_name,
    ACTIONS(4830), 6,
      anon_sym_NONE2,
      anon_sym_bg,
      anon_sym_background,
      anon_sym_fg,
      anon_sym_foreground,
      aux_sym_color_token2,
  [62983] = 6,
    ACTIONS(3771), 1,
      anon_sym_BSLASH2,
    ACTIONS(3773), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1484), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4838), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4660), 7,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [63010] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4509), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(4507), 10,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [63031] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4513), 2,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(4511), 10,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [63052] = 8,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(4820), 1,
      anon_sym_PLUS,
    STATE(2381), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1566), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(4111), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [63083] = 9,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(4100), 1,
      anon_sym_POUND,
    ACTIONS(4840), 1,
      anon_sym_PLUS,
    STATE(2960), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(3983), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1554), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [63116] = 5,
    ACTIONS(4842), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1445), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    ACTIONS(4682), 3,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4684), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [63141] = 6,
    ACTIONS(4845), 1,
      anon_sym_LBRACE2,
    ACTIONS(4848), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1446), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(912), 3,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
    ACTIONS(910), 5,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_EQ_LT_LT,
  [63168] = 9,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    STATE(2964), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1730), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1749), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [63201] = 9,
    ACTIONS(3485), 1,
      anon_sym_BSLASH,
    ACTIONS(3489), 1,
      anon_sym_LBRACK,
    ACTIONS(4851), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1835), 1,
      sym__pattern_branch,
    STATE(2099), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1030), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1031), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3493), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [63234] = 6,
    ACTIONS(4853), 1,
      anon_sym_BANG,
    ACTIONS(4855), 1,
      anon_sym_AMP,
    ACTIONS(4857), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4861), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4859), 6,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [63261] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(3145), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [63294] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4509), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(4507), 10,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [63315] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4513), 2,
      anon_sym_BANG,
      anon_sym_SLASH2,
    ACTIONS(4511), 10,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [63336] = 8,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(4820), 1,
      anon_sym_PLUS,
    STATE(2384), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1566), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(4115), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [63367] = 9,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    STATE(2976), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1730), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1791), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [63400] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(3134), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [63433] = 9,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    STATE(2391), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1525), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1746), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [63466] = 9,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    STATE(2391), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1730), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1746), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [63499] = 7,
    ACTIONS(3467), 1,
      anon_sym_LBRACE,
    ACTIONS(3469), 1,
      aux_sym_identifier_token1,
    STATE(1346), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3475), 2,
      sym__scope_dict,
      anon_sym_a_COLON,
    ACTIONS(4863), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(1502), 4,
      sym_scope_dict,
      sym_identifier,
      sym__assignment_variable,
      aux_sym_let_statement_repeat1,
  [63528] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3162), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3164), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [63549] = 6,
    ACTIONS(4865), 1,
      anon_sym_LBRACE2,
    ACTIONS(4867), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1062), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1467), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1064), 6,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [63576] = 6,
    ACTIONS(4869), 1,
      anon_sym_LBRACE2,
    ACTIONS(4871), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1062), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1462), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1064), 6,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [63603] = 6,
    ACTIONS(4869), 1,
      anon_sym_LBRACE2,
    ACTIONS(4873), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(902), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1463), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(904), 6,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [63630] = 6,
    ACTIONS(4875), 1,
      anon_sym_LBRACE2,
    ACTIONS(4878), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(910), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1463), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(912), 6,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [63657] = 5,
    STATE(1471), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4883), 2,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4881), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4123), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [63682] = 9,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    STATE(2850), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1730), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1779), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [63715] = 13,
    ACTIONS(4885), 1,
      anon_sym_define,
    ACTIONS(4887), 1,
      anon_sym_undefine,
    ACTIONS(4889), 1,
      anon_sym_list,
    ACTIONS(4891), 1,
      anon_sym_place,
    ACTIONS(4893), 1,
      anon_sym_unplace,
    ACTIONS(4895), 1,
      anon_sym_jump,
    STATE(2968), 1,
      sym__sign_define,
    STATE(2969), 1,
      sym__sign_undefine,
    STATE(2970), 1,
      sym__sign_list,
    STATE(2971), 1,
      sym__sign_place,
    STATE(2972), 1,
      sym__sign_unplace,
    STATE(2977), 1,
      sym__sign_jump,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [63756] = 6,
    ACTIONS(4865), 1,
      anon_sym_LBRACE2,
    ACTIONS(4897), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(902), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1483), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(904), 6,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [63783] = 5,
    STATE(1488), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4901), 2,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4899), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4151), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [63808] = 10,
    ACTIONS(4791), 1,
      aux_sym_option_name_token1,
    ACTIONS(4793), 1,
      anon_sym_t_,
    ACTIONS(4795), 1,
      anon_sym_all,
    ACTIONS(4797), 1,
      anon_sym_all_AMP,
    ACTIONS(4799), 1,
      sym__no,
    ACTIONS(4801), 1,
      sym__inv,
    STATE(1449), 1,
      sym_option_name,
    STATE(2147), 1,
      sym_set_item,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1549), 4,
      sym_no_option,
      sym_inv_option,
      sym_default_option,
      sym__set_option,
  [63843] = 10,
    ACTIONS(4791), 1,
      aux_sym_option_name_token1,
    ACTIONS(4793), 1,
      anon_sym_t_,
    ACTIONS(4795), 1,
      anon_sym_all,
    ACTIONS(4797), 1,
      anon_sym_all_AMP,
    ACTIONS(4799), 1,
      sym__no,
    ACTIONS(4801), 1,
      sym__inv,
    STATE(1449), 1,
      sym_option_name,
    STATE(2149), 1,
      sym_set_item,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1549), 4,
      sym_no_option,
      sym_inv_option,
      sym_default_option,
      sym__set_option,
  [63878] = 5,
    STATE(1492), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4905), 2,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4903), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4151), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [63903] = 13,
    ACTIONS(4907), 1,
      anon_sym_define,
    ACTIONS(4909), 1,
      anon_sym_undefine,
    ACTIONS(4911), 1,
      anon_sym_list,
    ACTIONS(4913), 1,
      anon_sym_place,
    ACTIONS(4915), 1,
      anon_sym_unplace,
    ACTIONS(4917), 1,
      anon_sym_jump,
    STATE(2433), 1,
      sym__sign_define,
    STATE(2434), 1,
      sym__sign_undefine,
    STATE(2435), 1,
      sym__sign_list,
    STATE(2436), 1,
      sym__sign_place,
    STATE(2439), 1,
      sym__sign_unplace,
    STATE(2441), 1,
      sym__sign_jump,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [63944] = 11,
    ACTIONS(4921), 1,
      anon_sym_detect,
    ACTIONS(4923), 1,
      anon_sym_plugin,
    ACTIONS(4925), 1,
      anon_sym_indent,
    STATE(2750), 1,
      sym__filetype_state,
    STATE(2828), 1,
      sym__filetype_enable,
    STATE(2892), 1,
      sym__filetype_detect,
    STATE(2923), 1,
      sym__filetype_plugin,
    STATE(2927), 1,
      sym__filetype_indent,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4648), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4919), 2,
      anon_sym_on,
      anon_sym_off,
  [63981] = 9,
    ACTIONS(4139), 1,
      anon_sym_BSLASH,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4806), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2292), 1,
      sym__pattern_branch,
    STATE(2412), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1203), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1234), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(4147), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [64014] = 9,
    ACTIONS(4139), 1,
      anon_sym_BSLASH,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4806), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2292), 1,
      sym__pattern_branch,
    STATE(2480), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1203), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1234), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(4147), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [64047] = 9,
    ACTIONS(3537), 1,
      anon_sym_BSLASH,
    ACTIONS(3541), 1,
      anon_sym_LBRACK,
    ACTIONS(4927), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1879), 1,
      sym__pattern_branch,
    STATE(1903), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1041), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1042), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3545), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [64080] = 9,
    ACTIONS(3558), 1,
      anon_sym_BSLASH,
    ACTIONS(3562), 1,
      anon_sym_LBRACK,
    ACTIONS(4929), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1883), 1,
      sym__pattern_branch,
    STATE(1918), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1044), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1045), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3566), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [64113] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(3140), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [64146] = 8,
    ACTIONS(4534), 1,
      anon_sym_BSLASH,
    STATE(1658), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1831), 1,
      sym_filename,
    STATE(1979), 1,
      sym__runtime_where,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4536), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token3,
    ACTIONS(4538), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(4524), 4,
      anon_sym_START,
      anon_sym_OPT,
      anon_sym_PACK,
      anon_sym_ALL,
  [64177] = 6,
    ACTIONS(4777), 1,
      anon_sym_LBRACE2,
    ACTIONS(4931), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1408), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1064), 3,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
    ACTIONS(1062), 5,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_EQ_LT_LT,
  [64204] = 9,
    ACTIONS(4139), 1,
      anon_sym_BSLASH,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4806), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2292), 1,
      sym__pattern_branch,
    STATE(2720), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1203), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1234), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(4147), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [64237] = 7,
    ACTIONS(4044), 1,
      anon_sym_cchar,
    ACTIONS(4933), 1,
      aux_sym__syn_keyword_token1,
    STATE(1491), 1,
      aux_sym__syn_keyword_repeat1,
    STATE(1637), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4046), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(4042), 6,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
  [64266] = 6,
    ACTIONS(4935), 1,
      anon_sym_LBRACE2,
    ACTIONS(4938), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(910), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1483), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(912), 6,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [64293] = 6,
    ACTIONS(4941), 1,
      anon_sym_BSLASH2,
    ACTIONS(4944), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1484), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4947), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4753), 7,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [64320] = 9,
    ACTIONS(3852), 1,
      anon_sym_BSLASH,
    ACTIONS(3856), 1,
      anon_sym_LBRACK,
    ACTIONS(4949), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2111), 1,
      sym__pattern_branch,
    STATE(2145), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1112), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1113), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3860), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [64353] = 9,
    ACTIONS(3864), 1,
      anon_sym_BSLASH,
    ACTIONS(3868), 1,
      anon_sym_LBRACK,
    ACTIONS(4951), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2113), 1,
      sym__pattern_branch,
    STATE(2151), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1115), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1116), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3872), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [64386] = 9,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(4840), 1,
      anon_sym_PLUS,
    ACTIONS(4953), 1,
      anon_sym_POUND,
    STATE(2952), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4636), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1554), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [64419] = 5,
    STATE(1492), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4905), 2,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4903), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4170), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [64444] = 7,
    ACTIONS(4957), 1,
      sym__hl_color_nr,
    ACTIONS(4959), 1,
      anon_sym_SQUOTE,
    ACTIONS(4961), 1,
      aux_sym_color_token1,
    STATE(1220), 1,
      sym_color,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1221), 2,
      sym__hl_none,
      sym__hl_quoted_name,
    ACTIONS(4955), 6,
      anon_sym_NONE2,
      anon_sym_bg,
      anon_sym_background,
      anon_sym_fg,
      anon_sym_foreground,
      aux_sym_color_token2,
  [64473] = 9,
    ACTIONS(3430), 1,
      anon_sym_BSLASH,
    ACTIONS(3438), 1,
      anon_sym_LBRACK,
    ACTIONS(4963), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1849), 1,
      sym__pattern_branch,
    STATE(2054), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1026), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1035), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(3442), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [64506] = 7,
    ACTIONS(4044), 1,
      anon_sym_cchar,
    ACTIONS(4965), 1,
      aux_sym__syn_keyword_token1,
    STATE(1519), 1,
      aux_sym__syn_keyword_repeat1,
    STATE(1637), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4046), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(4042), 6,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
  [64535] = 5,
    STATE(1492), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4970), 2,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4967), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(4177), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [64560] = 7,
    ACTIONS(4044), 1,
      anon_sym_cchar,
    ACTIONS(4973), 1,
      aux_sym__syn_keyword_token1,
    STATE(1519), 1,
      aux_sym__syn_keyword_repeat1,
    STATE(1637), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4046), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(4042), 6,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
  [64589] = 12,
    ACTIONS(4309), 1,
      anon_sym_LBRACE,
    ACTIONS(4311), 1,
      aux_sym_identifier_token1,
    ACTIONS(4315), 1,
      sym_au_event,
    ACTIONS(4317), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(1839), 1,
      sym__curly_braces_name_expression,
    STATE(1922), 1,
      sym__augroup_name,
    STATE(2285), 1,
      sym_au_event_list,
    STATE(2287), 1,
      sym_identifier,
    STATE(2878), 1,
      sym__autocmd_pattern,
    STATE(2879), 1,
      sym__autocmd_command,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4975), 2,
      sym__newline_or_pipe,
      sym_comment,
  [64628] = 5,
    ACTIONS(3791), 1,
      anon_sym_BSLASH2,
    ACTIONS(3793), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1501), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4717), 9,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [64653] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(3307), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [64686] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(3312), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [64719] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(3028), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [64752] = 3,
    ACTIONS(4977), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4979), 11,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [64773] = 3,
    ACTIONS(4981), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4979), 11,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [64794] = 5,
    ACTIONS(4983), 1,
      anon_sym_BSLASH2,
    ACTIONS(4986), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1501), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4753), 9,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [64819] = 7,
    ACTIONS(4992), 1,
      anon_sym_LBRACE,
    ACTIONS(4995), 1,
      aux_sym_identifier_token1,
    STATE(1346), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4989), 2,
      sym__scope_dict,
      anon_sym_a_COLON,
    ACTIONS(4998), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(1502), 4,
      sym_scope_dict,
      sym_identifier,
      sym__assignment_variable,
      aux_sym_let_statement_repeat1,
  [64848] = 6,
    ACTIONS(5002), 1,
      aux_sym_filename_token7,
    STATE(1409), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4153), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(4151), 4,
      sym__newline_or_pipe,
      sym_string_literal,
      sym_comment,
      anon_sym_BANG,
    ACTIONS(5000), 4,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
  [64875] = 6,
    ACTIONS(4783), 1,
      aux_sym_filename_token7,
    STATE(1410), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4153), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(4151), 4,
      sym__newline_or_pipe,
      sym_string_literal,
      sym_comment,
      anon_sym_BANG,
    ACTIONS(4781), 4,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
  [64902] = 9,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    STATE(2850), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1447), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    STATE(1779), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [64935] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4509), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(4507), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [64956] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4513), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
    ACTIONS(4511), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [64977] = 6,
    ACTIONS(5006), 1,
      aux_sym_filename_token7,
    STATE(1504), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4125), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(4123), 4,
      sym__newline_or_pipe,
      sym_string_literal,
      sym_comment,
      anon_sym_BANG,
    ACTIONS(5004), 4,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
  [65004] = 9,
    ACTIONS(4014), 1,
      anon_sym_BSLASH,
    ACTIONS(4018), 1,
      anon_sym_LBRACK,
    ACTIONS(4020), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2288), 1,
      sym__pattern_branch,
    STATE(2787), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1174), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1219), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(4022), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65037] = 8,
    ACTIONS(4399), 1,
      sym_hl_group,
    ACTIONS(4401), 1,
      anon_sym_link,
    ACTIONS(4403), 1,
      anon_sym_clear,
    ACTIONS(4405), 1,
      sym__default,
    STATE(2369), 1,
      sym__hl_body_link,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5008), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    STATE(2680), 4,
      sym__hl_body_clear,
      sym__hl_body_none,
      sym__hl_body_keys,
      sym__hl_body,
  [65068] = 9,
    ACTIONS(4437), 1,
      anon_sym_BSLASH,
    ACTIONS(4441), 1,
      anon_sym_LBRACK,
    ACTIONS(5010), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2574), 1,
      sym__pattern_branch,
    STATE(3335), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1271), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1272), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4445), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65101] = 9,
    ACTIONS(3899), 1,
      anon_sym_BSLASH,
    ACTIONS(3903), 1,
      anon_sym_LBRACK,
    ACTIONS(5012), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2081), 1,
      sym__pattern_branch,
    STATE(2300), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1120), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1121), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3907), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65134] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3188), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3190), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [65155] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4753), 12,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
      aux_sym__plus_cmd_arg_token1,
  [65174] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5016), 4,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5014), 8,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      sym_command_name,
  [65195] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4652), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4654), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [65216] = 8,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(4820), 1,
      anon_sym_PLUS,
    STATE(2488), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1566), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(4188), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [65247] = 7,
    ACTIONS(4044), 1,
      anon_sym_cchar,
    ACTIONS(5018), 1,
      aux_sym__syn_keyword_token1,
    STATE(1493), 1,
      aux_sym__syn_keyword_repeat1,
    STATE(1637), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4046), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(4042), 6,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
  [65276] = 7,
    ACTIONS(5023), 1,
      anon_sym_cchar,
    ACTIONS(5029), 1,
      aux_sym__syn_keyword_token1,
    STATE(1519), 1,
      aux_sym__syn_keyword_repeat1,
    STATE(1637), 1,
      sym__syn_arguments_keyword,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5026), 2,
      anon_sym_containedin,
      anon_sym_nextgroup,
    ACTIONS(5020), 6,
      anon_sym_conceal,
      anon_sym_contained,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
  [65305] = 8,
    ACTIONS(4526), 1,
      anon_sym_BSLASH,
    STATE(1771), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1898), 1,
      sym_filename,
    STATE(1944), 1,
      sym__runtime_where,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4530), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token3,
    ACTIONS(4532), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(4524), 4,
      anon_sym_START,
      anon_sym_OPT,
      anon_sym_PACK,
      anon_sym_ALL,
  [65336] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(3234), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65369] = 5,
    ACTIONS(5033), 1,
      anon_sym_PLUS,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1522), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(5031), 3,
      anon_sym_BSLASH,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5036), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [65394] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(3262), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65427] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(3310), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65460] = 9,
    ACTIONS(4391), 1,
      anon_sym_PLUS,
    ACTIONS(4393), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    STATE(2489), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1727), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    STATE(1730), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
  [65493] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(3176), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65526] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(3020), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65559] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(3111), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65592] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(3118), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65625] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(3284), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65658] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(3034), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65691] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(3106), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65724] = 9,
    ACTIONS(3740), 1,
      anon_sym_BSLASH,
    ACTIONS(3744), 1,
      anon_sym_LBRACK,
    ACTIONS(5038), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2085), 1,
      sym__pattern_branch,
    STATE(2301), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1090), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1091), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3748), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65757] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(3264), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65790] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(3322), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65823] = 9,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(4208), 1,
      anon_sym_POUND,
    ACTIONS(4840), 1,
      anon_sym_PLUS,
    STATE(2831), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(3931), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1554), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [65856] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(3056), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65889] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(3077), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65922] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(2984), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65955] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(3099), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [65988] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(3107), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [66021] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(3114), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [66054] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(3121), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [66087] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(3127), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [66120] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(3133), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [66153] = 9,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2479), 1,
      sym__pattern_branch,
    STATE(2998), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [66186] = 9,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2379), 1,
      sym__pattern_branch,
    STATE(3139), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [66219] = 6,
    ACTIONS(3771), 1,
      anon_sym_BSLASH2,
    ACTIONS(3773), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1484), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5040), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4717), 7,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [66246] = 6,
    ACTIONS(5044), 1,
      anon_sym_SPACE,
    STATE(2128), 1,
      sym__set_operator,
    STATE(2242), 1,
      sym__set_rhs,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5046), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5042), 5,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
  [66272] = 6,
    ACTIONS(5048), 1,
      anon_sym_BSLASH2,
    ACTIONS(5051), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1550), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4947), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4753), 6,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [66298] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5054), 11,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_SLASH2,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_BSLASH_RPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [66316] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5056), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH2,
    ACTIONS(4775), 8,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
      aux_sym__plus_cmd_arg_token1,
  [66336] = 8,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3694), 1,
      aux_sym_filename_token3,
    ACTIONS(5058), 1,
      anon_sym_BANG,
    STATE(1729), 1,
      sym_bang,
    STATE(2409), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(5060), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [66366] = 5,
    ACTIONS(5062), 1,
      anon_sym_PLUS,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5031), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1554), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(5036), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [66390] = 8,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(5065), 1,
      anon_sym_PLUS,
    STATE(2965), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4822), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1695), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [66420] = 8,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(5065), 1,
      anon_sym_PLUS,
    STATE(2974), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4188), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1695), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [66450] = 8,
    ACTIONS(4014), 1,
      anon_sym_BSLASH,
    ACTIONS(4018), 1,
      anon_sym_LBRACK,
    ACTIONS(4020), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1684), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1174), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1219), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(4022), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [66480] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5067), 4,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5069), 7,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
      anon_sym_PLUS_PLUS,
  [66500] = 8,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(2835), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1317), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [66530] = 7,
    ACTIONS(3646), 1,
      anon_sym_LBRACE,
    ACTIONS(3648), 1,
      aux_sym_identifier_token1,
    STATE(1480), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3650), 2,
      sym__scope_dict,
      anon_sym_a_COLON,
    ACTIONS(4826), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1583), 4,
      sym_scope_dict,
      sym_identifier,
      sym__assignment_variable,
      aux_sym_let_statement_repeat1,
  [66558] = 4,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5071), 2,
      anon_sym_vi,
      anon_sym_vim,
    ACTIONS(5075), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5073), 6,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [66580] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5077), 4,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5079), 7,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
      anon_sym_PLUS_PLUS,
  [66600] = 8,
    ACTIONS(5081), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(5083), 1,
      anon_sym_BSLASH,
    ACTIONS(5087), 1,
      anon_sym_LT2,
    STATE(369), 1,
      sym__map_lhs,
    STATE(970), 1,
      sym_keycode,
    STATE(1589), 1,
      aux_sym_map_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5085), 5,
      anon_sym_LTbuffer_GT,
      anon_sym_LTnowait_GT,
      anon_sym_LTsilent_GT,
      anon_sym_LTunique_GT,
      anon_sym_LTscript_GT,
  [66630] = 7,
    ACTIONS(5091), 1,
      anon_sym_icon,
    ACTIONS(5095), 1,
      anon_sym_text,
    STATE(1587), 1,
      aux_sym__sign_define_repeat1,
    STATE(1778), 1,
      sym__sign_define_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5089), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5093), 4,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [66658] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4775), 11,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
      aux_sym__plus_cmd_arg_token1,
  [66676] = 5,
    ACTIONS(5097), 1,
      anon_sym_PLUS,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1566), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(5031), 3,
      anon_sym_BSLASH,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5036), 5,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [66700] = 8,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1551), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1241), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [66730] = 8,
    ACTIONS(4604), 1,
      sym_hl_group,
    ACTIONS(4606), 1,
      anon_sym_link,
    ACTIONS(4608), 1,
      anon_sym_clear,
    ACTIONS(4610), 1,
      sym__default,
    STATE(2851), 1,
      sym__hl_body_link,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5008), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(2902), 4,
      sym__hl_body_clear,
      sym__hl_body_none,
      sym__hl_body_keys,
      sym__hl_body,
  [66760] = 8,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3694), 1,
      aux_sym_filename_token3,
    ACTIONS(5058), 1,
      anon_sym_BANG,
    STATE(1739), 1,
      sym_bang,
    STATE(2417), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(5100), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [66790] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4753), 11,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_BSLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
      aux_sym__plus_cmd_arg_token1,
  [66808] = 8,
    ACTIONS(3473), 1,
      anon_sym_LBRACK,
    ACTIONS(5102), 1,
      anon_sym_a_COLON,
    ACTIONS(5104), 1,
      anon_sym_LBRACE,
    ACTIONS(5106), 1,
      aux_sym_identifier_token1,
    ACTIONS(5108), 1,
      sym_scope,
    STATE(2207), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(3303), 5,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym_list_assignment,
  [66838] = 5,
    STATE(1575), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5112), 2,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(5110), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4123), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [66862] = 6,
    ACTIONS(2374), 1,
      anon_sym_EQ,
    ACTIONS(2378), 1,
      anon_sym_EQ_LT_LT,
    STATE(376), 1,
      sym__let_operator,
    STATE(2798), 1,
      sym__let_heredoc,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2376), 7,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
  [66888] = 5,
    STATE(1578), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5116), 2,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(5114), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4151), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [66912] = 5,
    STATE(1579), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5120), 2,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(5118), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4151), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [66936] = 8,
    ACTIONS(3485), 1,
      anon_sym_BSLASH,
    ACTIONS(3489), 1,
      anon_sym_LBRACK,
    ACTIONS(4851), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1684), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1030), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1031), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3493), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [66966] = 8,
    ACTIONS(3810), 1,
      anon_sym_BSLASH,
    ACTIONS(3814), 1,
      anon_sym_LBRACK,
    ACTIONS(5122), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1684), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1106), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1107), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3818), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [66996] = 5,
    STATE(1579), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5120), 2,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(5118), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4170), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [67020] = 5,
    STATE(1579), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5127), 2,
      aux_sym_filename_token5,
      aux_sym_filename_token7,
    ACTIONS(5124), 3,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
    ACTIONS(4177), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [67044] = 6,
    ACTIONS(4834), 1,
      anon_sym_SQUOTE,
    ACTIONS(4836), 1,
      aux_sym_color_token1,
    STATE(1323), 1,
      sym_color,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1321), 2,
      sym__hl_none,
      sym__hl_quoted_name,
    ACTIONS(4830), 6,
      anon_sym_NONE2,
      anon_sym_bg,
      anon_sym_background,
      anon_sym_fg,
      anon_sym_foreground,
      aux_sym_color_token2,
  [67070] = 8,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3694), 1,
      aux_sym_filename_token3,
    ACTIONS(5058), 1,
      anon_sym_BANG,
    STATE(1756), 1,
      sym_bang,
    STATE(2514), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(5130), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [67100] = 7,
    ACTIONS(3646), 1,
      anon_sym_LBRACE,
    ACTIONS(3648), 1,
      aux_sym_identifier_token1,
    STATE(1480), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3650), 2,
      sym__scope_dict,
      anon_sym_a_COLON,
    ACTIONS(4863), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1583), 4,
      sym_scope_dict,
      sym_identifier,
      sym__assignment_variable,
      aux_sym_let_statement_repeat1,
  [67128] = 7,
    ACTIONS(5135), 1,
      anon_sym_LBRACE,
    ACTIONS(5138), 1,
      aux_sym_identifier_token1,
    STATE(1480), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4998), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5132), 2,
      sym__scope_dict,
      anon_sym_a_COLON,
    STATE(1583), 4,
      sym_scope_dict,
      sym_identifier,
      sym__assignment_variable,
      aux_sym_let_statement_repeat1,
  [67156] = 8,
    ACTIONS(3899), 1,
      anon_sym_BSLASH,
    ACTIONS(3903), 1,
      anon_sym_LBRACK,
    ACTIONS(5012), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1684), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1120), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1121), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3907), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [67186] = 8,
    ACTIONS(3740), 1,
      anon_sym_BSLASH,
    ACTIONS(3744), 1,
      anon_sym_LBRACK,
    ACTIONS(5038), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1684), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1090), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1091), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3748), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [67216] = 8,
    ACTIONS(4437), 1,
      anon_sym_BSLASH,
    ACTIONS(4441), 1,
      anon_sym_LBRACK,
    ACTIONS(5010), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1551), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1271), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1272), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4445), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [67246] = 7,
    ACTIONS(5091), 1,
      anon_sym_icon,
    ACTIONS(5095), 1,
      anon_sym_text,
    STATE(1606), 1,
      aux_sym__sign_define_repeat1,
    STATE(1778), 1,
      sym__sign_define_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5141), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5093), 4,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [67274] = 8,
    ACTIONS(5147), 1,
      anon_sym_name,
    ACTIONS(5149), 1,
      anon_sym_group,
    ACTIONS(5151), 1,
      anon_sym_file,
    STATE(1608), 1,
      aux_sym__sign_place_place_repeat1,
    STATE(1783), 1,
      sym__sign_place_place_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5143), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5145), 3,
      anon_sym_line,
      anon_sym_buffer,
      anon_sym_priority,
  [67304] = 8,
    ACTIONS(5081), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(5083), 1,
      anon_sym_BSLASH,
    ACTIONS(5087), 1,
      anon_sym_LT2,
    STATE(305), 1,
      sym__map_lhs,
    STATE(970), 1,
      sym_keycode,
    STATE(1763), 1,
      aux_sym_map_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5153), 5,
      anon_sym_LTbuffer_GT,
      anon_sym_LTnowait_GT,
      anon_sym_LTsilent_GT,
      anon_sym_LTunique_GT,
      anon_sym_LTscript_GT,
  [67334] = 8,
    ACTIONS(4476), 1,
      anon_sym_BSLASH,
    ACTIONS(4480), 1,
      anon_sym_LBRACK,
    ACTIONS(4828), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1551), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1279), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1332), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(4484), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [67364] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5155), 11,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [67382] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5157), 11,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [67400] = 6,
    ACTIONS(3979), 1,
      anon_sym_BSLASH2,
    ACTIONS(3981), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1550), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5040), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4717), 6,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [67426] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5159), 11,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [67444] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5161), 11,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [67462] = 8,
    ACTIONS(3537), 1,
      anon_sym_BSLASH,
    ACTIONS(3541), 1,
      anon_sym_LBRACK,
    ACTIONS(4927), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1551), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1041), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1042), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3545), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [67492] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1322), 4,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      aux_sym_identifier_token2,
    ACTIONS(1320), 7,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_LBRACE2,
      anon_sym_EQ_LT_LT,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [67512] = 8,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(5065), 1,
      anon_sym_PLUS,
    STATE(2872), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4111), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1695), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [67542] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5016), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
    ACTIONS(5014), 8,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      sym_command_name,
  [67562] = 8,
    ACTIONS(3558), 1,
      anon_sym_BSLASH,
    ACTIONS(3562), 1,
      anon_sym_LBRACK,
    ACTIONS(4929), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1551), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1044), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1045), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3566), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [67592] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1338), 4,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      aux_sym_identifier_token2,
    ACTIONS(1336), 7,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_LBRACE2,
      anon_sym_EQ_LT_LT,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [67612] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5163), 11,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [67630] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5165), 11,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [67648] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5167), 11,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [67666] = 4,
    ACTIONS(5169), 1,
      sym__printable,
    STATE(1732), 1,
      sym__sign_define_arg_text,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4133), 9,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [67688] = 7,
    ACTIONS(5173), 1,
      anon_sym_icon,
    ACTIONS(5179), 1,
      anon_sym_text,
    STATE(1606), 1,
      aux_sym__sign_define_repeat1,
    STATE(1778), 1,
      sym__sign_define_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5171), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5176), 4,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [67716] = 8,
    ACTIONS(3831), 1,
      anon_sym_BSLASH,
    ACTIONS(3835), 1,
      anon_sym_LBRACK,
    ACTIONS(5182), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1551), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1109), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1110), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3839), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [67746] = 8,
    ACTIONS(5189), 1,
      anon_sym_name,
    ACTIONS(5192), 1,
      anon_sym_group,
    ACTIONS(5195), 1,
      anon_sym_file,
    STATE(1608), 1,
      aux_sym__sign_place_place_repeat1,
    STATE(1783), 1,
      sym__sign_place_place_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5184), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5186), 3,
      anon_sym_line,
      anon_sym_buffer,
      anon_sym_priority,
  [67776] = 8,
    ACTIONS(3852), 1,
      anon_sym_BSLASH,
    ACTIONS(3856), 1,
      anon_sym_LBRACK,
    ACTIONS(4949), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1551), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1112), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1113), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3860), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [67806] = 8,
    ACTIONS(3864), 1,
      anon_sym_BSLASH,
    ACTIONS(3868), 1,
      anon_sym_LBRACK,
    ACTIONS(4951), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1551), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1115), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1116), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3872), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [67836] = 8,
    ACTIONS(3473), 1,
      anon_sym_LBRACK,
    ACTIONS(5102), 1,
      anon_sym_a_COLON,
    ACTIONS(5104), 1,
      anon_sym_LBRACE,
    ACTIONS(5106), 1,
      aux_sym_identifier_token1,
    ACTIONS(5108), 1,
      sym_scope,
    STATE(2207), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(3347), 5,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
      sym_list_assignment,
  [67866] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1320), 4,
      anon_sym_LBRACE2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(1322), 7,
      aux_sym_identifier_token2,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [67886] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(742), 4,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(740), 7,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
      anon_sym_PLUS_PLUS,
  [67906] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1336), 4,
      anon_sym_LBRACE2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(1338), 7,
      aux_sym_identifier_token2,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [67926] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1320), 4,
      anon_sym_LBRACE2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(1322), 7,
      aux_sym_identifier_token2,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [67946] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1336), 4,
      anon_sym_LBRACE2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(1338), 7,
      aux_sym_identifier_token2,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [67966] = 8,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(5065), 1,
      anon_sym_PLUS,
    STATE(2874), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4115), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1695), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [67996] = 6,
    ACTIONS(2364), 1,
      anon_sym_EQ,
    ACTIONS(2368), 1,
      anon_sym_EQ_LT_LT,
    STATE(382), 1,
      sym__let_operator,
    STATE(2575), 1,
      sym__let_heredoc,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2366), 7,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
  [68022] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1940), 2,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1938), 9,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [68042] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4947), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH2,
    ACTIONS(4753), 8,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
      aux_sym__plus_cmd_arg_token1,
  [68062] = 8,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(5065), 1,
      anon_sym_PLUS,
    STATE(2955), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4824), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1695), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [68092] = 6,
    ACTIONS(4959), 1,
      anon_sym_SQUOTE,
    ACTIONS(4961), 1,
      aux_sym_color_token1,
    STATE(1223), 1,
      sym_color,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1221), 2,
      sym__hl_none,
      sym__hl_quoted_name,
    ACTIONS(4955), 6,
      anon_sym_NONE2,
      anon_sym_bg,
      anon_sym_background,
      anon_sym_fg,
      anon_sym_foreground,
      aux_sym_color_token2,
  [68118] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1928), 2,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1926), 9,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [68138] = 5,
    ACTIONS(5198), 1,
      anon_sym_BANG,
    ACTIONS(5200), 1,
      anon_sym_AMP,
    ACTIONS(5202), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4859), 8,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [68162] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4979), 11,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [68180] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5204), 11,
      sym_command_name,
      anon_sym_DASHnargs,
      anon_sym_DASHcomplete,
      anon_sym_DASHrange,
      anon_sym_DASHcount,
      anon_sym_DASHaddr,
      anon_sym_DASHbang,
      anon_sym_DASHbar,
      anon_sym_DASHregister,
      anon_sym_DASHbuffer,
      anon_sym_DASHkeepscript,
  [68198] = 8,
    ACTIONS(5081), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(5083), 1,
      anon_sym_BSLASH,
    ACTIONS(5087), 1,
      anon_sym_LT2,
    STATE(381), 1,
      sym__map_lhs,
    STATE(970), 1,
      sym_keycode,
    STATE(1628), 1,
      aux_sym_map_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5206), 5,
      anon_sym_LTbuffer_GT,
      anon_sym_LTnowait_GT,
      anon_sym_LTsilent_GT,
      anon_sym_LTunique_GT,
      anon_sym_LTscript_GT,
  [68228] = 8,
    ACTIONS(5081), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(5083), 1,
      anon_sym_BSLASH,
    ACTIONS(5087), 1,
      anon_sym_LT2,
    STATE(387), 1,
      sym__map_lhs,
    STATE(970), 1,
      sym_keycode,
    STATE(1763), 1,
      aux_sym_map_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5153), 5,
      anon_sym_LTbuffer_GT,
      anon_sym_LTnowait_GT,
      anon_sym_LTsilent_GT,
      anon_sym_LTunique_GT,
      anon_sym_LTscript_GT,
  [68258] = 6,
    ACTIONS(3979), 1,
      anon_sym_BSLASH2,
    ACTIONS(3981), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1550), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4838), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4660), 6,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [68284] = 5,
    ACTIONS(5208), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1630), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    ACTIONS(4682), 3,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4684), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [68308] = 8,
    ACTIONS(3430), 1,
      anon_sym_BSLASH,
    ACTIONS(3438), 1,
      anon_sym_LBRACK,
    ACTIONS(4963), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1684), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1026), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1035), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(3442), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [68338] = 8,
    ACTIONS(4139), 1,
      anon_sym_BSLASH,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4806), 1,
      aux_sym__pattern_ordinary_atom_token2,
    STATE(1551), 1,
      sym__pattern_branch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1203), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    STATE(1234), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    ACTIONS(4147), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [68368] = 7,
    ACTIONS(5211), 1,
      anon_sym_icon,
    ACTIONS(5215), 1,
      anon_sym_text,
    STATE(1670), 1,
      aux_sym__sign_define_repeat1,
    STATE(1812), 1,
      sym__sign_define_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5089), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5213), 4,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [68395] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5219), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(5217), 8,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      sym_command_name,
  [68414] = 8,
    ACTIONS(5221), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(5223), 1,
      anon_sym_BSLASH,
    ACTIONS(5225), 1,
      anon_sym_BANG,
    ACTIONS(5229), 1,
      sym_string_literal,
    STATE(1858), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1859), 2,
      sym__bang_filter_command_argument,
      aux_sym__bang_filter_command_repeat1,
    ACTIONS(5227), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [68443] = 7,
    ACTIONS(4544), 1,
      anon_sym_BSLASH,
    ACTIONS(4548), 1,
      anon_sym_LBRACK,
    ACTIONS(4550), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1316), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1345), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4552), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [68470] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5231), 10,
      anon_sym_conceal,
      anon_sym_cchar,
      anon_sym_contained,
      anon_sym_containedin,
      anon_sym_nextgroup,
      anon_sym_transparent,
      anon_sym_skipwhite,
      anon_sym_skipnl,
      anon_sym_skipempty,
      aux_sym__syn_keyword_token1,
  [68487] = 7,
    ACTIONS(5235), 1,
      anon_sym_enc,
    ACTIONS(5237), 1,
      anon_sym_encoding,
    ACTIONS(5243), 1,
      anon_sym_bad,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5233), 2,
      anon_sym_ff,
      anon_sym_fileformat,
    ACTIONS(5239), 2,
      anon_sym_bin,
      anon_sym_nobin,
    ACTIONS(5241), 3,
      anon_sym_binary,
      anon_sym_nobinary,
      anon_sym_edit,
  [68514] = 7,
    ACTIONS(3899), 1,
      anon_sym_BSLASH,
    ACTIONS(3903), 1,
      anon_sym_LBRACK,
    ACTIONS(5012), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1120), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1153), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3907), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [68541] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4947), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH2,
    ACTIONS(4753), 7,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
      aux_sym__plus_cmd_arg_token1,
  [68560] = 7,
    ACTIONS(5245), 1,
      anon_sym_clear,
    ACTIONS(5251), 1,
      anon_sym_fromstart,
    ACTIONS(5253), 1,
      anon_sym_ccomment,
    ACTIONS(5255), 1,
      anon_sym_linecont,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5247), 2,
      anon_sym_match,
      anon_sym_region,
    ACTIONS(5249), 4,
      anon_sym_minlines,
      anon_sym_maxlines,
      anon_sym_linebreaks,
      anon_sym_lines2,
  [68587] = 7,
    ACTIONS(3740), 1,
      anon_sym_BSLASH,
    ACTIONS(3744), 1,
      anon_sym_LBRACK,
    ACTIONS(5038), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1090), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1125), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3748), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [68614] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1338), 4,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      aux_sym_identifier_token2,
    ACTIONS(1336), 6,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE2,
      anon_sym_EQ_LT_LT,
  [68633] = 7,
    ACTIONS(4437), 1,
      anon_sym_BSLASH,
    ACTIONS(4441), 1,
      anon_sym_LBRACK,
    ACTIONS(5010), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1271), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1387), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4445), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [68660] = 7,
    ACTIONS(4536), 1,
      aux_sym_filename_token3,
    ACTIONS(5257), 1,
      anon_sym_BSLASH,
    STATE(1660), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1831), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4538), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(5259), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [68687] = 8,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3884), 1,
      aux_sym_filename_token3,
    ACTIONS(5261), 1,
      anon_sym_BANG,
    STATE(1847), 1,
      sym_bang,
    STATE(2781), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5130), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3882), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [68716] = 7,
    ACTIONS(4476), 1,
      anon_sym_BSLASH,
    ACTIONS(4480), 1,
      anon_sym_LBRACK,
    ACTIONS(4828), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1332), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1396), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4484), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [68743] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1336), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_LBRACE2,
    ACTIONS(1338), 7,
      aux_sym_identifier_token2,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [68762] = 8,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3884), 1,
      aux_sym_filename_token3,
    ACTIONS(5261), 1,
      anon_sym_BANG,
    STATE(1888), 1,
      sym_bang,
    STATE(2801), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5060), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3882), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [68791] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1320), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_LBRACE2,
    ACTIONS(1322), 7,
      aux_sym_identifier_token2,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [68810] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1322), 4,
      anon_sym_EQ,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      aux_sym_identifier_token2,
    ACTIONS(1320), 6,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE2,
      anon_sym_EQ_LT_LT,
  [68829] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4507), 10,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [68846] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4511), 10,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [68863] = 7,
    ACTIONS(4139), 1,
      anon_sym_BSLASH,
    ACTIONS(4143), 1,
      anon_sym_LBRACK,
    ACTIONS(4806), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1234), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1288), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4147), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [68890] = 8,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3884), 1,
      aux_sym_filename_token3,
    ACTIONS(5261), 1,
      anon_sym_BANG,
    STATE(1856), 1,
      sym_bang,
    STATE(2847), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5100), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3882), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [68919] = 5,
    STATE(1656), 1,
      aux_sym_map_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5263), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_LT2,
    ACTIONS(5265), 2,
      anon_sym_BSLASH,
      anon_sym_LTexpr_GT,
    ACTIONS(5267), 5,
      anon_sym_LTbuffer_GT,
      anon_sym_LTnowait_GT,
      anon_sym_LTsilent_GT,
      anon_sym_LTunique_GT,
      anon_sym_LTscript_GT,
  [68942] = 7,
    ACTIONS(3537), 1,
      anon_sym_BSLASH,
    ACTIONS(3541), 1,
      anon_sym_LBRACK,
    ACTIONS(4927), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1041), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1073), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3545), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [68969] = 7,
    ACTIONS(4536), 1,
      aux_sym_filename_token3,
    ACTIONS(5257), 1,
      anon_sym_BSLASH,
    STATE(1660), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1831), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4538), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(5270), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [68996] = 3,
    ACTIONS(5272), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5274), 9,
      anon_sym_in,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
  [69015] = 7,
    ACTIONS(5276), 1,
      anon_sym_BSLASH,
    ACTIONS(5284), 1,
      aux_sym_filename_token3,
    STATE(1660), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1831), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5279), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5281), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [69042] = 7,
    ACTIONS(3558), 1,
      anon_sym_BSLASH,
    ACTIONS(3562), 1,
      anon_sym_LBRACK,
    ACTIONS(4929), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1044), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1081), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3566), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [69069] = 5,
    STATE(1662), 1,
      aux_sym__syn_sync_repeat1,
    STATE(1817), 1,
      sym__syn_sync_lines,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5289), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
    ACTIONS(5287), 6,
      anon_sym_BSLASH,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [69092] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5067), 4,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5069), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
      anon_sym_PLUS_PLUS,
  [69111] = 4,
    ACTIONS(5292), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4131), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(4133), 6,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [69132] = 7,
    ACTIONS(3831), 1,
      anon_sym_BSLASH,
    ACTIONS(3835), 1,
      anon_sym_LBRACK,
    ACTIONS(5182), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1109), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1149), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3839), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [69159] = 7,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    ACTIONS(4303), 1,
      anon_sym_LBRACK,
    ACTIONS(4305), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1240), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1363), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4307), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [69186] = 7,
    ACTIONS(3852), 1,
      anon_sym_BSLASH,
    ACTIONS(3856), 1,
      anon_sym_LBRACK,
    ACTIONS(4949), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1112), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1157), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3860), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [69213] = 7,
    ACTIONS(3864), 1,
      anon_sym_BSLASH,
    ACTIONS(3868), 1,
      anon_sym_LBRACK,
    ACTIONS(4951), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1115), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1165), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3872), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [69240] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4509), 3,
      sym__newline_or_pipe,
      sym_comment,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(4507), 7,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [69259] = 7,
    ACTIONS(5211), 1,
      anon_sym_icon,
    ACTIONS(5215), 1,
      anon_sym_text,
    STATE(1697), 1,
      aux_sym__sign_define_repeat1,
    STATE(1812), 1,
      sym__sign_define_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5141), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5213), 4,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [69286] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4513), 3,
      sym__newline_or_pipe,
      sym_comment,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(4511), 7,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [69305] = 7,
    ACTIONS(4014), 1,
      anon_sym_BSLASH,
    ACTIONS(4018), 1,
      anon_sym_LBRACK,
    ACTIONS(4020), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1219), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1315), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(4022), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [69332] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1320), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_LBRACE2,
    ACTIONS(1322), 7,
      aux_sym_identifier_token2,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [69351] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(742), 4,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(740), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
      anon_sym_PLUS_PLUS,
  [69370] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1336), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_LBRACE2,
    ACTIONS(1338), 7,
      aux_sym_identifier_token2,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [69389] = 3,
    ACTIONS(5294), 1,
      sym__printable,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5296), 9,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [69408] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(742), 3,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(740), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
      anon_sym_PLUS_PLUS,
  [69427] = 8,
    ACTIONS(5300), 1,
      anon_sym_name,
    ACTIONS(5302), 1,
      anon_sym_group,
    ACTIONS(5304), 1,
      anon_sym_file,
    STATE(1698), 1,
      aux_sym__sign_place_place_repeat1,
    STATE(1826), 1,
      sym__sign_place_place_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5143), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5298), 3,
      anon_sym_line,
      anon_sym_buffer,
      anon_sym_priority,
  [69456] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5077), 4,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5079), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
      anon_sym_PLUS_PLUS,
  [69475] = 7,
    ACTIONS(5306), 1,
      anon_sym_clear,
    ACTIONS(5312), 1,
      anon_sym_fromstart,
    ACTIONS(5314), 1,
      anon_sym_ccomment,
    ACTIONS(5316), 1,
      anon_sym_linecont,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5308), 2,
      anon_sym_match,
      anon_sym_region,
    ACTIONS(5310), 4,
      anon_sym_minlines,
      anon_sym_maxlines,
      anon_sym_linebreaks,
      anon_sym_lines2,
  [69502] = 7,
    ACTIONS(5320), 1,
      anon_sym_enc,
    ACTIONS(5322), 1,
      anon_sym_encoding,
    ACTIONS(5328), 1,
      anon_sym_bad,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5318), 2,
      anon_sym_ff,
      anon_sym_fileformat,
    ACTIONS(5324), 2,
      anon_sym_bin,
      anon_sym_nobin,
    ACTIONS(5326), 3,
      anon_sym_binary,
      anon_sym_nobinary,
      anon_sym_edit,
  [69529] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5330), 2,
      anon_sym_vi,
      anon_sym_vim,
    ACTIONS(5073), 8,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [69548] = 7,
    ACTIONS(4536), 1,
      aux_sym_filename_token3,
    ACTIONS(5257), 1,
      anon_sym_BSLASH,
    STATE(1660), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1831), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4538), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(5332), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [69575] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5054), 10,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_SLASH2,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
      anon_sym_minlines,
      anon_sym_maxlines,
  [69592] = 7,
    ACTIONS(5336), 1,
      anon_sym_enc,
    ACTIONS(5338), 1,
      anon_sym_encoding,
    ACTIONS(5344), 1,
      anon_sym_bad,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5334), 2,
      anon_sym_ff,
      anon_sym_fileformat,
    ACTIONS(5340), 2,
      anon_sym_bin,
      anon_sym_nobin,
    ACTIONS(5342), 3,
      anon_sym_binary,
      anon_sym_nobinary,
      anon_sym_edit,
  [69619] = 7,
    ACTIONS(3485), 1,
      anon_sym_BSLASH,
    ACTIONS(3489), 1,
      anon_sym_LBRACK,
    ACTIONS(4851), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1030), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1069), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3493), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [69646] = 5,
    STATE(2244), 1,
      sym__set_operator,
    STATE(2730), 1,
      sym__set_rhs,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5044), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_SPACE,
    ACTIONS(5346), 5,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
  [69669] = 7,
    ACTIONS(5350), 1,
      anon_sym_enc,
    ACTIONS(5352), 1,
      anon_sym_encoding,
    ACTIONS(5358), 1,
      anon_sym_bad,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5348), 2,
      anon_sym_ff,
      anon_sym_fileformat,
    ACTIONS(5354), 2,
      anon_sym_bin,
      anon_sym_nobin,
    ACTIONS(5356), 3,
      anon_sym_binary,
      anon_sym_nobinary,
      anon_sym_edit,
  [69696] = 3,
    ACTIONS(2466), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2468), 9,
      anon_sym_in,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
  [69715] = 7,
    ACTIONS(5362), 1,
      anon_sym_enc,
    ACTIONS(5364), 1,
      anon_sym_encoding,
    ACTIONS(5370), 1,
      anon_sym_bad,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5360), 2,
      anon_sym_ff,
      anon_sym_fileformat,
    ACTIONS(5366), 2,
      anon_sym_bin,
      anon_sym_nobin,
    ACTIONS(5368), 3,
      anon_sym_binary,
      anon_sym_nobinary,
      anon_sym_edit,
  [69742] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5372), 3,
      anon_sym_BSLASH,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5374), 7,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [69761] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5056), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH2,
    ACTIONS(4775), 7,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
      aux_sym__plus_cmd_arg_token1,
  [69780] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5376), 3,
      anon_sym_BSLASH,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5378), 7,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [69799] = 7,
    ACTIONS(3810), 1,
      anon_sym_BSLASH,
    ACTIONS(3814), 1,
      anon_sym_LBRACK,
    ACTIONS(5122), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1106), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1132), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3818), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [69826] = 5,
    ACTIONS(5380), 1,
      anon_sym_PLUS,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5031), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1695), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(5036), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [69849] = 5,
    ACTIONS(5383), 1,
      sym__printable,
    STATE(1865), 1,
      sym__sign_define_arg_text,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4131), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4133), 6,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [69872] = 7,
    ACTIONS(5385), 1,
      anon_sym_icon,
    ACTIONS(5391), 1,
      anon_sym_text,
    STATE(1697), 1,
      aux_sym__sign_define_repeat1,
    STATE(1812), 1,
      sym__sign_define_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5171), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5388), 4,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [69899] = 8,
    ACTIONS(5397), 1,
      anon_sym_name,
    ACTIONS(5400), 1,
      anon_sym_group,
    ACTIONS(5403), 1,
      anon_sym_file,
    STATE(1698), 1,
      aux_sym__sign_place_place_repeat1,
    STATE(1826), 1,
      sym__sign_place_place_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5184), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5394), 3,
      anon_sym_line,
      anon_sym_buffer,
      anon_sym_priority,
  [69928] = 7,
    ACTIONS(3430), 1,
      anon_sym_BSLASH,
    ACTIONS(3438), 1,
      anon_sym_LBRACK,
    ACTIONS(4963), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1035), 2,
      aux_sym__pattern_ordinary_atom,
      sym__pattern_atom,
    STATE(1053), 2,
      sym__pattern_piece,
      aux_sym__pattern_concat,
    ACTIONS(3442), 3,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [69955] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5077), 3,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5079), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
      anon_sym_PLUS_PLUS,
  [69974] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5067), 3,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5069), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
      anon_sym_PLUS_PLUS,
  [69993] = 3,
    ACTIONS(5406), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5408), 9,
      anon_sym_in,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_EQ,
      anon_sym_DOT_DOT_EQ,
      anon_sym_EQ_LT_LT,
  [70012] = 5,
    ACTIONS(1318), 1,
      aux_sym_identifier_token1,
    ACTIONS(5410), 1,
      aux_sym_argument_token1,
    ACTIONS(5412), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1312), 6,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [70034] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5376), 3,
      anon_sym_BSLASH,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5378), 6,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [70052] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5416), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5414), 6,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [70070] = 5,
    ACTIONS(4342), 1,
      anon_sym_BSLASH2,
    ACTIONS(4344), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1719), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4717), 6,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [70092] = 7,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(5418), 1,
      anon_sym_PLUS,
    STATE(2976), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1820), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [70118] = 3,
    ACTIONS(4509), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4507), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_RPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [70136] = 3,
    ACTIONS(4509), 1,
      anon_sym_SLASH2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4507), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [70154] = 3,
    ACTIONS(4513), 1,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4511), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_RPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [70172] = 3,
    ACTIONS(4513), 1,
      anon_sym_SLASH2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4511), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [70190] = 7,
    ACTIONS(4526), 1,
      anon_sym_BSLASH,
    ACTIONS(4530), 1,
      aux_sym_filename_token3,
    STATE(1790), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1898), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5259), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4532), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [70216] = 5,
    STATE(1737), 1,
      aux_sym__bang_filter_command_argument_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5420), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(5422), 2,
      aux_sym__bang_filter_command_argument_token3,
      aux_sym__bang_filter_command_argument_token4,
    ACTIONS(5424), 4,
      sym_string_literal,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [70238] = 5,
    STATE(1738), 1,
      aux_sym__bang_filter_command_argument_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5420), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(5426), 2,
      aux_sym__bang_filter_command_argument_token3,
      aux_sym__bang_filter_command_argument_token4,
    ACTIONS(5424), 4,
      sym_string_literal,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [70260] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(742), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token3,
    ACTIONS(740), 7,
      anon_sym_START,
      anon_sym_OPT,
      anon_sym_PACK,
      anon_sym_ALL,
      anon_sym_BSLASH,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [70278] = 5,
    STATE(1766), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5428), 2,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token7,
    ACTIONS(4123), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5430), 3,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
  [70300] = 6,
    ACTIONS(1062), 1,
      sym_au_event,
    ACTIONS(5432), 1,
      anon_sym_LBRACE2,
    ACTIONS(5434), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1718), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1064), 4,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__autocmd_pattern_token1,
  [70324] = 6,
    ACTIONS(902), 1,
      sym_au_event,
    ACTIONS(5432), 1,
      anon_sym_LBRACE2,
    ACTIONS(5436), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1721), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(904), 4,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__autocmd_pattern_token1,
  [70348] = 5,
    ACTIONS(5438), 1,
      anon_sym_BSLASH2,
    ACTIONS(5441), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1719), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4753), 6,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [70370] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5446), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5444), 6,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [70388] = 6,
    ACTIONS(910), 1,
      sym_au_event,
    ACTIONS(5448), 1,
      anon_sym_LBRACE2,
    ACTIONS(5451), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1721), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(912), 4,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__autocmd_pattern_token1,
  [70412] = 5,
    ACTIONS(4342), 1,
      anon_sym_BSLASH2,
    ACTIONS(4344), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1719), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4660), 6,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
  [70434] = 8,
    ACTIONS(5454), 1,
      anon_sym_BANG,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1912), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(1916), 1,
      sym_bang,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5458), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [70462] = 7,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    ACTIONS(5418), 1,
      anon_sym_PLUS,
    STATE(2658), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1820), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [70488] = 6,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3694), 1,
      aux_sym_filename_token3,
    STATE(2418), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(5462), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [70512] = 8,
    ACTIONS(804), 1,
      anon_sym_LT,
    ACTIONS(806), 1,
      anon_sym_BSLASH2,
    ACTIONS(3300), 1,
      aux_sym__map_rhs_statement_token1,
    ACTIONS(5464), 1,
      aux_sym__bang_filter_command_argument_token3,
    STATE(1743), 1,
      aux_sym__map_lhs_repeat1,
    STATE(1935), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3304), 3,
      anon_sym_BSLASH,
      anon_sym_LT2,
      aux_sym__map_rhs_token1,
  [70540] = 7,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    ACTIONS(5418), 1,
      anon_sym_PLUS,
    STATE(2660), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1820), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [70566] = 8,
    ACTIONS(804), 1,
      anon_sym_LT,
    ACTIONS(806), 1,
      anon_sym_BSLASH2,
    ACTIONS(3300), 1,
      aux_sym__map_rhs_statement_token1,
    ACTIONS(5466), 1,
      aux_sym__bang_filter_command_argument_token3,
    STATE(1745), 1,
      aux_sym__map_lhs_repeat1,
    STATE(1935), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3304), 3,
      anon_sym_BSLASH,
      anon_sym_LT2,
      aux_sym__map_rhs_token1,
  [70594] = 6,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3694), 1,
      aux_sym_filename_token3,
    STATE(2507), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(5130), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [70618] = 5,
    ACTIONS(5468), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1730), 2,
      sym_plus_plus_opt,
      aux_sym_edit_statement_repeat1,
    ACTIONS(4682), 3,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(4684), 3,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [70640] = 7,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    ACTIONS(5418), 1,
      anon_sym_PLUS,
    STATE(2486), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1820), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [70666] = 3,
    ACTIONS(5473), 1,
      anon_sym_text,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5471), 8,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [70684] = 4,
    ACTIONS(5475), 1,
      anon_sym_BSLASH_AMP,
    STATE(1733), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
  [70704] = 8,
    ACTIONS(5454), 1,
      anon_sym_BANG,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1975), 1,
      sym_bang,
    STATE(1978), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5478), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [70732] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(742), 3,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(740), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
      anon_sym_PLUS_PLUS,
  [70750] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5480), 9,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [70766] = 5,
    STATE(1737), 1,
      aux_sym__bang_filter_command_argument_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5482), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(5484), 2,
      aux_sym__bang_filter_command_argument_token3,
      aux_sym__bang_filter_command_argument_token4,
    ACTIONS(5487), 4,
      sym_string_literal,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [70788] = 5,
    STATE(1737), 1,
      aux_sym__bang_filter_command_argument_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5422), 2,
      aux_sym__bang_filter_command_argument_token3,
      aux_sym__bang_filter_command_argument_token4,
    ACTIONS(5489), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(5491), 4,
      sym_string_literal,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [70810] = 6,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3694), 1,
      aux_sym_filename_token3,
    STATE(2710), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(5493), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [70834] = 5,
    STATE(1713), 1,
      aux_sym__bang_filter_command_argument_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5495), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(5497), 2,
      aux_sym__bang_filter_command_argument_token3,
      aux_sym__bang_filter_command_argument_token4,
    ACTIONS(5499), 4,
      sym_string_literal,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [70856] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4509), 2,
      sym__separator,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(4507), 7,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [70874] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5503), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5501), 6,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [70892] = 8,
    ACTIONS(3308), 1,
      aux_sym__map_rhs_statement_token1,
    ACTIONS(5505), 1,
      aux_sym__bang_filter_command_argument_token3,
    ACTIONS(5508), 1,
      anon_sym_LT,
    ACTIONS(5511), 1,
      anon_sym_BSLASH2,
    STATE(1743), 1,
      aux_sym__map_lhs_repeat1,
    STATE(1935), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3313), 3,
      anon_sym_BSLASH,
      anon_sym_LT2,
      aux_sym__map_rhs_token1,
  [70920] = 3,
    ACTIONS(4509), 1,
      anon_sym_QMARK2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4507), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [70938] = 8,
    ACTIONS(804), 1,
      anon_sym_LT,
    ACTIONS(806), 1,
      anon_sym_BSLASH2,
    ACTIONS(3327), 1,
      aux_sym__map_rhs_statement_token1,
    ACTIONS(5464), 1,
      aux_sym__bang_filter_command_argument_token3,
    STATE(1743), 1,
      aux_sym__map_lhs_repeat1,
    STATE(1935), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3329), 3,
      anon_sym_BSLASH,
      anon_sym_LT2,
      aux_sym__map_rhs_token1,
  [70966] = 7,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    ACTIONS(5418), 1,
      anon_sym_PLUS,
    STATE(2489), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1820), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [70992] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5372), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5374), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [71010] = 3,
    ACTIONS(5516), 1,
      anon_sym_text,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5514), 8,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [71028] = 7,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(5418), 1,
      anon_sym_PLUS,
    STATE(2954), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1820), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [71054] = 4,
    ACTIONS(5518), 1,
      anon_sym_BSLASH_AMP,
    STATE(1750), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 7,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_SLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [71074] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5077), 3,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5079), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
      anon_sym_PLUS_PLUS,
  [71092] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5523), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5521), 6,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [71110] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5376), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5378), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      anon_sym_POUND,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [71128] = 7,
    ACTIONS(5525), 1,
      anon_sym_LBRACE,
    ACTIONS(5527), 1,
      aux_sym_identifier_token1,
    ACTIONS(5531), 1,
      sym_integer_literal,
    STATE(948), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2716), 2,
      sym_identifier,
      sym__sign_name,
    ACTIONS(5529), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [71154] = 8,
    ACTIONS(5535), 1,
      anon_sym_group,
    ACTIONS(5537), 1,
      anon_sym_STAR2,
    ACTIONS(5539), 1,
      sym_integer_literal,
    STATE(2724), 1,
      sym__sign_unplace_cursor_argument,
    STATE(2728), 1,
      sym__sign_unplace_cursor,
    STATE(2729), 1,
      sym__sign_unplace_id,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5533), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [71182] = 6,
    ACTIONS(3682), 1,
      anon_sym_BSLASH,
    ACTIONS(3694), 1,
      aux_sym_filename_token3,
    STATE(2665), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
    ACTIONS(5541), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [71206] = 8,
    ACTIONS(5454), 1,
      anon_sym_BANG,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1913), 1,
      sym_bang,
    STATE(1950), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5543), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [71234] = 8,
    ACTIONS(5545), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(5547), 1,
      anon_sym_BSLASH,
    ACTIONS(5549), 1,
      anon_sym_BANG,
    ACTIONS(5551), 1,
      sym_string_literal,
    STATE(1905), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5227), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1906), 2,
      sym__bang_filter_command_argument,
      aux_sym__bang_filter_command_repeat1,
  [71262] = 3,
    ACTIONS(4513), 1,
      anon_sym_QMARK2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4511), 8,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [71280] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4513), 2,
      sym__separator,
      aux_sym__pattern_ordinary_atom_token2,
    ACTIONS(4511), 7,
      anon_sym_BSLASH,
      anon_sym_BSLASH_AMP,
      anon_sym_BSLASH_PIPE,
      anon_sym_LBRACK,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
  [71298] = 8,
    ACTIONS(5454), 1,
      anon_sym_BANG,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1929), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(1984), 1,
      sym_bang,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5553), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [71326] = 4,
    ACTIONS(5557), 1,
      anon_sym_BSLASH_AMP,
    STATE(1772), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 7,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [71346] = 5,
    ACTIONS(5265), 1,
      anon_sym_BSLASH,
    STATE(1763), 1,
      aux_sym_map_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5263), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_LT2,
    ACTIONS(5559), 5,
      anon_sym_LTbuffer_GT,
      anon_sym_LTnowait_GT,
      anon_sym_LTsilent_GT,
      anon_sym_LTunique_GT,
      anon_sym_LTscript_GT,
  [71368] = 5,
    STATE(1782), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5562), 2,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token7,
    ACTIONS(4151), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5564), 3,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
  [71390] = 5,
    ACTIONS(1606), 1,
      anon_sym_EQ,
    ACTIONS(1608), 1,
      aux_sym_identifier_token1,
    ACTIONS(1610), 1,
      anon_sym_EQ_LT_LT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1604), 6,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [71412] = 5,
    STATE(1789), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5566), 2,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token7,
    ACTIONS(4151), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5568), 3,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
  [71434] = 4,
    ACTIONS(5570), 1,
      sym__printable,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5572), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5296), 6,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [71454] = 7,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(5418), 1,
      anon_sym_PLUS,
    STATE(2896), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1820), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [71480] = 3,
    STATE(1604), 1,
      sym__command_attribute_address_behavior,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5574), 8,
      anon_sym_lines,
      anon_sym_arguments,
      anon_sym_buffers,
      anon_sym_loaded_buffers,
      anon_sym_windows,
      anon_sym_tabs,
      anon_sym_quickfix,
      anon_sym_other,
  [71498] = 7,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    ACTIONS(5418), 1,
      anon_sym_PLUS,
    STATE(2378), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1820), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [71524] = 7,
    ACTIONS(4526), 1,
      anon_sym_BSLASH,
    ACTIONS(4530), 1,
      aux_sym_filename_token3,
    STATE(1790), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1898), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5270), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4532), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [71550] = 4,
    ACTIONS(5576), 1,
      anon_sym_BSLASH_AMP,
    STATE(1772), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 7,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [71570] = 7,
    ACTIONS(4526), 1,
      anon_sym_BSLASH,
    ACTIONS(4530), 1,
      aux_sym_filename_token3,
    STATE(1790), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1898), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5332), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4532), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [71596] = 4,
    ACTIONS(5579), 1,
      anon_sym_BSLASH_AMP,
    STATE(1733), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
  [71616] = 8,
    ACTIONS(744), 1,
      aux_sym__map_rhs_statement_token1,
    ACTIONS(798), 1,
      aux_sym__bang_filter_command_argument_token3,
    ACTIONS(804), 1,
      anon_sym_LT,
    ACTIONS(806), 1,
      anon_sym_BSLASH2,
    STATE(1726), 1,
      aux_sym__map_lhs_repeat1,
    STATE(1935), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(748), 3,
      anon_sym_BSLASH,
      anon_sym_LT2,
      aux_sym__map_rhs_token1,
  [71644] = 7,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(5418), 1,
      anon_sym_PLUS,
    STATE(2850), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1820), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [71670] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5067), 3,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5069), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
      anon_sym_PLUS_PLUS,
  [71688] = 3,
    ACTIONS(5583), 1,
      anon_sym_text,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5581), 8,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [71706] = 7,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(5418), 1,
      anon_sym_PLUS,
    STATE(2964), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1820), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [71732] = 7,
    ACTIONS(3477), 1,
      sym_scope,
    ACTIONS(5525), 1,
      anon_sym_LBRACE,
    ACTIONS(5585), 1,
      anon_sym_a_COLON,
    ACTIONS(5587), 1,
      aux_sym_identifier_token1,
    STATE(948), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1626), 4,
      sym_scoped_identifier,
      sym_argument,
      sym_identifier,
      sym__ident,
  [71758] = 4,
    ACTIONS(5589), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4131), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(4133), 6,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_text,
      anon_sym_texthl,
      anon_sym_culhl,
  [71778] = 5,
    STATE(1789), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5566), 2,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token7,
    ACTIONS(4170), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5568), 3,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
  [71800] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5591), 9,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [71816] = 4,
    ACTIONS(5593), 1,
      anon_sym_BSLASH_AMP,
    STATE(1750), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 7,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_SLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [71836] = 4,
    ACTIONS(5595), 1,
      anon_sym_BSLASH_AMP,
    STATE(1785), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_SLASH2,
      anon_sym_BSLASH_PIPE,
  [71856] = 7,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    ACTIONS(5418), 1,
      anon_sym_PLUS,
    STATE(2391), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3694), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1820), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [71882] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5372), 3,
      anon_sym_BSLASH,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5374), 6,
      anon_sym_PLUS,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [71900] = 4,
    ACTIONS(5598), 1,
      anon_sym_BSLASH_AMP,
    STATE(1785), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_SLASH2,
      anon_sym_BSLASH_PIPE,
  [71920] = 5,
    STATE(1789), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5600), 2,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token7,
    ACTIONS(4177), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5603), 3,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
  [71942] = 7,
    ACTIONS(5606), 1,
      anon_sym_BSLASH,
    ACTIONS(5612), 1,
      aux_sym_filename_token3,
    STATE(1790), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1898), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5279), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5609), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [71968] = 7,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(5418), 1,
      anon_sym_PLUS,
    STATE(2957), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 2,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
    ACTIONS(3884), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1820), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
  [71994] = 4,
    ACTIONS(5617), 1,
      anon_sym_BSLASH_PIPE,
    STATE(1884), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5615), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_SLASH2,
  [72013] = 8,
    ACTIONS(5619), 1,
      anon_sym_BANG,
    ACTIONS(5621), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5625), 1,
      sym_string_literal,
    STATE(2035), 1,
      sym_bang,
    STATE(2039), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5623), 2,
      sym__newline_or_pipe,
      sym_comment,
  [72040] = 7,
    ACTIONS(5629), 1,
      anon_sym_buffer,
    ACTIONS(5631), 1,
      anon_sym_group,
    ACTIONS(5633), 1,
      anon_sym_file,
    STATE(1829), 1,
      aux_sym__sign_unplace_id_repeat1,
    STATE(2045), 1,
      sym__sign_unplace_id_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5627), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72065] = 7,
    ACTIONS(5637), 1,
      anon_sym_buffer,
    ACTIONS(5639), 1,
      anon_sym_group,
    ACTIONS(5641), 1,
      anon_sym_file,
    STATE(1832), 1,
      aux_sym__sign_jump_repeat1,
    STATE(2052), 1,
      sym__sign_jump_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5635), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72090] = 3,
    STATE(1064), 1,
      sym__syn_pattern_offset,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2574), 7,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
  [72107] = 5,
    ACTIONS(1606), 1,
      anon_sym_EQ,
    ACTIONS(1608), 1,
      aux_sym_identifier_token1,
    ACTIONS(1610), 1,
      anon_sym_EQ_LT_LT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1604), 5,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
  [72128] = 5,
    ACTIONS(2992), 1,
      sym_hl_group,
    STATE(2018), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5643), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5645), 3,
      anon_sym_contains,
      anon_sym_add,
      anon_sym_remove,
  [72149] = 5,
    STATE(1799), 1,
      aux_sym__syn_cluster_repeat1,
    STATE(2019), 1,
      sym__syn_arguments_cluster,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5647), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5649), 3,
      anon_sym_contains,
      anon_sym_add,
      anon_sym_remove,
  [72170] = 7,
    ACTIONS(5637), 1,
      anon_sym_buffer,
    ACTIONS(5639), 1,
      anon_sym_group,
    ACTIONS(5641), 1,
      anon_sym_file,
    STATE(1834), 1,
      aux_sym__sign_jump_repeat1,
    STATE(2052), 1,
      sym__sign_jump_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5652), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72195] = 4,
    ACTIONS(5654), 1,
      anon_sym_BSLASH_PIPE,
    STATE(1801), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5054), 6,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_SLASH2,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72214] = 7,
    ACTIONS(812), 1,
      anon_sym_LT,
    ACTIONS(814), 1,
      anon_sym_BSLASH2,
    ACTIONS(5659), 1,
      aux_sym__map_rhs_token2,
    STATE(1880), 1,
      aux_sym__map_rhs_repeat1,
    STATE(2006), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5657), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72239] = 7,
    ACTIONS(4058), 1,
      sym_au_event,
    ACTIONS(4060), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(2165), 1,
      sym_au_event_list,
    STATE(2437), 1,
      sym__autocmd_pattern,
    STATE(2438), 1,
      sym__autocmd_command,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5661), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72264] = 3,
    ACTIONS(5056), 1,
      anon_sym_BSLASH2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4775), 7,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
      aux_sym__plus_cmd_arg_token1,
  [72281] = 7,
    ACTIONS(812), 1,
      anon_sym_LT,
    ACTIONS(814), 1,
      anon_sym_BSLASH2,
    ACTIONS(5663), 1,
      aux_sym__map_rhs_token2,
    STATE(1882), 1,
      aux_sym__map_rhs_repeat1,
    STATE(2006), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5657), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72306] = 7,
    ACTIONS(5667), 1,
      anon_sym_buffer,
    ACTIONS(5670), 1,
      anon_sym_group,
    ACTIONS(5673), 1,
      anon_sym_file,
    STATE(1806), 1,
      aux_sym__sign_unplace_id_repeat1,
    STATE(2045), 1,
      sym__sign_unplace_id_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5665), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72331] = 5,
    STATE(1815), 1,
      aux_sym__syn_cluster_repeat1,
    STATE(2019), 1,
      sym__syn_arguments_cluster,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5676), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
    ACTIONS(5678), 3,
      anon_sym_contains,
      anon_sym_add,
      anon_sym_remove,
  [72352] = 7,
    ACTIONS(5682), 1,
      anon_sym_buffer,
    ACTIONS(5685), 1,
      anon_sym_group,
    ACTIONS(5688), 1,
      anon_sym_file,
    STATE(1808), 1,
      aux_sym__sign_jump_repeat1,
    STATE(2052), 1,
      sym__sign_jump_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5680), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72377] = 6,
    ACTIONS(5221), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(5223), 1,
      anon_sym_BSLASH,
    ACTIONS(5229), 1,
      sym_string_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1810), 2,
      sym__bang_filter_command_argument,
      aux_sym__bang_filter_command_repeat1,
    ACTIONS(5691), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72400] = 6,
    ACTIONS(5693), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(5696), 1,
      anon_sym_BSLASH,
    ACTIONS(5701), 1,
      sym_string_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1810), 2,
      sym__bang_filter_command_argument,
      aux_sym__bang_filter_command_repeat1,
    ACTIONS(5699), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72423] = 6,
    ACTIONS(5706), 1,
      sym_hl_group,
    STATE(1907), 1,
      aux_sym__syn_sync_repeat1,
    STATE(2124), 1,
      sym__syn_sync_lines,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5708), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
    ACTIONS(5704), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72446] = 3,
    ACTIONS(5583), 1,
      anon_sym_text,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5581), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [72463] = 9,
    ACTIONS(5710), 1,
      anon_sym_COLON,
    ACTIONS(5712), 1,
      sym_command_name,
    ACTIONS(5714), 1,
      sym__normal,
    ACTIONS(5716), 1,
      sym__source,
    ACTIONS(5718), 1,
      sym__global,
    ACTIONS(5720), 1,
      sym__call,
    ACTIONS(5722), 1,
      sym__substitute,
    ACTIONS(5724), 1,
      sym_unknown_command_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [72492] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(742), 2,
      anon_sym_BSLASH,
      aux_sym_filename_token3,
    ACTIONS(740), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [72509] = 5,
    STATE(1799), 1,
      aux_sym__syn_cluster_repeat1,
    STATE(2019), 1,
      sym__syn_arguments_cluster,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5678), 3,
      anon_sym_contains,
      anon_sym_add,
      anon_sym_remove,
    ACTIONS(5726), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72530] = 6,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3884), 1,
      aux_sym_filename_token3,
    STATE(2861), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5462), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3882), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [72553] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5728), 8,
      anon_sym_BSLASH,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [72568] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5730), 8,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      sym_command_name,
  [72583] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5501), 8,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [72598] = 5,
    ACTIONS(5732), 1,
      anon_sym_PLUS,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5031), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    STATE(1820), 2,
      sym_plus_cmd,
      aux_sym_edit_statement_repeat2,
    ACTIONS(5036), 3,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [72619] = 8,
    ACTIONS(5619), 1,
      anon_sym_BANG,
    ACTIONS(5621), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5625), 1,
      sym_string_literal,
    STATE(2055), 1,
      sym_bang,
    STATE(2057), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5735), 2,
      sym__newline_or_pipe,
      sym_comment,
  [72646] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5737), 8,
      anon_sym_BSLASH,
      anon_sym_LBRACK,
      aux_sym__pattern_ordinary_atom_token2,
      anon_sym_BSLASH_LPAREN,
      anon_sym_BSLASH_PERCENT_LPAREN,
      anon_sym_BSLASHz_LPAREN,
      anon_sym_minlines,
      anon_sym_maxlines,
  [72661] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5739), 8,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      sym_command_name,
  [72676] = 5,
    ACTIONS(5743), 1,
      aux_sym_filename_token7,
    STATE(1825), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4170), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5741), 4,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
  [72697] = 5,
    ACTIONS(5748), 1,
      aux_sym_filename_token7,
    STATE(1825), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4177), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5745), 4,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
  [72718] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5591), 8,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [72733] = 7,
    ACTIONS(5753), 1,
      anon_sym_buffer,
    ACTIONS(5756), 1,
      anon_sym_group,
    ACTIONS(5759), 1,
      anon_sym_file,
    STATE(1827), 1,
      aux_sym__sign_place_list,
    STATE(1993), 1,
      sym__sign_place_list_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5751), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72758] = 7,
    ACTIONS(5629), 1,
      anon_sym_buffer,
    ACTIONS(5631), 1,
      anon_sym_group,
    ACTIONS(5633), 1,
      anon_sym_file,
    STATE(1806), 1,
      aux_sym__sign_unplace_id_repeat1,
    STATE(2045), 1,
      sym__sign_unplace_id_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5762), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72783] = 7,
    ACTIONS(5629), 1,
      anon_sym_buffer,
    ACTIONS(5631), 1,
      anon_sym_group,
    ACTIONS(5633), 1,
      anon_sym_file,
    STATE(1806), 1,
      aux_sym__sign_unplace_id_repeat1,
    STATE(2045), 1,
      sym__sign_unplace_id_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5764), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72808] = 9,
    ACTIONS(5766), 1,
      anon_sym_COLON,
    ACTIONS(5768), 1,
      sym_command_name,
    ACTIONS(5770), 1,
      sym__normal,
    ACTIONS(5772), 1,
      sym__source,
    ACTIONS(5774), 1,
      sym__global,
    ACTIONS(5776), 1,
      sym__call,
    ACTIONS(5778), 1,
      sym__substitute,
    ACTIONS(5780), 1,
      sym_unknown_command_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [72837] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5782), 2,
      anon_sym_BSLASH,
      aux_sym_filename_token3,
    ACTIONS(5784), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [72854] = 7,
    ACTIONS(5637), 1,
      anon_sym_buffer,
    ACTIONS(5639), 1,
      anon_sym_group,
    ACTIONS(5641), 1,
      anon_sym_file,
    STATE(1808), 1,
      aux_sym__sign_jump_repeat1,
    STATE(2052), 1,
      sym__sign_jump_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5786), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72879] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5414), 8,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [72894] = 7,
    ACTIONS(5637), 1,
      anon_sym_buffer,
    ACTIONS(5639), 1,
      anon_sym_group,
    ACTIONS(5641), 1,
      anon_sym_file,
    STATE(1808), 1,
      aux_sym__sign_jump_repeat1,
    STATE(2052), 1,
      sym__sign_jump_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5788), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [72919] = 4,
    ACTIONS(5792), 1,
      anon_sym_BSLASH_PIPE,
    STATE(1851), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5790), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_QMARK2,
  [72938] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5444), 8,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [72953] = 9,
    ACTIONS(5794), 1,
      anon_sym_LBRACE,
    ACTIONS(5796), 1,
      aux_sym_identifier_token1,
    ACTIONS(5798), 1,
      anon_sym_COMMA,
    ACTIONS(5800), 1,
      anon_sym_RPAREN,
    ACTIONS(5802), 1,
      sym_spread,
    STATE(1949), 1,
      sym__curly_braces_name_expression,
    STATE(2604), 1,
      sym_default_parameter,
    STATE(3189), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [72982] = 3,
    ACTIONS(4947), 1,
      anon_sym_BSLASH2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4753), 7,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
      aux_sym_filename_token4,
      aux_sym__plus_cmd_arg_token1,
  [72999] = 6,
    ACTIONS(1064), 1,
      aux_sym__autocmd_pattern_token1,
    ACTIONS(5804), 1,
      anon_sym_LBRACE2,
    ACTIONS(5806), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1897), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1062), 3,
      sym__newline_or_pipe,
      sym_comment,
      sym_au_event,
  [73022] = 7,
    ACTIONS(5147), 1,
      anon_sym_name,
    ACTIONS(5149), 1,
      anon_sym_group,
    ACTIONS(5151), 1,
      anon_sym_file,
    STATE(1588), 1,
      aux_sym__sign_place_place_repeat1,
    STATE(1783), 1,
      sym__sign_place_place_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5145), 3,
      anon_sym_line,
      anon_sym_buffer,
      anon_sym_priority,
  [73047] = 5,
    STATE(21), 1,
      sym__cmd_separator,
    STATE(1983), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5810), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5808), 4,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [73068] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5521), 8,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_EQ2,
      anon_sym_COLON2,
      anon_sym_PLUS_EQ2,
      anon_sym_CARET_EQ,
      anon_sym_DASH_EQ2,
      anon_sym_SPACE,
  [73083] = 9,
    ACTIONS(5794), 1,
      anon_sym_LBRACE,
    ACTIONS(5796), 1,
      aux_sym_identifier_token1,
    ACTIONS(5812), 1,
      anon_sym_COMMA,
    ACTIONS(5814), 1,
      anon_sym_RPAREN,
    ACTIONS(5816), 1,
      sym_spread,
    STATE(1949), 1,
      sym__curly_braces_name_expression,
    STATE(2286), 1,
      sym_identifier,
    STATE(2525), 1,
      sym_default_parameter,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [73112] = 7,
    ACTIONS(812), 1,
      anon_sym_LT,
    ACTIONS(814), 1,
      anon_sym_BSLASH2,
    ACTIONS(818), 1,
      aux_sym__map_rhs_token2,
    STATE(1805), 1,
      aux_sym__map_rhs_repeat1,
    STATE(2006), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(816), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [73137] = 6,
    ACTIONS(5818), 1,
      aux_sym__bang_filter_command_argument_token3,
    ACTIONS(5820), 1,
      aux_sym__bang_filter_command_argument_token4,
    STATE(1891), 1,
      aux_sym__bang_filter_command_argument_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5495), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(5499), 3,
      sym__newline_or_pipe,
      sym_string_literal,
      sym_comment,
  [73160] = 3,
    STATE(827), 1,
      sym__syn_pattern_offset,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2478), 7,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
  [73177] = 6,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3884), 1,
      aux_sym_filename_token3,
    STATE(2963), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5541), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3882), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [73200] = 3,
    STATE(1889), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5615), 7,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [73217] = 4,
    ACTIONS(5617), 1,
      anon_sym_BSLASH_PIPE,
    STATE(1792), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5790), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_SLASH2,
  [73236] = 4,
    ACTIONS(5822), 1,
      anon_sym_BSLASH_PIPE,
    STATE(1850), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5054), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_QMARK2,
  [73255] = 4,
    ACTIONS(5792), 1,
      anon_sym_BSLASH_PIPE,
    STATE(1850), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5615), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_QMARK2,
  [73274] = 3,
    STATE(1038), 1,
      sym__syn_pattern_offset,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2524), 7,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
  [73291] = 3,
    STATE(1801), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5615), 7,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_SLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [73308] = 9,
    ACTIONS(5794), 1,
      anon_sym_LBRACE,
    ACTIONS(5796), 1,
      aux_sym_identifier_token1,
    ACTIONS(5825), 1,
      anon_sym_COMMA,
    ACTIONS(5827), 1,
      anon_sym_RPAREN,
    ACTIONS(5829), 1,
      sym_spread,
    STATE(1949), 1,
      sym__curly_braces_name_expression,
    STATE(2736), 1,
      sym_identifier,
    STATE(2741), 1,
      sym_default_parameter,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [73337] = 5,
    ACTIONS(5833), 1,
      aux_sym_filename_token7,
    STATE(1864), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4123), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5831), 4,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
  [73358] = 6,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3884), 1,
      aux_sym_filename_token3,
    STATE(2818), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5493), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3882), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [73381] = 3,
    STATE(964), 1,
      sym__syn_pattern_offset,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2554), 7,
      anon_sym_ms,
      anon_sym_me,
      anon_sym_hs,
      anon_sym_he,
      anon_sym_rs,
      anon_sym_re,
      anon_sym_lc,
  [73398] = 6,
    ACTIONS(5221), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(5223), 1,
      anon_sym_BSLASH,
    ACTIONS(5229), 1,
      sym_string_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1809), 2,
      sym__bang_filter_command_argument,
      aux_sym__bang_filter_command_repeat1,
    ACTIONS(5835), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [73421] = 6,
    ACTIONS(5221), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(5223), 1,
      anon_sym_BSLASH,
    ACTIONS(5229), 1,
      sym_string_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1810), 2,
      sym__bang_filter_command_argument,
      aux_sym__bang_filter_command_repeat1,
    ACTIONS(5835), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [73444] = 5,
    STATE(28), 1,
      sym__cmd_separator,
    STATE(1983), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5837), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5808), 4,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [73465] = 3,
    ACTIONS(5516), 1,
      anon_sym_text,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5514), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [73482] = 5,
    ACTIONS(1318), 1,
      aux_sym_identifier_token1,
    ACTIONS(5410), 1,
      aux_sym_argument_token1,
    ACTIONS(5412), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1312), 5,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
  [73503] = 5,
    ACTIONS(5841), 1,
      aux_sym_filename_token7,
    STATE(1824), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4151), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5839), 4,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
  [73524] = 5,
    ACTIONS(5743), 1,
      aux_sym_filename_token7,
    STATE(1825), 1,
      aux_sym_filename_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4151), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5741), 4,
      aux_sym__bang_filter_command_argument_token4,
      aux_sym_filename_token5,
      aux_sym_filename_token6,
      aux_sym_filename_token8,
  [73545] = 3,
    ACTIONS(5473), 1,
      anon_sym_text,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5471), 7,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_icon,
      anon_sym_linehl,
      anon_sym_numhl,
      anon_sym_texthl,
      anon_sym_culhl,
  [73562] = 5,
    STATE(28), 1,
      sym__cmd_separator,
    STATE(1841), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5837), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5843), 4,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [73583] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5480), 8,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_line,
      anon_sym_name,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_priority,
      anon_sym_file,
  [73598] = 6,
    ACTIONS(912), 1,
      aux_sym__autocmd_pattern_token1,
    ACTIONS(5845), 1,
      anon_sym_LBRACE2,
    ACTIONS(5848), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1868), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(910), 3,
      sym__newline_or_pipe,
      sym_comment,
      sym_au_event,
  [73621] = 6,
    ACTIONS(5851), 1,
      aux_sym__bang_filter_command_argument_token3,
    ACTIONS(5853), 1,
      aux_sym__bang_filter_command_argument_token4,
    STATE(1878), 1,
      aux_sym__bang_filter_command_argument_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5489), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(5491), 3,
      sym__newline_or_pipe,
      sym_string_literal,
      sym_comment,
  [73644] = 5,
    STATE(42), 1,
      sym__cmd_separator,
    STATE(1872), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5857), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5855), 4,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [73665] = 5,
    STATE(24), 1,
      sym__cmd_separator,
    STATE(1860), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5861), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5859), 4,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [73686] = 5,
    STATE(46), 1,
      sym__cmd_separator,
    STATE(1983), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5863), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5808), 4,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [73707] = 5,
    STATE(46), 1,
      sym__cmd_separator,
    STATE(1876), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5863), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5865), 4,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [73728] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5372), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5374), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [73745] = 7,
    ACTIONS(5869), 1,
      anon_sym_buffer,
    ACTIONS(5871), 1,
      anon_sym_group,
    ACTIONS(5873), 1,
      anon_sym_file,
    STATE(1827), 1,
      aux_sym__sign_place_list,
    STATE(1993), 1,
      sym__sign_place_list_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5867), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [73770] = 5,
    STATE(49), 1,
      sym__cmd_separator,
    STATE(1983), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5875), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5808), 4,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [73791] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5376), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5378), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [73808] = 6,
    ACTIONS(5877), 1,
      aux_sym__bang_filter_command_argument_token3,
    ACTIONS(5880), 1,
      aux_sym__bang_filter_command_argument_token4,
    STATE(1878), 1,
      aux_sym__bang_filter_command_argument_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5482), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(5487), 3,
      sym__newline_or_pipe,
      sym_string_literal,
      sym_comment,
  [73831] = 3,
    STATE(1848), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5790), 7,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [73848] = 7,
    ACTIONS(812), 1,
      anon_sym_LT,
    ACTIONS(814), 1,
      anon_sym_BSLASH2,
    ACTIONS(5663), 1,
      aux_sym__map_rhs_token2,
    STATE(1882), 1,
      aux_sym__map_rhs_repeat1,
    STATE(2006), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5883), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [73873] = 7,
    ACTIONS(5885), 1,
      anon_sym_LBRACE,
    ACTIONS(5887), 1,
      aux_sym_identifier_token1,
    ACTIONS(5889), 1,
      sym_integer_literal,
    STATE(2117), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5529), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(2845), 2,
      sym_identifier,
      sym__sign_name,
  [73898] = 7,
    ACTIONS(5891), 1,
      anon_sym_LT,
    ACTIONS(5894), 1,
      anon_sym_BSLASH2,
    ACTIONS(5899), 1,
      aux_sym__map_rhs_token2,
    STATE(1882), 1,
      aux_sym__map_rhs_repeat1,
    STATE(2006), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5897), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [73923] = 3,
    STATE(1853), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5790), 7,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_SLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [73940] = 4,
    ACTIONS(5902), 1,
      anon_sym_BSLASH_PIPE,
    STATE(1884), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5054), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_SLASH2,
  [73959] = 8,
    ACTIONS(5619), 1,
      anon_sym_BANG,
    ACTIONS(5621), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5625), 1,
      sym_string_literal,
    STATE(2012), 1,
      sym_bang,
    STATE(2013), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5905), 2,
      sym__newline_or_pipe,
      sym_comment,
  [73986] = 7,
    ACTIONS(5629), 1,
      anon_sym_buffer,
    ACTIONS(5631), 1,
      anon_sym_group,
    ACTIONS(5633), 1,
      anon_sym_file,
    STATE(1828), 1,
      aux_sym__sign_unplace_id_repeat1,
    STATE(2045), 1,
      sym__sign_unplace_id_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5907), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74011] = 8,
    ACTIONS(5619), 1,
      anon_sym_BANG,
    ACTIONS(5621), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5625), 1,
      sym_string_literal,
    STATE(2027), 1,
      sym_bang,
    STATE(2033), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5909), 2,
      sym__newline_or_pipe,
      sym_comment,
  [74038] = 6,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3884), 1,
      aux_sym_filename_token3,
    STATE(2771), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5130), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(3882), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [74061] = 4,
    ACTIONS(5911), 1,
      anon_sym_BSLASH_PIPE,
    STATE(1889), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5054), 6,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_QMARK2,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74080] = 9,
    ACTIONS(5794), 1,
      anon_sym_LBRACE,
    ACTIONS(5796), 1,
      aux_sym_identifier_token1,
    ACTIONS(5914), 1,
      anon_sym_COMMA,
    ACTIONS(5916), 1,
      anon_sym_RPAREN,
    ACTIONS(5918), 1,
      sym_spread,
    STATE(1949), 1,
      sym__curly_braces_name_expression,
    STATE(2416), 1,
      sym_default_parameter,
    STATE(2736), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [74109] = 6,
    ACTIONS(5851), 1,
      aux_sym__bang_filter_command_argument_token3,
    ACTIONS(5853), 1,
      aux_sym__bang_filter_command_argument_token4,
    STATE(1878), 1,
      aux_sym__bang_filter_command_argument_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5420), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(5424), 3,
      sym__newline_or_pipe,
      sym_string_literal,
      sym_comment,
  [74132] = 6,
    ACTIONS(5920), 1,
      aux_sym__bang_filter_command_argument_token3,
    ACTIONS(5922), 1,
      aux_sym__bang_filter_command_argument_token4,
    STATE(1869), 1,
      aux_sym__bang_filter_command_argument_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5420), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(5424), 3,
      sym__newline_or_pipe,
      sym_string_literal,
      sym_comment,
  [74155] = 7,
    ACTIONS(4058), 1,
      sym_au_event,
    ACTIONS(4060), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(2158), 1,
      sym_au_event_list,
    STATE(2612), 1,
      sym__autocmd_pattern,
    STATE(2623), 1,
      sym__autocmd_command,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5924), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74180] = 7,
    ACTIONS(5300), 1,
      anon_sym_name,
    ACTIONS(5302), 1,
      anon_sym_group,
    ACTIONS(5304), 1,
      anon_sym_file,
    STATE(1678), 1,
      aux_sym__sign_place_place_repeat1,
    STATE(1826), 1,
      sym__sign_place_place_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5298), 3,
      anon_sym_line,
      anon_sym_buffer,
      anon_sym_priority,
  [74205] = 8,
    ACTIONS(5926), 1,
      anon_sym_group,
    ACTIONS(5928), 1,
      anon_sym_STAR2,
    ACTIONS(5930), 1,
      sym_integer_literal,
    STATE(2898), 1,
      sym__sign_unplace_cursor_argument,
    STATE(2908), 1,
      sym__sign_unplace_cursor,
    STATE(2918), 1,
      sym__sign_unplace_id,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5533), 2,
      sym__newline_or_pipe,
      sym_comment,
  [74232] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4515), 8,
      sym__normal,
      sym__source,
      sym__global,
      sym__call,
      sym__substitute,
      sym_unknown_command_name,
      anon_sym_COLON,
      sym_command_name,
  [74247] = 6,
    ACTIONS(904), 1,
      aux_sym__autocmd_pattern_token1,
    ACTIONS(5804), 1,
      anon_sym_LBRACE2,
    ACTIONS(5932), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1868), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(902), 3,
      sym__newline_or_pipe,
      sym_comment,
      sym_au_event,
  [74270] = 3,
    ACTIONS(5782), 1,
      aux_sym_filename_token3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5784), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [74286] = 7,
    ACTIONS(824), 1,
      anon_sym_LT,
    ACTIONS(826), 1,
      anon_sym_BSLASH2,
    ACTIONS(5934), 1,
      aux_sym__map_rhs_token2,
    STATE(1927), 1,
      aux_sym__map_rhs_repeat1,
    STATE(2138), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5936), 2,
      sym__newline_or_pipe,
      sym_comment,
  [74310] = 7,
    ACTIONS(5938), 1,
      anon_sym_buffer,
    ACTIONS(5940), 1,
      anon_sym_group,
    ACTIONS(5942), 1,
      anon_sym_file,
    STATE(1971), 1,
      aux_sym__sign_jump_repeat1,
    STATE(2210), 1,
      sym__sign_jump_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5635), 2,
      sym__newline_or_pipe,
      sym_comment,
  [74334] = 5,
    STATE(1965), 1,
      aux_sym__syn_sync_repeat1,
    STATE(2124), 1,
      sym__syn_sync_lines,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5946), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
    ACTIONS(5944), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74354] = 7,
    ACTIONS(5938), 1,
      anon_sym_buffer,
    ACTIONS(5940), 1,
      anon_sym_group,
    ACTIONS(5942), 1,
      anon_sym_file,
    STATE(1973), 1,
      aux_sym__sign_jump_repeat1,
    STATE(2210), 1,
      sym__sign_jump_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5652), 2,
      sym__newline_or_pipe,
      sym_comment,
  [74378] = 3,
    ACTIONS(5950), 1,
      anon_sym_QMARK2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5948), 6,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74394] = 4,
    ACTIONS(5952), 1,
      anon_sym_BSLASH_AMP,
    STATE(1904), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 5,
      anon_sym_BANG,
      anon_sym_SLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74412] = 6,
    ACTIONS(5545), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(5547), 1,
      anon_sym_BSLASH,
    ACTIONS(5551), 1,
      sym_string_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5835), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1980), 2,
      sym__bang_filter_command_argument,
      aux_sym__bang_filter_command_repeat1,
  [74434] = 6,
    ACTIONS(5545), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(5547), 1,
      anon_sym_BSLASH,
    ACTIONS(5551), 1,
      sym_string_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5835), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1982), 2,
      sym__bang_filter_command_argument,
      aux_sym__bang_filter_command_repeat1,
  [74456] = 5,
    STATE(1932), 1,
      aux_sym__syn_sync_repeat1,
    STATE(2124), 1,
      sym__syn_sync_lines,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5946), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
    ACTIONS(5955), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74476] = 4,
    ACTIONS(5957), 1,
      anon_sym_BSLASH_AMP,
    STATE(1953), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
  [74494] = 5,
    STATE(1974), 1,
      aux_sym__syn_cluster_repeat1,
    STATE(2193), 1,
      sym__syn_arguments_cluster,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5676), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5959), 3,
      anon_sym_contains,
      anon_sym_add,
      anon_sym_remove,
  [74514] = 8,
    ACTIONS(5961), 1,
      anon_sym_BSLASH,
    ACTIONS(5963), 1,
      anon_sym_LT2,
    ACTIONS(5965), 1,
      aux_sym__map_rhs_statement_token1,
    ACTIONS(5967), 1,
      aux_sym__map_rhs_token1,
    STATE(1955), 1,
      sym_keycode,
    STATE(2936), 1,
      sym__map_rhs_statement,
    STATE(2949), 1,
      sym__map_rhs,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [74540] = 4,
    ACTIONS(5969), 1,
      anon_sym_BSLASH_AMP,
    STATE(1911), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
      anon_sym_BSLASH_PIPE,
  [74558] = 6,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1930), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5972), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74580] = 6,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1943), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5974), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74602] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(742), 3,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(740), 4,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
      anon_sym_PLUS_PLUS,
  [74618] = 4,
    ACTIONS(5976), 1,
      anon_sym_BSLASH_AMP,
    STATE(1915), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 5,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_minlines,
      anon_sym_maxlines,
  [74636] = 6,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1989), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5979), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74658] = 6,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1930), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5981), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74680] = 3,
    ACTIONS(5950), 1,
      anon_sym_SLASH2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5948), 6,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74696] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(742), 3,
      sym_hl_group,
      anon_sym_link,
      anon_sym_clear,
    ACTIONS(740), 4,
      sym__default,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74712] = 5,
    STATE(1932), 1,
      aux_sym__syn_sync_repeat1,
    STATE(2124), 1,
      sym__syn_sync_lines,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5946), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
    ACTIONS(5983), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74732] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3308), 2,
      anon_sym_BSLASH2,
      aux_sym__map_rhs_statement_token1,
    ACTIONS(3313), 5,
      anon_sym_BSLASH,
      aux_sym__bang_filter_command_argument_token3,
      anon_sym_LT,
      anon_sym_LT2,
      aux_sym__map_rhs_token1,
  [74748] = 7,
    ACTIONS(4315), 1,
      sym_au_event,
    ACTIONS(4317), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(2344), 1,
      sym_au_event_list,
    STATE(2855), 1,
      sym__autocmd_pattern,
    STATE(2856), 1,
      sym__autocmd_command,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5985), 2,
      sym__newline_or_pipe,
      sym_comment,
  [74772] = 3,
    ACTIONS(742), 1,
      aux_sym_filename_token3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(740), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [74788] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3399), 2,
      anon_sym_BSLASH2,
      aux_sym__map_rhs_statement_token1,
    ACTIONS(3401), 5,
      anon_sym_BSLASH,
      aux_sym__bang_filter_command_argument_token3,
      anon_sym_LT,
      anon_sym_LT2,
      aux_sym__map_rhs_token1,
  [74804] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5077), 3,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5079), 4,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
      anon_sym_PLUS_PLUS,
  [74820] = 7,
    ACTIONS(824), 1,
      anon_sym_LT,
    ACTIONS(826), 1,
      anon_sym_BSLASH2,
    ACTIONS(5934), 1,
      aux_sym__map_rhs_token2,
    STATE(1927), 1,
      aux_sym__map_rhs_repeat1,
    STATE(2138), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5987), 2,
      sym__newline_or_pipe,
      sym_comment,
  [74844] = 7,
    ACTIONS(5989), 1,
      anon_sym_LT,
    ACTIONS(5992), 1,
      anon_sym_BSLASH2,
    ACTIONS(5995), 1,
      aux_sym__map_rhs_token2,
    STATE(1927), 1,
      aux_sym__map_rhs_repeat1,
    STATE(2138), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5998), 2,
      sym__newline_or_pipe,
      sym_comment,
  [74868] = 5,
    ACTIONS(6002), 1,
      anon_sym_BANG,
    ACTIONS(6004), 1,
      aux_sym_filename_token3,
    STATE(2198), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6000), 4,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [74888] = 6,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1930), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6006), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74910] = 6,
    ACTIONS(6008), 1,
      aux_sym_command_argument_token1,
    ACTIONS(6013), 1,
      sym_string_literal,
    STATE(1930), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6011), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74932] = 4,
    ACTIONS(6016), 1,
      anon_sym_BSLASH_AMP,
    STATE(1967), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH_PIPE,
      anon_sym_minlines,
      anon_sym_maxlines,
  [74950] = 5,
    STATE(1932), 1,
      aux_sym__syn_sync_repeat1,
    STATE(2124), 1,
      sym__syn_sync_lines,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6020), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
    ACTIONS(6018), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [74970] = 6,
    ACTIONS(6023), 1,
      anon_sym_BSLASH,
    ACTIONS(6027), 1,
      aux_sym_filename_token3,
    STATE(1758), 1,
      sym_filename,
    STATE(2756), 1,
      sym__bang_filter_command,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6025), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [74992] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3388), 2,
      anon_sym_BSLASH2,
      aux_sym__map_rhs_statement_token1,
    ACTIONS(3390), 5,
      anon_sym_BSLASH,
      aux_sym__bang_filter_command_argument_token3,
      anon_sym_LT,
      anon_sym_LT2,
      aux_sym__map_rhs_token1,
  [75008] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3426), 2,
      anon_sym_BSLASH2,
      aux_sym__map_rhs_statement_token1,
    ACTIONS(3428), 5,
      anon_sym_BSLASH,
      aux_sym__bang_filter_command_argument_token3,
      anon_sym_LT,
      anon_sym_LT2,
      aux_sym__map_rhs_token1,
  [75024] = 6,
    ACTIONS(4526), 1,
      anon_sym_BSLASH,
    ACTIONS(4530), 1,
      aux_sym_filename_token3,
    STATE(1771), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1898), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4532), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [75046] = 3,
    ACTIONS(740), 1,
      sym_au_event,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(742), 6,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__autocmd_pattern_token1,
  [75062] = 5,
    STATE(1920), 1,
      aux_sym__syn_sync_repeat1,
    STATE(2124), 1,
      sym__syn_sync_lines,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5946), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
    ACTIONS(6029), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [75082] = 6,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1930), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6031), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [75104] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5067), 3,
      anon_sym_PLUS,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5069), 4,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
      anon_sym_PLUS_PLUS,
  [75120] = 6,
    ACTIONS(6033), 1,
      sym_hl_group,
    STATE(2024), 1,
      aux_sym__syn_sync_repeat1,
    STATE(2296), 1,
      sym__syn_sync_lines,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5704), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(6035), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
  [75142] = 4,
    ACTIONS(6037), 1,
      anon_sym_BSLASH_AMP,
    STATE(1957), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 5,
      anon_sym_BANG,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [75160] = 6,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1930), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6039), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [75182] = 6,
    ACTIONS(4526), 1,
      anon_sym_BSLASH,
    ACTIONS(4530), 1,
      aux_sym_filename_token3,
    STATE(1712), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1898), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4532), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [75204] = 7,
    ACTIONS(824), 1,
      anon_sym_LT,
    ACTIONS(826), 1,
      anon_sym_BSLASH2,
    ACTIONS(6041), 1,
      aux_sym__map_rhs_token2,
    STATE(1926), 1,
      aux_sym__map_rhs_repeat1,
    STATE(2138), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5936), 2,
      sym__newline_or_pipe,
      sym_comment,
  [75228] = 3,
    ACTIONS(1336), 1,
      sym_au_event,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1338), 6,
      anon_sym_LBRACE2,
      aux_sym_identifier_token2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__autocmd_pattern_token1,
  [75244] = 7,
    ACTIONS(6043), 1,
      anon_sym_buffer,
    ACTIONS(6046), 1,
      anon_sym_group,
    ACTIONS(6049), 1,
      anon_sym_file,
    STATE(1947), 1,
      aux_sym__sign_place_list,
    STATE(2205), 1,
      sym__sign_place_list_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5751), 2,
      sym__newline_or_pipe,
      sym_comment,
  [75268] = 8,
    ACTIONS(6052), 1,
      anon_sym_BSLASH,
    ACTIONS(6054), 1,
      anon_sym_LT2,
    ACTIONS(6056), 1,
      aux_sym__map_rhs_statement_token1,
    ACTIONS(6058), 1,
      aux_sym__map_rhs_token1,
    STATE(1844), 1,
      sym_keycode,
    STATE(2641), 1,
      sym__map_rhs_statement,
    STATE(2642), 1,
      sym__map_rhs,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [75294] = 5,
    ACTIONS(6060), 1,
      anon_sym_LBRACE2,
    ACTIONS(6062), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1958), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(1062), 3,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [75314] = 6,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1930), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6064), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [75336] = 6,
    ACTIONS(3694), 1,
      aux_sym_filename_token3,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    ACTIONS(6066), 1,
      anon_sym_AT,
    STATE(2690), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [75358] = 5,
    ACTIONS(3533), 1,
      sym_hl_group,
    STATE(2182), 1,
      sym_hl_groups,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5643), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5645), 3,
      anon_sym_contains,
      anon_sym_add,
      anon_sym_remove,
  [75378] = 4,
    ACTIONS(6068), 1,
      anon_sym_BSLASH_AMP,
    STATE(1953), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
  [75396] = 5,
    STATE(1954), 1,
      aux_sym__syn_cluster_repeat1,
    STATE(2193), 1,
      sym__syn_arguments_cluster,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5647), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(6071), 3,
      anon_sym_contains,
      anon_sym_add,
      anon_sym_remove,
  [75416] = 7,
    ACTIONS(824), 1,
      anon_sym_LT,
    ACTIONS(826), 1,
      anon_sym_BSLASH2,
    ACTIONS(828), 1,
      aux_sym__map_rhs_token2,
    STATE(1899), 1,
      aux_sym__map_rhs_repeat1,
    STATE(2138), 1,
      sym__immediate_keycode,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(830), 2,
      sym__newline_or_pipe,
      sym_comment,
  [75440] = 6,
    ACTIONS(4534), 1,
      anon_sym_BSLASH,
    ACTIONS(4536), 1,
      aux_sym_filename_token3,
    STATE(1658), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1831), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4538), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [75462] = 4,
    ACTIONS(6074), 1,
      anon_sym_BSLASH_AMP,
    STATE(1957), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 5,
      anon_sym_BANG,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [75480] = 5,
    ACTIONS(6060), 1,
      anon_sym_LBRACE2,
    ACTIONS(6077), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1968), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(902), 3,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [75500] = 8,
    ACTIONS(5869), 1,
      anon_sym_buffer,
    ACTIONS(5871), 1,
      anon_sym_group,
    ACTIONS(5873), 1,
      anon_sym_file,
    ACTIONS(6079), 1,
      sym_integer_literal,
    STATE(1875), 1,
      aux_sym__sign_place_list,
    STATE(1993), 1,
      sym__sign_place_list_argument,
    STATE(2717), 1,
      sym__sign_place_place,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [75526] = 3,
    ACTIONS(1320), 1,
      sym_au_event,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1322), 6,
      anon_sym_LBRACE2,
      aux_sym_identifier_token2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__autocmd_pattern_token1,
  [75542] = 7,
    ACTIONS(6081), 1,
      anon_sym_buffer,
    ACTIONS(6083), 1,
      anon_sym_group,
    ACTIONS(6085), 1,
      anon_sym_file,
    STATE(1969), 1,
      aux_sym__sign_unplace_id_repeat1,
    STATE(2194), 1,
      sym__sign_unplace_id_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5762), 2,
      sym__newline_or_pipe,
      sym_comment,
  [75566] = 3,
    ACTIONS(1318), 1,
      aux_sym_identifier_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1312), 6,
      sym__scope_dict,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [75582] = 6,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3884), 1,
      aux_sym_filename_token3,
    ACTIONS(6087), 1,
      anon_sym_AT,
    STATE(2938), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [75604] = 6,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6093), 1,
      aux_sym_filename_token3,
    STATE(1635), 1,
      sym_filename,
    STATE(2405), 1,
      sym__bang_filter_command,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6091), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [75626] = 5,
    STATE(1932), 1,
      aux_sym__syn_sync_repeat1,
    STATE(2124), 1,
      sym__syn_sync_lines,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5946), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
    ACTIONS(6095), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [75646] = 7,
    ACTIONS(6081), 1,
      anon_sym_buffer,
    ACTIONS(6083), 1,
      anon_sym_group,
    ACTIONS(6085), 1,
      anon_sym_file,
    STATE(1969), 1,
      aux_sym__sign_unplace_id_repeat1,
    STATE(2194), 1,
      sym__sign_unplace_id_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5764), 2,
      sym__newline_or_pipe,
      sym_comment,
  [75670] = 4,
    ACTIONS(6097), 1,
      anon_sym_BSLASH_AMP,
    STATE(1967), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH_PIPE,
      anon_sym_minlines,
      anon_sym_maxlines,
  [75688] = 5,
    ACTIONS(6100), 1,
      anon_sym_LBRACE2,
    ACTIONS(6103), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1968), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
    ACTIONS(910), 3,
      anon_sym_EQ,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [75708] = 7,
    ACTIONS(6106), 1,
      anon_sym_buffer,
    ACTIONS(6109), 1,
      anon_sym_group,
    ACTIONS(6112), 1,
      anon_sym_file,
    STATE(1969), 1,
      aux_sym__sign_unplace_id_repeat1,
    STATE(2194), 1,
      sym__sign_unplace_id_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5665), 2,
      sym__newline_or_pipe,
      sym_comment,
  [75732] = 7,
    ACTIONS(6115), 1,
      anon_sym_buffer,
    ACTIONS(6118), 1,
      anon_sym_group,
    ACTIONS(6121), 1,
      anon_sym_file,
    STATE(1970), 1,
      aux_sym__sign_jump_repeat1,
    STATE(2210), 1,
      sym__sign_jump_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5680), 2,
      sym__newline_or_pipe,
      sym_comment,
  [75756] = 7,
    ACTIONS(5938), 1,
      anon_sym_buffer,
    ACTIONS(5940), 1,
      anon_sym_group,
    ACTIONS(5942), 1,
      anon_sym_file,
    STATE(1970), 1,
      aux_sym__sign_jump_repeat1,
    STATE(2210), 1,
      sym__sign_jump_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5786), 2,
      sym__newline_or_pipe,
      sym_comment,
  [75780] = 8,
    ACTIONS(6124), 1,
      anon_sym_buffer,
    ACTIONS(6126), 1,
      anon_sym_group,
    ACTIONS(6128), 1,
      anon_sym_file,
    ACTIONS(6130), 1,
      sym_integer_literal,
    STATE(1985), 1,
      aux_sym__sign_place_list,
    STATE(2205), 1,
      sym__sign_place_list_argument,
    STATE(2864), 1,
      sym__sign_place_place,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [75806] = 7,
    ACTIONS(5938), 1,
      anon_sym_buffer,
    ACTIONS(5940), 1,
      anon_sym_group,
    ACTIONS(5942), 1,
      anon_sym_file,
    STATE(1970), 1,
      aux_sym__sign_jump_repeat1,
    STATE(2210), 1,
      sym__sign_jump_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5788), 2,
      sym__newline_or_pipe,
      sym_comment,
  [75830] = 5,
    STATE(1954), 1,
      aux_sym__syn_cluster_repeat1,
    STATE(2193), 1,
      sym__syn_arguments_cluster,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5726), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(5959), 3,
      anon_sym_contains,
      anon_sym_add,
      anon_sym_remove,
  [75850] = 6,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1939), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6132), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [75872] = 4,
    ACTIONS(6134), 1,
      anon_sym_BSLASH_AMP,
    STATE(1915), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 5,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_minlines,
      anon_sym_maxlines,
  [75890] = 4,
    ACTIONS(6136), 1,
      anon_sym_BSLASH_AMP,
    STATE(1911), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
      anon_sym_BSLASH_PIPE,
  [75908] = 6,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1930), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6138), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [75930] = 6,
    ACTIONS(4534), 1,
      anon_sym_BSLASH,
    ACTIONS(4536), 1,
      aux_sym_filename_token3,
    STATE(1645), 1,
      aux_sym_runtime_statement_repeat1,
    STATE(1831), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4538), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [75952] = 6,
    ACTIONS(5545), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(5547), 1,
      anon_sym_BSLASH,
    ACTIONS(5551), 1,
      sym_string_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5691), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1982), 2,
      sym__bang_filter_command_argument,
      aux_sym__bang_filter_command_repeat1,
  [75974] = 4,
    ACTIONS(6140), 1,
      anon_sym_BSLASH_AMP,
    STATE(1904), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 5,
      anon_sym_BANG,
      anon_sym_SLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [75992] = 6,
    ACTIONS(6142), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(6145), 1,
      anon_sym_BSLASH,
    ACTIONS(6148), 1,
      sym_string_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5699), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1982), 2,
      sym__bang_filter_command_argument,
      aux_sym__bang_filter_command_repeat1,
  [76014] = 4,
    STATE(1983), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6154), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(6151), 4,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [76032] = 6,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1917), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6156), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [76054] = 7,
    ACTIONS(6124), 1,
      anon_sym_buffer,
    ACTIONS(6126), 1,
      anon_sym_group,
    ACTIONS(6128), 1,
      anon_sym_file,
    STATE(1947), 1,
      aux_sym__sign_place_list,
    STATE(2205), 1,
      sym__sign_place_list_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5867), 2,
      sym__newline_or_pipe,
      sym_comment,
  [76078] = 7,
    ACTIONS(6081), 1,
      anon_sym_buffer,
    ACTIONS(6083), 1,
      anon_sym_group,
    ACTIONS(6085), 1,
      anon_sym_file,
    STATE(1961), 1,
      aux_sym__sign_unplace_id_repeat1,
    STATE(2194), 1,
      sym__sign_unplace_id_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5907), 2,
      sym__newline_or_pipe,
      sym_comment,
  [76102] = 7,
    ACTIONS(6081), 1,
      anon_sym_buffer,
    ACTIONS(6083), 1,
      anon_sym_group,
    ACTIONS(6085), 1,
      anon_sym_file,
    STATE(1966), 1,
      aux_sym__sign_unplace_id_repeat1,
    STATE(2194), 1,
      sym__sign_unplace_id_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5627), 2,
      sym__newline_or_pipe,
      sym_comment,
  [76126] = 7,
    ACTIONS(4315), 1,
      sym_au_event,
    ACTIONS(4317), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(2363), 1,
      sym_au_event_list,
    STATE(2900), 1,
      sym__autocmd_pattern,
    STATE(2907), 1,
      sym__autocmd_command,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6158), 2,
      sym__newline_or_pipe,
      sym_comment,
  [76150] = 6,
    ACTIONS(5456), 1,
      aux_sym_command_argument_token1,
    ACTIONS(5460), 1,
      sym_string_literal,
    STATE(1930), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2199), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6160), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [76172] = 5,
    STATE(2004), 1,
      aux_sym__syn_sync_repeat1,
    STATE(2296), 1,
      sym__syn_sync_lines,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6029), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(6162), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
  [76191] = 5,
    ACTIONS(6164), 1,
      anon_sym_LBRACE2,
    ACTIONS(6166), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(902), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(2000), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
  [76210] = 6,
    ACTIONS(167), 1,
      sym__catch,
    ACTIONS(169), 1,
      sym__finally,
    ACTIONS(6168), 1,
      sym__endtry,
    STATE(3089), 1,
      sym_finally_statement,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2131), 2,
      sym_catch_statement,
      aux_sym_try_statement_repeat1,
  [76231] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6170), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [76244] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6172), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [76257] = 4,
    ACTIONS(6174), 1,
      anon_sym_COMMA,
    STATE(1995), 1,
      aux_sym_au_event_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6177), 4,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__autocmd_pattern_token1,
  [76274] = 6,
    ACTIONS(6179), 1,
      anon_sym_LBRACE,
    ACTIONS(6181), 1,
      aux_sym_identifier_token1,
    ACTIONS(6183), 1,
      sym_integer_literal,
    STATE(1370), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1736), 2,
      sym_identifier,
      sym__sign_name,
  [76295] = 4,
    ACTIONS(6185), 1,
      anon_sym_BSLASH_PIPE,
    STATE(1997), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5054), 4,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_minlines,
      anon_sym_maxlines,
  [76312] = 7,
    ACTIONS(5794), 1,
      anon_sym_LBRACE,
    ACTIONS(5796), 1,
      aux_sym_identifier_token1,
    ACTIONS(6188), 1,
      sym_spread,
    STATE(1949), 1,
      sym__curly_braces_name_expression,
    STATE(2981), 1,
      sym_default_parameter,
    STATE(3189), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [76335] = 4,
    ACTIONS(6190), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2001), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5615), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
  [76352] = 5,
    ACTIONS(6192), 1,
      anon_sym_LBRACE2,
    ACTIONS(6195), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(910), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(2000), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
  [76371] = 4,
    ACTIONS(6198), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2001), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5054), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
  [76388] = 4,
    ACTIONS(6201), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2002), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5054), 4,
      anon_sym_BANG,
      anon_sym_QMARK2,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [76405] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6204), 3,
      anon_sym_default,
      anon_sym_toplevel,
      anon_sym_notoplevel,
    ACTIONS(6206), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [76420] = 5,
    STATE(2101), 1,
      aux_sym__syn_sync_repeat1,
    STATE(2296), 1,
      sym__syn_sync_lines,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5983), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(6162), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
  [76439] = 5,
    ACTIONS(3874), 1,
      anon_sym_BSLASH,
    ACTIONS(3884), 1,
      aux_sym_filename_token3,
    STATE(2932), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3882), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [76458] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6208), 6,
      anon_sym_LT,
      anon_sym_BSLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__map_rhs_token2,
  [76471] = 4,
    ACTIONS(6210), 1,
      anon_sym_COMMA,
    STATE(1995), 1,
      aux_sym_au_event_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6212), 4,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__autocmd_pattern_token1,
  [76488] = 4,
    ACTIONS(6214), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2008), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5054), 4,
      anon_sym_BANG,
      anon_sym_SLASH2,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [76505] = 5,
    STATE(2100), 1,
      aux_sym__syn_sync_repeat1,
    STATE(2296), 1,
      sym__syn_sync_lines,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5944), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(6162), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
  [76524] = 5,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(2015), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6217), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [76543] = 5,
    ACTIONS(6219), 1,
      anon_sym_BSLASH,
    ACTIONS(6223), 1,
      aux_sym_filename_token3,
    STATE(2185), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6221), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [76562] = 5,
    STATE(2067), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5625), 2,
      sym_string_literal,
      aux_sym_command_argument_token1,
    ACTIONS(6225), 2,
      sym__newline_or_pipe,
      sym_comment,
  [76581] = 5,
    STATE(2053), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5625), 2,
      sym_string_literal,
      aux_sym_command_argument_token1,
    ACTIONS(6227), 2,
      sym__newline_or_pipe,
      sym_comment,
  [76600] = 5,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(2015), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6229), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [76619] = 5,
    ACTIONS(6233), 1,
      anon_sym_end,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(2015), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6231), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [76638] = 5,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(2015), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6236), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [76657] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5372), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5374), 4,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [76672] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6238), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_contains,
      anon_sym_add,
      anon_sym_remove,
  [76685] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6240), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_contains,
      anon_sym_add,
      anon_sym_remove,
  [76698] = 6,
    ACTIONS(175), 1,
      sym__elseif,
    ACTIONS(177), 1,
      sym__else,
    ACTIONS(6242), 1,
      sym__endif,
    STATE(3019), 1,
      sym_else_statement,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2132), 2,
      sym_elseif_statement,
      aux_sym_if_statement_repeat1,
  [76719] = 6,
    ACTIONS(167), 1,
      sym__catch,
    ACTIONS(169), 1,
      sym__finally,
    ACTIONS(6244), 1,
      sym__endtry,
    STATE(3029), 1,
      sym_finally_statement,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2131), 2,
      sym_catch_statement,
      aux_sym_try_statement_repeat1,
  [76740] = 4,
    ACTIONS(6246), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2034), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5615), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
  [76757] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(742), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(740), 4,
      sym_string_literal,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [76772] = 5,
    STATE(2101), 1,
      aux_sym__syn_sync_repeat1,
    STATE(2296), 1,
      sym__syn_sync_lines,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5955), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(6162), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
  [76791] = 5,
    ACTIONS(3694), 1,
      aux_sym_filename_token3,
    ACTIONS(4540), 1,
      anon_sym_BSLASH,
    STATE(2601), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3692), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [76810] = 5,
    ACTIONS(6248), 1,
      anon_sym_BANG,
    STATE(1928), 1,
      sym_bang,
    STATE(1964), 1,
      sym__bang_filter_bangs,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6250), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [76829] = 5,
    STATE(2071), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5625), 2,
      sym_string_literal,
      aux_sym_command_argument_token1,
    ACTIONS(6252), 2,
      sym__newline_or_pipe,
      sym_comment,
  [76848] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3390), 6,
      anon_sym_LT,
      anon_sym_BSLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__map_rhs_token2,
  [76861] = 7,
    ACTIONS(5525), 1,
      anon_sym_LBRACE,
    ACTIONS(5527), 1,
      aux_sym_identifier_token1,
    ACTIONS(6254), 1,
      anon_sym_BANG,
    STATE(948), 1,
      sym__curly_braces_name_expression,
    STATE(2265), 1,
      sym_bang,
    STATE(2721), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [76884] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6256), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [76897] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6258), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [76910] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5376), 2,
      aux_sym_filename_token2,
      aux_sym_filename_token3,
    ACTIONS(5378), 4,
      anon_sym_BSLASH,
      anon_sym_PLUS,
      aux_sym_filename_token1,
      aux_sym_filename_token4,
  [76925] = 5,
    STATE(2053), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5625), 2,
      sym_string_literal,
      aux_sym_command_argument_token1,
    ACTIONS(6260), 2,
      sym__newline_or_pipe,
      sym_comment,
  [76944] = 4,
    ACTIONS(6262), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2034), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5054), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
  [76961] = 5,
    STATE(2049), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5625), 2,
      sym_string_literal,
      aux_sym_command_argument_token1,
    ACTIONS(6265), 2,
      sym__newline_or_pipe,
      sym_comment,
  [76980] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6269), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(6267), 4,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [76995] = 6,
    ACTIONS(6271), 1,
      anon_sym_LBRACE,
    ACTIONS(6273), 1,
      aux_sym_identifier_token1,
    ACTIONS(6275), 1,
      sym_integer_literal,
    STATE(1367), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1564), 2,
      sym_identifier,
      sym__sign_name,
  [77016] = 6,
    ACTIONS(5525), 1,
      anon_sym_LBRACE,
    ACTIONS(5527), 1,
      aux_sym_identifier_token1,
    ACTIONS(6277), 1,
      sym_integer_literal,
    STATE(948), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2715), 2,
      sym_identifier,
      sym__sign_name,
  [77037] = 5,
    STATE(2053), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5625), 2,
      sym_string_literal,
      aux_sym_command_argument_token1,
    ACTIONS(6279), 2,
      sym__newline_or_pipe,
      sym_comment,
  [77056] = 7,
    ACTIONS(5794), 1,
      anon_sym_LBRACE,
    ACTIONS(5796), 1,
      aux_sym_identifier_token1,
    ACTIONS(6281), 1,
      sym_spread,
    STATE(1949), 1,
      sym__curly_braces_name_expression,
    STATE(2981), 1,
      sym_default_parameter,
    STATE(3189), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [77079] = 6,
    ACTIONS(6283), 1,
      anon_sym_LBRACE2,
    ACTIONS(6285), 1,
      aux_sym__immediate_identifier_token1,
    STATE(820), 1,
      sym__method_call_expression,
    STATE(2121), 1,
      sym__immediate_curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(3201), 2,
      sym__immediate_identifier,
      sym__immediate_lambda_expression,
  [77100] = 6,
    ACTIONS(167), 1,
      sym__catch,
    ACTIONS(169), 1,
      sym__finally,
    ACTIONS(6287), 1,
      sym__endtry,
    STATE(3337), 1,
      sym_finally_statement,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2131), 2,
      sym_catch_statement,
      aux_sym_try_statement_repeat1,
  [77121] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3401), 6,
      anon_sym_LT,
      anon_sym_BSLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__map_rhs_token2,
  [77134] = 5,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(2015), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6289), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [77153] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6291), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [77166] = 5,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(2015), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6293), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [77185] = 5,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(2015), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6295), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [77204] = 5,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(2015), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6297), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [77223] = 5,
    STATE(2053), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5625), 2,
      sym_string_literal,
      aux_sym_command_argument_token1,
    ACTIONS(6299), 2,
      sym__newline_or_pipe,
      sym_comment,
  [77242] = 6,
    ACTIONS(175), 1,
      sym__elseif,
    ACTIONS(177), 1,
      sym__else,
    ACTIONS(6301), 1,
      sym__endif,
    STATE(2985), 1,
      sym_else_statement,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2132), 2,
      sym_elseif_statement,
      aux_sym_if_statement_repeat1,
  [77263] = 6,
    ACTIONS(167), 1,
      sym__catch,
    ACTIONS(169), 1,
      sym__finally,
    ACTIONS(6303), 1,
      sym__endtry,
    STATE(2997), 1,
      sym_finally_statement,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2131), 2,
      sym_catch_statement,
      aux_sym_try_statement_repeat1,
  [77284] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6305), 6,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [77297] = 5,
    STATE(2053), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6307), 2,
      sym_string_literal,
      aux_sym_command_argument_token1,
    ACTIONS(6310), 2,
      sym__newline_or_pipe,
      sym_comment,
  [77316] = 3,
    ACTIONS(6312), 1,
      anon_sym_SLASH2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5948), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [77331] = 5,
    STATE(2068), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5625), 2,
      sym_string_literal,
      aux_sym_command_argument_token1,
    ACTIONS(6314), 2,
      sym__newline_or_pipe,
      sym_comment,
  [77350] = 5,
    ACTIONS(4959), 1,
      anon_sym_SQUOTE,
    STATE(1225), 1,
      sym_font,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6316), 2,
      anon_sym_NONE2,
      aux_sym_font_token1,
    STATE(1224), 2,
      sym__hl_none,
      sym__hl_quoted_name,
  [77369] = 5,
    STATE(2053), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5625), 2,
      sym_string_literal,
      aux_sym_command_argument_token1,
    ACTIONS(6318), 2,
      sym__newline_or_pipe,
      sym_comment,
  [77388] = 5,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(2015), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6320), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [77407] = 5,
    ACTIONS(6322), 1,
      anon_sym_BSLASH,
    ACTIONS(6326), 1,
      aux_sym_filename_token3,
    STATE(1994), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6324), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [77426] = 5,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(2015), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6328), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [77445] = 5,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(2015), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6330), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [77464] = 5,
    STATE(10), 1,
      sym__cmd_separator,
    STATE(2747), 1,
      sym__au_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6332), 2,
      aux_sym__au_pattern_token1,
      aux_sym__au_pattern_token2,
    ACTIONS(6334), 2,
      sym__newline_or_pipe,
      sym_comment,
  [77483] = 6,
    ACTIONS(6283), 1,
      anon_sym_LBRACE2,
    ACTIONS(6285), 1,
      aux_sym__immediate_identifier_token1,
    STATE(604), 1,
      sym__method_call_expression,
    STATE(2121), 1,
      sym__immediate_curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(3147), 2,
      sym__immediate_identifier,
      sym__immediate_lambda_expression,
  [77504] = 5,
    ACTIONS(6336), 1,
      anon_sym_BSLASH,
    ACTIONS(6340), 1,
      aux_sym_filename_token3,
    STATE(1736), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6338), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [77523] = 5,
    ACTIONS(6322), 1,
      anon_sym_BSLASH,
    ACTIONS(6326), 1,
      aux_sym_filename_token3,
    STATE(2030), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6324), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [77542] = 5,
    ACTIONS(6322), 1,
      anon_sym_BSLASH,
    ACTIONS(6326), 1,
      aux_sym_filename_token3,
    STATE(2031), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6324), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [77561] = 5,
    STATE(2053), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5625), 2,
      sym_string_literal,
      aux_sym_command_argument_token1,
    ACTIONS(6342), 2,
      sym__newline_or_pipe,
      sym_comment,
  [77580] = 5,
    STATE(2053), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5625), 2,
      sym_string_literal,
      aux_sym_command_argument_token1,
    ACTIONS(6344), 2,
      sym__newline_or_pipe,
      sym_comment,
  [77599] = 5,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(2015), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6346), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [77618] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6348), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [77631] = 5,
    STATE(2053), 1,
      aux_sym_unknown_builtin_statement_repeat1,
    STATE(2334), 1,
      sym_command_argument,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5625), 2,
      sym_string_literal,
      aux_sym_command_argument_token1,
    ACTIONS(6350), 2,
      sym__newline_or_pipe,
      sym_comment,
  [77650] = 6,
    ACTIONS(6283), 1,
      anon_sym_LBRACE2,
    ACTIONS(6285), 1,
      aux_sym__immediate_identifier_token1,
    STATE(468), 1,
      sym__method_call_expression,
    STATE(2121), 1,
      sym__immediate_curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(3242), 2,
      sym__immediate_identifier,
      sym__immediate_lambda_expression,
  [77671] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(740), 3,
      sym__newline_or_pipe,
      sym_comment,
      sym__default,
    ACTIONS(742), 3,
      sym_hl_group,
      anon_sym_link,
      anon_sym_clear,
  [77686] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(740), 3,
      sym__newline_or_pipe,
      sym_comment,
      sym_au_event,
    ACTIONS(742), 3,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      aux_sym__autocmd_pattern_token1,
  [77701] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6352), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [77714] = 4,
    ACTIONS(6354), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2094), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5790), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_minlines,
      anon_sym_maxlines,
  [77731] = 6,
    ACTIONS(6283), 1,
      anon_sym_LBRACE2,
    ACTIONS(6285), 1,
      aux_sym__immediate_identifier_token1,
    STATE(653), 1,
      sym__method_call_expression,
    STATE(2121), 1,
      sym__immediate_curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(3261), 2,
      sym__immediate_identifier,
      sym__immediate_lambda_expression,
  [77752] = 7,
    ACTIONS(5794), 1,
      anon_sym_LBRACE,
    ACTIONS(5796), 1,
      aux_sym_identifier_token1,
    ACTIONS(5829), 1,
      sym_spread,
    STATE(1949), 1,
      sym__curly_braces_name_expression,
    STATE(2981), 1,
      sym_default_parameter,
    STATE(3189), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [77775] = 3,
    ACTIONS(742), 1,
      aux_sym_filename_token3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(740), 5,
      anon_sym_BSLASH,
      anon_sym_BANG,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [77790] = 3,
    STATE(1997), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5615), 5,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_minlines,
      anon_sym_maxlines,
  [77805] = 4,
    ACTIONS(6190), 1,
      anon_sym_BSLASH_PIPE,
    STATE(1999), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5790), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_QMARK2,
  [77822] = 6,
    ACTIONS(6283), 1,
      anon_sym_LBRACE2,
    ACTIONS(6285), 1,
      aux_sym__immediate_identifier_token1,
    STATE(318), 1,
      sym__method_call_expression,
    STATE(2121), 1,
      sym__immediate_curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(3278), 2,
      sym__immediate_identifier,
      sym__immediate_lambda_expression,
  [77843] = 6,
    ACTIONS(175), 1,
      sym__elseif,
    ACTIONS(177), 1,
      sym__else,
    ACTIONS(6356), 1,
      sym__endif,
    STATE(3289), 1,
      sym_else_statement,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2132), 2,
      sym_elseif_statement,
      aux_sym_if_statement_repeat1,
  [77864] = 3,
    STATE(2002), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5615), 5,
      anon_sym_BANG,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [77879] = 4,
    ACTIONS(6246), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2022), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5790), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_SLASH2,
  [77896] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5495), 2,
      aux_sym__bang_filter_command_argument_token1,
      anon_sym_BSLASH,
    ACTIONS(5499), 4,
      sym_string_literal,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [77911] = 3,
    STATE(2008), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5615), 5,
      anon_sym_BANG,
      anon_sym_SLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [77926] = 3,
    ACTIONS(1318), 1,
      aux_sym_identifier_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1312), 5,
      sym__newline_or_pipe,
      sym__scope_dict,
      sym_comment,
      anon_sym_a_COLON,
      anon_sym_LBRACE,
  [77941] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6358), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [77954] = 7,
    ACTIONS(5794), 1,
      anon_sym_LBRACE,
    ACTIONS(5796), 1,
      aux_sym_identifier_token1,
    ACTIONS(6360), 1,
      sym_spread,
    STATE(1949), 1,
      sym__curly_braces_name_expression,
    STATE(2981), 1,
      sym_default_parameter,
    STATE(3189), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [77977] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6362), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [77990] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6364), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [78003] = 7,
    ACTIONS(5885), 1,
      anon_sym_LBRACE,
    ACTIONS(5887), 1,
      aux_sym_identifier_token1,
    ACTIONS(6254), 1,
      anon_sym_BANG,
    STATE(2117), 1,
      sym__curly_braces_name_expression,
    STATE(2365), 1,
      sym_bang,
    STATE(2759), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [78026] = 4,
    ACTIONS(6354), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2109), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5615), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_minlines,
      anon_sym_maxlines,
  [78043] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1336), 3,
      sym__newline_or_pipe,
      sym_comment,
      sym_au_event,
    ACTIONS(1338), 3,
      anon_sym_LBRACE2,
      aux_sym_identifier_token2,
      aux_sym__autocmd_pattern_token1,
  [78058] = 6,
    ACTIONS(6366), 1,
      anon_sym_LBRACE,
    ACTIONS(6368), 1,
      aux_sym_identifier_token1,
    ACTIONS(6370), 1,
      sym_integer_literal,
    STATE(1460), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1633), 2,
      sym_identifier,
      sym__sign_name,
  [78079] = 6,
    ACTIONS(5885), 1,
      anon_sym_LBRACE,
    ACTIONS(5887), 1,
      aux_sym_identifier_token1,
    ACTIONS(6372), 1,
      sym_integer_literal,
    STATE(2117), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2841), 2,
      sym_identifier,
      sym__sign_name,
  [78100] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5897), 6,
      anon_sym_LT,
      anon_sym_BSLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__map_rhs_token2,
  [78113] = 3,
    ACTIONS(6312), 1,
      anon_sym_QMARK2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5948), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [78128] = 5,
    STATE(2101), 1,
      aux_sym__syn_sync_repeat1,
    STATE(2296), 1,
      sym__syn_sync_lines,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6095), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(6162), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
  [78147] = 5,
    STATE(2101), 1,
      aux_sym__syn_sync_repeat1,
    STATE(2296), 1,
      sym__syn_sync_lines,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6018), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(6374), 2,
      anon_sym_minlines,
      anon_sym_maxlines,
  [78166] = 4,
    ACTIONS(6210), 1,
      anon_sym_COMMA,
    STATE(2007), 1,
      aux_sym_au_event_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6377), 4,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__autocmd_pattern_token1,
  [78183] = 6,
    ACTIONS(6379), 1,
      anon_sym_LBRACE,
    ACTIONS(6381), 1,
      aux_sym_identifier_token1,
    ACTIONS(6383), 1,
      sym_integer_literal,
    STATE(1461), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1867), 2,
      sym_identifier,
      sym__sign_name,
  [78204] = 5,
    ACTIONS(6385), 1,
      anon_sym_BSLASH,
    ACTIONS(6389), 1,
      aux_sym_filename_token3,
    STATE(1867), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6387), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [78223] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6391), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [78236] = 3,
    STATE(2080), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5790), 5,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_minlines,
      anon_sym_maxlines,
  [78251] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6393), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [78264] = 5,
    ACTIONS(6219), 1,
      anon_sym_BSLASH,
    ACTIONS(6223), 1,
      aux_sym_filename_token3,
    STATE(2154), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6221), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [78283] = 4,
    ACTIONS(6395), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2109), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5054), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_minlines,
      anon_sym_maxlines,
  [78300] = 5,
    ACTIONS(6219), 1,
      anon_sym_BSLASH,
    ACTIONS(6223), 1,
      aux_sym_filename_token3,
    STATE(2180), 1,
      sym_filename,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6221), 3,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [78319] = 3,
    STATE(2084), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5790), 5,
      anon_sym_BANG,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [78334] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1320), 3,
      sym__newline_or_pipe,
      sym_comment,
      sym_au_event,
    ACTIONS(1322), 3,
      anon_sym_LBRACE2,
      aux_sym_identifier_token2,
      aux_sym__autocmd_pattern_token1,
  [78349] = 3,
    STATE(2087), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5790), 5,
      anon_sym_BANG,
      anon_sym_SLASH2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [78364] = 5,
    ACTIONS(4834), 1,
      anon_sym_SQUOTE,
    STATE(1325), 1,
      sym_font,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6398), 2,
      anon_sym_NONE2,
      aux_sym_font_token1,
    STATE(1324), 2,
      sym__hl_none,
      sym__hl_quoted_name,
  [78383] = 5,
    ACTIONS(2613), 1,
      anon_sym_end,
    STATE(646), 1,
      sym__syn_region_end,
    STATE(2015), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6400), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [78402] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6402), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [78415] = 5,
    ACTIONS(6164), 1,
      anon_sym_LBRACE2,
    ACTIONS(6404), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1062), 2,
      sym__newline_or_pipe,
      sym_comment,
    STATE(1991), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
  [78434] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6406), 6,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_dict,
      anon_sym_range,
      anon_sym_abort,
      anon_sym_closure,
  [78447] = 7,
    ACTIONS(5794), 1,
      anon_sym_LBRACE,
    ACTIONS(5796), 1,
      aux_sym_identifier_token1,
    ACTIONS(5918), 1,
      sym_spread,
    STATE(1949), 1,
      sym__curly_braces_name_expression,
    STATE(2981), 1,
      sym_default_parameter,
    STATE(3189), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [78470] = 6,
    ACTIONS(175), 1,
      sym__elseif,
    ACTIONS(177), 1,
      sym__else,
    ACTIONS(6408), 1,
      sym__endif,
    STATE(3152), 1,
      sym_else_statement,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2132), 2,
      sym_elseif_statement,
      aux_sym_if_statement_repeat1,
  [78491] = 5,
    ACTIONS(3259), 1,
      anon_sym_LBRACE2,
    ACTIONS(6410), 1,
      aux_sym_identifier_token2,
    ACTIONS(6412), 1,
      anon_sym_LPAREN2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2125), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
  [78509] = 5,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(2170), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6293), 2,
      sym__newline_or_pipe,
      sym_comment,
  [78527] = 4,
    ACTIONS(6414), 1,
      anon_sym_DOT,
    STATE(2172), 1,
      aux_sym_filetypes_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6416), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [78543] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6418), 5,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_minlines,
      anon_sym_maxlines,
  [78555] = 5,
    ACTIONS(3259), 1,
      anon_sym_LBRACE2,
    ACTIONS(3263), 1,
      aux_sym_identifier_token2,
    ACTIONS(6420), 1,
      anon_sym_LPAREN2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(920), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
  [78573] = 4,
    ACTIONS(6254), 1,
      anon_sym_BANG,
    STATE(2463), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6422), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [78589] = 6,
    ACTIONS(5794), 1,
      anon_sym_LBRACE,
    ACTIONS(5796), 1,
      aux_sym_identifier_token1,
    STATE(1949), 1,
      sym__curly_braces_name_expression,
    STATE(2981), 1,
      sym_default_parameter,
    STATE(3189), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [78609] = 4,
    ACTIONS(6424), 1,
      sym_set_value,
    ACTIONS(6426), 1,
      anon_sym_SPACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6428), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [78625] = 3,
    ACTIONS(3390), 1,
      aux_sym__map_rhs_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3388), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_LT,
      anon_sym_BSLASH2,
  [78639] = 3,
    ACTIONS(740), 1,
      sym_string_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(742), 4,
      aux_sym_command_argument_token1,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [78653] = 4,
    ACTIONS(6430), 1,
      sym__catch,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6433), 2,
      sym__finally,
      sym__endtry,
    STATE(2131), 2,
      sym_catch_statement,
      aux_sym_try_statement_repeat1,
  [78669] = 4,
    ACTIONS(6435), 1,
      sym__elseif,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6438), 2,
      sym__else,
      sym__endif,
    STATE(2132), 2,
      sym_elseif_statement,
      aux_sym_if_statement_repeat1,
  [78685] = 4,
    ACTIONS(6443), 1,
      sym__let_heredoc_marker,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6440), 2,
      anon_sym_trim,
      anon_sym_eval,
    STATE(2133), 2,
      sym__let_heredoc_parameter,
      aux_sym__let_heredoc_repeat1,
  [78701] = 3,
    ACTIONS(6445), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6177), 4,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__autocmd_pattern_token1,
  [78715] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1320), 5,
      anon_sym_EQ,
      anon_sym_LBRACE2,
      aux_sym_identifier_token2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [78727] = 5,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(2170), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6297), 2,
      sym__newline_or_pipe,
      sym_comment,
  [78745] = 5,
    ACTIONS(904), 1,
      anon_sym_in,
    ACTIONS(6447), 1,
      anon_sym_LBRACE2,
    ACTIONS(6449), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2208), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
  [78763] = 3,
    ACTIONS(6208), 1,
      aux_sym__map_rhs_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6451), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_LT,
      anon_sym_BSLASH2,
  [78777] = 3,
    ACTIONS(5897), 1,
      aux_sym__map_rhs_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5998), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_LT,
      anon_sym_BSLASH2,
  [78791] = 4,
    ACTIONS(6455), 1,
      sym__let_heredoc_marker,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6453), 2,
      anon_sym_trim,
      anon_sym_eval,
    STATE(2203), 2,
      sym__let_heredoc_parameter,
      aux_sym__let_heredoc_repeat1,
  [78807] = 4,
    ACTIONS(6457), 1,
      anon_sym_COMMA,
    STATE(2152), 1,
      aux_sym_au_event_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6459), 3,
      sym__newline_or_pipe,
      sym_comment,
      aux_sym__autocmd_pattern_token1,
  [78823] = 4,
    ACTIONS(6254), 1,
      anon_sym_BANG,
    STATE(2651), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6461), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [78839] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6206), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(6463), 3,
      anon_sym_default,
      anon_sym_toplevel,
      anon_sym_notoplevel,
  [78853] = 4,
    ACTIONS(6465), 1,
      anon_sym_COMMA,
    STATE(2157), 1,
      aux_sym__autocmd_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(705), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [78869] = 3,
    ACTIONS(6467), 1,
      anon_sym_QMARK2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5948), 4,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [78883] = 5,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(2170), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6217), 2,
      sym__newline_or_pipe,
      sym_comment,
  [78901] = 4,
    ACTIONS(6469), 1,
      anon_sym_SPACE,
    STATE(2153), 1,
      aux_sym_set_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6471), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [78917] = 4,
    ACTIONS(6473), 1,
      anon_sym_BSLASH_AMP,
    STATE(2155), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [78933] = 4,
    ACTIONS(6469), 1,
      anon_sym_SPACE,
    STATE(2212), 1,
      aux_sym_set_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6475), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [78949] = 3,
    ACTIONS(6479), 1,
      aux_sym_filename_token3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6477), 4,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [78963] = 3,
    ACTIONS(6467), 1,
      anon_sym_SLASH2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5948), 4,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [78977] = 4,
    ACTIONS(6457), 1,
      anon_sym_COMMA,
    STATE(2169), 1,
      aux_sym_au_event_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6481), 3,
      sym__newline_or_pipe,
      sym_comment,
      aux_sym__autocmd_pattern_token1,
  [78993] = 4,
    ACTIONS(6469), 1,
      anon_sym_SPACE,
    STATE(2187), 1,
      aux_sym_set_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6483), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79009] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6256), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [79021] = 4,
    ACTIONS(6485), 1,
      anon_sym_BSLASH_AMP,
    STATE(2155), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79037] = 3,
    ACTIONS(6490), 1,
      sym_string_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6488), 4,
      aux_sym_command_argument_token1,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79051] = 4,
    ACTIONS(6465), 1,
      anon_sym_COMMA,
    STATE(2204), 1,
      aux_sym__autocmd_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(711), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79067] = 4,
    ACTIONS(6494), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(32), 1,
      sym__autocmd_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6492), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79083] = 3,
    ACTIONS(742), 1,
      aux_sym_filename_token3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(740), 4,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [79097] = 4,
    ACTIONS(6254), 1,
      anon_sym_BANG,
    STATE(2640), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6496), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79113] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6500), 2,
      anon_sym_match,
      anon_sym_ignore,
    ACTIONS(6498), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79127] = 5,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(2170), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6400), 2,
      sym__newline_or_pipe,
      sym_comment,
  [79145] = 4,
    ACTIONS(6494), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(31), 1,
      sym__autocmd_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5661), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79161] = 5,
    ACTIONS(6248), 1,
      anon_sym_BANG,
    STATE(1928), 1,
      sym_bang,
    STATE(1933), 1,
      sym__bang_filter_bangs,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6250), 2,
      sym__newline_or_pipe,
      sym_comment,
  [79179] = 4,
    ACTIONS(6494), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(52), 1,
      sym__autocmd_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6502), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79195] = 5,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(2170), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6320), 2,
      sym__newline_or_pipe,
      sym_comment,
  [79213] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(740), 5,
      anon_sym_LBRACE,
      aux_sym_identifier_token1,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79225] = 5,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(2170), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6295), 2,
      sym__newline_or_pipe,
      sym_comment,
  [79243] = 4,
    ACTIONS(6504), 1,
      anon_sym_COMMA,
    STATE(2169), 1,
      aux_sym_au_event_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6445), 3,
      sym__newline_or_pipe,
      sym_comment,
      aux_sym__autocmd_pattern_token1,
  [79259] = 5,
    ACTIONS(6507), 1,
      anon_sym_end,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(2170), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6231), 2,
      sym__newline_or_pipe,
      sym_comment,
  [79277] = 5,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(2170), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6236), 2,
      sym__newline_or_pipe,
      sym_comment,
  [79295] = 4,
    ACTIONS(6414), 1,
      anon_sym_DOT,
    STATE(2188), 1,
      aux_sym_filetypes_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6510), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79311] = 3,
    ACTIONS(3401), 1,
      aux_sym__map_rhs_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3399), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_LT,
      anon_sym_BSLASH2,
  [79325] = 4,
    ACTIONS(6254), 1,
      anon_sym_BANG,
    STATE(2413), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6512), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79341] = 4,
    ACTIONS(6514), 1,
      anon_sym_BSLASH_AMP,
    STATE(2175), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH_PIPE,
  [79357] = 3,
    ACTIONS(5495), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5499), 4,
      sym__newline_or_pipe,
      sym_string_literal,
      sym_comment,
      anon_sym_BSLASH,
  [79371] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1336), 5,
      anon_sym_EQ,
      anon_sym_LBRACE2,
      aux_sym_identifier_token2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [79383] = 6,
    ACTIONS(6517), 1,
      sym__normal,
    ACTIONS(6519), 1,
      sym__source,
    ACTIONS(6521), 1,
      sym__global,
    ACTIONS(6523), 1,
      sym__call,
    ACTIONS(6525), 1,
      sym__substitute,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [79403] = 5,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(2170), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6328), 2,
      sym__newline_or_pipe,
      sym_comment,
  [79421] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6258), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [79433] = 5,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(2170), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6289), 2,
      sym__newline_or_pipe,
      sym_comment,
  [79451] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6238), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_contains,
      anon_sym_add,
      anon_sym_remove,
  [79463] = 3,
    ACTIONS(6529), 1,
      sym_au_event,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6527), 4,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      aux_sym__autocmd_pattern_token1,
  [79477] = 5,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(2170), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6330), 2,
      sym__newline_or_pipe,
      sym_comment,
  [79495] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6172), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [79507] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6531), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(6267), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
  [79521] = 4,
    ACTIONS(6533), 1,
      anon_sym_SPACE,
    STATE(2187), 1,
      aux_sym_set_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6536), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79537] = 4,
    ACTIONS(6538), 1,
      anon_sym_DOT,
    STATE(2188), 1,
      aux_sym_filetypes_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6541), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79553] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6545), 2,
      anon_sym_start,
      anon_sym_minimum,
    ACTIONS(6543), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79567] = 4,
    ACTIONS(6547), 1,
      anon_sym_BSLASH_AMP,
    STATE(2175), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BSLASH_PIPE,
  [79583] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6551), 2,
      anon_sym_clear,
      aux_sym__syn_iskeyword_token1,
    ACTIONS(6549), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79597] = 5,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(2170), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6346), 2,
      sym__newline_or_pipe,
      sym_comment,
  [79615] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6240), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_contains,
      anon_sym_add,
      anon_sym_remove,
  [79627] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6291), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [79639] = 5,
    ACTIONS(2634), 1,
      anon_sym_end,
    STATE(786), 1,
      sym__syn_region_end,
    STATE(2170), 1,
      aux_sym__syn_region_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6229), 2,
      sym__newline_or_pipe,
      sym_comment,
  [79657] = 3,
    ACTIONS(742), 1,
      aux_sym__bang_filter_command_argument_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(740), 4,
      sym__newline_or_pipe,
      sym_string_literal,
      sym_comment,
      anon_sym_BSLASH,
  [79671] = 4,
    ACTIONS(6494), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(30), 1,
      sym__autocmd_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5924), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79687] = 3,
    ACTIONS(6555), 1,
      aux_sym_filename_token3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6553), 4,
      anon_sym_BSLASH,
      aux_sym_filename_token1,
      aux_sym_filename_token2,
      aux_sym_filename_token4,
  [79701] = 3,
    ACTIONS(6559), 1,
      sym_string_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6557), 4,
      aux_sym_command_argument_token1,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79715] = 4,
    ACTIONS(6561), 1,
      sym__let_heredoc_marker,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6453), 2,
      anon_sym_trim,
      anon_sym_eval,
    STATE(2133), 2,
      sym__let_heredoc_parameter,
      aux_sym__let_heredoc_repeat1,
  [79731] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6563), 2,
      anon_sym_on,
      anon_sym_off,
    ACTIONS(6565), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79745] = 4,
    ACTIONS(6567), 1,
      anon_sym_COMMA,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2644), 3,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [79761] = 4,
    ACTIONS(6570), 1,
      sym__let_heredoc_marker,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6453), 2,
      anon_sym_trim,
      anon_sym_eval,
    STATE(2133), 2,
      sym__let_heredoc_parameter,
      aux_sym__let_heredoc_repeat1,
  [79777] = 4,
    ACTIONS(6572), 1,
      anon_sym_COMMA,
    STATE(2204), 1,
      aux_sym__autocmd_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(715), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79793] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6170), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [79805] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6575), 5,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
      anon_sym_minlines,
      anon_sym_maxlines,
  [79817] = 5,
    ACTIONS(1064), 1,
      anon_sym_in,
    ACTIONS(6447), 1,
      anon_sym_LBRACE2,
    ACTIONS(6577), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2137), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
  [79835] = 5,
    ACTIONS(912), 1,
      anon_sym_in,
    ACTIONS(6579), 1,
      anon_sym_LBRACE2,
    ACTIONS(6582), 1,
      aux_sym_identifier_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(2208), 2,
      sym__immediate_curly_braces_name_expression,
      aux_sym_identifier_repeat1,
  [79853] = 6,
    ACTIONS(6585), 1,
      sym__normal,
    ACTIONS(6587), 1,
      sym__source,
    ACTIONS(6589), 1,
      sym__global,
    ACTIONS(6591), 1,
      sym__call,
    ACTIONS(6593), 1,
      sym__substitute,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [79873] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6305), 5,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_buffer,
      anon_sym_group,
      anon_sym_file,
  [79885] = 4,
    ACTIONS(6595), 1,
      sym__let_heredoc_marker,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6453), 2,
      anon_sym_trim,
      anon_sym_eval,
    STATE(2200), 2,
      sym__let_heredoc_parameter,
      aux_sym__let_heredoc_repeat1,
  [79901] = 4,
    ACTIONS(6469), 1,
      anon_sym_SPACE,
    STATE(2187), 1,
      aux_sym_set_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6597), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79917] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6599), 2,
      anon_sym_clear,
      aux_sym__syn_iskeyword_token1,
    ACTIONS(6601), 2,
      sym__newline_or_pipe,
      sym_comment,
  [79930] = 5,
    ACTIONS(6603), 1,
      anon_sym_LBRACE,
    ACTIONS(6605), 1,
      aux_sym_identifier_token1,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    STATE(690), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [79947] = 3,
    ACTIONS(6609), 1,
      aux_sym_command_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6607), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79960] = 5,
    ACTIONS(6611), 1,
      anon_sym_LBRACE,
    ACTIONS(6613), 1,
      aux_sym_identifier_token1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    STATE(496), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [79977] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4375), 4,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [79988] = 5,
    ACTIONS(6615), 1,
      aux_sym_option_name_token1,
    ACTIONS(6617), 1,
      anon_sym_t_,
    ACTIONS(6619), 1,
      sym_scope,
    STATE(688), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80005] = 4,
    ACTIONS(6623), 1,
      anon_sym_indent,
    STATE(2732), 1,
      sym__filetype_state,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6621), 2,
      anon_sym_on,
      anon_sym_off,
  [80020] = 5,
    ACTIONS(6625), 1,
      anon_sym_RBRACE,
    ACTIONS(6627), 1,
      anon_sym_COMMA,
    ACTIONS(6629), 1,
      sym_literal_key,
    STATE(2632), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80037] = 4,
    ACTIONS(6631), 1,
      anon_sym_SPACE,
    STATE(2221), 1,
      aux_sym_set_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6634), 2,
      sym__newline_or_pipe,
      sym_comment,
  [80052] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6638), 1,
      anon_sym_RBRACK,
    ACTIONS(6640), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2225), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80069] = 3,
    STATE(1700), 1,
      sym__immediate_file_format,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(778), 3,
      anon_sym_dos,
      anon_sym_unix,
      anon_sym_mac,
  [80082] = 4,
    ACTIONS(780), 1,
      aux_sym__map_lhs_token1,
    STATE(1700), 1,
      sym__plus_plus_opt_bad,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(778), 2,
      anon_sym_keep,
      anon_sym_drop,
  [80097] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6642), 1,
      anon_sym_RBRACK,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80114] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(740), 4,
      sym__newline_or_pipe,
      sym_string_literal,
      sym_comment,
      aux_sym_command_argument_token1,
  [80125] = 3,
    ACTIONS(6646), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5704), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [80138] = 4,
    ACTIONS(6650), 1,
      anon_sym_plugin,
    STATE(2746), 1,
      sym__filetype_state,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6648), 2,
      anon_sym_on,
      anon_sym_off,
  [80153] = 3,
    STATE(1679), 1,
      sym__immediate_file_format,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(794), 3,
      anon_sym_dos,
      anon_sym_unix,
      anon_sym_mac,
  [80166] = 4,
    ACTIONS(796), 1,
      aux_sym__map_lhs_token1,
    STATE(1679), 1,
      sym__plus_plus_opt_bad,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(794), 2,
      anon_sym_keep,
      anon_sym_drop,
  [80181] = 5,
    ACTIONS(6652), 1,
      anon_sym_LBRACE,
    ACTIONS(6654), 1,
      aux_sym_identifier_token1,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(607), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80198] = 5,
    ACTIONS(6656), 1,
      anon_sym_LBRACE,
    ACTIONS(6658), 1,
      aux_sym_identifier_token1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    STATE(340), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80215] = 3,
    ACTIONS(6660), 1,
      anon_sym_SPACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6662), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [80228] = 5,
    ACTIONS(6664), 1,
      anon_sym_LBRACE,
    ACTIONS(6666), 1,
      aux_sym_identifier_token1,
    STATE(510), 1,
      sym__curly_braces_name_expression,
    STATE(524), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80245] = 5,
    ACTIONS(6668), 1,
      aux_sym_option_name_token1,
    ACTIONS(6670), 1,
      anon_sym_t_,
    ACTIONS(6672), 1,
      sym_scope,
    STATE(339), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80262] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6674), 1,
      anon_sym_RBRACK,
    ACTIONS(6676), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2239), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80279] = 5,
    ACTIONS(5104), 1,
      anon_sym_LBRACE,
    ACTIONS(6678), 1,
      aux_sym_identifier_token1,
    STATE(546), 1,
      sym_identifier,
    STATE(2207), 1,
      sym__curly_braces_name_expression,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80296] = 3,
    ACTIONS(6634), 1,
      anon_sym_SPACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6536), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [80309] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(6680), 1,
      anon_sym_RBRACK,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80326] = 4,
    ACTIONS(6684), 1,
      aux_sym__map_rhs_statement_token3,
    STATE(2298), 1,
      aux_sym__map_rhs_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6682), 2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
  [80341] = 5,
    ACTIONS(6686), 1,
      aux_sym_option_name_token1,
    ACTIONS(6688), 1,
      anon_sym_t_,
    ACTIONS(6690), 1,
      sym_scope,
    STATE(759), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80358] = 3,
    ACTIONS(6692), 1,
      anon_sym_SPACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6694), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [80371] = 4,
    ACTIONS(3508), 1,
      anon_sym_LT,
    ACTIONS(6696), 1,
      aux_sym__hl_term_list_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1033), 2,
      sym__immediate_keycode,
      aux_sym__hl_term_list,
  [80386] = 3,
    ACTIONS(6698), 1,
      sym_set_value,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6426), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_SPACE,
  [80399] = 5,
    ACTIONS(6603), 1,
      anon_sym_LBRACE,
    ACTIONS(6605), 1,
      aux_sym_identifier_token1,
    STATE(555), 1,
      sym__curly_braces_name_expression,
    STATE(721), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80416] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6700), 1,
      anon_sym_RBRACK,
    ACTIONS(6702), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2249), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80433] = 5,
    ACTIONS(6629), 1,
      sym_literal_key,
    ACTIONS(6704), 1,
      anon_sym_RBRACE,
    ACTIONS(6706), 1,
      anon_sym_COMMA,
    STATE(2523), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80450] = 4,
    ACTIONS(6708), 1,
      aux_sym__map_rhs_statement_token3,
    STATE(2252), 1,
      aux_sym__map_rhs_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6682), 2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
  [80465] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(6710), 1,
      anon_sym_RBRACK,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80482] = 5,
    ACTIONS(6656), 1,
      anon_sym_LBRACE,
    ACTIONS(6658), 1,
      aux_sym_identifier_token1,
    STATE(159), 1,
      sym__curly_braces_name_expression,
    STATE(351), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80499] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6712), 1,
      anon_sym_RBRACK,
    ACTIONS(6714), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2253), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80516] = 4,
    ACTIONS(6716), 1,
      aux_sym__map_rhs_statement_token3,
    STATE(2309), 1,
      aux_sym__map_rhs_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6682), 2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
  [80531] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(6718), 1,
      anon_sym_RBRACK,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80548] = 4,
    ACTIONS(6720), 1,
      anon_sym_SPACE,
    STATE(2221), 1,
      aux_sym_set_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6722), 2,
      sym__newline_or_pipe,
      sym_comment,
  [80563] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6724), 1,
      anon_sym_RBRACK,
    ACTIONS(6726), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2257), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80580] = 5,
    ACTIONS(6629), 1,
      sym_literal_key,
    ACTIONS(6728), 1,
      anon_sym_RBRACE,
    ACTIONS(6730), 1,
      anon_sym_COMMA,
    STATE(2559), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80597] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(6732), 1,
      anon_sym_RBRACK,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80614] = 4,
    ACTIONS(6734), 1,
      anon_sym_DOT,
    STATE(2258), 1,
      aux_sym_filetypes_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6541), 2,
      sym__newline_or_pipe,
      sym_comment,
  [80629] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6737), 1,
      anon_sym_RBRACK,
    ACTIONS(6739), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2261), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80646] = 4,
    ACTIONS(6741), 1,
      anon_sym_DOT,
    STATE(2258), 1,
      aux_sym_filetypes_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6510), 2,
      sym__newline_or_pipe,
      sym_comment,
  [80661] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(6743), 1,
      anon_sym_RBRACK,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80678] = 4,
    ACTIONS(6745), 1,
      anon_sym_COMMA,
    STATE(2269), 1,
      aux_sym__autocmd_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(705), 2,
      sym__newline_or_pipe,
      sym_comment,
  [80693] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6747), 1,
      anon_sym_RBRACK,
    ACTIONS(6749), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2264), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80710] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(6751), 1,
      anon_sym_RBRACK,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80727] = 5,
    ACTIONS(5525), 1,
      anon_sym_LBRACE,
    ACTIONS(5527), 1,
      aux_sym_identifier_token1,
    STATE(948), 1,
      sym__curly_braces_name_expression,
    STATE(2652), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80744] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6753), 1,
      anon_sym_RBRACK,
    ACTIONS(6755), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2268), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80761] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6541), 4,
      anon_sym_DOT,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [80772] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(6757), 1,
      anon_sym_RBRACK,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80789] = 4,
    ACTIONS(6745), 1,
      anon_sym_COMMA,
    STATE(2330), 1,
      aux_sym__autocmd_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(711), 2,
      sym__newline_or_pipe,
      sym_comment,
  [80804] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6759), 1,
      anon_sym_RBRACK,
    ACTIONS(6761), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2272), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80821] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6763), 4,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [80832] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(6765), 1,
      anon_sym_RBRACK,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80849] = 3,
    STATE(1925), 1,
      sym__immediate_file_format,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(782), 3,
      anon_sym_dos,
      anon_sym_unix,
      anon_sym_mac,
  [80862] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6767), 1,
      anon_sym_RBRACK,
    ACTIONS(6769), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2276), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80879] = 5,
    ACTIONS(6771), 1,
      anon_sym_BSLASH,
    ACTIONS(6774), 1,
      anon_sym_RBRACK,
    ACTIONS(6776), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80896] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(6779), 1,
      anon_sym_RBRACK,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80913] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6781), 1,
      anon_sym_RBRACK,
    ACTIONS(6783), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2278), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80930] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(6785), 1,
      anon_sym_RBRACK,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80947] = 3,
    STATE(2291), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5615), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [80960] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6787), 1,
      anon_sym_RBRACK,
    ACTIONS(6789), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2282), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [80977] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4270), 4,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [80988] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(6791), 1,
      anon_sym_RBRACK,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81005] = 4,
    ACTIONS(784), 1,
      aux_sym__map_lhs_token1,
    STATE(1925), 1,
      sym__plus_plus_opt_bad,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(782), 2,
      anon_sym_keep,
      anon_sym_drop,
  [81020] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6490), 4,
      sym__newline_or_pipe,
      sym_string_literal,
      sym_comment,
      aux_sym_command_argument_token1,
  [81031] = 4,
    ACTIONS(6793), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(55), 1,
      sym__autocmd_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5985), 2,
      sym__newline_or_pipe,
      sym_comment,
  [81046] = 5,
    ACTIONS(5800), 1,
      anon_sym_RPAREN,
    ACTIONS(6795), 1,
      anon_sym_EQ,
    ACTIONS(6797), 1,
      anon_sym_COMMA,
    STATE(2609), 1,
      aux_sym_parameters_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81063] = 3,
    ACTIONS(6527), 1,
      aux_sym__autocmd_pattern_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6529), 3,
      sym__newline_or_pipe,
      sym_comment,
      sym_au_event,
  [81076] = 4,
    ACTIONS(6799), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2303), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5790), 2,
      sym__newline_or_pipe,
      sym_comment,
  [81091] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6498), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(6801), 2,
      anon_sym_match,
      anon_sym_ignore,
  [81104] = 4,
    ACTIONS(6803), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2290), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5054), 2,
      sym__newline_or_pipe,
      sym_comment,
  [81119] = 4,
    ACTIONS(6806), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2291), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5054), 2,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [81134] = 3,
    STATE(2279), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5790), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [81147] = 4,
    ACTIONS(6809), 1,
      anon_sym_BSLASH_AMP,
    STATE(2293), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 2,
      sym__separator,
      anon_sym_BSLASH_PIPE,
  [81162] = 4,
    ACTIONS(6812), 1,
      anon_sym_BANG,
    STATE(2873), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6422), 2,
      sym__newline_or_pipe,
      sym_comment,
  [81177] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6814), 1,
      anon_sym_RBRACK,
    ACTIONS(6816), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2352), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81194] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6418), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_minlines,
      anon_sym_maxlines,
  [81205] = 4,
    ACTIONS(6820), 1,
      anon_sym_plugin,
    STATE(2782), 1,
      sym__filetype_state,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6818), 2,
      anon_sym_on,
      anon_sym_off,
  [81220] = 4,
    ACTIONS(6822), 1,
      aux_sym__map_rhs_statement_token3,
    STATE(2309), 1,
      aux_sym__map_rhs_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6682), 2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
  [81235] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4517), 4,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [81246] = 3,
    ACTIONS(6824), 1,
      anon_sym_QMARK2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5948), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
  [81259] = 3,
    ACTIONS(6824), 1,
      anon_sym_SLASH2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5948), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
  [81272] = 4,
    ACTIONS(6812), 1,
      anon_sym_BANG,
    STATE(2843), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6512), 2,
      sym__newline_or_pipe,
      sym_comment,
  [81287] = 4,
    ACTIONS(6799), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2290), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5615), 2,
      sym__newline_or_pipe,
      sym_comment,
  [81302] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6826), 1,
      anon_sym_RBRACK,
    ACTIONS(6828), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2364), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81319] = 4,
    ACTIONS(6720), 1,
      anon_sym_SPACE,
    STATE(2221), 1,
      aux_sym_set_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6830), 2,
      sym__newline_or_pipe,
      sym_comment,
  [81334] = 4,
    ACTIONS(6832), 1,
      anon_sym_BSLASH_AMP,
    STATE(2354), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 2,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
  [81349] = 4,
    ACTIONS(6834), 1,
      anon_sym_BSLASH_AMP,
    STATE(2336), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 2,
      anon_sym_SLASH2,
      anon_sym_BSLASH_PIPE,
  [81364] = 4,
    ACTIONS(6836), 1,
      anon_sym_BSLASH_AMP,
    STATE(2308), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 2,
      anon_sym_BSLASH_PIPE,
      anon_sym_BSLASH_RPAREN,
  [81379] = 4,
    ACTIONS(6842), 1,
      aux_sym__map_rhs_statement_token3,
    STATE(2309), 1,
      aux_sym__map_rhs_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6839), 2,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
  [81394] = 4,
    ACTIONS(6844), 1,
      anon_sym_BSLASH_AMP,
    STATE(2293), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 2,
      sym__separator,
      anon_sym_BSLASH_PIPE,
  [81409] = 4,
    ACTIONS(3710), 1,
      anon_sym_LT,
    ACTIONS(6846), 1,
      aux_sym__hl_term_list_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    STATE(1083), 2,
      sym__immediate_keycode,
      aux_sym__hl_term_list,
  [81424] = 5,
    ACTIONS(6611), 1,
      anon_sym_LBRACE,
    ACTIONS(6613), 1,
      aux_sym_identifier_token1,
    STATE(191), 1,
      sym__curly_braces_name_expression,
    STATE(501), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81441] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6445), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_COMMA,
      aux_sym__autocmd_pattern_token1,
  [81452] = 5,
    ACTIONS(6848), 1,
      anon_sym_LBRACE,
    ACTIONS(6850), 1,
      aux_sym_identifier_token1,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    STATE(754), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81469] = 4,
    ACTIONS(6852), 1,
      anon_sym_BSLASH_AMP,
    STATE(2308), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5555), 2,
      anon_sym_BSLASH_PIPE,
      anon_sym_BSLASH_RPAREN,
  [81484] = 5,
    ACTIONS(6854), 1,
      aux_sym_option_name_token1,
    ACTIONS(6856), 1,
      anon_sym_t_,
    ACTIONS(6858), 1,
      sym_scope,
    STATE(499), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81501] = 5,
    ACTIONS(6629), 1,
      sym_literal_key,
    ACTIONS(6860), 1,
      anon_sym_RBRACE,
    ACTIONS(6862), 1,
      anon_sym_COMMA,
    STATE(2579), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81518] = 4,
    ACTIONS(6866), 1,
      anon_sym_indent,
    STATE(2778), 1,
      sym__filetype_state,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6864), 2,
      anon_sym_on,
      anon_sym_off,
  [81533] = 3,
    ACTIONS(6870), 1,
      aux_sym_command_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6868), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [81546] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6565), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(6872), 2,
      anon_sym_on,
      anon_sym_off,
  [81559] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6874), 1,
      anon_sym_RBRACK,
    ACTIONS(6876), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2325), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81576] = 3,
    ACTIONS(6880), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6878), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [81589] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6882), 4,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [81600] = 3,
    ACTIONS(6886), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6884), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [81613] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(6888), 1,
      anon_sym_RBRACK,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81630] = 4,
    ACTIONS(6890), 1,
      anon_sym_COMMA,
    STATE(2326), 1,
      aux_sym_parameters_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6893), 2,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
  [81645] = 3,
    STATE(1751), 1,
      sym__immediate_file_format,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(786), 3,
      anon_sym_dos,
      anon_sym_unix,
      anon_sym_mac,
  [81658] = 4,
    ACTIONS(788), 1,
      aux_sym__map_lhs_token1,
    STATE(1751), 1,
      sym__plus_plus_opt_bad,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(786), 2,
      anon_sym_keep,
      anon_sym_drop,
  [81673] = 5,
    ACTIONS(5525), 1,
      anon_sym_LBRACE,
    ACTIONS(5527), 1,
      aux_sym_identifier_token1,
    STATE(948), 1,
      sym__curly_braces_name_expression,
    STATE(2578), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81690] = 4,
    ACTIONS(6895), 1,
      anon_sym_COMMA,
    STATE(2330), 1,
      aux_sym__autocmd_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(715), 2,
      sym__newline_or_pipe,
      sym_comment,
  [81705] = 3,
    ACTIONS(6900), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6898), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [81718] = 4,
    ACTIONS(6812), 1,
      anon_sym_BANG,
    STATE(2804), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6496), 2,
      sym__newline_or_pipe,
      sym_comment,
  [81733] = 5,
    ACTIONS(6902), 1,
      anon_sym_COMMA,
    ACTIONS(6904), 1,
      anon_sym_SEMI,
    ACTIONS(6906), 1,
      anon_sym_RBRACK,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81750] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6559), 4,
      sym__newline_or_pipe,
      sym_string_literal,
      sym_comment,
      aux_sym_command_argument_token1,
  [81761] = 5,
    ACTIONS(6664), 1,
      anon_sym_LBRACE,
    ACTIONS(6666), 1,
      aux_sym_identifier_token1,
    STATE(510), 1,
      sym__curly_braces_name_expression,
    STATE(533), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81778] = 4,
    ACTIONS(6908), 1,
      anon_sym_BSLASH_AMP,
    STATE(2336), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 2,
      anon_sym_SLASH2,
      anon_sym_BSLASH_PIPE,
  [81793] = 5,
    ACTIONS(5525), 1,
      anon_sym_LBRACE,
    ACTIONS(5527), 1,
      aux_sym_identifier_token1,
    STATE(948), 1,
      sym__curly_braces_name_expression,
    STATE(1341), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81810] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1336), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_LBRACE2,
      aux_sym_identifier_token2,
  [81821] = 5,
    ACTIONS(6911), 1,
      aux_sym_option_name_token1,
    ACTIONS(6913), 1,
      anon_sym_t_,
    ACTIONS(6915), 1,
      sym_scope,
    STATE(530), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81838] = 5,
    ACTIONS(6629), 1,
      sym_literal_key,
    ACTIONS(6917), 1,
      anon_sym_RBRACE,
    ACTIONS(6919), 1,
      anon_sym_COMMA,
    STATE(2606), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81855] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4371), 4,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [81866] = 5,
    ACTIONS(6652), 1,
      anon_sym_LBRACE,
    ACTIONS(6654), 1,
      aux_sym_identifier_token1,
    STATE(521), 1,
      sym__curly_braces_name_expression,
    STATE(546), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81883] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6921), 1,
      anon_sym_RBRACK,
    ACTIONS(6923), 1,
      aux_sym__pattern_ordinary_atom_token1,
    STATE(2349), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81900] = 4,
    ACTIONS(6793), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(54), 1,
      sym__autocmd_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(641), 2,
      sym__newline_or_pipe,
      sym_comment,
  [81915] = 4,
    ACTIONS(6720), 1,
      anon_sym_SPACE,
    STATE(2305), 1,
      aux_sym_set_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6925), 2,
      sym__newline_or_pipe,
      sym_comment,
  [81930] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4373), 4,
      anon_sym_BANG,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [81941] = 3,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6543), 2,
      sym__newline_or_pipe,
      sym_comment,
    ACTIONS(6927), 2,
      anon_sym_start,
      anon_sym_minimum,
  [81954] = 5,
    ACTIONS(6929), 1,
      aux_sym_option_name_token1,
    ACTIONS(6931), 1,
      anon_sym_t_,
    ACTIONS(6933), 1,
      sym_scope,
    STATE(597), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81971] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(6935), 1,
      anon_sym_RBRACK,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [81988] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6575), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_minlines,
      anon_sym_maxlines,
  [81999] = 4,
    ACTIONS(6812), 1,
      anon_sym_BANG,
    STATE(2805), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6461), 2,
      sym__newline_or_pipe,
      sym_comment,
  [82014] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(6937), 1,
      anon_sym_RBRACK,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82031] = 5,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(3217), 1,
      anon_sym_RBRACK,
    ACTIONS(6904), 1,
      anon_sym_SEMI,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82048] = 4,
    ACTIONS(6939), 1,
      anon_sym_BSLASH_AMP,
    STATE(2354), 1,
      aux_sym__pattern_branch_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3617), 2,
      anon_sym_QMARK2,
      anon_sym_BSLASH_PIPE,
  [82063] = 4,
    ACTIONS(6720), 1,
      anon_sym_SPACE,
    STATE(2254), 1,
      aux_sym_set_statement_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6942), 2,
      sym__newline_or_pipe,
      sym_comment,
  [82078] = 4,
    ACTIONS(6741), 1,
      anon_sym_DOT,
    STATE(2260), 1,
      aux_sym_filetypes_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6416), 2,
      sym__newline_or_pipe,
      sym_comment,
  [82093] = 3,
    STATE(1562), 1,
      sym__immediate_file_format,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(790), 3,
      anon_sym_dos,
      anon_sym_unix,
      anon_sym_mac,
  [82106] = 3,
    ACTIONS(6944), 1,
      aux_sym_shebang_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6946), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82119] = 4,
    ACTIONS(792), 1,
      aux_sym__map_lhs_token1,
    STATE(1562), 1,
      sym__plus_plus_opt_bad,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(790), 2,
      anon_sym_keep,
      anon_sym_drop,
  [82134] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(715), 4,
      anon_sym_COMMA,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82145] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1320), 4,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_LBRACE2,
      aux_sym_identifier_token2,
  [82156] = 5,
    ACTIONS(6848), 1,
      anon_sym_LBRACE,
    ACTIONS(6850), 1,
      aux_sym_identifier_token1,
    STATE(580), 1,
      sym__curly_braces_name_expression,
    STATE(764), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82173] = 4,
    ACTIONS(6793), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(53), 1,
      sym__autocmd_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(501), 2,
      sym__newline_or_pipe,
      sym_comment,
  [82188] = 5,
    ACTIONS(6636), 1,
      anon_sym_BSLASH,
    ACTIONS(6644), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(6948), 1,
      anon_sym_RBRACK,
    STATE(2275), 1,
      aux_sym__pattern_ordinary_atom_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82205] = 5,
    ACTIONS(5885), 1,
      anon_sym_LBRACE,
    ACTIONS(5887), 1,
      aux_sym_identifier_token1,
    STATE(2117), 1,
      sym__curly_braces_name_expression,
    STATE(2975), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82222] = 4,
    ACTIONS(6793), 1,
      aux_sym__autocmd_pattern_token1,
    STATE(56), 1,
      sym__autocmd_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6158), 2,
      sym__newline_or_pipe,
      sym_comment,
  [82237] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82247] = 4,
    ACTIONS(6952), 1,
      sym_chunk,
    ACTIONS(6954), 1,
      anon_sym_LT_LT,
    STATE(2881), 1,
      sym_script,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82261] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6956), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82271] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6958), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82281] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6960), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82291] = 3,
    STATE(112), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6962), 2,
      sym__newline_or_pipe,
      sym_comment,
  [82303] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6964), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82313] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6660), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_SPACE,
  [82323] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6634), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_SPACE,
  [82333] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6541), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_DOT,
  [82343] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3983), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82353] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6966), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82363] = 4,
    ACTIONS(5790), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(6968), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2573), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82377] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82387] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4822), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82397] = 4,
    ACTIONS(6970), 1,
      anon_sym_COMMA,
    ACTIONS(6973), 1,
      anon_sym_RPAREN,
    STATE(2382), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82411] = 4,
    ACTIONS(5615), 1,
      anon_sym_QMARK2,
    ACTIONS(6975), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2389), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82425] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4188), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82435] = 3,
    STATE(1591), 1,
      sym__command_attribute_nargs_value,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6977), 2,
      aux_sym__command_attribute_nargs_value_token1,
      aux_sym__command_attribute_nargs_value_token2,
  [82447] = 4,
    ACTIONS(6977), 1,
      anon_sym_PERCENT2,
    ACTIONS(6979), 1,
      aux_sym_argument_token2,
    STATE(1591), 1,
      sym__command_attribute_range_value,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82461] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82471] = 3,
    ACTIONS(6981), 1,
      aux_sym_command_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6983), 2,
      sym__newline_or_pipe,
      sym_comment,
  [82483] = 4,
    ACTIONS(5054), 1,
      anon_sym_QMARK2,
    ACTIONS(6985), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2389), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82497] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82507] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6988), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82517] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82527] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82537] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82547] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82557] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82567] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82577] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6990), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82587] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6992), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82597] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82607] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82617] = 4,
    ACTIONS(5615), 1,
      anon_sym_SLASH2,
    ACTIONS(6994), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2408), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82631] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6996), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82641] = 4,
    ACTIONS(6998), 1,
      anon_sym_COMMA,
    ACTIONS(7000), 1,
      anon_sym_RPAREN,
    STATE(2382), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82655] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7002), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82665] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7004), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82675] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7006), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82685] = 4,
    ACTIONS(5054), 1,
      anon_sym_SLASH2,
    ACTIONS(7008), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2408), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82699] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7011), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82709] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7013), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82719] = 3,
    ACTIONS(2462), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2464), 2,
      anon_sym_in,
      anon_sym_EQ_LT_LT,
  [82731] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7015), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82741] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7017), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82751] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7019), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82761] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7021), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82771] = 4,
    ACTIONS(6998), 1,
      anon_sym_COMMA,
    ACTIONS(7000), 1,
      anon_sym_RPAREN,
    STATE(2694), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82785] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7023), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82795] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7025), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82805] = 3,
    ACTIONS(1336), 1,
      anon_sym_LBRACE2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1338), 2,
      anon_sym_in,
      aux_sym_identifier_token2,
  [82817] = 4,
    ACTIONS(7027), 1,
      sym_filetype,
    ACTIONS(7029), 1,
      anon_sym_FALLBACK,
    STATE(2839), 1,
      sym_filetypes,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82831] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7031), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82841] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7033), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82851] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7035), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82861] = 3,
    STATE(2909), 1,
      sym__filetype_state,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7037), 2,
      anon_sym_on,
      anon_sym_off,
  [82873] = 3,
    STATE(2910), 1,
      sym__filetype_state,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7039), 2,
      anon_sym_on,
      anon_sym_off,
  [82885] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7041), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82895] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7043), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82905] = 4,
    ACTIONS(3771), 1,
      anon_sym_BSLASH2,
    ACTIONS(3773), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1548), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82919] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7045), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82929] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7047), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82939] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7051), 1,
      sym__heredoc_end,
    STATE(2618), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [82953] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7053), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82963] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7055), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82973] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7055), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82983] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7055), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [82993] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7057), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83003] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(641), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83013] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7059), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83023] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7057), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83033] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7061), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83043] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7057), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83053] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7063), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83063] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7065), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83073] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7067), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83083] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7067), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83093] = 3,
    STATE(111), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7069), 2,
      sym__newline_or_pipe,
      sym_comment,
  [83105] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7067), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83115] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7071), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83125] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7067), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83135] = 4,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(7073), 1,
      anon_sym_RPAREN,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83149] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4863), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83159] = 4,
    ACTIONS(7075), 1,
      anon_sym_RBRACE,
    ACTIONS(7077), 1,
      anon_sym_COMMA,
    STATE(2511), 1,
      aux_sym_dictionnary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83173] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7079), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83183] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7081), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83193] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7083), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83203] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7085), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83213] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5944), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83223] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7087), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83233] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7089), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83243] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7091), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83253] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3931), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83263] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7093), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83273] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7095), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83283] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7097), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83293] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6882), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
  [83303] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7099), 1,
      sym__heredoc_end,
    STATE(2647), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83317] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7101), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83327] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4111), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83337] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7103), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83347] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7105), 1,
      sym__heredoc_end,
    STATE(2696), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83361] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4115), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83371] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7107), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83381] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7109), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83391] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7111), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83401] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7113), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83411] = 4,
    ACTIONS(5615), 1,
      sym__separator,
    ACTIONS(7115), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2499), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83425] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7117), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83435] = 4,
    ACTIONS(6954), 1,
      anon_sym_LT_LT,
    ACTIONS(7119), 1,
      sym_chunk,
    STATE(2869), 1,
      sym_script,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83449] = 4,
    ACTIONS(5790), 1,
      sym__separator,
    ACTIONS(7115), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2476), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83463] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7121), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83473] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7123), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83483] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4636), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83493] = 4,
    ACTIONS(7125), 1,
      aux_sym_normal_statement_token1,
    ACTIONS(7127), 1,
      anon_sym_BANG,
    STATE(3232), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83507] = 4,
    ACTIONS(7129), 1,
      anon_sym_BANG,
    ACTIONS(7131), 1,
      sym__separator_first,
    STATE(3295), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83521] = 4,
    ACTIONS(2378), 1,
      anon_sym_EQ_LT_LT,
    ACTIONS(7133), 1,
      anon_sym_EQ,
    STATE(2772), 1,
      sym__let_heredoc,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83535] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7135), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83545] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7137), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83555] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4824), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83565] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7139), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83575] = 4,
    ACTIONS(7127), 1,
      anon_sym_BANG,
    ACTIONS(7141), 1,
      aux_sym_normal_statement_token1,
    STATE(3013), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83589] = 4,
    ACTIONS(7143), 1,
      sym_chunk,
    ACTIONS(7145), 1,
      anon_sym_LT_LT,
    STATE(2666), 1,
      sym_script,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83603] = 4,
    ACTIONS(7145), 1,
      anon_sym_LT_LT,
    ACTIONS(7147), 1,
      sym_chunk,
    STATE(2667), 1,
      sym_script,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83617] = 4,
    ACTIONS(7145), 1,
      anon_sym_LT_LT,
    ACTIONS(7149), 1,
      sym_chunk,
    STATE(2678), 1,
      sym_script,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83631] = 4,
    ACTIONS(7145), 1,
      anon_sym_LT_LT,
    ACTIONS(7151), 1,
      sym_chunk,
    STATE(2689), 1,
      sym_script,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83645] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7153), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83655] = 4,
    ACTIONS(7155), 1,
      sym_filetype,
    ACTIONS(7157), 1,
      anon_sym_FALLBACK,
    STATE(2407), 1,
      sym_filetypes,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83669] = 4,
    ACTIONS(6929), 1,
      aux_sym_option_name_token1,
    ACTIONS(6931), 1,
      anon_sym_t_,
    STATE(575), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83683] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7159), 1,
      sym__heredoc_end,
    STATE(2466), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83697] = 4,
    ACTIONS(5054), 1,
      sym__separator,
    ACTIONS(7161), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2499), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83711] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4371), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
  [83721] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4373), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
  [83731] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4375), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
  [83741] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4270), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
  [83751] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7164), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83761] = 4,
    ACTIONS(2615), 1,
      anon_sym_COMMA,
    ACTIONS(7166), 1,
      anon_sym_DASH_GT,
    STATE(2326), 1,
      aux_sym_parameters_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83775] = 4,
    ACTIONS(2368), 1,
      anon_sym_EQ_LT_LT,
    ACTIONS(7168), 1,
      anon_sym_EQ,
    STATE(2566), 1,
      sym__let_heredoc,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83789] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7170), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83799] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7172), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83809] = 4,
    ACTIONS(4791), 1,
      aux_sym_option_name_token1,
    ACTIONS(4793), 1,
      anon_sym_t_,
    STATE(1705), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83823] = 4,
    ACTIONS(4791), 1,
      aux_sym_option_name_token1,
    ACTIONS(4793), 1,
      anon_sym_t_,
    STATE(1720), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83837] = 4,
    ACTIONS(1330), 1,
      anon_sym_RBRACE,
    ACTIONS(7174), 1,
      anon_sym_COMMA,
    STATE(2586), 1,
      aux_sym_dictionnary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83851] = 3,
    ACTIONS(7176), 1,
      anon_sym_trim,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7178), 2,
      sym__script_heredoc_marker,
      anon_sym_LF,
  [83863] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7164), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83873] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7170), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83883] = 4,
    ACTIONS(1456), 1,
      anon_sym_RBRACK,
    ACTIONS(6902), 1,
      anon_sym_COMMA,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83897] = 4,
    ACTIONS(6954), 1,
      anon_sym_LT_LT,
    ACTIONS(7180), 1,
      sym_chunk,
    STATE(2884), 1,
      sym_script,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83911] = 4,
    ACTIONS(6629), 1,
      sym_literal_key,
    ACTIONS(7182), 1,
      anon_sym_RBRACE,
    STATE(2814), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83925] = 4,
    ACTIONS(7127), 1,
      anon_sym_BANG,
    ACTIONS(7184), 1,
      aux_sym_normal_statement_token1,
    STATE(3281), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83939] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7186), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [83949] = 4,
    ACTIONS(7188), 1,
      anon_sym_RBRACE,
    ACTIONS(7190), 1,
      anon_sym_COMMA,
    STATE(2592), 1,
      aux_sym_literal_dictionary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83963] = 4,
    ACTIONS(7192), 1,
      anon_sym_RBRACE,
    ACTIONS(7194), 1,
      anon_sym_COMMA,
    STATE(2535), 1,
      aux_sym_dictionnary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83977] = 4,
    ACTIONS(6686), 1,
      aux_sym_option_name_token1,
    ACTIONS(6688), 1,
      anon_sym_t_,
    STATE(800), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [83991] = 4,
    ACTIONS(7196), 1,
      anon_sym_RBRACE,
    ACTIONS(7198), 1,
      anon_sym_COMMA,
    STATE(2538), 1,
      aux_sym_literal_dictionary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84005] = 4,
    ACTIONS(6954), 1,
      anon_sym_LT_LT,
    ACTIONS(7200), 1,
      sym_chunk,
    STATE(2882), 1,
      sym_script,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84019] = 4,
    ACTIONS(5800), 1,
      anon_sym_RPAREN,
    ACTIONS(7202), 1,
      anon_sym_COMMA,
    STATE(2613), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84033] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7204), 1,
      sym__heredoc_end,
    STATE(2541), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84047] = 3,
    ACTIONS(1320), 1,
      anon_sym_LBRACE2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(1322), 2,
      anon_sym_in,
      aux_sym_identifier_token2,
  [84059] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7206), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84069] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7208), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84079] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7210), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84089] = 3,
    STATE(103), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7212), 2,
      sym__newline_or_pipe,
      sym_comment,
  [84101] = 4,
    ACTIONS(4342), 1,
      anon_sym_BSLASH2,
    ACTIONS(4344), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1706), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84115] = 4,
    ACTIONS(7127), 1,
      anon_sym_BANG,
    ACTIONS(7214), 1,
      aux_sym_normal_statement_token1,
    STATE(3200), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84129] = 3,
    STATE(2), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7216), 2,
      sym__newline_or_pipe,
      sym_comment,
  [84141] = 4,
    ACTIONS(1324), 1,
      anon_sym_RBRACE,
    ACTIONS(7218), 1,
      anon_sym_COMMA,
    STATE(2586), 1,
      aux_sym_dictionnary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84155] = 4,
    ACTIONS(1414), 1,
      anon_sym_RBRACK,
    ACTIONS(7220), 1,
      anon_sym_COMMA,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84169] = 4,
    ACTIONS(6629), 1,
      sym_literal_key,
    ACTIONS(7222), 1,
      anon_sym_RBRACE,
    STATE(2814), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84183] = 4,
    ACTIONS(7224), 1,
      anon_sym_RBRACE,
    ACTIONS(7226), 1,
      anon_sym_COMMA,
    STATE(2592), 1,
      aux_sym_literal_dictionary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84197] = 4,
    ACTIONS(7129), 1,
      anon_sym_BANG,
    ACTIONS(7228), 1,
      sym__separator_first,
    STATE(2996), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84211] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7230), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84221] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7232), 1,
      sym__heredoc_end,
    STATE(2647), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84235] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7234), 1,
      sym__heredoc_end,
    STATE(2557), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84249] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7236), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84259] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7238), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84269] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7240), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84279] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7242), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84289] = 3,
    ACTIONS(7244), 1,
      aux_sym__pattern_ordinary_atom_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6774), 2,
      anon_sym_BSLASH,
      anon_sym_RBRACK,
  [84301] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7246), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84311] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7248), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84321] = 3,
    ACTIONS(2458), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(2460), 2,
      anon_sym_in,
      anon_sym_EQ_LT_LT,
  [84333] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7250), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84343] = 4,
    ACTIONS(6629), 1,
      sym_literal_key,
    ACTIONS(7252), 1,
      anon_sym_RBRACE,
    STATE(2814), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84357] = 4,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(7254), 1,
      anon_sym_RPAREN,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84371] = 3,
    STATE(108), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7256), 2,
      sym__newline_or_pipe,
      sym_comment,
  [84383] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7258), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84393] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7260), 1,
      sym__heredoc_end,
    STATE(2565), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84407] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7262), 1,
      sym__heredoc_end,
    STATE(2647), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84421] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7264), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84431] = 4,
    ACTIONS(7266), 1,
      anon_sym_RBRACE,
    ACTIONS(7268), 1,
      anon_sym_COMMA,
    STATE(2520), 1,
      aux_sym_literal_dictionary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84445] = 3,
    STATE(107), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7270), 2,
      sym__newline_or_pipe,
      sym_comment,
  [84457] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7272), 1,
      sym__heredoc_end,
    STATE(2647), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84471] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7274), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84481] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7276), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84491] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7278), 1,
      sym__heredoc_end,
    STATE(2570), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84505] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7280), 1,
      sym__heredoc_end,
    STATE(2647), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84519] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7282), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84529] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7274), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84539] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7284), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84549] = 4,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(7286), 1,
      anon_sym_RPAREN,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84563] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7288), 1,
      sym__heredoc_end,
    STATE(2647), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84577] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7290), 1,
      sym__heredoc_end,
    STATE(2572), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84591] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7292), 1,
      sym__heredoc_end,
    STATE(2647), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84605] = 4,
    ACTIONS(5615), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(6968), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2608), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84619] = 4,
    ACTIONS(5790), 1,
      anon_sym_QMARK2,
    ACTIONS(6975), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2383), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84633] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7294), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84643] = 4,
    ACTIONS(7296), 1,
      anon_sym_RBRACE,
    ACTIONS(7298), 1,
      anon_sym_COMMA,
    STATE(2582), 1,
      aux_sym_dictionnary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84657] = 4,
    ACTIONS(6854), 1,
      aux_sym_option_name_token1,
    ACTIONS(6856), 1,
      anon_sym_t_,
    STATE(507), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84671] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6893), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
  [84681] = 4,
    ACTIONS(7300), 1,
      anon_sym_RBRACE,
    ACTIONS(7302), 1,
      anon_sym_COMMA,
    STATE(2585), 1,
      aux_sym_literal_dictionary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84695] = 3,
    ACTIONS(7304), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6898), 2,
      sym__newline_or_pipe,
      sym_comment,
  [84707] = 4,
    ACTIONS(3979), 1,
      anon_sym_BSLASH2,
    ACTIONS(3981), 1,
      aux_sym__plus_cmd_arg_token1,
    STATE(1593), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84721] = 4,
    ACTIONS(1348), 1,
      anon_sym_RBRACE,
    ACTIONS(7306), 1,
      anon_sym_COMMA,
    STATE(2586), 1,
      aux_sym_dictionnary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84735] = 4,
    ACTIONS(1422), 1,
      anon_sym_RBRACK,
    ACTIONS(7308), 1,
      anon_sym_COMMA,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84749] = 4,
    ACTIONS(6629), 1,
      sym_literal_key,
    ACTIONS(7310), 1,
      anon_sym_RBRACE,
    STATE(2814), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84763] = 4,
    ACTIONS(7312), 1,
      anon_sym_RBRACE,
    ACTIONS(7314), 1,
      anon_sym_COMMA,
    STATE(2592), 1,
      aux_sym_literal_dictionary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84777] = 4,
    ACTIONS(7316), 1,
      anon_sym_RBRACE,
    ACTIONS(7318), 1,
      anon_sym_COMMA,
    STATE(2586), 1,
      aux_sym_dictionnary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84791] = 4,
    ACTIONS(4808), 1,
      aux_sym_option_name_token1,
    ACTIONS(4810), 1,
      anon_sym_t_,
    STATE(1833), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84805] = 4,
    ACTIONS(4808), 1,
      aux_sym_option_name_token1,
    ACTIONS(4810), 1,
      anon_sym_t_,
    STATE(1836), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84819] = 4,
    ACTIONS(6629), 1,
      sym_literal_key,
    ACTIONS(7321), 1,
      anon_sym_RBRACE,
    STATE(2814), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84833] = 4,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(7323), 1,
      anon_sym_RPAREN,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84847] = 4,
    ACTIONS(6629), 1,
      sym_literal_key,
    ACTIONS(7325), 1,
      anon_sym_RBRACE,
    STATE(2814), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84861] = 4,
    ACTIONS(7327), 1,
      anon_sym_RBRACE,
    ACTIONS(7329), 1,
      anon_sym_COMMA,
    STATE(2592), 1,
      aux_sym_literal_dictionary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84875] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6763), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
  [84885] = 4,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(7332), 1,
      anon_sym_RPAREN,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84899] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7334), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84909] = 4,
    ACTIONS(5790), 1,
      anon_sym_SLASH2,
    ACTIONS(6994), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2402), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84923] = 4,
    ACTIONS(7127), 1,
      anon_sym_BANG,
    ACTIONS(7336), 1,
      aux_sym_normal_statement_token1,
    STATE(3015), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84937] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6842), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84947] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5985), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84957] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7338), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84967] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7340), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [84977] = 4,
    ACTIONS(7342), 1,
      anon_sym_RBRACE,
    ACTIONS(7344), 1,
      anon_sym_COMMA,
    STATE(2614), 1,
      aux_sym_dictionnary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [84991] = 4,
    ACTIONS(6911), 1,
      aux_sym_option_name_token1,
    ACTIONS(6913), 1,
      anon_sym_t_,
    STATE(541), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85005] = 4,
    ACTIONS(5827), 1,
      anon_sym_RPAREN,
    ACTIONS(7346), 1,
      anon_sym_COMMA,
    STATE(2733), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85019] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7348), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85029] = 4,
    ACTIONS(7350), 1,
      anon_sym_RBRACE,
    ACTIONS(7352), 1,
      anon_sym_COMMA,
    STATE(2617), 1,
      aux_sym_literal_dictionary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85043] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7354), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85053] = 4,
    ACTIONS(5054), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(7356), 1,
      anon_sym_BSLASH_PIPE,
    STATE(2608), 1,
      aux_sym_pattern_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85067] = 4,
    ACTIONS(5827), 1,
      anon_sym_RPAREN,
    ACTIONS(7359), 1,
      anon_sym_COMMA,
    STATE(2326), 1,
      aux_sym_parameters_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85081] = 4,
    ACTIONS(3639), 1,
      aux_sym__plus_cmd_arg_token1,
    ACTIONS(7361), 1,
      anon_sym_BSLASH2,
    STATE(1390), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85095] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7363), 3,
      sym__let_heredoc_marker,
      anon_sym_trim,
      anon_sym_eval,
  [85105] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(501), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85115] = 4,
    ACTIONS(5827), 1,
      anon_sym_RPAREN,
    ACTIONS(7346), 1,
      anon_sym_COMMA,
    STATE(2382), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85129] = 4,
    ACTIONS(1360), 1,
      anon_sym_RBRACE,
    ACTIONS(7365), 1,
      anon_sym_COMMA,
    STATE(2586), 1,
      aux_sym_dictionnary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85143] = 4,
    ACTIONS(1468), 1,
      anon_sym_RBRACK,
    ACTIONS(7367), 1,
      anon_sym_COMMA,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85157] = 4,
    ACTIONS(6629), 1,
      sym_literal_key,
    ACTIONS(7369), 1,
      anon_sym_RBRACE,
    STATE(2814), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85171] = 4,
    ACTIONS(7371), 1,
      anon_sym_RBRACE,
    ACTIONS(7373), 1,
      anon_sym_COMMA,
    STATE(2592), 1,
      aux_sym_literal_dictionary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85185] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7375), 1,
      sym__heredoc_end,
    STATE(2647), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85199] = 4,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(7377), 1,
      anon_sym_RPAREN,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85213] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7379), 1,
      sym__heredoc_end,
    STATE(2654), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85227] = 4,
    ACTIONS(6629), 1,
      sym_literal_key,
    ACTIONS(7381), 1,
      anon_sym_RBRACE,
    STATE(2814), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85241] = 4,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(7383), 1,
      anon_sym_RPAREN,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85255] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7385), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85265] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7387), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85275] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(715), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_COMMA,
  [85285] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7389), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85295] = 4,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(7391), 1,
      anon_sym_RPAREN,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85309] = 4,
    ACTIONS(7129), 1,
      anon_sym_BANG,
    ACTIONS(7393), 1,
      sym__separator_first,
    STATE(3045), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85323] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7395), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85333] = 4,
    ACTIONS(7397), 1,
      anon_sym_RBRACE,
    ACTIONS(7399), 1,
      anon_sym_COMMA,
    STATE(2636), 1,
      aux_sym_dictionnary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85347] = 4,
    ACTIONS(6615), 1,
      aux_sym_option_name_token1,
    ACTIONS(6617), 1,
      anon_sym_t_,
    STATE(694), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85361] = 4,
    ACTIONS(7401), 1,
      anon_sym_RBRACE,
    ACTIONS(7403), 1,
      anon_sym_COMMA,
    STATE(2639), 1,
      aux_sym_literal_dictionary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85375] = 3,
    ACTIONS(7405), 1,
      aux_sym_command_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7407), 2,
      sym__newline_or_pipe,
      sym_comment,
  [85387] = 3,
    ACTIONS(7409), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6878), 2,
      sym__newline_or_pipe,
      sym_comment,
  [85399] = 4,
    ACTIONS(3793), 1,
      aux_sym__plus_cmd_arg_token1,
    ACTIONS(7411), 1,
      anon_sym_BSLASH2,
    STATE(1495), 1,
      aux_sym__plus_cmd_arg,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85413] = 4,
    ACTIONS(1372), 1,
      anon_sym_RBRACE,
    ACTIONS(7413), 1,
      anon_sym_COMMA,
    STATE(2586), 1,
      aux_sym_dictionnary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85427] = 4,
    ACTIONS(1500), 1,
      anon_sym_RBRACK,
    ACTIONS(7415), 1,
      anon_sym_COMMA,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85441] = 4,
    ACTIONS(6629), 1,
      sym_literal_key,
    ACTIONS(7417), 1,
      anon_sym_RBRACE,
    STATE(2814), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85455] = 4,
    ACTIONS(7419), 1,
      anon_sym_RBRACE,
    ACTIONS(7421), 1,
      anon_sym_COMMA,
    STATE(2592), 1,
      aux_sym_literal_dictionary_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85469] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7423), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85479] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(830), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85489] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7425), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85499] = 4,
    ACTIONS(6629), 1,
      sym_literal_key,
    ACTIONS(7427), 1,
      anon_sym_RBRACE,
    STATE(2814), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85513] = 4,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(7429), 1,
      anon_sym_RPAREN,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85527] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7431), 1,
      sym__heredoc_end,
    STATE(2561), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85541] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7433), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85551] = 4,
    ACTIONS(7435), 1,
      sym__heredoc_line,
    ACTIONS(7438), 1,
      sym__heredoc_end,
    STATE(2647), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85565] = 4,
    ACTIONS(2622), 1,
      anon_sym_COMMA,
    ACTIONS(7440), 1,
      anon_sym_RPAREN,
    STATE(2202), 1,
      aux_sym_list_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85579] = 3,
    ACTIONS(7442), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6884), 2,
      sym__newline_or_pipe,
      sym_comment,
  [85591] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7444), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85601] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7446), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85611] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7448), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85621] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7450), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85631] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7452), 1,
      sym__heredoc_end,
    STATE(2647), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85645] = 4,
    ACTIONS(6668), 1,
      aux_sym_option_name_token1,
    ACTIONS(6670), 1,
      anon_sym_t_,
    STATE(342), 1,
      sym_option_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [85659] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7454), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85669] = 3,
    STATE(110), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7456), 2,
      sym__newline_or_pipe,
      sym_comment,
  [85681] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7458), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85691] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7460), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85701] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7462), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85711] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7464), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85721] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4826), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85731] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7466), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85741] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7468), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85751] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7470), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85761] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7472), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85771] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7474), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85781] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7476), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85791] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7478), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85801] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7480), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85811] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7482), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85821] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7484), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85831] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7486), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85841] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7488), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85851] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7490), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85861] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7492), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85871] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7494), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85881] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7496), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85891] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7498), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85901] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7500), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85911] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7502), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85921] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7504), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85931] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7506), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85941] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7508), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85951] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7510), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85961] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7512), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85971] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7514), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [85981] = 3,
    STATE(8), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7516), 2,
      sym__newline_or_pipe,
      sym_comment,
  [85993] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7518), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86003] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7520), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86013] = 3,
    ACTIONS(7522), 1,
      anon_sym_trim,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7524), 2,
      sym__script_heredoc_marker,
      anon_sym_LF,
  [86025] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5704), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86035] = 3,
    STATE(115), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7526), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86047] = 4,
    ACTIONS(7528), 1,
      anon_sym_COMMA,
    ACTIONS(7530), 1,
      anon_sym_RPAREN,
    STATE(2382), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [86061] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7532), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86071] = 4,
    ACTIONS(7049), 1,
      sym__heredoc_line,
    ACTIONS(7534), 1,
      sym__heredoc_end,
    STATE(2647), 1,
      aux_sym_script_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [86085] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6158), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86095] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7536), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86105] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7538), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86115] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7540), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86125] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7542), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86135] = 3,
    ACTIONS(7544), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5704), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86147] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7546), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86157] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7548), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86167] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7550), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86177] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7552), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86187] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7554), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86197] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7556), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86207] = 4,
    ACTIONS(2615), 1,
      anon_sym_COMMA,
    ACTIONS(7558), 1,
      anon_sym_DASH_GT,
    STATE(2326), 1,
      aux_sym_parameters_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [86221] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7560), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86231] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7562), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86241] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7564), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86251] = 3,
    ACTIONS(7566), 1,
      aux_sym_shebang_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7568), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86263] = 4,
    ACTIONS(7127), 1,
      anon_sym_BANG,
    ACTIONS(7570), 1,
      aux_sym_normal_statement_token1,
    STATE(3017), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [86277] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7572), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86287] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7574), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86297] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7576), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86307] = 3,
    STATE(117), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7578), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86319] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7580), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86329] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7582), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86339] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7584), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86349] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7586), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86359] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7586), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86369] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7588), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86379] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4517), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_BANG,
  [86389] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7590), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86399] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7592), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86409] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7594), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86419] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7596), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86429] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6692), 3,
      sym__newline_or_pipe,
      sym_comment,
      anon_sym_SPACE,
  [86439] = 3,
    STATE(2475), 1,
      sym__filetype_state,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7598), 2,
      anon_sym_on,
      anon_sym_off,
  [86451] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7600), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86461] = 4,
    ACTIONS(5916), 1,
      anon_sym_RPAREN,
    ACTIONS(7602), 1,
      anon_sym_COMMA,
    STATE(2382), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [86475] = 4,
    ACTIONS(7129), 1,
      anon_sym_BANG,
    ACTIONS(7604), 1,
      sym__separator_first,
    STATE(3331), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [86489] = 4,
    ACTIONS(7129), 1,
      anon_sym_BANG,
    ACTIONS(7606), 1,
      sym__separator_first,
    STATE(3336), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [86503] = 3,
    ACTIONS(6795), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6893), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [86515] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7608), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86525] = 4,
    ACTIONS(7129), 1,
      anon_sym_BANG,
    ACTIONS(7610), 1,
      sym__separator_first,
    STATE(3340), 1,
      sym_bang,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [86539] = 4,
    ACTIONS(2615), 1,
      anon_sym_COMMA,
    ACTIONS(7612), 1,
      anon_sym_DASH_GT,
    STATE(2326), 1,
      aux_sym_parameters_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [86553] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7614), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86563] = 4,
    ACTIONS(5916), 1,
      anon_sym_RPAREN,
    ACTIONS(7602), 1,
      anon_sym_COMMA,
    STATE(2404), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [86577] = 4,
    ACTIONS(2615), 1,
      anon_sym_COMMA,
    ACTIONS(7616), 1,
      anon_sym_DASH_GT,
    STATE(2326), 1,
      aux_sym_parameters_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [86591] = 3,
    STATE(2477), 1,
      sym__filetype_state,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7618), 2,
      anon_sym_on,
      anon_sym_off,
  [86603] = 4,
    ACTIONS(2615), 1,
      anon_sym_COMMA,
    ACTIONS(7620), 1,
      anon_sym_DASH_GT,
    STATE(2326), 1,
      aux_sym_parameters_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [86617] = 4,
    ACTIONS(2615), 1,
      anon_sym_COMMA,
    ACTIONS(7622), 1,
      anon_sym_DASH_GT,
    STATE(2326), 1,
      aux_sym_parameters_repeat2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [86631] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7624), 3,
      anon_sym_BSLASH_PIPE,
      aux_sym__map_rhs_statement_token2,
      aux_sym__map_rhs_statement_token3,
  [86641] = 3,
    STATE(12), 1,
      sym__cmd_separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7626), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86653] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7019), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86662] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7097), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86671] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7065), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86680] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6996), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86689] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7550), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86698] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7628), 2,
      anon_sym_STAR,
      sym_hl_group,
  [86707] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7580), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86716] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7630), 2,
      anon_sym_STAR,
      sym_hl_group,
  [86725] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7002), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86734] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7464), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86743] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7041), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86752] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7584), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86761] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7276), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86770] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7153), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86779] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4115), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86788] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7552), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86797] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7093), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86806] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7091), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86815] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7482), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86824] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7164), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86833] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7554), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86842] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7632), 2,
      anon_sym_STAR,
      sym_hl_group,
  [86851] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7490), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86860] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7170), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86869] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7282), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86878] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7121), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86887] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7164), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86896] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7480), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86905] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7484), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86914] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7634), 2,
      aux_sym__syn_pattern_offset_token1,
      aux_sym__syn_pattern_offset_token2,
  [86923] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7600), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86932] = 3,
    ACTIONS(7636), 1,
      sym__separator_first,
    STATE(547), 1,
      sym__syn_hl_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [86943] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7478), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86952] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7170), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86961] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7624), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86970] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7081), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86979] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86988] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 2,
      sym__newline_or_pipe,
      sym_comment,
  [86997] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7083), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87006] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7186), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87015] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7638), 2,
      anon_sym_STAR,
      sym_hl_group,
  [87024] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7103), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87033] = 3,
    ACTIONS(7640), 1,
      sym_hl_group,
    ACTIONS(7642), 1,
      anon_sym_link,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [87044] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7043), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87053] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7644), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87062] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7004), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87071] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87080] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7284), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87089] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87098] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87107] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7294), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87116] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7045), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87125] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87134] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7011), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87143] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6990), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87152] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6992), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87161] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7423), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87170] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7446), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87179] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7316), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [87188] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87197] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7646), 2,
      aux_sym__syn_pattern_offset_token1,
      aux_sym__syn_pattern_offset_token2,
  [87206] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87215] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7015), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87224] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7047), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87233] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87242] = 3,
    ACTIONS(7648), 1,
      sym_filetype,
    STATE(2708), 1,
      sym_filetypes,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [87253] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7650), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [87262] = 3,
    ACTIONS(7652), 1,
      anon_sym_LF,
    ACTIONS(7654), 1,
      sym_comment,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [87273] = 3,
    ACTIONS(7636), 1,
      sym__separator_first,
    STATE(637), 1,
      sym__syn_hl_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [87284] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7656), 2,
      aux_sym__syn_pattern_offset_token1,
      aux_sym__syn_pattern_offset_token2,
  [87293] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7560), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87302] = 3,
    ACTIONS(7658), 1,
      sym__separator_first,
    STATE(606), 1,
      sym__syn_hl_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [87313] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7492), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87322] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7063), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87331] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7085), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87340] = 3,
    ACTIONS(7660), 1,
      aux_sym__filetype_immediate_token1,
    STATE(2376), 1,
      sym__filetype_immediate,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [87351] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6964), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87360] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7582), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87369] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7532), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87378] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7662), 2,
      sym__script_heredoc_marker,
      anon_sym_LF,
  [87387] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7067), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87396] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7087), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87405] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7089), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87414] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3983), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87423] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7208), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87432] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7210), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87441] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4111), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87450] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5054), 2,
      sym__separator,
      anon_sym_BSLASH_PIPE,
  [87459] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7053), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87468] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7664), 2,
      sym__heredoc_end,
      sym__heredoc_line,
  [87477] = 3,
    ACTIONS(7666), 1,
      sym_filetype,
    STATE(2886), 1,
      sym_filetypes,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [87488] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7006), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87497] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7486), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87506] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7572), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87515] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7013), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87524] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7017), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87533] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7476), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87542] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7574), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87551] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7021), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87560] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7023), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87569] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7668), 2,
      aux_sym__syn_pattern_offset_token1,
      aux_sym__syn_pattern_offset_token2,
  [87578] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4826), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87587] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6966), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87596] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6956), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87605] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7466), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87614] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7586), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87623] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7274), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87632] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(641), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87641] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7059), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87650] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6958), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87659] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6960), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87668] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7061), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87677] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7670), 2,
      anon_sym_STAR,
      sym_hl_group,
  [87686] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7025), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87695] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7230), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87704] = 3,
    ACTIONS(5412), 1,
      aux_sym_argument_token2,
    ACTIONS(7672), 1,
      aux_sym_argument_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [87715] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7576), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87724] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7236), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87733] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7274), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87742] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7238), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87751] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7334), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87760] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7472), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87769] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7240), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87778] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7242), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87787] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4822), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87796] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7095), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87805] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4188), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87814] = 3,
    ACTIONS(7674), 1,
      anon_sym_LF,
    ACTIONS(7676), 1,
      sym_comment,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [87825] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7614), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87834] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7248), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87843] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5985), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87852] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7338), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87861] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7079), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87870] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7474), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87879] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7496), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87888] = 3,
    ACTIONS(7678), 1,
      anon_sym_STAR2,
    ACTIONS(7680), 1,
      sym_integer_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [87899] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7518), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87908] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7206), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87917] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7556), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87926] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7250), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87935] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7608), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87944] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7586), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87953] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7488), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87962] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7494), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87971] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7067), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87980] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7258), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87989] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7562), 2,
      sym__newline_or_pipe,
      sym_comment,
  [87998] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7264), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88007] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6988), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88016] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7109), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88025] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7588), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88034] = 3,
    ACTIONS(2472), 1,
      aux_sym_argument_token2,
    ACTIONS(7682), 1,
      aux_sym_argument_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88045] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(501), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88054] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7498), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88063] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7500), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88072] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7502), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88081] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7504), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88090] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7506), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88099] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7101), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88108] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7385), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88117] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7594), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88126] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7113), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88135] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7117), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88144] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7508), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88153] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7510), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88162] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7512), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88171] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7514), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88180] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7031), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88189] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88198] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7033), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88207] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7596), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88216] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7071), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88225] = 3,
    ACTIONS(7636), 1,
      sym__separator_first,
    STATE(618), 1,
      sym__syn_hl_pattern,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88236] = 3,
    ACTIONS(7684), 1,
      sym_hl_group,
    ACTIONS(7686), 1,
      anon_sym_link,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88247] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88256] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7067), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88265] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7035), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88274] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7688), 2,
      sym__script_heredoc_marker,
      anon_sym_LF,
  [88283] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7111), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88292] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7067), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88301] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7590), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88310] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7592), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88319] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7387), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88328] = 3,
    ACTIONS(7690), 1,
      anon_sym_LF,
    ACTIONS(7692), 1,
      sym_comment,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88339] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7340), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88348] = 3,
    ACTIONS(7694), 1,
      anon_sym_LF,
    ACTIONS(7696), 1,
      sym_comment,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88359] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7348), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88368] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7172), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88377] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(830), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88386] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7354), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88395] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7520), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88404] = 3,
    ACTIONS(7698), 1,
      aux_sym__filetype_immediate_token1,
    STATE(2267), 1,
      sym__filetype_immediate,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88415] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7389), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88424] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7395), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88433] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5704), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88442] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6158), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88451] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7536), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88460] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7538), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88469] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7433), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88478] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7700), 2,
      anon_sym_STAR,
      sym_hl_group,
  [88487] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7540), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88496] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7425), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88505] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6950), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88514] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7450), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88523] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7454), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88532] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(5944), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88541] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7458), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88550] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7460), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88559] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(3931), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88568] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7462), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88577] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7123), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88586] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7548), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88595] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4636), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88604] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7444), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88613] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7468), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88622] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7470), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88631] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7135), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88640] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7137), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88649] = 3,
    ACTIONS(7702), 1,
      anon_sym_STAR2,
    ACTIONS(7704), 1,
      sym_integer_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88660] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7542), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88669] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7055), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88678] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7055), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88687] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7055), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88696] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7057), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88705] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7057), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88714] = 3,
    ACTIONS(6629), 1,
      sym_literal_key,
    STATE(2814), 1,
      sym__literal_dictionary_entry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88725] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4824), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88734] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7448), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88743] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7139), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88752] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7057), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88761] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(4863), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88770] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7546), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88779] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7107), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88788] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(6973), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [88797] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7564), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88806] = 2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
    ACTIONS(7246), 2,
      sym__newline_or_pipe,
      sym_comment,
  [88815] = 2,
    ACTIONS(7706), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88823] = 2,
    ACTIONS(7708), 1,
      sym__endif,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88831] = 2,
    ACTIONS(7710), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88839] = 2,
    ACTIONS(7712), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88847] = 2,
    ACTIONS(7714), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88855] = 2,
    ACTIONS(7716), 1,
      aux_sym_option_name_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88863] = 2,
    ACTIONS(7718), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88871] = 2,
    ACTIONS(7296), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88879] = 2,
    ACTIONS(7720), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88887] = 2,
    ACTIONS(7722), 1,
      anon_sym_SLASH2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88895] = 2,
    ACTIONS(7724), 1,
      sym_command_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88903] = 2,
    ACTIONS(7397), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88911] = 2,
    ACTIONS(7726), 1,
      sym__separator_first,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88919] = 2,
    ACTIONS(7728), 1,
      sym__endtry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88927] = 2,
    ACTIONS(7730), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88935] = 2,
    ACTIONS(7732), 1,
      aux_sym_command_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88943] = 2,
    ACTIONS(2783), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88951] = 2,
    ACTIONS(2711), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88959] = 2,
    ACTIONS(7734), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88967] = 2,
    ACTIONS(7736), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88975] = 2,
    ACTIONS(740), 1,
      aux_sym_normal_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88983] = 2,
    ACTIONS(7738), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88991] = 2,
    ACTIONS(7740), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [88999] = 2,
    ACTIONS(7742), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89007] = 2,
    ACTIONS(7744), 1,
      aux_sym__map_lhs_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89015] = 2,
    ACTIONS(7746), 1,
      anon_sym_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89023] = 2,
    ACTIONS(7748), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89031] = 2,
    ACTIONS(7750), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89039] = 2,
    ACTIONS(6356), 1,
      sym__endif,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89047] = 2,
    ACTIONS(7752), 1,
      aux_sym_normal_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89055] = 2,
    ACTIONS(7754), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89063] = 2,
    ACTIONS(7756), 1,
      aux_sym_normal_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89071] = 2,
    ACTIONS(7758), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89079] = 2,
    ACTIONS(7760), 1,
      aux_sym_normal_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89087] = 2,
    ACTIONS(7762), 1,
      aux_sym_wincmd_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89095] = 2,
    ACTIONS(7764), 1,
      sym__endif,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89103] = 2,
    ACTIONS(7766), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89111] = 2,
    ACTIONS(7768), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89119] = 2,
    ACTIONS(7770), 1,
      aux_sym__autocmd_pattern_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89127] = 2,
    ACTIONS(7772), 1,
      anon_sym_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89135] = 2,
    ACTIONS(7774), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89143] = 2,
    ACTIONS(7776), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89151] = 2,
    ACTIONS(7778), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89159] = 2,
    ACTIONS(7780), 1,
      anon_sym_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89167] = 2,
    ACTIONS(7782), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89175] = 2,
    ACTIONS(7784), 1,
      sym__endtry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89183] = 2,
    ACTIONS(7786), 1,
      sym__printable,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89191] = 2,
    ACTIONS(7674), 1,
      anon_sym_LF,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89199] = 2,
    ACTIONS(7788), 1,
      aux_sym__map_lhs_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89207] = 2,
    ACTIONS(7790), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89215] = 2,
    ACTIONS(7792), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89223] = 2,
    ACTIONS(6244), 1,
      sym__endtry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89231] = 2,
    ACTIONS(7794), 1,
      aux_sym_option_name_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89239] = 2,
    ACTIONS(7796), 1,
      sym__printable,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89247] = 2,
    ACTIONS(7798), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89255] = 2,
    ACTIONS(7800), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89263] = 2,
    ACTIONS(7802), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89271] = 2,
    ACTIONS(7628), 1,
      sym_integer_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89279] = 2,
    ACTIONS(7804), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89287] = 2,
    ACTIONS(7806), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89295] = 2,
    ACTIONS(7808), 1,
      aux_sym__syn_sync_lines_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89303] = 2,
    ACTIONS(7810), 1,
      sym__separator_first,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89311] = 2,
    ACTIONS(7812), 1,
      anon_sym_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89319] = 2,
    ACTIONS(7814), 1,
      aux_sym_option_name_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89327] = 2,
    ACTIONS(7816), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89335] = 2,
    ACTIONS(7818), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89343] = 2,
    ACTIONS(6183), 1,
      sym_integer_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89351] = 2,
    ACTIONS(6183), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89359] = 2,
    ACTIONS(7820), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89367] = 2,
    ACTIONS(7822), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89375] = 2,
    ACTIONS(7632), 1,
      sym_integer_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89383] = 2,
    ACTIONS(7824), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89391] = 2,
    ACTIONS(7826), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89399] = 2,
    ACTIONS(7828), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89407] = 2,
    ACTIONS(7830), 1,
      anon_sym_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89415] = 2,
    ACTIONS(7832), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89423] = 2,
    ACTIONS(7834), 1,
      anon_sym_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89431] = 2,
    ACTIONS(7836), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89439] = 2,
    ACTIONS(7838), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89447] = 2,
    ACTIONS(7840), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89455] = 2,
    ACTIONS(7842), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89463] = 2,
    ACTIONS(7844), 1,
      sym__printable,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89471] = 2,
    ACTIONS(7846), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89479] = 2,
    ACTIONS(7848), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89487] = 2,
    ACTIONS(7850), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89495] = 2,
    ACTIONS(7852), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89503] = 2,
    ACTIONS(7854), 1,
      aux_sym_option_name_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89511] = 2,
    ACTIONS(7856), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89519] = 2,
    ACTIONS(7858), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89527] = 2,
    ACTIONS(7860), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89535] = 2,
    ACTIONS(7862), 1,
      aux_sym_wincmd_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89543] = 2,
    ACTIONS(7864), 1,
      anon_sym_LF,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89551] = 2,
    ACTIONS(7866), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89559] = 2,
    ACTIONS(7868), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89567] = 2,
    ACTIONS(7870), 1,
      sym_integer_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89575] = 2,
    ACTIONS(7872), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89583] = 2,
    ACTIONS(7874), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89591] = 2,
    ACTIONS(7876), 1,
      sym__printable,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89599] = 2,
    ACTIONS(7878), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89607] = 2,
    ACTIONS(7880), 1,
      aux_sym__map_lhs_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89615] = 2,
    ACTIONS(7882), 1,
      aux_sym_option_name_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89623] = 2,
    ACTIONS(7884), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89631] = 2,
    ACTIONS(7886), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89639] = 2,
    ACTIONS(7888), 1,
      anon_sym_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89647] = 2,
    ACTIONS(7870), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89655] = 2,
    ACTIONS(7890), 1,
      sym__endtry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89663] = 2,
    ACTIONS(7892), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89671] = 2,
    ACTIONS(6281), 1,
      sym_spread,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89679] = 2,
    ACTIONS(7894), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89687] = 2,
    ACTIONS(7896), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89695] = 2,
    ACTIONS(7898), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89703] = 2,
    ACTIONS(7900), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89711] = 2,
    ACTIONS(7902), 1,
      aux_sym_option_name_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89719] = 2,
    ACTIONS(7904), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89727] = 2,
    ACTIONS(7906), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89735] = 2,
    ACTIONS(7908), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89743] = 2,
    ACTIONS(7910), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89751] = 2,
    ACTIONS(7912), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89759] = 2,
    ACTIONS(7914), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89767] = 2,
    ACTIONS(7916), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89775] = 2,
    ACTIONS(7192), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89783] = 2,
    ACTIONS(7918), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89791] = 2,
    ACTIONS(7920), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89799] = 2,
    ACTIONS(7922), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89807] = 2,
    ACTIONS(7924), 1,
      sym__printable,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89815] = 2,
    ACTIONS(7926), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89823] = 2,
    ACTIONS(7928), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89831] = 2,
    ACTIONS(7930), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89839] = 2,
    ACTIONS(7932), 1,
      aux_sym__hl_quoted_name_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89847] = 2,
    ACTIONS(7934), 1,
      aux_sym__syn_sync_lines_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89855] = 2,
    ACTIONS(7936), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89863] = 2,
    ACTIONS(7938), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89871] = 2,
    ACTIONS(7940), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89879] = 2,
    ACTIONS(7942), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89887] = 2,
    ACTIONS(7944), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89895] = 2,
    ACTIONS(7946), 1,
      aux_sym_command_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89903] = 2,
    ACTIONS(7948), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89911] = 2,
    ACTIONS(7950), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89919] = 2,
    ACTIONS(2686), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89927] = 2,
    ACTIONS(7952), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89935] = 2,
    ACTIONS(7954), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89943] = 2,
    ACTIONS(7956), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89951] = 2,
    ACTIONS(7958), 1,
      aux_sym__map_lhs_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89959] = 2,
    ACTIONS(7960), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89967] = 2,
    ACTIONS(7962), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89975] = 2,
    ACTIONS(7964), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89983] = 2,
    ACTIONS(7966), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89991] = 2,
    ACTIONS(5800), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [89999] = 2,
    ACTIONS(5829), 1,
      sym_spread,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90007] = 2,
    ACTIONS(7968), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90015] = 2,
    ACTIONS(7970), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90023] = 2,
    ACTIONS(7972), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90031] = 2,
    ACTIONS(7974), 1,
      anon_sym_LPAREN2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90039] = 2,
    ACTIONS(7976), 1,
      sym__printable,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90047] = 2,
    ACTIONS(7978), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90055] = 2,
    ACTIONS(7980), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90063] = 2,
    ACTIONS(7982), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90071] = 2,
    ACTIONS(7984), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90079] = 2,
    ACTIONS(7986), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90087] = 2,
    ACTIONS(7988), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90095] = 2,
    ACTIONS(6981), 1,
      aux_sym_command_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90103] = 2,
    ACTIONS(7990), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90111] = 2,
    ACTIONS(7992), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90119] = 2,
    ACTIONS(7994), 1,
      anon_sym_LPAREN2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90127] = 2,
    ACTIONS(7996), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90135] = 2,
    ACTIONS(6287), 1,
      sym__endtry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90143] = 2,
    ACTIONS(7998), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90151] = 2,
    ACTIONS(8000), 1,
      sym_integer_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90159] = 2,
    ACTIONS(8002), 1,
      sym__endif,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90167] = 2,
    ACTIONS(8004), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90175] = 2,
    ACTIONS(5827), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90183] = 2,
    ACTIONS(8006), 1,
      sym_au_event,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90191] = 2,
    ACTIONS(8008), 1,
      aux_sym__autocmd_pattern_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90199] = 2,
    ACTIONS(8010), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90207] = 2,
    ACTIONS(8012), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90215] = 2,
    ACTIONS(8014), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90223] = 2,
    ACTIONS(8016), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90231] = 2,
    ACTIONS(8018), 1,
      aux_sym__map_lhs_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90239] = 2,
    ACTIONS(8020), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90247] = 2,
    ACTIONS(8022), 1,
      aux_sym_option_name_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90255] = 2,
    ACTIONS(8024), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90263] = 2,
    ACTIONS(8026), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90271] = 2,
    ACTIONS(8028), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90279] = 2,
    ACTIONS(7530), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90287] = 2,
    ACTIONS(8030), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90295] = 2,
    ACTIONS(8032), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90303] = 2,
    ACTIONS(8034), 1,
      anon_sym_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90311] = 2,
    ACTIONS(8036), 1,
      anon_sym_SQUOTE2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90319] = 2,
    ACTIONS(8038), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90327] = 2,
    ACTIONS(8040), 1,
      anon_sym_LPAREN2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90335] = 2,
    ACTIONS(8042), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90343] = 2,
    ACTIONS(740), 1,
      sym__separator_first,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90351] = 2,
    ACTIONS(8044), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90359] = 2,
    ACTIONS(8046), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90367] = 2,
    ACTIONS(7342), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90375] = 2,
    ACTIONS(8048), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90383] = 2,
    ACTIONS(8050), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90391] = 2,
    ACTIONS(8052), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90399] = 2,
    ACTIONS(8054), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90407] = 2,
    ACTIONS(8056), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90415] = 2,
    ACTIONS(8058), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90423] = 2,
    ACTIONS(8060), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90431] = 2,
    ACTIONS(8062), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90439] = 2,
    ACTIONS(8064), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90447] = 2,
    ACTIONS(8066), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90455] = 2,
    ACTIONS(6795), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90463] = 2,
    ACTIONS(8068), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90471] = 2,
    ACTIONS(8070), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90479] = 2,
    ACTIONS(8072), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90487] = 2,
    ACTIONS(8074), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90495] = 2,
    ACTIONS(8076), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90503] = 2,
    ACTIONS(8078), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90511] = 2,
    ACTIONS(8080), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90519] = 2,
    ACTIONS(8082), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90527] = 2,
    ACTIONS(8084), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90535] = 2,
    ACTIONS(2703), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90543] = 2,
    ACTIONS(8086), 1,
      aux_sym_normal_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90551] = 2,
    ACTIONS(8088), 1,
      anon_sym_LPAREN2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90559] = 2,
    ACTIONS(8090), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90567] = 2,
    ACTIONS(8092), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90575] = 2,
    ACTIONS(8094), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90583] = 2,
    ACTIONS(8096), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90591] = 2,
    ACTIONS(2771), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90599] = 2,
    ACTIONS(8098), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90607] = 2,
    ACTIONS(8100), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90615] = 2,
    ACTIONS(8102), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90623] = 2,
    ACTIONS(8104), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90631] = 2,
    ACTIONS(8106), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90639] = 2,
    ACTIONS(8108), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90647] = 2,
    ACTIONS(8110), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90655] = 2,
    ACTIONS(8112), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90663] = 2,
    ACTIONS(8114), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90671] = 2,
    ACTIONS(8116), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90679] = 2,
    ACTIONS(8118), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90687] = 2,
    ACTIONS(8120), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90695] = 2,
    ACTIONS(8122), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90703] = 2,
    ACTIONS(7694), 1,
      anon_sym_LF,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90711] = 2,
    ACTIONS(8124), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90719] = 2,
    ACTIONS(8126), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90727] = 2,
    ACTIONS(8128), 1,
      aux_sym__hl_quoted_name_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90735] = 2,
    ACTIONS(8130), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90743] = 2,
    ACTIONS(8132), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90751] = 2,
    ACTIONS(8134), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90759] = 2,
    ACTIONS(8136), 1,
      anon_sym_LF,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90767] = 2,
    ACTIONS(8138), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90775] = 2,
    ACTIONS(7000), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90783] = 2,
    ACTIONS(8140), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90791] = 2,
    ACTIONS(8142), 1,
      aux_sym__syn_sync_lines_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90799] = 2,
    ACTIONS(8144), 1,
      aux_sym_normal_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90807] = 2,
    ACTIONS(8146), 1,
      aux_sym__autocmd_pattern_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90815] = 2,
    ACTIONS(8148), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90823] = 2,
    ACTIONS(8150), 1,
      anon_sym_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90831] = 2,
    ACTIONS(8152), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90839] = 2,
    ACTIONS(8154), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90847] = 2,
    ACTIONS(8156), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90855] = 2,
    ACTIONS(8158), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90863] = 2,
    ACTIONS(8160), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90871] = 2,
    ACTIONS(8162), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90879] = 2,
    ACTIONS(8164), 1,
      anon_sym_LPAREN2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90887] = 2,
    ACTIONS(8166), 1,
      aux_sym_command_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90895] = 2,
    ACTIONS(8168), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90903] = 2,
    ACTIONS(8170), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90911] = 2,
    ACTIONS(8172), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90919] = 2,
    ACTIONS(8174), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90927] = 2,
    ACTIONS(8176), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90935] = 2,
    ACTIONS(8178), 1,
      aux_sym__map_lhs_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90943] = 2,
    ACTIONS(8180), 1,
      anon_sym_COMMA2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90951] = 2,
    ACTIONS(8182), 1,
      aux_sym__map_lhs_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90959] = 2,
    ACTIONS(8184), 1,
      anon_sym_SQUOTE2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90967] = 2,
    ACTIONS(8186), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90975] = 2,
    ACTIONS(6383), 1,
      sym_integer_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90983] = 2,
    ACTIONS(8188), 1,
      aux_sym__map_lhs_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90991] = 2,
    ACTIONS(6383), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [90999] = 2,
    ACTIONS(8190), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91007] = 2,
    ACTIONS(8192), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91015] = 2,
    ACTIONS(8194), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91023] = 2,
    ACTIONS(8196), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91031] = 2,
    ACTIONS(8198), 1,
      anon_sym_LPAREN2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91039] = 2,
    ACTIONS(8200), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91047] = 2,
    ACTIONS(8202), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91055] = 2,
    ACTIONS(8204), 1,
      anon_sym_BSLASH_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91063] = 2,
    ACTIONS(8206), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91071] = 2,
    ACTIONS(8208), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91079] = 2,
    ACTIONS(8210), 1,
      sym__set,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91087] = 2,
    ACTIONS(7700), 1,
      sym_integer_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91095] = 2,
    ACTIONS(8212), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91103] = 2,
    ACTIONS(8214), 1,
      sym_command_name,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91111] = 2,
    ACTIONS(8216), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91119] = 2,
    ACTIONS(8218), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91127] = 2,
    ACTIONS(8220), 1,
      sym_integer_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91135] = 2,
    ACTIONS(8222), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91143] = 2,
    ACTIONS(8224), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91151] = 2,
    ACTIONS(8226), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91159] = 2,
    ACTIONS(8220), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91167] = 2,
    ACTIONS(8228), 1,
      anon_sym_LPAREN2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91175] = 2,
    ACTIONS(8230), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91183] = 2,
    ACTIONS(8232), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91191] = 2,
    ACTIONS(8234), 1,
      aux_sym_normal_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91199] = 2,
    ACTIONS(8236), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91207] = 2,
    ACTIONS(8238), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91215] = 2,
    ACTIONS(8240), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91223] = 2,
    ACTIONS(8242), 1,
      aux_sym_wincmd_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91231] = 2,
    ACTIONS(8244), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91239] = 2,
    ACTIONS(7075), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91247] = 2,
    ACTIONS(8246), 1,
      aux_sym_wincmd_statement_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91255] = 2,
    ACTIONS(8248), 1,
      sym__endif,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91263] = 2,
    ACTIONS(8250), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91271] = 2,
    ACTIONS(8252), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91279] = 2,
    ACTIONS(8254), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91287] = 2,
    ACTIONS(7638), 1,
      sym_integer_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91295] = 2,
    ACTIONS(8256), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91303] = 2,
    ACTIONS(8258), 1,
      sym__separator_first,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91311] = 2,
    ACTIONS(8260), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91319] = 2,
    ACTIONS(8262), 1,
      anon_sym_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91327] = 2,
    ACTIONS(8264), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91335] = 2,
    ACTIONS(8266), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91343] = 2,
    ACTIONS(8268), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91351] = 2,
    ACTIONS(8270), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91359] = 2,
    ACTIONS(8272), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91367] = 2,
    ACTIONS(8274), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91375] = 2,
    ACTIONS(8276), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91383] = 2,
    ACTIONS(8278), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91391] = 2,
    ACTIONS(8280), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91399] = 2,
    ACTIONS(8282), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91407] = 2,
    ACTIONS(8284), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91415] = 2,
    ACTIONS(8286), 1,
      sym_integer_literal,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91423] = 2,
    ACTIONS(8288), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91431] = 2,
    ACTIONS(8290), 1,
      sym__set,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91439] = 2,
    ACTIONS(8292), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91447] = 2,
    ACTIONS(8294), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91455] = 2,
    ACTIONS(8296), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91463] = 2,
    ACTIONS(8298), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91471] = 2,
    ACTIONS(8300), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91479] = 2,
    ACTIONS(8302), 1,
      sym_au_event,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91487] = 2,
    ACTIONS(6408), 1,
      sym__endif,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91495] = 2,
    ACTIONS(6168), 1,
      sym__endtry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91503] = 2,
    ACTIONS(8304), 1,
      aux_sym__bang_filter_command_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91511] = 2,
    ACTIONS(8306), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91519] = 2,
    ACTIONS(8308), 1,
      sym__separator,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91527] = 2,
    ACTIONS(8310), 1,
      sym__printable,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91535] = 2,
    ACTIONS(5916), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91543] = 2,
    ACTIONS(8312), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91551] = 2,
    ACTIONS(8314), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91559] = 2,
    ACTIONS(8316), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91567] = 2,
    ACTIONS(6301), 1,
      sym__endif,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91575] = 2,
    ACTIONS(6242), 1,
      sym__endif,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91583] = 2,
    ACTIONS(8318), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91591] = 2,
    ACTIONS(8320), 1,
      sym__separator_first,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91599] = 2,
    ACTIONS(8322), 1,
      aux_sym_argument_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91607] = 2,
    ACTIONS(5918), 1,
      sym_spread,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91615] = 2,
    ACTIONS(6303), 1,
      sym__endtry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91623] = 2,
    ACTIONS(7722), 1,
      anon_sym_QMARK2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91631] = 2,
    ACTIONS(8324), 1,
      sym__separator_first,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91639] = 2,
    ACTIONS(8326), 1,
      sym__endtry,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91647] = 2,
    ACTIONS(8328), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91655] = 2,
    ACTIONS(8330), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91663] = 2,
    ACTIONS(8332), 1,
      sym__separator_first,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91671] = 2,
    ACTIONS(8334), 1,
      anon_sym_GT,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91679] = 2,
    ACTIONS(8336), 1,
      anon_sym_LPAREN2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91687] = 2,
    ACTIONS(8338), 1,
      aux_sym__map_lhs_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91695] = 2,
    ACTIONS(8340), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91703] = 2,
    ACTIONS(8342), 1,
      aux_sym_option_name_token2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91711] = 2,
    ACTIONS(8344), 1,
      sym_hl_group,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91719] = 2,
    ACTIONS(8346), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91727] = 2,
    ACTIONS(8348), 1,
      aux_sym__autocmd_pattern_token1,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
  [91735] = 2,
    ACTIONS(8350), 1,
      anon_sym_EQ2,
    ACTIONS(3), 2,
      sym__line_continuation,
      sym_line_continuation_comment,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(124)] = 0,
  [SMALL_STATE(125)] = 75,
  [SMALL_STATE(126)] = 149,
  [SMALL_STATE(127)] = 219,
  [SMALL_STATE(128)] = 289,
  [SMALL_STATE(129)] = 359,
  [SMALL_STATE(130)] = 429,
  [SMALL_STATE(131)] = 499,
  [SMALL_STATE(132)] = 580,
  [SMALL_STATE(133)] = 658,
  [SMALL_STATE(134)] = 735,
  [SMALL_STATE(135)] = 804,
  [SMALL_STATE(136)] = 870,
  [SMALL_STATE(137)] = 937,
  [SMALL_STATE(138)] = 1038,
  [SMALL_STATE(139)] = 1097,
  [SMALL_STATE(140)] = 1197,
  [SMALL_STATE(141)] = 1255,
  [SMALL_STATE(142)] = 1313,
  [SMALL_STATE(143)] = 1371,
  [SMALL_STATE(144)] = 1429,
  [SMALL_STATE(145)] = 1513,
  [SMALL_STATE(146)] = 1597,
  [SMALL_STATE(147)] = 1681,
  [SMALL_STATE(148)] = 1765,
  [SMALL_STATE(149)] = 1849,
  [SMALL_STATE(150)] = 1933,
  [SMALL_STATE(151)] = 2023,
  [SMALL_STATE(152)] = 2113,
  [SMALL_STATE(153)] = 2197,
  [SMALL_STATE(154)] = 2281,
  [SMALL_STATE(155)] = 2365,
  [SMALL_STATE(156)] = 2449,
  [SMALL_STATE(157)] = 2539,
  [SMALL_STATE(158)] = 2623,
  [SMALL_STATE(159)] = 2713,
  [SMALL_STATE(160)] = 2771,
  [SMALL_STATE(161)] = 2861,
  [SMALL_STATE(162)] = 2919,
  [SMALL_STATE(163)] = 3009,
  [SMALL_STATE(164)] = 3067,
  [SMALL_STATE(165)] = 3157,
  [SMALL_STATE(166)] = 3215,
  [SMALL_STATE(167)] = 3299,
  [SMALL_STATE(168)] = 3389,
  [SMALL_STATE(169)] = 3472,
  [SMALL_STATE(170)] = 3559,
  [SMALL_STATE(171)] = 3640,
  [SMALL_STATE(172)] = 3725,
  [SMALL_STATE(173)] = 3782,
  [SMALL_STATE(174)] = 3865,
  [SMALL_STATE(175)] = 3948,
  [SMALL_STATE(176)] = 4005,
  [SMALL_STATE(177)] = 4062,
  [SMALL_STATE(178)] = 4145,
  [SMALL_STATE(179)] = 4228,
  [SMALL_STATE(180)] = 4311,
  [SMALL_STATE(181)] = 4394,
  [SMALL_STATE(182)] = 4477,
  [SMALL_STATE(183)] = 4560,
  [SMALL_STATE(184)] = 4643,
  [SMALL_STATE(185)] = 4726,
  [SMALL_STATE(186)] = 4811,
  [SMALL_STATE(187)] = 4896,
  [SMALL_STATE(188)] = 4981,
  [SMALL_STATE(189)] = 5064,
  [SMALL_STATE(190)] = 5149,
  [SMALL_STATE(191)] = 5232,
  [SMALL_STATE(192)] = 5289,
  [SMALL_STATE(193)] = 5372,
  [SMALL_STATE(194)] = 5429,
  [SMALL_STATE(195)] = 5514,
  [SMALL_STATE(196)] = 5571,
  [SMALL_STATE(197)] = 5658,
  [SMALL_STATE(198)] = 5740,
  [SMALL_STATE(199)] = 5822,
  [SMALL_STATE(200)] = 5876,
  [SMALL_STATE(201)] = 5926,
  [SMALL_STATE(202)] = 6008,
  [SMALL_STATE(203)] = 6090,
  [SMALL_STATE(204)] = 6172,
  [SMALL_STATE(205)] = 6254,
  [SMALL_STATE(206)] = 6304,
  [SMALL_STATE(207)] = 6386,
  [SMALL_STATE(208)] = 6468,
  [SMALL_STATE(209)] = 6518,
  [SMALL_STATE(210)] = 6600,
  [SMALL_STATE(211)] = 6682,
  [SMALL_STATE(212)] = 6764,
  [SMALL_STATE(213)] = 6846,
  [SMALL_STATE(214)] = 6896,
  [SMALL_STATE(215)] = 6978,
  [SMALL_STATE(216)] = 7060,
  [SMALL_STATE(217)] = 7142,
  [SMALL_STATE(218)] = 7224,
  [SMALL_STATE(219)] = 7304,
  [SMALL_STATE(220)] = 7383,
  [SMALL_STATE(221)] = 7462,
  [SMALL_STATE(222)] = 7543,
  [SMALL_STATE(223)] = 7622,
  [SMALL_STATE(224)] = 7701,
  [SMALL_STATE(225)] = 7780,
  [SMALL_STATE(226)] = 7859,
  [SMALL_STATE(227)] = 7938,
  [SMALL_STATE(228)] = 8017,
  [SMALL_STATE(229)] = 8066,
  [SMALL_STATE(230)] = 8145,
  [SMALL_STATE(231)] = 8224,
  [SMALL_STATE(232)] = 8303,
  [SMALL_STATE(233)] = 8382,
  [SMALL_STATE(234)] = 8461,
  [SMALL_STATE(235)] = 8540,
  [SMALL_STATE(236)] = 8619,
  [SMALL_STATE(237)] = 8672,
  [SMALL_STATE(238)] = 8751,
  [SMALL_STATE(239)] = 8830,
  [SMALL_STATE(240)] = 8909,
  [SMALL_STATE(241)] = 8988,
  [SMALL_STATE(242)] = 9067,
  [SMALL_STATE(243)] = 9146,
  [SMALL_STATE(244)] = 9229,
  [SMALL_STATE(245)] = 9278,
  [SMALL_STATE(246)] = 9357,
  [SMALL_STATE(247)] = 9436,
  [SMALL_STATE(248)] = 9515,
  [SMALL_STATE(249)] = 9594,
  [SMALL_STATE(250)] = 9673,
  [SMALL_STATE(251)] = 9752,
  [SMALL_STATE(252)] = 9831,
  [SMALL_STATE(253)] = 9910,
  [SMALL_STATE(254)] = 9989,
  [SMALL_STATE(255)] = 10068,
  [SMALL_STATE(256)] = 10147,
  [SMALL_STATE(257)] = 10226,
  [SMALL_STATE(258)] = 10305,
  [SMALL_STATE(259)] = 10384,
  [SMALL_STATE(260)] = 10463,
  [SMALL_STATE(261)] = 10512,
  [SMALL_STATE(262)] = 10595,
  [SMALL_STATE(263)] = 10674,
  [SMALL_STATE(264)] = 10723,
  [SMALL_STATE(265)] = 10802,
  [SMALL_STATE(266)] = 10881,
  [SMALL_STATE(267)] = 10960,
  [SMALL_STATE(268)] = 11039,
  [SMALL_STATE(269)] = 11118,
  [SMALL_STATE(270)] = 11197,
  [SMALL_STATE(271)] = 11273,
  [SMALL_STATE(272)] = 11349,
  [SMALL_STATE(273)] = 11425,
  [SMALL_STATE(274)] = 11501,
  [SMALL_STATE(275)] = 11553,
  [SMALL_STATE(276)] = 11629,
  [SMALL_STATE(277)] = 11705,
  [SMALL_STATE(278)] = 11781,
  [SMALL_STATE(279)] = 11857,
  [SMALL_STATE(280)] = 11935,
  [SMALL_STATE(281)] = 12011,
  [SMALL_STATE(282)] = 12087,
  [SMALL_STATE(283)] = 12163,
  [SMALL_STATE(284)] = 12239,
  [SMALL_STATE(285)] = 12315,
  [SMALL_STATE(286)] = 12391,
  [SMALL_STATE(287)] = 12469,
  [SMALL_STATE(288)] = 12545,
  [SMALL_STATE(289)] = 12621,
  [SMALL_STATE(290)] = 12697,
  [SMALL_STATE(291)] = 12773,
  [SMALL_STATE(292)] = 12849,
  [SMALL_STATE(293)] = 12925,
  [SMALL_STATE(294)] = 12973,
  [SMALL_STATE(295)] = 13049,
  [SMALL_STATE(296)] = 13105,
  [SMALL_STATE(297)] = 13153,
  [SMALL_STATE(298)] = 13201,
  [SMALL_STATE(299)] = 13277,
  [SMALL_STATE(300)] = 13355,
  [SMALL_STATE(301)] = 13431,
  [SMALL_STATE(302)] = 13507,
  [SMALL_STATE(303)] = 13583,
  [SMALL_STATE(304)] = 13659,
  [SMALL_STATE(305)] = 13707,
  [SMALL_STATE(306)] = 13783,
  [SMALL_STATE(307)] = 13859,
  [SMALL_STATE(308)] = 13907,
  [SMALL_STATE(309)] = 13955,
  [SMALL_STATE(310)] = 14003,
  [SMALL_STATE(311)] = 14051,
  [SMALL_STATE(312)] = 14099,
  [SMALL_STATE(313)] = 14155,
  [SMALL_STATE(314)] = 14213,
  [SMALL_STATE(315)] = 14275,
  [SMALL_STATE(316)] = 14351,
  [SMALL_STATE(317)] = 14419,
  [SMALL_STATE(318)] = 14485,
  [SMALL_STATE(319)] = 14533,
  [SMALL_STATE(320)] = 14581,
  [SMALL_STATE(321)] = 14629,
  [SMALL_STATE(322)] = 14677,
  [SMALL_STATE(323)] = 14725,
  [SMALL_STATE(324)] = 14773,
  [SMALL_STATE(325)] = 14849,
  [SMALL_STATE(326)] = 14897,
  [SMALL_STATE(327)] = 14959,
  [SMALL_STATE(328)] = 15007,
  [SMALL_STATE(329)] = 15055,
  [SMALL_STATE(330)] = 15103,
  [SMALL_STATE(331)] = 15151,
  [SMALL_STATE(332)] = 15221,
  [SMALL_STATE(333)] = 15269,
  [SMALL_STATE(334)] = 15317,
  [SMALL_STATE(335)] = 15365,
  [SMALL_STATE(336)] = 15413,
  [SMALL_STATE(337)] = 15461,
  [SMALL_STATE(338)] = 15533,
  [SMALL_STATE(339)] = 15609,
  [SMALL_STATE(340)] = 15657,
  [SMALL_STATE(341)] = 15705,
  [SMALL_STATE(342)] = 15783,
  [SMALL_STATE(343)] = 15831,
  [SMALL_STATE(344)] = 15879,
  [SMALL_STATE(345)] = 15927,
  [SMALL_STATE(346)] = 15975,
  [SMALL_STATE(347)] = 16023,
  [SMALL_STATE(348)] = 16071,
  [SMALL_STATE(349)] = 16119,
  [SMALL_STATE(350)] = 16195,
  [SMALL_STATE(351)] = 16271,
  [SMALL_STATE(352)] = 16319,
  [SMALL_STATE(353)] = 16367,
  [SMALL_STATE(354)] = 16415,
  [SMALL_STATE(355)] = 16463,
  [SMALL_STATE(356)] = 16511,
  [SMALL_STATE(357)] = 16587,
  [SMALL_STATE(358)] = 16663,
  [SMALL_STATE(359)] = 16711,
  [SMALL_STATE(360)] = 16789,
  [SMALL_STATE(361)] = 16865,
  [SMALL_STATE(362)] = 16943,
  [SMALL_STATE(363)] = 17019,
  [SMALL_STATE(364)] = 17095,
  [SMALL_STATE(365)] = 17171,
  [SMALL_STATE(366)] = 17247,
  [SMALL_STATE(367)] = 17323,
  [SMALL_STATE(368)] = 17399,
  [SMALL_STATE(369)] = 17475,
  [SMALL_STATE(370)] = 17551,
  [SMALL_STATE(371)] = 17627,
  [SMALL_STATE(372)] = 17703,
  [SMALL_STATE(373)] = 17783,
  [SMALL_STATE(374)] = 17861,
  [SMALL_STATE(375)] = 17937,
  [SMALL_STATE(376)] = 18013,
  [SMALL_STATE(377)] = 18089,
  [SMALL_STATE(378)] = 18169,
  [SMALL_STATE(379)] = 18249,
  [SMALL_STATE(380)] = 18325,
  [SMALL_STATE(381)] = 18401,
  [SMALL_STATE(382)] = 18477,
  [SMALL_STATE(383)] = 18553,
  [SMALL_STATE(384)] = 18633,
  [SMALL_STATE(385)] = 18709,
  [SMALL_STATE(386)] = 18785,
  [SMALL_STATE(387)] = 18861,
  [SMALL_STATE(388)] = 18937,
  [SMALL_STATE(389)] = 19013,
  [SMALL_STATE(390)] = 19089,
  [SMALL_STATE(391)] = 19165,
  [SMALL_STATE(392)] = 19241,
  [SMALL_STATE(393)] = 19317,
  [SMALL_STATE(394)] = 19393,
  [SMALL_STATE(395)] = 19471,
  [SMALL_STATE(396)] = 19547,
  [SMALL_STATE(397)] = 19623,
  [SMALL_STATE(398)] = 19699,
  [SMALL_STATE(399)] = 19775,
  [SMALL_STATE(400)] = 19851,
  [SMALL_STATE(401)] = 19927,
  [SMALL_STATE(402)] = 20003,
  [SMALL_STATE(403)] = 20079,
  [SMALL_STATE(404)] = 20155,
  [SMALL_STATE(405)] = 20231,
  [SMALL_STATE(406)] = 20307,
  [SMALL_STATE(407)] = 20383,
  [SMALL_STATE(408)] = 20459,
  [SMALL_STATE(409)] = 20535,
  [SMALL_STATE(410)] = 20611,
  [SMALL_STATE(411)] = 20687,
  [SMALL_STATE(412)] = 20763,
  [SMALL_STATE(413)] = 20839,
  [SMALL_STATE(414)] = 20915,
  [SMALL_STATE(415)] = 20991,
  [SMALL_STATE(416)] = 21067,
  [SMALL_STATE(417)] = 21143,
  [SMALL_STATE(418)] = 21219,
  [SMALL_STATE(419)] = 21295,
  [SMALL_STATE(420)] = 21371,
  [SMALL_STATE(421)] = 21447,
  [SMALL_STATE(422)] = 21523,
  [SMALL_STATE(423)] = 21599,
  [SMALL_STATE(424)] = 21675,
  [SMALL_STATE(425)] = 21751,
  [SMALL_STATE(426)] = 21827,
  [SMALL_STATE(427)] = 21903,
  [SMALL_STATE(428)] = 21979,
  [SMALL_STATE(429)] = 22055,
  [SMALL_STATE(430)] = 22131,
  [SMALL_STATE(431)] = 22207,
  [SMALL_STATE(432)] = 22283,
  [SMALL_STATE(433)] = 22359,
  [SMALL_STATE(434)] = 22435,
  [SMALL_STATE(435)] = 22511,
  [SMALL_STATE(436)] = 22587,
  [SMALL_STATE(437)] = 22663,
  [SMALL_STATE(438)] = 22739,
  [SMALL_STATE(439)] = 22815,
  [SMALL_STATE(440)] = 22891,
  [SMALL_STATE(441)] = 22967,
  [SMALL_STATE(442)] = 23043,
  [SMALL_STATE(443)] = 23119,
  [SMALL_STATE(444)] = 23195,
  [SMALL_STATE(445)] = 23271,
  [SMALL_STATE(446)] = 23347,
  [SMALL_STATE(447)] = 23423,
  [SMALL_STATE(448)] = 23499,
  [SMALL_STATE(449)] = 23575,
  [SMALL_STATE(450)] = 23651,
  [SMALL_STATE(451)] = 23727,
  [SMALL_STATE(452)] = 23803,
  [SMALL_STATE(453)] = 23879,
  [SMALL_STATE(454)] = 23955,
  [SMALL_STATE(455)] = 24031,
  [SMALL_STATE(456)] = 24107,
  [SMALL_STATE(457)] = 24183,
  [SMALL_STATE(458)] = 24259,
  [SMALL_STATE(459)] = 24335,
  [SMALL_STATE(460)] = 24382,
  [SMALL_STATE(461)] = 24429,
  [SMALL_STATE(462)] = 24476,
  [SMALL_STATE(463)] = 24531,
  [SMALL_STATE(464)] = 24578,
  [SMALL_STATE(465)] = 24635,
  [SMALL_STATE(466)] = 24696,
  [SMALL_STATE(467)] = 24763,
  [SMALL_STATE(468)] = 24828,
  [SMALL_STATE(469)] = 24875,
  [SMALL_STATE(470)] = 24922,
  [SMALL_STATE(471)] = 24969,
  [SMALL_STATE(472)] = 25016,
  [SMALL_STATE(473)] = 25063,
  [SMALL_STATE(474)] = 25110,
  [SMALL_STATE(475)] = 25157,
  [SMALL_STATE(476)] = 25218,
  [SMALL_STATE(477)] = 25265,
  [SMALL_STATE(478)] = 25312,
  [SMALL_STATE(479)] = 25359,
  [SMALL_STATE(480)] = 25406,
  [SMALL_STATE(481)] = 25453,
  [SMALL_STATE(482)] = 25504,
  [SMALL_STATE(483)] = 25551,
  [SMALL_STATE(484)] = 25598,
  [SMALL_STATE(485)] = 25669,
  [SMALL_STATE(486)] = 25716,
  [SMALL_STATE(487)] = 25763,
  [SMALL_STATE(488)] = 25810,
  [SMALL_STATE(489)] = 25857,
  [SMALL_STATE(490)] = 25904,
  [SMALL_STATE(491)] = 25951,
  [SMALL_STATE(492)] = 25998,
  [SMALL_STATE(493)] = 26045,
  [SMALL_STATE(494)] = 26092,
  [SMALL_STATE(495)] = 26139,
  [SMALL_STATE(496)] = 26186,
  [SMALL_STATE(497)] = 26233,
  [SMALL_STATE(498)] = 26280,
  [SMALL_STATE(499)] = 26327,
  [SMALL_STATE(500)] = 26374,
  [SMALL_STATE(501)] = 26429,
  [SMALL_STATE(502)] = 26476,
  [SMALL_STATE(503)] = 26523,
  [SMALL_STATE(504)] = 26570,
  [SMALL_STATE(505)] = 26617,
  [SMALL_STATE(506)] = 26664,
  [SMALL_STATE(507)] = 26711,
  [SMALL_STATE(508)] = 26758,
  [SMALL_STATE(509)] = 26827,
  [SMALL_STATE(510)] = 26879,
  [SMALL_STATE(511)] = 26930,
  [SMALL_STATE(512)] = 26981,
  [SMALL_STATE(513)] = 27032,
  [SMALL_STATE(514)] = 27075,
  [SMALL_STATE(515)] = 27128,
  [SMALL_STATE(516)] = 27181,
  [SMALL_STATE(517)] = 27234,
  [SMALL_STATE(518)] = 27277,
  [SMALL_STATE(519)] = 27374,
  [SMALL_STATE(520)] = 27427,
  [SMALL_STATE(521)] = 27475,
  [SMALL_STATE(522)] = 27523,
  [SMALL_STATE(523)] = 27619,
  [SMALL_STATE(524)] = 27667,
  [SMALL_STATE(525)] = 27708,
  [SMALL_STATE(526)] = 27749,
  [SMALL_STATE(527)] = 27790,
  [SMALL_STATE(528)] = 27831,
  [SMALL_STATE(529)] = 27872,
  [SMALL_STATE(530)] = 27917,
  [SMALL_STATE(531)] = 27958,
  [SMALL_STATE(532)] = 27999,
  [SMALL_STATE(533)] = 28044,
  [SMALL_STATE(534)] = 28085,
  [SMALL_STATE(535)] = 28126,
  [SMALL_STATE(536)] = 28167,
  [SMALL_STATE(537)] = 28212,
  [SMALL_STATE(538)] = 28253,
  [SMALL_STATE(539)] = 28298,
  [SMALL_STATE(540)] = 28339,
  [SMALL_STATE(541)] = 28380,
  [SMALL_STATE(542)] = 28421,
  [SMALL_STATE(543)] = 28461,
  [SMALL_STATE(544)] = 28505,
  [SMALL_STATE(545)] = 28549,
  [SMALL_STATE(546)] = 28589,
  [SMALL_STATE(547)] = 28628,
  [SMALL_STATE(548)] = 28671,
  [SMALL_STATE(549)] = 28710,
  [SMALL_STATE(550)] = 28753,
  [SMALL_STATE(551)] = 28792,
  [SMALL_STATE(552)] = 28831,
  [SMALL_STATE(553)] = 28870,
  [SMALL_STATE(554)] = 28915,
  [SMALL_STATE(555)] = 28960,
  [SMALL_STATE(556)] = 29005,
  [SMALL_STATE(557)] = 29043,
  [SMALL_STATE(558)] = 29081,
  [SMALL_STATE(559)] = 29119,
  [SMALL_STATE(560)] = 29157,
  [SMALL_STATE(561)] = 29195,
  [SMALL_STATE(562)] = 29233,
  [SMALL_STATE(563)] = 29271,
  [SMALL_STATE(564)] = 29309,
  [SMALL_STATE(565)] = 29351,
  [SMALL_STATE(566)] = 29389,
  [SMALL_STATE(567)] = 29427,
  [SMALL_STATE(568)] = 29465,
  [SMALL_STATE(569)] = 29503,
  [SMALL_STATE(570)] = 29541,
  [SMALL_STATE(571)] = 29579,
  [SMALL_STATE(572)] = 29631,
  [SMALL_STATE(573)] = 29669,
  [SMALL_STATE(574)] = 29727,
  [SMALL_STATE(575)] = 29765,
  [SMALL_STATE(576)] = 29803,
  [SMALL_STATE(577)] = 29861,
  [SMALL_STATE(578)] = 29899,
  [SMALL_STATE(579)] = 29937,
  [SMALL_STATE(580)] = 29975,
  [SMALL_STATE(581)] = 30019,
  [SMALL_STATE(582)] = 30057,
  [SMALL_STATE(583)] = 30101,
  [SMALL_STATE(584)] = 30139,
  [SMALL_STATE(585)] = 30185,
  [SMALL_STATE(586)] = 30229,
  [SMALL_STATE(587)] = 30267,
  [SMALL_STATE(588)] = 30305,
  [SMALL_STATE(589)] = 30343,
  [SMALL_STATE(590)] = 30391,
  [SMALL_STATE(591)] = 30429,
  [SMALL_STATE(592)] = 30467,
  [SMALL_STATE(593)] = 30519,
  [SMALL_STATE(594)] = 30577,
  [SMALL_STATE(595)] = 30615,
  [SMALL_STATE(596)] = 30653,
  [SMALL_STATE(597)] = 30691,
  [SMALL_STATE(598)] = 30729,
  [SMALL_STATE(599)] = 30767,
  [SMALL_STATE(600)] = 30823,
  [SMALL_STATE(601)] = 30877,
  [SMALL_STATE(602)] = 30923,
  [SMALL_STATE(603)] = 30961,
  [SMALL_STATE(604)] = 30999,
  [SMALL_STATE(605)] = 31037,
  [SMALL_STATE(606)] = 31075,
  [SMALL_STATE(607)] = 31117,
  [SMALL_STATE(608)] = 31155,
  [SMALL_STATE(609)] = 31193,
  [SMALL_STATE(610)] = 31234,
  [SMALL_STATE(611)] = 31291,
  [SMALL_STATE(612)] = 31332,
  [SMALL_STATE(613)] = 31369,
  [SMALL_STATE(614)] = 31410,
  [SMALL_STATE(615)] = 31451,
  [SMALL_STATE(616)] = 31508,
  [SMALL_STATE(617)] = 31545,
  [SMALL_STATE(618)] = 31582,
  [SMALL_STATE(619)] = 31623,
  [SMALL_STATE(620)] = 31689,
  [SMALL_STATE(621)] = 31731,
  [SMALL_STATE(622)] = 31795,
  [SMALL_STATE(623)] = 31861,
  [SMALL_STATE(624)] = 31903,
  [SMALL_STATE(625)] = 31945,
  [SMALL_STATE(626)] = 32011,
  [SMALL_STATE(627)] = 32077,
  [SMALL_STATE(628)] = 32143,
  [SMALL_STATE(629)] = 32209,
  [SMALL_STATE(630)] = 32245,
  [SMALL_STATE(631)] = 32309,
  [SMALL_STATE(632)] = 32349,
  [SMALL_STATE(633)] = 32415,
  [SMALL_STATE(634)] = 32451,
  [SMALL_STATE(635)] = 32517,
  [SMALL_STATE(636)] = 32575,
  [SMALL_STATE(637)] = 32611,
  [SMALL_STATE(638)] = 32651,
  [SMALL_STATE(639)] = 32693,
  [SMALL_STATE(640)] = 32735,
  [SMALL_STATE(641)] = 32796,
  [SMALL_STATE(642)] = 32831,
  [SMALL_STATE(643)] = 32866,
  [SMALL_STATE(644)] = 32923,
  [SMALL_STATE(645)] = 32958,
  [SMALL_STATE(646)] = 33019,
  [SMALL_STATE(647)] = 33076,
  [SMALL_STATE(648)] = 33117,
  [SMALL_STATE(649)] = 33152,
  [SMALL_STATE(650)] = 33213,
  [SMALL_STATE(651)] = 33248,
  [SMALL_STATE(652)] = 33305,
  [SMALL_STATE(653)] = 33360,
  [SMALL_STATE(654)] = 33395,
  [SMALL_STATE(655)] = 33430,
  [SMALL_STATE(656)] = 33491,
  [SMALL_STATE(657)] = 33552,
  [SMALL_STATE(658)] = 33609,
  [SMALL_STATE(659)] = 33670,
  [SMALL_STATE(660)] = 33731,
  [SMALL_STATE(661)] = 33790,
  [SMALL_STATE(662)] = 33825,
  [SMALL_STATE(663)] = 33882,
  [SMALL_STATE(664)] = 33943,
  [SMALL_STATE(665)] = 33978,
  [SMALL_STATE(666)] = 34039,
  [SMALL_STATE(667)] = 34074,
  [SMALL_STATE(668)] = 34133,
  [SMALL_STATE(669)] = 34194,
  [SMALL_STATE(670)] = 34253,
  [SMALL_STATE(671)] = 34288,
  [SMALL_STATE(672)] = 34323,
  [SMALL_STATE(673)] = 34384,
  [SMALL_STATE(674)] = 34419,
  [SMALL_STATE(675)] = 34480,
  [SMALL_STATE(676)] = 34515,
  [SMALL_STATE(677)] = 34550,
  [SMALL_STATE(678)] = 34585,
  [SMALL_STATE(679)] = 34646,
  [SMALL_STATE(680)] = 34681,
  [SMALL_STATE(681)] = 34742,
  [SMALL_STATE(682)] = 34777,
  [SMALL_STATE(683)] = 34812,
  [SMALL_STATE(684)] = 34847,
  [SMALL_STATE(685)] = 34882,
  [SMALL_STATE(686)] = 34941,
  [SMALL_STATE(687)] = 35000,
  [SMALL_STATE(688)] = 35057,
  [SMALL_STATE(689)] = 35092,
  [SMALL_STATE(690)] = 35149,
  [SMALL_STATE(691)] = 35184,
  [SMALL_STATE(692)] = 35241,
  [SMALL_STATE(693)] = 35300,
  [SMALL_STATE(694)] = 35343,
  [SMALL_STATE(695)] = 35378,
  [SMALL_STATE(696)] = 35415,
  [SMALL_STATE(697)] = 35472,
  [SMALL_STATE(698)] = 35507,
  [SMALL_STATE(699)] = 35542,
  [SMALL_STATE(700)] = 35577,
  [SMALL_STATE(701)] = 35638,
  [SMALL_STATE(702)] = 35683,
  [SMALL_STATE(703)] = 35718,
  [SMALL_STATE(704)] = 35753,
  [SMALL_STATE(705)] = 35802,
  [SMALL_STATE(706)] = 35837,
  [SMALL_STATE(707)] = 35872,
  [SMALL_STATE(708)] = 35931,
  [SMALL_STATE(709)] = 35966,
  [SMALL_STATE(710)] = 36015,
  [SMALL_STATE(711)] = 36050,
  [SMALL_STATE(712)] = 36085,
  [SMALL_STATE(713)] = 36138,
  [SMALL_STATE(714)] = 36189,
  [SMALL_STATE(715)] = 36246,
  [SMALL_STATE(716)] = 36283,
  [SMALL_STATE(717)] = 36318,
  [SMALL_STATE(718)] = 36361,
  [SMALL_STATE(719)] = 36398,
  [SMALL_STATE(720)] = 36433,
  [SMALL_STATE(721)] = 36468,
  [SMALL_STATE(722)] = 36503,
  [SMALL_STATE(723)] = 36540,
  [SMALL_STATE(724)] = 36577,
  [SMALL_STATE(725)] = 36612,
  [SMALL_STATE(726)] = 36647,
  [SMALL_STATE(727)] = 36701,
  [SMALL_STATE(728)] = 36757,
  [SMALL_STATE(729)] = 36793,
  [SMALL_STATE(730)] = 36849,
  [SMALL_STATE(731)] = 36915,
  [SMALL_STATE(732)] = 36949,
  [SMALL_STATE(733)] = 36983,
  [SMALL_STATE(734)] = 37017,
  [SMALL_STATE(735)] = 37051,
  [SMALL_STATE(736)] = 37085,
  [SMALL_STATE(737)] = 37141,
  [SMALL_STATE(738)] = 37175,
  [SMALL_STATE(739)] = 37223,
  [SMALL_STATE(740)] = 37257,
  [SMALL_STATE(741)] = 37291,
  [SMALL_STATE(742)] = 37327,
  [SMALL_STATE(743)] = 37363,
  [SMALL_STATE(744)] = 37421,
  [SMALL_STATE(745)] = 37457,
  [SMALL_STATE(746)] = 37513,
  [SMALL_STATE(747)] = 37547,
  [SMALL_STATE(748)] = 37581,
  [SMALL_STATE(749)] = 37615,
  [SMALL_STATE(750)] = 37649,
  [SMALL_STATE(751)] = 37683,
  [SMALL_STATE(752)] = 37717,
  [SMALL_STATE(753)] = 37751,
  [SMALL_STATE(754)] = 37785,
  [SMALL_STATE(755)] = 37819,
  [SMALL_STATE(756)] = 37877,
  [SMALL_STATE(757)] = 37911,
  [SMALL_STATE(758)] = 37945,
  [SMALL_STATE(759)] = 37979,
  [SMALL_STATE(760)] = 38013,
  [SMALL_STATE(761)] = 38047,
  [SMALL_STATE(762)] = 38081,
  [SMALL_STATE(763)] = 38141,
  [SMALL_STATE(764)] = 38183,
  [SMALL_STATE(765)] = 38217,
  [SMALL_STATE(766)] = 38251,
  [SMALL_STATE(767)] = 38285,
  [SMALL_STATE(768)] = 38345,
  [SMALL_STATE(769)] = 38405,
  [SMALL_STATE(770)] = 38465,
  [SMALL_STATE(771)] = 38499,
  [SMALL_STATE(772)] = 38559,
  [SMALL_STATE(773)] = 38619,
  [SMALL_STATE(774)] = 38679,
  [SMALL_STATE(775)] = 38739,
  [SMALL_STATE(776)] = 38797,
  [SMALL_STATE(777)] = 38835,
  [SMALL_STATE(778)] = 38891,
  [SMALL_STATE(779)] = 38949,
  [SMALL_STATE(780)] = 38983,
  [SMALL_STATE(781)] = 39041,
  [SMALL_STATE(782)] = 39099,
  [SMALL_STATE(783)] = 39133,
  [SMALL_STATE(784)] = 39191,
  [SMALL_STATE(785)] = 39247,
  [SMALL_STATE(786)] = 39305,
  [SMALL_STATE(787)] = 39361,
  [SMALL_STATE(788)] = 39417,
  [SMALL_STATE(789)] = 39475,
  [SMALL_STATE(790)] = 39535,
  [SMALL_STATE(791)] = 39569,
  [SMALL_STATE(792)] = 39625,
  [SMALL_STATE(793)] = 39683,
  [SMALL_STATE(794)] = 39739,
  [SMALL_STATE(795)] = 39797,
  [SMALL_STATE(796)] = 39855,
  [SMALL_STATE(797)] = 39913,
  [SMALL_STATE(798)] = 39969,
  [SMALL_STATE(799)] = 40003,
  [SMALL_STATE(800)] = 40037,
  [SMALL_STATE(801)] = 40071,
  [SMALL_STATE(802)] = 40105,
  [SMALL_STATE(803)] = 40139,
  [SMALL_STATE(804)] = 40173,
  [SMALL_STATE(805)] = 40229,
  [SMALL_STATE(806)] = 40263,
  [SMALL_STATE(807)] = 40297,
  [SMALL_STATE(808)] = 40339,
  [SMALL_STATE(809)] = 40373,
  [SMALL_STATE(810)] = 40417,
  [SMALL_STATE(811)] = 40465,
  [SMALL_STATE(812)] = 40525,
  [SMALL_STATE(813)] = 40581,
  [SMALL_STATE(814)] = 40641,
  [SMALL_STATE(815)] = 40701,
  [SMALL_STATE(816)] = 40735,
  [SMALL_STATE(817)] = 40793,
  [SMALL_STATE(818)] = 40829,
  [SMALL_STATE(819)] = 40881,
  [SMALL_STATE(820)] = 40931,
  [SMALL_STATE(821)] = 40965,
  [SMALL_STATE(822)] = 41025,
  [SMALL_STATE(823)] = 41085,
  [SMALL_STATE(824)] = 41145,
  [SMALL_STATE(825)] = 41205,
  [SMALL_STATE(826)] = 41260,
  [SMALL_STATE(827)] = 41293,
  [SMALL_STATE(828)] = 41326,
  [SMALL_STATE(829)] = 41381,
  [SMALL_STATE(830)] = 41436,
  [SMALL_STATE(831)] = 41491,
  [SMALL_STATE(832)] = 41546,
  [SMALL_STATE(833)] = 41601,
  [SMALL_STATE(834)] = 41656,
  [SMALL_STATE(835)] = 41711,
  [SMALL_STATE(836)] = 41748,
  [SMALL_STATE(837)] = 41803,
  [SMALL_STATE(838)] = 41858,
  [SMALL_STATE(839)] = 41913,
  [SMALL_STATE(840)] = 41950,
  [SMALL_STATE(841)] = 41987,
  [SMALL_STATE(842)] = 42042,
  [SMALL_STATE(843)] = 42097,
  [SMALL_STATE(844)] = 42152,
  [SMALL_STATE(845)] = 42189,
  [SMALL_STATE(846)] = 42244,
  [SMALL_STATE(847)] = 42281,
  [SMALL_STATE(848)] = 42336,
  [SMALL_STATE(849)] = 42391,
  [SMALL_STATE(850)] = 42456,
  [SMALL_STATE(851)] = 42511,
  [SMALL_STATE(852)] = 42566,
  [SMALL_STATE(853)] = 42621,
  [SMALL_STATE(854)] = 42676,
  [SMALL_STATE(855)] = 42731,
  [SMALL_STATE(856)] = 42786,
  [SMALL_STATE(857)] = 42841,
  [SMALL_STATE(858)] = 42896,
  [SMALL_STATE(859)] = 42951,
  [SMALL_STATE(860)] = 43006,
  [SMALL_STATE(861)] = 43063,
  [SMALL_STATE(862)] = 43118,
  [SMALL_STATE(863)] = 43173,
  [SMALL_STATE(864)] = 43228,
  [SMALL_STATE(865)] = 43283,
  [SMALL_STATE(866)] = 43338,
  [SMALL_STATE(867)] = 43393,
  [SMALL_STATE(868)] = 43456,
  [SMALL_STATE(869)] = 43511,
  [SMALL_STATE(870)] = 43566,
  [SMALL_STATE(871)] = 43621,
  [SMALL_STATE(872)] = 43676,
  [SMALL_STATE(873)] = 43709,
  [SMALL_STATE(874)] = 43764,
  [SMALL_STATE(875)] = 43819,
  [SMALL_STATE(876)] = 43874,
  [SMALL_STATE(877)] = 43929,
  [SMALL_STATE(878)] = 43984,
  [SMALL_STATE(879)] = 44039,
  [SMALL_STATE(880)] = 44094,
  [SMALL_STATE(881)] = 44149,
  [SMALL_STATE(882)] = 44182,
  [SMALL_STATE(883)] = 44237,
  [SMALL_STATE(884)] = 44292,
  [SMALL_STATE(885)] = 44347,
  [SMALL_STATE(886)] = 44402,
  [SMALL_STATE(887)] = 44457,
  [SMALL_STATE(888)] = 44512,
  [SMALL_STATE(889)] = 44567,
  [SMALL_STATE(890)] = 44622,
  [SMALL_STATE(891)] = 44677,
  [SMALL_STATE(892)] = 44732,
  [SMALL_STATE(893)] = 44787,
  [SMALL_STATE(894)] = 44842,
  [SMALL_STATE(895)] = 44897,
  [SMALL_STATE(896)] = 44952,
  [SMALL_STATE(897)] = 45007,
  [SMALL_STATE(898)] = 45062,
  [SMALL_STATE(899)] = 45117,
  [SMALL_STATE(900)] = 45172,
  [SMALL_STATE(901)] = 45227,
  [SMALL_STATE(902)] = 45282,
  [SMALL_STATE(903)] = 45337,
  [SMALL_STATE(904)] = 45392,
  [SMALL_STATE(905)] = 45447,
  [SMALL_STATE(906)] = 45510,
  [SMALL_STATE(907)] = 45543,
  [SMALL_STATE(908)] = 45606,
  [SMALL_STATE(909)] = 45663,
  [SMALL_STATE(910)] = 45718,
  [SMALL_STATE(911)] = 45775,
  [SMALL_STATE(912)] = 45830,
  [SMALL_STATE(913)] = 45863,
  [SMALL_STATE(914)] = 45918,
  [SMALL_STATE(915)] = 45973,
  [SMALL_STATE(916)] = 46028,
  [SMALL_STATE(917)] = 46061,
  [SMALL_STATE(918)] = 46098,
  [SMALL_STATE(919)] = 46153,
  [SMALL_STATE(920)] = 46186,
  [SMALL_STATE(921)] = 46225,
  [SMALL_STATE(922)] = 46258,
  [SMALL_STATE(923)] = 46291,
  [SMALL_STATE(924)] = 46348,
  [SMALL_STATE(925)] = 46403,
  [SMALL_STATE(926)] = 46458,
  [SMALL_STATE(927)] = 46513,
  [SMALL_STATE(928)] = 46550,
  [SMALL_STATE(929)] = 46605,
  [SMALL_STATE(930)] = 46662,
  [SMALL_STATE(931)] = 46695,
  [SMALL_STATE(932)] = 46750,
  [SMALL_STATE(933)] = 46805,
  [SMALL_STATE(934)] = 46860,
  [SMALL_STATE(935)] = 46893,
  [SMALL_STATE(936)] = 46948,
  [SMALL_STATE(937)] = 46984,
  [SMALL_STATE(938)] = 47038,
  [SMALL_STATE(939)] = 47074,
  [SMALL_STATE(940)] = 47126,
  [SMALL_STATE(941)] = 47162,
  [SMALL_STATE(942)] = 47224,
  [SMALL_STATE(943)] = 47276,
  [SMALL_STATE(944)] = 47328,
  [SMALL_STATE(945)] = 47380,
  [SMALL_STATE(946)] = 47416,
  [SMALL_STATE(947)] = 47452,
  [SMALL_STATE(948)] = 47504,
  [SMALL_STATE(949)] = 47542,
  [SMALL_STATE(950)] = 47580,
  [SMALL_STATE(951)] = 47616,
  [SMALL_STATE(952)] = 47652,
  [SMALL_STATE(953)] = 47714,
  [SMALL_STATE(954)] = 47776,
  [SMALL_STATE(955)] = 47812,
  [SMALL_STATE(956)] = 47864,
  [SMALL_STATE(957)] = 47900,
  [SMALL_STATE(958)] = 47952,
  [SMALL_STATE(959)] = 48004,
  [SMALL_STATE(960)] = 48045,
  [SMALL_STATE(961)] = 48076,
  [SMALL_STATE(962)] = 48109,
  [SMALL_STATE(963)] = 48160,
  [SMALL_STATE(964)] = 48201,
  [SMALL_STATE(965)] = 48232,
  [SMALL_STATE(966)] = 48263,
  [SMALL_STATE(967)] = 48296,
  [SMALL_STATE(968)] = 48347,
  [SMALL_STATE(969)] = 48382,
  [SMALL_STATE(970)] = 48415,
  [SMALL_STATE(971)] = 48456,
  [SMALL_STATE(972)] = 48487,
  [SMALL_STATE(973)] = 48538,
  [SMALL_STATE(974)] = 48589,
  [SMALL_STATE(975)] = 48630,
  [SMALL_STATE(976)] = 48671,
  [SMALL_STATE(977)] = 48706,
  [SMALL_STATE(978)] = 48752,
  [SMALL_STATE(979)] = 48782,
  [SMALL_STATE(980)] = 48840,
  [SMALL_STATE(981)] = 48886,
  [SMALL_STATE(982)] = 48916,
  [SMALL_STATE(983)] = 48946,
  [SMALL_STATE(984)] = 48980,
  [SMALL_STATE(985)] = 49026,
  [SMALL_STATE(986)] = 49060,
  [SMALL_STATE(987)] = 49118,
  [SMALL_STATE(988)] = 49148,
  [SMALL_STATE(989)] = 49182,
  [SMALL_STATE(990)] = 49212,
  [SMALL_STATE(991)] = 49246,
  [SMALL_STATE(992)] = 49278,
  [SMALL_STATE(993)] = 49308,
  [SMALL_STATE(994)] = 49354,
  [SMALL_STATE(995)] = 49388,
  [SMALL_STATE(996)] = 49418,
  [SMALL_STATE(997)] = 49448,
  [SMALL_STATE(998)] = 49494,
  [SMALL_STATE(999)] = 49524,
  [SMALL_STATE(1000)] = 49556,
  [SMALL_STATE(1001)] = 49602,
  [SMALL_STATE(1002)] = 49632,
  [SMALL_STATE(1003)] = 49678,
  [SMALL_STATE(1004)] = 49710,
  [SMALL_STATE(1005)] = 49757,
  [SMALL_STATE(1006)] = 49786,
  [SMALL_STATE(1007)] = 49831,
  [SMALL_STATE(1008)] = 49864,
  [SMALL_STATE(1009)] = 49897,
  [SMALL_STATE(1010)] = 49930,
  [SMALL_STATE(1011)] = 49963,
  [SMALL_STATE(1012)] = 49992,
  [SMALL_STATE(1013)] = 50039,
  [SMALL_STATE(1014)] = 50084,
  [SMALL_STATE(1015)] = 50129,
  [SMALL_STATE(1016)] = 50162,
  [SMALL_STATE(1017)] = 50195,
  [SMALL_STATE(1018)] = 50224,
  [SMALL_STATE(1019)] = 50269,
  [SMALL_STATE(1020)] = 50298,
  [SMALL_STATE(1021)] = 50345,
  [SMALL_STATE(1022)] = 50390,
  [SMALL_STATE(1023)] = 50435,
  [SMALL_STATE(1024)] = 50482,
  [SMALL_STATE(1025)] = 50527,
  [SMALL_STATE(1026)] = 50556,
  [SMALL_STATE(1027)] = 50600,
  [SMALL_STATE(1028)] = 50644,
  [SMALL_STATE(1029)] = 50676,
  [SMALL_STATE(1030)] = 50724,
  [SMALL_STATE(1031)] = 50756,
  [SMALL_STATE(1032)] = 50800,
  [SMALL_STATE(1033)] = 50836,
  [SMALL_STATE(1034)] = 50868,
  [SMALL_STATE(1035)] = 50900,
  [SMALL_STATE(1036)] = 50932,
  [SMALL_STATE(1037)] = 50968,
  [SMALL_STATE(1038)] = 50996,
  [SMALL_STATE(1039)] = 51024,
  [SMALL_STATE(1040)] = 51056,
  [SMALL_STATE(1041)] = 51084,
  [SMALL_STATE(1042)] = 51116,
  [SMALL_STATE(1043)] = 51160,
  [SMALL_STATE(1044)] = 51196,
  [SMALL_STATE(1045)] = 51228,
  [SMALL_STATE(1046)] = 51272,
  [SMALL_STATE(1047)] = 51308,
  [SMALL_STATE(1048)] = 51340,
  [SMALL_STATE(1049)] = 51379,
  [SMALL_STATE(1050)] = 51418,
  [SMALL_STATE(1051)] = 51445,
  [SMALL_STATE(1052)] = 51472,
  [SMALL_STATE(1053)] = 51499,
  [SMALL_STATE(1054)] = 51538,
  [SMALL_STATE(1055)] = 51571,
  [SMALL_STATE(1056)] = 51602,
  [SMALL_STATE(1057)] = 51629,
  [SMALL_STATE(1058)] = 51666,
  [SMALL_STATE(1059)] = 51697,
  [SMALL_STATE(1060)] = 51744,
  [SMALL_STATE(1061)] = 51771,
  [SMALL_STATE(1062)] = 51798,
  [SMALL_STATE(1063)] = 51825,
  [SMALL_STATE(1064)] = 51856,
  [SMALL_STATE(1065)] = 51883,
  [SMALL_STATE(1066)] = 51910,
  [SMALL_STATE(1067)] = 51937,
  [SMALL_STATE(1068)] = 51964,
  [SMALL_STATE(1069)] = 51991,
  [SMALL_STATE(1070)] = 52030,
  [SMALL_STATE(1071)] = 52069,
  [SMALL_STATE(1072)] = 52096,
  [SMALL_STATE(1073)] = 52123,
  [SMALL_STATE(1074)] = 52162,
  [SMALL_STATE(1075)] = 52189,
  [SMALL_STATE(1076)] = 52234,
  [SMALL_STATE(1077)] = 52261,
  [SMALL_STATE(1078)] = 52308,
  [SMALL_STATE(1079)] = 52347,
  [SMALL_STATE(1080)] = 52374,
  [SMALL_STATE(1081)] = 52401,
  [SMALL_STATE(1082)] = 52440,
  [SMALL_STATE(1083)] = 52467,
  [SMALL_STATE(1084)] = 52500,
  [SMALL_STATE(1085)] = 52531,
  [SMALL_STATE(1086)] = 52562,
  [SMALL_STATE(1087)] = 52589,
  [SMALL_STATE(1088)] = 52623,
  [SMALL_STATE(1089)] = 52667,
  [SMALL_STATE(1090)] = 52697,
  [SMALL_STATE(1091)] = 52727,
  [SMALL_STATE(1092)] = 52769,
  [SMALL_STATE(1093)] = 52803,
  [SMALL_STATE(1094)] = 52829,
  [SMALL_STATE(1095)] = 52873,
  [SMALL_STATE(1096)] = 52911,
  [SMALL_STATE(1097)] = 52937,
  [SMALL_STATE(1098)] = 52963,
  [SMALL_STATE(1099)] = 52993,
  [SMALL_STATE(1100)] = 53019,
  [SMALL_STATE(1101)] = 53045,
  [SMALL_STATE(1102)] = 53081,
  [SMALL_STATE(1103)] = 53107,
  [SMALL_STATE(1104)] = 53141,
  [SMALL_STATE(1105)] = 53167,
  [SMALL_STATE(1106)] = 53197,
  [SMALL_STATE(1107)] = 53227,
  [SMALL_STATE(1108)] = 53269,
  [SMALL_STATE(1109)] = 53303,
  [SMALL_STATE(1110)] = 53331,
  [SMALL_STATE(1111)] = 53371,
  [SMALL_STATE(1112)] = 53403,
  [SMALL_STATE(1113)] = 53433,
  [SMALL_STATE(1114)] = 53475,
  [SMALL_STATE(1115)] = 53499,
  [SMALL_STATE(1116)] = 53529,
  [SMALL_STATE(1117)] = 53571,
  [SMALL_STATE(1118)] = 53617,
  [SMALL_STATE(1119)] = 53651,
  [SMALL_STATE(1120)] = 53677,
  [SMALL_STATE(1121)] = 53707,
  [SMALL_STATE(1122)] = 53749,
  [SMALL_STATE(1123)] = 53775,
  [SMALL_STATE(1124)] = 53800,
  [SMALL_STATE(1125)] = 53825,
  [SMALL_STATE(1126)] = 53862,
  [SMALL_STATE(1127)] = 53905,
  [SMALL_STATE(1128)] = 53930,
  [SMALL_STATE(1129)] = 53969,
  [SMALL_STATE(1130)] = 54006,
  [SMALL_STATE(1131)] = 54031,
  [SMALL_STATE(1132)] = 54056,
  [SMALL_STATE(1133)] = 54093,
  [SMALL_STATE(1134)] = 54118,
  [SMALL_STATE(1135)] = 54143,
  [SMALL_STATE(1136)] = 54184,
  [SMALL_STATE(1137)] = 54209,
  [SMALL_STATE(1138)] = 54234,
  [SMALL_STATE(1139)] = 54259,
  [SMALL_STATE(1140)] = 54300,
  [SMALL_STATE(1141)] = 54325,
  [SMALL_STATE(1142)] = 54350,
  [SMALL_STATE(1143)] = 54375,
  [SMALL_STATE(1144)] = 54412,
  [SMALL_STATE(1145)] = 54435,
  [SMALL_STATE(1146)] = 54478,
  [SMALL_STATE(1147)] = 54513,
  [SMALL_STATE(1148)] = 54542,
  [SMALL_STATE(1149)] = 54565,
  [SMALL_STATE(1150)] = 54600,
  [SMALL_STATE(1151)] = 54625,
  [SMALL_STATE(1152)] = 54650,
  [SMALL_STATE(1153)] = 54675,
  [SMALL_STATE(1154)] = 54712,
  [SMALL_STATE(1155)] = 54749,
  [SMALL_STATE(1156)] = 54774,
  [SMALL_STATE(1157)] = 54799,
  [SMALL_STATE(1158)] = 54836,
  [SMALL_STATE(1159)] = 54873,
  [SMALL_STATE(1160)] = 54898,
  [SMALL_STATE(1161)] = 54939,
  [SMALL_STATE(1162)] = 54964,
  [SMALL_STATE(1163)] = 55001,
  [SMALL_STATE(1164)] = 55026,
  [SMALL_STATE(1165)] = 55051,
  [SMALL_STATE(1166)] = 55088,
  [SMALL_STATE(1167)] = 55131,
  [SMALL_STATE(1168)] = 55174,
  [SMALL_STATE(1169)] = 55203,
  [SMALL_STATE(1170)] = 55232,
  [SMALL_STATE(1171)] = 55269,
  [SMALL_STATE(1172)] = 55312,
  [SMALL_STATE(1173)] = 55337,
  [SMALL_STATE(1174)] = 55360,
  [SMALL_STATE(1175)] = 55400,
  [SMALL_STATE(1176)] = 55428,
  [SMALL_STATE(1177)] = 55462,
  [SMALL_STATE(1178)] = 55496,
  [SMALL_STATE(1179)] = 55542,
  [SMALL_STATE(1180)] = 55566,
  [SMALL_STATE(1181)] = 55594,
  [SMALL_STATE(1182)] = 55622,
  [SMALL_STATE(1183)] = 55646,
  [SMALL_STATE(1184)] = 55684,
  [SMALL_STATE(1185)] = 55712,
  [SMALL_STATE(1186)] = 55748,
  [SMALL_STATE(1187)] = 55784,
  [SMALL_STATE(1188)] = 55824,
  [SMALL_STATE(1189)] = 55856,
  [SMALL_STATE(1190)] = 55894,
  [SMALL_STATE(1191)] = 55920,
  [SMALL_STATE(1192)] = 55958,
  [SMALL_STATE(1193)] = 55996,
  [SMALL_STATE(1194)] = 56022,
  [SMALL_STATE(1195)] = 56046,
  [SMALL_STATE(1196)] = 56070,
  [SMALL_STATE(1197)] = 56094,
  [SMALL_STATE(1198)] = 56118,
  [SMALL_STATE(1199)] = 56142,
  [SMALL_STATE(1200)] = 56166,
  [SMALL_STATE(1201)] = 56190,
  [SMALL_STATE(1202)] = 56220,
  [SMALL_STATE(1203)] = 56252,
  [SMALL_STATE(1204)] = 56290,
  [SMALL_STATE(1205)] = 56320,
  [SMALL_STATE(1206)] = 56350,
  [SMALL_STATE(1207)] = 56380,
  [SMALL_STATE(1208)] = 56410,
  [SMALL_STATE(1209)] = 56440,
  [SMALL_STATE(1210)] = 56468,
  [SMALL_STATE(1211)] = 56506,
  [SMALL_STATE(1212)] = 56534,
  [SMALL_STATE(1213)] = 56562,
  [SMALL_STATE(1214)] = 56590,
  [SMALL_STATE(1215)] = 56618,
  [SMALL_STATE(1216)] = 56652,
  [SMALL_STATE(1217)] = 56692,
  [SMALL_STATE(1218)] = 56732,
  [SMALL_STATE(1219)] = 56756,
  [SMALL_STATE(1220)] = 56784,
  [SMALL_STATE(1221)] = 56808,
  [SMALL_STATE(1222)] = 56832,
  [SMALL_STATE(1223)] = 56856,
  [SMALL_STATE(1224)] = 56880,
  [SMALL_STATE(1225)] = 56904,
  [SMALL_STATE(1226)] = 56928,
  [SMALL_STATE(1227)] = 56952,
  [SMALL_STATE(1228)] = 56980,
  [SMALL_STATE(1229)] = 57014,
  [SMALL_STATE(1230)] = 57048,
  [SMALL_STATE(1231)] = 57084,
  [SMALL_STATE(1232)] = 57110,
  [SMALL_STATE(1233)] = 57136,
  [SMALL_STATE(1234)] = 57174,
  [SMALL_STATE(1235)] = 57200,
  [SMALL_STATE(1236)] = 57221,
  [SMALL_STATE(1237)] = 57256,
  [SMALL_STATE(1238)] = 57287,
  [SMALL_STATE(1239)] = 57310,
  [SMALL_STATE(1240)] = 57339,
  [SMALL_STATE(1241)] = 57364,
  [SMALL_STATE(1242)] = 57401,
  [SMALL_STATE(1243)] = 57446,
  [SMALL_STATE(1244)] = 57475,
  [SMALL_STATE(1245)] = 57504,
  [SMALL_STATE(1246)] = 57533,
  [SMALL_STATE(1247)] = 57566,
  [SMALL_STATE(1248)] = 57595,
  [SMALL_STATE(1249)] = 57624,
  [SMALL_STATE(1250)] = 57651,
  [SMALL_STATE(1251)] = 57678,
  [SMALL_STATE(1252)] = 57715,
  [SMALL_STATE(1253)] = 57742,
  [SMALL_STATE(1254)] = 57769,
  [SMALL_STATE(1255)] = 57802,
  [SMALL_STATE(1256)] = 57823,
  [SMALL_STATE(1257)] = 57844,
  [SMALL_STATE(1258)] = 57865,
  [SMALL_STATE(1259)] = 57898,
  [SMALL_STATE(1260)] = 57925,
  [SMALL_STATE(1261)] = 57958,
  [SMALL_STATE(1262)] = 57997,
  [SMALL_STATE(1263)] = 58034,
  [SMALL_STATE(1264)] = 58071,
  [SMALL_STATE(1265)] = 58100,
  [SMALL_STATE(1266)] = 58129,
  [SMALL_STATE(1267)] = 58158,
  [SMALL_STATE(1268)] = 58181,
  [SMALL_STATE(1269)] = 58210,
  [SMALL_STATE(1270)] = 58239,
  [SMALL_STATE(1271)] = 58266,
  [SMALL_STATE(1272)] = 58293,
  [SMALL_STATE(1273)] = 58332,
  [SMALL_STATE(1274)] = 58359,
  [SMALL_STATE(1275)] = 58386,
  [SMALL_STATE(1276)] = 58417,
  [SMALL_STATE(1277)] = 58444,
  [SMALL_STATE(1278)] = 58471,
  [SMALL_STATE(1279)] = 58502,
  [SMALL_STATE(1280)] = 58541,
  [SMALL_STATE(1281)] = 58572,
  [SMALL_STATE(1282)] = 58593,
  [SMALL_STATE(1283)] = 58632,
  [SMALL_STATE(1284)] = 58665,
  [SMALL_STATE(1285)] = 58688,
  [SMALL_STATE(1286)] = 58711,
  [SMALL_STATE(1287)] = 58732,
  [SMALL_STATE(1288)] = 58753,
  [SMALL_STATE(1289)] = 58786,
  [SMALL_STATE(1290)] = 58811,
  [SMALL_STATE(1291)] = 58848,
  [SMALL_STATE(1292)] = 58871,
  [SMALL_STATE(1293)] = 58894,
  [SMALL_STATE(1294)] = 58931,
  [SMALL_STATE(1295)] = 58954,
  [SMALL_STATE(1296)] = 58977,
  [SMALL_STATE(1297)] = 59014,
  [SMALL_STATE(1298)] = 59039,
  [SMALL_STATE(1299)] = 59062,
  [SMALL_STATE(1300)] = 59085,
  [SMALL_STATE(1301)] = 59122,
  [SMALL_STATE(1302)] = 59159,
  [SMALL_STATE(1303)] = 59182,
  [SMALL_STATE(1304)] = 59219,
  [SMALL_STATE(1305)] = 59242,
  [SMALL_STATE(1306)] = 59265,
  [SMALL_STATE(1307)] = 59286,
  [SMALL_STATE(1308)] = 59323,
  [SMALL_STATE(1309)] = 59362,
  [SMALL_STATE(1310)] = 59401,
  [SMALL_STATE(1311)] = 59424,
  [SMALL_STATE(1312)] = 59447,
  [SMALL_STATE(1313)] = 59470,
  [SMALL_STATE(1314)] = 59493,
  [SMALL_STATE(1315)] = 59516,
  [SMALL_STATE(1316)] = 59551,
  [SMALL_STATE(1317)] = 59578,
  [SMALL_STATE(1318)] = 59617,
  [SMALL_STATE(1319)] = 59640,
  [SMALL_STATE(1320)] = 59663,
  [SMALL_STATE(1321)] = 59686,
  [SMALL_STATE(1322)] = 59709,
  [SMALL_STATE(1323)] = 59732,
  [SMALL_STATE(1324)] = 59755,
  [SMALL_STATE(1325)] = 59778,
  [SMALL_STATE(1326)] = 59801,
  [SMALL_STATE(1327)] = 59824,
  [SMALL_STATE(1328)] = 59847,
  [SMALL_STATE(1329)] = 59870,
  [SMALL_STATE(1330)] = 59893,
  [SMALL_STATE(1331)] = 59926,
  [SMALL_STATE(1332)] = 59959,
  [SMALL_STATE(1333)] = 59986,
  [SMALL_STATE(1334)] = 60014,
  [SMALL_STATE(1335)] = 60042,
  [SMALL_STATE(1336)] = 60078,
  [SMALL_STATE(1337)] = 60110,
  [SMALL_STATE(1338)] = 60138,
  [SMALL_STATE(1339)] = 60160,
  [SMALL_STATE(1340)] = 60188,
  [SMALL_STATE(1341)] = 60208,
  [SMALL_STATE(1342)] = 60230,
  [SMALL_STATE(1343)] = 60252,
  [SMALL_STATE(1344)] = 60274,
  [SMALL_STATE(1345)] = 60296,
  [SMALL_STATE(1346)] = 60330,
  [SMALL_STATE(1347)] = 60358,
  [SMALL_STATE(1348)] = 60394,
  [SMALL_STATE(1349)] = 60422,
  [SMALL_STATE(1350)] = 60442,
  [SMALL_STATE(1351)] = 60462,
  [SMALL_STATE(1352)] = 60490,
  [SMALL_STATE(1353)] = 60512,
  [SMALL_STATE(1354)] = 60540,
  [SMALL_STATE(1355)] = 60568,
  [SMALL_STATE(1356)] = 60596,
  [SMALL_STATE(1357)] = 60630,
  [SMALL_STATE(1358)] = 60658,
  [SMALL_STATE(1359)] = 60696,
  [SMALL_STATE(1360)] = 60716,
  [SMALL_STATE(1361)] = 60756,
  [SMALL_STATE(1362)] = 60780,
  [SMALL_STATE(1363)] = 60802,
  [SMALL_STATE(1364)] = 60834,
  [SMALL_STATE(1365)] = 60862,
  [SMALL_STATE(1366)] = 60896,
  [SMALL_STATE(1367)] = 60922,
  [SMALL_STATE(1368)] = 60950,
  [SMALL_STATE(1369)] = 60978,
  [SMALL_STATE(1370)] = 61006,
  [SMALL_STATE(1371)] = 61034,
  [SMALL_STATE(1372)] = 61062,
  [SMALL_STATE(1373)] = 61084,
  [SMALL_STATE(1374)] = 61104,
  [SMALL_STATE(1375)] = 61140,
  [SMALL_STATE(1376)] = 61166,
  [SMALL_STATE(1377)] = 61186,
  [SMALL_STATE(1378)] = 61208,
  [SMALL_STATE(1379)] = 61244,
  [SMALL_STATE(1380)] = 61266,
  [SMALL_STATE(1381)] = 61288,
  [SMALL_STATE(1382)] = 61312,
  [SMALL_STATE(1383)] = 61346,
  [SMALL_STATE(1384)] = 61380,
  [SMALL_STATE(1385)] = 61414,
  [SMALL_STATE(1386)] = 61436,
  [SMALL_STATE(1387)] = 61458,
  [SMALL_STATE(1388)] = 61492,
  [SMALL_STATE(1389)] = 61526,
  [SMALL_STATE(1390)] = 61562,
  [SMALL_STATE(1391)] = 61588,
  [SMALL_STATE(1392)] = 61610,
  [SMALL_STATE(1393)] = 61630,
  [SMALL_STATE(1394)] = 61664,
  [SMALL_STATE(1395)] = 61686,
  [SMALL_STATE(1396)] = 61708,
  [SMALL_STATE(1397)] = 61742,
  [SMALL_STATE(1398)] = 61776,
  [SMALL_STATE(1399)] = 61810,
  [SMALL_STATE(1400)] = 61836,
  [SMALL_STATE(1401)] = 61864,
  [SMALL_STATE(1402)] = 61884,
  [SMALL_STATE(1403)] = 61918,
  [SMALL_STATE(1404)] = 61952,
  [SMALL_STATE(1405)] = 61980,
  [SMALL_STATE(1406)] = 62013,
  [SMALL_STATE(1407)] = 62032,
  [SMALL_STATE(1408)] = 62065,
  [SMALL_STATE(1409)] = 62092,
  [SMALL_STATE(1410)] = 62119,
  [SMALL_STATE(1411)] = 62146,
  [SMALL_STATE(1412)] = 62167,
  [SMALL_STATE(1413)] = 62192,
  [SMALL_STATE(1414)] = 62227,
  [SMALL_STATE(1415)] = 62252,
  [SMALL_STATE(1416)] = 62273,
  [SMALL_STATE(1417)] = 62306,
  [SMALL_STATE(1418)] = 62327,
  [SMALL_STATE(1419)] = 62362,
  [SMALL_STATE(1420)] = 62397,
  [SMALL_STATE(1421)] = 62418,
  [SMALL_STATE(1422)] = 62451,
  [SMALL_STATE(1423)] = 62484,
  [SMALL_STATE(1424)] = 62517,
  [SMALL_STATE(1425)] = 62538,
  [SMALL_STATE(1426)] = 62571,
  [SMALL_STATE(1427)] = 62604,
  [SMALL_STATE(1428)] = 62625,
  [SMALL_STATE(1429)] = 62658,
  [SMALL_STATE(1430)] = 62689,
  [SMALL_STATE(1431)] = 62724,
  [SMALL_STATE(1432)] = 62743,
  [SMALL_STATE(1433)] = 62762,
  [SMALL_STATE(1434)] = 62793,
  [SMALL_STATE(1435)] = 62826,
  [SMALL_STATE(1436)] = 62855,
  [SMALL_STATE(1437)] = 62888,
  [SMALL_STATE(1438)] = 62921,
  [SMALL_STATE(1439)] = 62954,
  [SMALL_STATE(1440)] = 62983,
  [SMALL_STATE(1441)] = 63010,
  [SMALL_STATE(1442)] = 63031,
  [SMALL_STATE(1443)] = 63052,
  [SMALL_STATE(1444)] = 63083,
  [SMALL_STATE(1445)] = 63116,
  [SMALL_STATE(1446)] = 63141,
  [SMALL_STATE(1447)] = 63168,
  [SMALL_STATE(1448)] = 63201,
  [SMALL_STATE(1449)] = 63234,
  [SMALL_STATE(1450)] = 63261,
  [SMALL_STATE(1451)] = 63294,
  [SMALL_STATE(1452)] = 63315,
  [SMALL_STATE(1453)] = 63336,
  [SMALL_STATE(1454)] = 63367,
  [SMALL_STATE(1455)] = 63400,
  [SMALL_STATE(1456)] = 63433,
  [SMALL_STATE(1457)] = 63466,
  [SMALL_STATE(1458)] = 63499,
  [SMALL_STATE(1459)] = 63528,
  [SMALL_STATE(1460)] = 63549,
  [SMALL_STATE(1461)] = 63576,
  [SMALL_STATE(1462)] = 63603,
  [SMALL_STATE(1463)] = 63630,
  [SMALL_STATE(1464)] = 63657,
  [SMALL_STATE(1465)] = 63682,
  [SMALL_STATE(1466)] = 63715,
  [SMALL_STATE(1467)] = 63756,
  [SMALL_STATE(1468)] = 63783,
  [SMALL_STATE(1469)] = 63808,
  [SMALL_STATE(1470)] = 63843,
  [SMALL_STATE(1471)] = 63878,
  [SMALL_STATE(1472)] = 63903,
  [SMALL_STATE(1473)] = 63944,
  [SMALL_STATE(1474)] = 63981,
  [SMALL_STATE(1475)] = 64014,
  [SMALL_STATE(1476)] = 64047,
  [SMALL_STATE(1477)] = 64080,
  [SMALL_STATE(1478)] = 64113,
  [SMALL_STATE(1479)] = 64146,
  [SMALL_STATE(1480)] = 64177,
  [SMALL_STATE(1481)] = 64204,
  [SMALL_STATE(1482)] = 64237,
  [SMALL_STATE(1483)] = 64266,
  [SMALL_STATE(1484)] = 64293,
  [SMALL_STATE(1485)] = 64320,
  [SMALL_STATE(1486)] = 64353,
  [SMALL_STATE(1487)] = 64386,
  [SMALL_STATE(1488)] = 64419,
  [SMALL_STATE(1489)] = 64444,
  [SMALL_STATE(1490)] = 64473,
  [SMALL_STATE(1491)] = 64506,
  [SMALL_STATE(1492)] = 64535,
  [SMALL_STATE(1493)] = 64560,
  [SMALL_STATE(1494)] = 64589,
  [SMALL_STATE(1495)] = 64628,
  [SMALL_STATE(1496)] = 64653,
  [SMALL_STATE(1497)] = 64686,
  [SMALL_STATE(1498)] = 64719,
  [SMALL_STATE(1499)] = 64752,
  [SMALL_STATE(1500)] = 64773,
  [SMALL_STATE(1501)] = 64794,
  [SMALL_STATE(1502)] = 64819,
  [SMALL_STATE(1503)] = 64848,
  [SMALL_STATE(1504)] = 64875,
  [SMALL_STATE(1505)] = 64902,
  [SMALL_STATE(1506)] = 64935,
  [SMALL_STATE(1507)] = 64956,
  [SMALL_STATE(1508)] = 64977,
  [SMALL_STATE(1509)] = 65004,
  [SMALL_STATE(1510)] = 65037,
  [SMALL_STATE(1511)] = 65068,
  [SMALL_STATE(1512)] = 65101,
  [SMALL_STATE(1513)] = 65134,
  [SMALL_STATE(1514)] = 65155,
  [SMALL_STATE(1515)] = 65174,
  [SMALL_STATE(1516)] = 65195,
  [SMALL_STATE(1517)] = 65216,
  [SMALL_STATE(1518)] = 65247,
  [SMALL_STATE(1519)] = 65276,
  [SMALL_STATE(1520)] = 65305,
  [SMALL_STATE(1521)] = 65336,
  [SMALL_STATE(1522)] = 65369,
  [SMALL_STATE(1523)] = 65394,
  [SMALL_STATE(1524)] = 65427,
  [SMALL_STATE(1525)] = 65460,
  [SMALL_STATE(1526)] = 65493,
  [SMALL_STATE(1527)] = 65526,
  [SMALL_STATE(1528)] = 65559,
  [SMALL_STATE(1529)] = 65592,
  [SMALL_STATE(1530)] = 65625,
  [SMALL_STATE(1531)] = 65658,
  [SMALL_STATE(1532)] = 65691,
  [SMALL_STATE(1533)] = 65724,
  [SMALL_STATE(1534)] = 65757,
  [SMALL_STATE(1535)] = 65790,
  [SMALL_STATE(1536)] = 65823,
  [SMALL_STATE(1537)] = 65856,
  [SMALL_STATE(1538)] = 65889,
  [SMALL_STATE(1539)] = 65922,
  [SMALL_STATE(1540)] = 65955,
  [SMALL_STATE(1541)] = 65988,
  [SMALL_STATE(1542)] = 66021,
  [SMALL_STATE(1543)] = 66054,
  [SMALL_STATE(1544)] = 66087,
  [SMALL_STATE(1545)] = 66120,
  [SMALL_STATE(1546)] = 66153,
  [SMALL_STATE(1547)] = 66186,
  [SMALL_STATE(1548)] = 66219,
  [SMALL_STATE(1549)] = 66246,
  [SMALL_STATE(1550)] = 66272,
  [SMALL_STATE(1551)] = 66298,
  [SMALL_STATE(1552)] = 66316,
  [SMALL_STATE(1553)] = 66336,
  [SMALL_STATE(1554)] = 66366,
  [SMALL_STATE(1555)] = 66390,
  [SMALL_STATE(1556)] = 66420,
  [SMALL_STATE(1557)] = 66450,
  [SMALL_STATE(1558)] = 66480,
  [SMALL_STATE(1559)] = 66500,
  [SMALL_STATE(1560)] = 66530,
  [SMALL_STATE(1561)] = 66558,
  [SMALL_STATE(1562)] = 66580,
  [SMALL_STATE(1563)] = 66600,
  [SMALL_STATE(1564)] = 66630,
  [SMALL_STATE(1565)] = 66658,
  [SMALL_STATE(1566)] = 66676,
  [SMALL_STATE(1567)] = 66700,
  [SMALL_STATE(1568)] = 66730,
  [SMALL_STATE(1569)] = 66760,
  [SMALL_STATE(1570)] = 66790,
  [SMALL_STATE(1571)] = 66808,
  [SMALL_STATE(1572)] = 66838,
  [SMALL_STATE(1573)] = 66862,
  [SMALL_STATE(1574)] = 66888,
  [SMALL_STATE(1575)] = 66912,
  [SMALL_STATE(1576)] = 66936,
  [SMALL_STATE(1577)] = 66966,
  [SMALL_STATE(1578)] = 66996,
  [SMALL_STATE(1579)] = 67020,
  [SMALL_STATE(1580)] = 67044,
  [SMALL_STATE(1581)] = 67070,
  [SMALL_STATE(1582)] = 67100,
  [SMALL_STATE(1583)] = 67128,
  [SMALL_STATE(1584)] = 67156,
  [SMALL_STATE(1585)] = 67186,
  [SMALL_STATE(1586)] = 67216,
  [SMALL_STATE(1587)] = 67246,
  [SMALL_STATE(1588)] = 67274,
  [SMALL_STATE(1589)] = 67304,
  [SMALL_STATE(1590)] = 67334,
  [SMALL_STATE(1591)] = 67364,
  [SMALL_STATE(1592)] = 67382,
  [SMALL_STATE(1593)] = 67400,
  [SMALL_STATE(1594)] = 67426,
  [SMALL_STATE(1595)] = 67444,
  [SMALL_STATE(1596)] = 67462,
  [SMALL_STATE(1597)] = 67492,
  [SMALL_STATE(1598)] = 67512,
  [SMALL_STATE(1599)] = 67542,
  [SMALL_STATE(1600)] = 67562,
  [SMALL_STATE(1601)] = 67592,
  [SMALL_STATE(1602)] = 67612,
  [SMALL_STATE(1603)] = 67630,
  [SMALL_STATE(1604)] = 67648,
  [SMALL_STATE(1605)] = 67666,
  [SMALL_STATE(1606)] = 67688,
  [SMALL_STATE(1607)] = 67716,
  [SMALL_STATE(1608)] = 67746,
  [SMALL_STATE(1609)] = 67776,
  [SMALL_STATE(1610)] = 67806,
  [SMALL_STATE(1611)] = 67836,
  [SMALL_STATE(1612)] = 67866,
  [SMALL_STATE(1613)] = 67886,
  [SMALL_STATE(1614)] = 67906,
  [SMALL_STATE(1615)] = 67926,
  [SMALL_STATE(1616)] = 67946,
  [SMALL_STATE(1617)] = 67966,
  [SMALL_STATE(1618)] = 67996,
  [SMALL_STATE(1619)] = 68022,
  [SMALL_STATE(1620)] = 68042,
  [SMALL_STATE(1621)] = 68062,
  [SMALL_STATE(1622)] = 68092,
  [SMALL_STATE(1623)] = 68118,
  [SMALL_STATE(1624)] = 68138,
  [SMALL_STATE(1625)] = 68162,
  [SMALL_STATE(1626)] = 68180,
  [SMALL_STATE(1627)] = 68198,
  [SMALL_STATE(1628)] = 68228,
  [SMALL_STATE(1629)] = 68258,
  [SMALL_STATE(1630)] = 68284,
  [SMALL_STATE(1631)] = 68308,
  [SMALL_STATE(1632)] = 68338,
  [SMALL_STATE(1633)] = 68368,
  [SMALL_STATE(1634)] = 68395,
  [SMALL_STATE(1635)] = 68414,
  [SMALL_STATE(1636)] = 68443,
  [SMALL_STATE(1637)] = 68470,
  [SMALL_STATE(1638)] = 68487,
  [SMALL_STATE(1639)] = 68514,
  [SMALL_STATE(1640)] = 68541,
  [SMALL_STATE(1641)] = 68560,
  [SMALL_STATE(1642)] = 68587,
  [SMALL_STATE(1643)] = 68614,
  [SMALL_STATE(1644)] = 68633,
  [SMALL_STATE(1645)] = 68660,
  [SMALL_STATE(1646)] = 68687,
  [SMALL_STATE(1647)] = 68716,
  [SMALL_STATE(1648)] = 68743,
  [SMALL_STATE(1649)] = 68762,
  [SMALL_STATE(1650)] = 68791,
  [SMALL_STATE(1651)] = 68810,
  [SMALL_STATE(1652)] = 68829,
  [SMALL_STATE(1653)] = 68846,
  [SMALL_STATE(1654)] = 68863,
  [SMALL_STATE(1655)] = 68890,
  [SMALL_STATE(1656)] = 68919,
  [SMALL_STATE(1657)] = 68942,
  [SMALL_STATE(1658)] = 68969,
  [SMALL_STATE(1659)] = 68996,
  [SMALL_STATE(1660)] = 69015,
  [SMALL_STATE(1661)] = 69042,
  [SMALL_STATE(1662)] = 69069,
  [SMALL_STATE(1663)] = 69092,
  [SMALL_STATE(1664)] = 69111,
  [SMALL_STATE(1665)] = 69132,
  [SMALL_STATE(1666)] = 69159,
  [SMALL_STATE(1667)] = 69186,
  [SMALL_STATE(1668)] = 69213,
  [SMALL_STATE(1669)] = 69240,
  [SMALL_STATE(1670)] = 69259,
  [SMALL_STATE(1671)] = 69286,
  [SMALL_STATE(1672)] = 69305,
  [SMALL_STATE(1673)] = 69332,
  [SMALL_STATE(1674)] = 69351,
  [SMALL_STATE(1675)] = 69370,
  [SMALL_STATE(1676)] = 69389,
  [SMALL_STATE(1677)] = 69408,
  [SMALL_STATE(1678)] = 69427,
  [SMALL_STATE(1679)] = 69456,
  [SMALL_STATE(1680)] = 69475,
  [SMALL_STATE(1681)] = 69502,
  [SMALL_STATE(1682)] = 69529,
  [SMALL_STATE(1683)] = 69548,
  [SMALL_STATE(1684)] = 69575,
  [SMALL_STATE(1685)] = 69592,
  [SMALL_STATE(1686)] = 69619,
  [SMALL_STATE(1687)] = 69646,
  [SMALL_STATE(1688)] = 69669,
  [SMALL_STATE(1689)] = 69696,
  [SMALL_STATE(1690)] = 69715,
  [SMALL_STATE(1691)] = 69742,
  [SMALL_STATE(1692)] = 69761,
  [SMALL_STATE(1693)] = 69780,
  [SMALL_STATE(1694)] = 69799,
  [SMALL_STATE(1695)] = 69826,
  [SMALL_STATE(1696)] = 69849,
  [SMALL_STATE(1697)] = 69872,
  [SMALL_STATE(1698)] = 69899,
  [SMALL_STATE(1699)] = 69928,
  [SMALL_STATE(1700)] = 69955,
  [SMALL_STATE(1701)] = 69974,
  [SMALL_STATE(1702)] = 69993,
  [SMALL_STATE(1703)] = 70012,
  [SMALL_STATE(1704)] = 70034,
  [SMALL_STATE(1705)] = 70052,
  [SMALL_STATE(1706)] = 70070,
  [SMALL_STATE(1707)] = 70092,
  [SMALL_STATE(1708)] = 70118,
  [SMALL_STATE(1709)] = 70136,
  [SMALL_STATE(1710)] = 70154,
  [SMALL_STATE(1711)] = 70172,
  [SMALL_STATE(1712)] = 70190,
  [SMALL_STATE(1713)] = 70216,
  [SMALL_STATE(1714)] = 70238,
  [SMALL_STATE(1715)] = 70260,
  [SMALL_STATE(1716)] = 70278,
  [SMALL_STATE(1717)] = 70300,
  [SMALL_STATE(1718)] = 70324,
  [SMALL_STATE(1719)] = 70348,
  [SMALL_STATE(1720)] = 70370,
  [SMALL_STATE(1721)] = 70388,
  [SMALL_STATE(1722)] = 70412,
  [SMALL_STATE(1723)] = 70434,
  [SMALL_STATE(1724)] = 70462,
  [SMALL_STATE(1725)] = 70488,
  [SMALL_STATE(1726)] = 70512,
  [SMALL_STATE(1727)] = 70540,
  [SMALL_STATE(1728)] = 70566,
  [SMALL_STATE(1729)] = 70594,
  [SMALL_STATE(1730)] = 70618,
  [SMALL_STATE(1731)] = 70640,
  [SMALL_STATE(1732)] = 70666,
  [SMALL_STATE(1733)] = 70684,
  [SMALL_STATE(1734)] = 70704,
  [SMALL_STATE(1735)] = 70732,
  [SMALL_STATE(1736)] = 70750,
  [SMALL_STATE(1737)] = 70766,
  [SMALL_STATE(1738)] = 70788,
  [SMALL_STATE(1739)] = 70810,
  [SMALL_STATE(1740)] = 70834,
  [SMALL_STATE(1741)] = 70856,
  [SMALL_STATE(1742)] = 70874,
  [SMALL_STATE(1743)] = 70892,
  [SMALL_STATE(1744)] = 70920,
  [SMALL_STATE(1745)] = 70938,
  [SMALL_STATE(1746)] = 70966,
  [SMALL_STATE(1747)] = 70992,
  [SMALL_STATE(1748)] = 71010,
  [SMALL_STATE(1749)] = 71028,
  [SMALL_STATE(1750)] = 71054,
  [SMALL_STATE(1751)] = 71074,
  [SMALL_STATE(1752)] = 71092,
  [SMALL_STATE(1753)] = 71110,
  [SMALL_STATE(1754)] = 71128,
  [SMALL_STATE(1755)] = 71154,
  [SMALL_STATE(1756)] = 71182,
  [SMALL_STATE(1757)] = 71206,
  [SMALL_STATE(1758)] = 71234,
  [SMALL_STATE(1759)] = 71262,
  [SMALL_STATE(1760)] = 71280,
  [SMALL_STATE(1761)] = 71298,
  [SMALL_STATE(1762)] = 71326,
  [SMALL_STATE(1763)] = 71346,
  [SMALL_STATE(1764)] = 71368,
  [SMALL_STATE(1765)] = 71390,
  [SMALL_STATE(1766)] = 71412,
  [SMALL_STATE(1767)] = 71434,
  [SMALL_STATE(1768)] = 71454,
  [SMALL_STATE(1769)] = 71480,
  [SMALL_STATE(1770)] = 71498,
  [SMALL_STATE(1771)] = 71524,
  [SMALL_STATE(1772)] = 71550,
  [SMALL_STATE(1773)] = 71570,
  [SMALL_STATE(1774)] = 71596,
  [SMALL_STATE(1775)] = 71616,
  [SMALL_STATE(1776)] = 71644,
  [SMALL_STATE(1777)] = 71670,
  [SMALL_STATE(1778)] = 71688,
  [SMALL_STATE(1779)] = 71706,
  [SMALL_STATE(1780)] = 71732,
  [SMALL_STATE(1781)] = 71758,
  [SMALL_STATE(1782)] = 71778,
  [SMALL_STATE(1783)] = 71800,
  [SMALL_STATE(1784)] = 71816,
  [SMALL_STATE(1785)] = 71836,
  [SMALL_STATE(1786)] = 71856,
  [SMALL_STATE(1787)] = 71882,
  [SMALL_STATE(1788)] = 71900,
  [SMALL_STATE(1789)] = 71920,
  [SMALL_STATE(1790)] = 71942,
  [SMALL_STATE(1791)] = 71968,
  [SMALL_STATE(1792)] = 71994,
  [SMALL_STATE(1793)] = 72013,
  [SMALL_STATE(1794)] = 72040,
  [SMALL_STATE(1795)] = 72065,
  [SMALL_STATE(1796)] = 72090,
  [SMALL_STATE(1797)] = 72107,
  [SMALL_STATE(1798)] = 72128,
  [SMALL_STATE(1799)] = 72149,
  [SMALL_STATE(1800)] = 72170,
  [SMALL_STATE(1801)] = 72195,
  [SMALL_STATE(1802)] = 72214,
  [SMALL_STATE(1803)] = 72239,
  [SMALL_STATE(1804)] = 72264,
  [SMALL_STATE(1805)] = 72281,
  [SMALL_STATE(1806)] = 72306,
  [SMALL_STATE(1807)] = 72331,
  [SMALL_STATE(1808)] = 72352,
  [SMALL_STATE(1809)] = 72377,
  [SMALL_STATE(1810)] = 72400,
  [SMALL_STATE(1811)] = 72423,
  [SMALL_STATE(1812)] = 72446,
  [SMALL_STATE(1813)] = 72463,
  [SMALL_STATE(1814)] = 72492,
  [SMALL_STATE(1815)] = 72509,
  [SMALL_STATE(1816)] = 72530,
  [SMALL_STATE(1817)] = 72553,
  [SMALL_STATE(1818)] = 72568,
  [SMALL_STATE(1819)] = 72583,
  [SMALL_STATE(1820)] = 72598,
  [SMALL_STATE(1821)] = 72619,
  [SMALL_STATE(1822)] = 72646,
  [SMALL_STATE(1823)] = 72661,
  [SMALL_STATE(1824)] = 72676,
  [SMALL_STATE(1825)] = 72697,
  [SMALL_STATE(1826)] = 72718,
  [SMALL_STATE(1827)] = 72733,
  [SMALL_STATE(1828)] = 72758,
  [SMALL_STATE(1829)] = 72783,
  [SMALL_STATE(1830)] = 72808,
  [SMALL_STATE(1831)] = 72837,
  [SMALL_STATE(1832)] = 72854,
  [SMALL_STATE(1833)] = 72879,
  [SMALL_STATE(1834)] = 72894,
  [SMALL_STATE(1835)] = 72919,
  [SMALL_STATE(1836)] = 72938,
  [SMALL_STATE(1837)] = 72953,
  [SMALL_STATE(1838)] = 72982,
  [SMALL_STATE(1839)] = 72999,
  [SMALL_STATE(1840)] = 73022,
  [SMALL_STATE(1841)] = 73047,
  [SMALL_STATE(1842)] = 73068,
  [SMALL_STATE(1843)] = 73083,
  [SMALL_STATE(1844)] = 73112,
  [SMALL_STATE(1845)] = 73137,
  [SMALL_STATE(1846)] = 73160,
  [SMALL_STATE(1847)] = 73177,
  [SMALL_STATE(1848)] = 73200,
  [SMALL_STATE(1849)] = 73217,
  [SMALL_STATE(1850)] = 73236,
  [SMALL_STATE(1851)] = 73255,
  [SMALL_STATE(1852)] = 73274,
  [SMALL_STATE(1853)] = 73291,
  [SMALL_STATE(1854)] = 73308,
  [SMALL_STATE(1855)] = 73337,
  [SMALL_STATE(1856)] = 73358,
  [SMALL_STATE(1857)] = 73381,
  [SMALL_STATE(1858)] = 73398,
  [SMALL_STATE(1859)] = 73421,
  [SMALL_STATE(1860)] = 73444,
  [SMALL_STATE(1861)] = 73465,
  [SMALL_STATE(1862)] = 73482,
  [SMALL_STATE(1863)] = 73503,
  [SMALL_STATE(1864)] = 73524,
  [SMALL_STATE(1865)] = 73545,
  [SMALL_STATE(1866)] = 73562,
  [SMALL_STATE(1867)] = 73583,
  [SMALL_STATE(1868)] = 73598,
  [SMALL_STATE(1869)] = 73621,
  [SMALL_STATE(1870)] = 73644,
  [SMALL_STATE(1871)] = 73665,
  [SMALL_STATE(1872)] = 73686,
  [SMALL_STATE(1873)] = 73707,
  [SMALL_STATE(1874)] = 73728,
  [SMALL_STATE(1875)] = 73745,
  [SMALL_STATE(1876)] = 73770,
  [SMALL_STATE(1877)] = 73791,
  [SMALL_STATE(1878)] = 73808,
  [SMALL_STATE(1879)] = 73831,
  [SMALL_STATE(1880)] = 73848,
  [SMALL_STATE(1881)] = 73873,
  [SMALL_STATE(1882)] = 73898,
  [SMALL_STATE(1883)] = 73923,
  [SMALL_STATE(1884)] = 73940,
  [SMALL_STATE(1885)] = 73959,
  [SMALL_STATE(1886)] = 73986,
  [SMALL_STATE(1887)] = 74011,
  [SMALL_STATE(1888)] = 74038,
  [SMALL_STATE(1889)] = 74061,
  [SMALL_STATE(1890)] = 74080,
  [SMALL_STATE(1891)] = 74109,
  [SMALL_STATE(1892)] = 74132,
  [SMALL_STATE(1893)] = 74155,
  [SMALL_STATE(1894)] = 74180,
  [SMALL_STATE(1895)] = 74205,
  [SMALL_STATE(1896)] = 74232,
  [SMALL_STATE(1897)] = 74247,
  [SMALL_STATE(1898)] = 74270,
  [SMALL_STATE(1899)] = 74286,
  [SMALL_STATE(1900)] = 74310,
  [SMALL_STATE(1901)] = 74334,
  [SMALL_STATE(1902)] = 74354,
  [SMALL_STATE(1903)] = 74378,
  [SMALL_STATE(1904)] = 74394,
  [SMALL_STATE(1905)] = 74412,
  [SMALL_STATE(1906)] = 74434,
  [SMALL_STATE(1907)] = 74456,
  [SMALL_STATE(1908)] = 74476,
  [SMALL_STATE(1909)] = 74494,
  [SMALL_STATE(1910)] = 74514,
  [SMALL_STATE(1911)] = 74540,
  [SMALL_STATE(1912)] = 74558,
  [SMALL_STATE(1913)] = 74580,
  [SMALL_STATE(1914)] = 74602,
  [SMALL_STATE(1915)] = 74618,
  [SMALL_STATE(1916)] = 74636,
  [SMALL_STATE(1917)] = 74658,
  [SMALL_STATE(1918)] = 74680,
  [SMALL_STATE(1919)] = 74696,
  [SMALL_STATE(1920)] = 74712,
  [SMALL_STATE(1921)] = 74732,
  [SMALL_STATE(1922)] = 74748,
  [SMALL_STATE(1923)] = 74772,
  [SMALL_STATE(1924)] = 74788,
  [SMALL_STATE(1925)] = 74804,
  [SMALL_STATE(1926)] = 74820,
  [SMALL_STATE(1927)] = 74844,
  [SMALL_STATE(1928)] = 74868,
  [SMALL_STATE(1929)] = 74888,
  [SMALL_STATE(1930)] = 74910,
  [SMALL_STATE(1931)] = 74932,
  [SMALL_STATE(1932)] = 74950,
  [SMALL_STATE(1933)] = 74970,
  [SMALL_STATE(1934)] = 74992,
  [SMALL_STATE(1935)] = 75008,
  [SMALL_STATE(1936)] = 75024,
  [SMALL_STATE(1937)] = 75046,
  [SMALL_STATE(1938)] = 75062,
  [SMALL_STATE(1939)] = 75082,
  [SMALL_STATE(1940)] = 75104,
  [SMALL_STATE(1941)] = 75120,
  [SMALL_STATE(1942)] = 75142,
  [SMALL_STATE(1943)] = 75160,
  [SMALL_STATE(1944)] = 75182,
  [SMALL_STATE(1945)] = 75204,
  [SMALL_STATE(1946)] = 75228,
  [SMALL_STATE(1947)] = 75244,
  [SMALL_STATE(1948)] = 75268,
  [SMALL_STATE(1949)] = 75294,
  [SMALL_STATE(1950)] = 75314,
  [SMALL_STATE(1951)] = 75336,
  [SMALL_STATE(1952)] = 75358,
  [SMALL_STATE(1953)] = 75378,
  [SMALL_STATE(1954)] = 75396,
  [SMALL_STATE(1955)] = 75416,
  [SMALL_STATE(1956)] = 75440,
  [SMALL_STATE(1957)] = 75462,
  [SMALL_STATE(1958)] = 75480,
  [SMALL_STATE(1959)] = 75500,
  [SMALL_STATE(1960)] = 75526,
  [SMALL_STATE(1961)] = 75542,
  [SMALL_STATE(1962)] = 75566,
  [SMALL_STATE(1963)] = 75582,
  [SMALL_STATE(1964)] = 75604,
  [SMALL_STATE(1965)] = 75626,
  [SMALL_STATE(1966)] = 75646,
  [SMALL_STATE(1967)] = 75670,
  [SMALL_STATE(1968)] = 75688,
  [SMALL_STATE(1969)] = 75708,
  [SMALL_STATE(1970)] = 75732,
  [SMALL_STATE(1971)] = 75756,
  [SMALL_STATE(1972)] = 75780,
  [SMALL_STATE(1973)] = 75806,
  [SMALL_STATE(1974)] = 75830,
  [SMALL_STATE(1975)] = 75850,
  [SMALL_STATE(1976)] = 75872,
  [SMALL_STATE(1977)] = 75890,
  [SMALL_STATE(1978)] = 75908,
  [SMALL_STATE(1979)] = 75930,
  [SMALL_STATE(1980)] = 75952,
  [SMALL_STATE(1981)] = 75974,
  [SMALL_STATE(1982)] = 75992,
  [SMALL_STATE(1983)] = 76014,
  [SMALL_STATE(1984)] = 76032,
  [SMALL_STATE(1985)] = 76054,
  [SMALL_STATE(1986)] = 76078,
  [SMALL_STATE(1987)] = 76102,
  [SMALL_STATE(1988)] = 76126,
  [SMALL_STATE(1989)] = 76150,
  [SMALL_STATE(1990)] = 76172,
  [SMALL_STATE(1991)] = 76191,
  [SMALL_STATE(1992)] = 76210,
  [SMALL_STATE(1993)] = 76231,
  [SMALL_STATE(1994)] = 76244,
  [SMALL_STATE(1995)] = 76257,
  [SMALL_STATE(1996)] = 76274,
  [SMALL_STATE(1997)] = 76295,
  [SMALL_STATE(1998)] = 76312,
  [SMALL_STATE(1999)] = 76335,
  [SMALL_STATE(2000)] = 76352,
  [SMALL_STATE(2001)] = 76371,
  [SMALL_STATE(2002)] = 76388,
  [SMALL_STATE(2003)] = 76405,
  [SMALL_STATE(2004)] = 76420,
  [SMALL_STATE(2005)] = 76439,
  [SMALL_STATE(2006)] = 76458,
  [SMALL_STATE(2007)] = 76471,
  [SMALL_STATE(2008)] = 76488,
  [SMALL_STATE(2009)] = 76505,
  [SMALL_STATE(2010)] = 76524,
  [SMALL_STATE(2011)] = 76543,
  [SMALL_STATE(2012)] = 76562,
  [SMALL_STATE(2013)] = 76581,
  [SMALL_STATE(2014)] = 76600,
  [SMALL_STATE(2015)] = 76619,
  [SMALL_STATE(2016)] = 76638,
  [SMALL_STATE(2017)] = 76657,
  [SMALL_STATE(2018)] = 76672,
  [SMALL_STATE(2019)] = 76685,
  [SMALL_STATE(2020)] = 76698,
  [SMALL_STATE(2021)] = 76719,
  [SMALL_STATE(2022)] = 76740,
  [SMALL_STATE(2023)] = 76757,
  [SMALL_STATE(2024)] = 76772,
  [SMALL_STATE(2025)] = 76791,
  [SMALL_STATE(2026)] = 76810,
  [SMALL_STATE(2027)] = 76829,
  [SMALL_STATE(2028)] = 76848,
  [SMALL_STATE(2029)] = 76861,
  [SMALL_STATE(2030)] = 76884,
  [SMALL_STATE(2031)] = 76897,
  [SMALL_STATE(2032)] = 76910,
  [SMALL_STATE(2033)] = 76925,
  [SMALL_STATE(2034)] = 76944,
  [SMALL_STATE(2035)] = 76961,
  [SMALL_STATE(2036)] = 76980,
  [SMALL_STATE(2037)] = 76995,
  [SMALL_STATE(2038)] = 77016,
  [SMALL_STATE(2039)] = 77037,
  [SMALL_STATE(2040)] = 77056,
  [SMALL_STATE(2041)] = 77079,
  [SMALL_STATE(2042)] = 77100,
  [SMALL_STATE(2043)] = 77121,
  [SMALL_STATE(2044)] = 77134,
  [SMALL_STATE(2045)] = 77153,
  [SMALL_STATE(2046)] = 77166,
  [SMALL_STATE(2047)] = 77185,
  [SMALL_STATE(2048)] = 77204,
  [SMALL_STATE(2049)] = 77223,
  [SMALL_STATE(2050)] = 77242,
  [SMALL_STATE(2051)] = 77263,
  [SMALL_STATE(2052)] = 77284,
  [SMALL_STATE(2053)] = 77297,
  [SMALL_STATE(2054)] = 77316,
  [SMALL_STATE(2055)] = 77331,
  [SMALL_STATE(2056)] = 77350,
  [SMALL_STATE(2057)] = 77369,
  [SMALL_STATE(2058)] = 77388,
  [SMALL_STATE(2059)] = 77407,
  [SMALL_STATE(2060)] = 77426,
  [SMALL_STATE(2061)] = 77445,
  [SMALL_STATE(2062)] = 77464,
  [SMALL_STATE(2063)] = 77483,
  [SMALL_STATE(2064)] = 77504,
  [SMALL_STATE(2065)] = 77523,
  [SMALL_STATE(2066)] = 77542,
  [SMALL_STATE(2067)] = 77561,
  [SMALL_STATE(2068)] = 77580,
  [SMALL_STATE(2069)] = 77599,
  [SMALL_STATE(2070)] = 77618,
  [SMALL_STATE(2071)] = 77631,
  [SMALL_STATE(2072)] = 77650,
  [SMALL_STATE(2073)] = 77671,
  [SMALL_STATE(2074)] = 77686,
  [SMALL_STATE(2075)] = 77701,
  [SMALL_STATE(2076)] = 77714,
  [SMALL_STATE(2077)] = 77731,
  [SMALL_STATE(2078)] = 77752,
  [SMALL_STATE(2079)] = 77775,
  [SMALL_STATE(2080)] = 77790,
  [SMALL_STATE(2081)] = 77805,
  [SMALL_STATE(2082)] = 77822,
  [SMALL_STATE(2083)] = 77843,
  [SMALL_STATE(2084)] = 77864,
  [SMALL_STATE(2085)] = 77879,
  [SMALL_STATE(2086)] = 77896,
  [SMALL_STATE(2087)] = 77911,
  [SMALL_STATE(2088)] = 77926,
  [SMALL_STATE(2089)] = 77941,
  [SMALL_STATE(2090)] = 77954,
  [SMALL_STATE(2091)] = 77977,
  [SMALL_STATE(2092)] = 77990,
  [SMALL_STATE(2093)] = 78003,
  [SMALL_STATE(2094)] = 78026,
  [SMALL_STATE(2095)] = 78043,
  [SMALL_STATE(2096)] = 78058,
  [SMALL_STATE(2097)] = 78079,
  [SMALL_STATE(2098)] = 78100,
  [SMALL_STATE(2099)] = 78113,
  [SMALL_STATE(2100)] = 78128,
  [SMALL_STATE(2101)] = 78147,
  [SMALL_STATE(2102)] = 78166,
  [SMALL_STATE(2103)] = 78183,
  [SMALL_STATE(2104)] = 78204,
  [SMALL_STATE(2105)] = 78223,
  [SMALL_STATE(2106)] = 78236,
  [SMALL_STATE(2107)] = 78251,
  [SMALL_STATE(2108)] = 78264,
  [SMALL_STATE(2109)] = 78283,
  [SMALL_STATE(2110)] = 78300,
  [SMALL_STATE(2111)] = 78319,
  [SMALL_STATE(2112)] = 78334,
  [SMALL_STATE(2113)] = 78349,
  [SMALL_STATE(2114)] = 78364,
  [SMALL_STATE(2115)] = 78383,
  [SMALL_STATE(2116)] = 78402,
  [SMALL_STATE(2117)] = 78415,
  [SMALL_STATE(2118)] = 78434,
  [SMALL_STATE(2119)] = 78447,
  [SMALL_STATE(2120)] = 78470,
  [SMALL_STATE(2121)] = 78491,
  [SMALL_STATE(2122)] = 78509,
  [SMALL_STATE(2123)] = 78527,
  [SMALL_STATE(2124)] = 78543,
  [SMALL_STATE(2125)] = 78555,
  [SMALL_STATE(2126)] = 78573,
  [SMALL_STATE(2127)] = 78589,
  [SMALL_STATE(2128)] = 78609,
  [SMALL_STATE(2129)] = 78625,
  [SMALL_STATE(2130)] = 78639,
  [SMALL_STATE(2131)] = 78653,
  [SMALL_STATE(2132)] = 78669,
  [SMALL_STATE(2133)] = 78685,
  [SMALL_STATE(2134)] = 78701,
  [SMALL_STATE(2135)] = 78715,
  [SMALL_STATE(2136)] = 78727,
  [SMALL_STATE(2137)] = 78745,
  [SMALL_STATE(2138)] = 78763,
  [SMALL_STATE(2139)] = 78777,
  [SMALL_STATE(2140)] = 78791,
  [SMALL_STATE(2141)] = 78807,
  [SMALL_STATE(2142)] = 78823,
  [SMALL_STATE(2143)] = 78839,
  [SMALL_STATE(2144)] = 78853,
  [SMALL_STATE(2145)] = 78869,
  [SMALL_STATE(2146)] = 78883,
  [SMALL_STATE(2147)] = 78901,
  [SMALL_STATE(2148)] = 78917,
  [SMALL_STATE(2149)] = 78933,
  [SMALL_STATE(2150)] = 78949,
  [SMALL_STATE(2151)] = 78963,
  [SMALL_STATE(2152)] = 78977,
  [SMALL_STATE(2153)] = 78993,
  [SMALL_STATE(2154)] = 79009,
  [SMALL_STATE(2155)] = 79021,
  [SMALL_STATE(2156)] = 79037,
  [SMALL_STATE(2157)] = 79051,
  [SMALL_STATE(2158)] = 79067,
  [SMALL_STATE(2159)] = 79083,
  [SMALL_STATE(2160)] = 79097,
  [SMALL_STATE(2161)] = 79113,
  [SMALL_STATE(2162)] = 79127,
  [SMALL_STATE(2163)] = 79145,
  [SMALL_STATE(2164)] = 79161,
  [SMALL_STATE(2165)] = 79179,
  [SMALL_STATE(2166)] = 79195,
  [SMALL_STATE(2167)] = 79213,
  [SMALL_STATE(2168)] = 79225,
  [SMALL_STATE(2169)] = 79243,
  [SMALL_STATE(2170)] = 79259,
  [SMALL_STATE(2171)] = 79277,
  [SMALL_STATE(2172)] = 79295,
  [SMALL_STATE(2173)] = 79311,
  [SMALL_STATE(2174)] = 79325,
  [SMALL_STATE(2175)] = 79341,
  [SMALL_STATE(2176)] = 79357,
  [SMALL_STATE(2177)] = 79371,
  [SMALL_STATE(2178)] = 79383,
  [SMALL_STATE(2179)] = 79403,
  [SMALL_STATE(2180)] = 79421,
  [SMALL_STATE(2181)] = 79433,
  [SMALL_STATE(2182)] = 79451,
  [SMALL_STATE(2183)] = 79463,
  [SMALL_STATE(2184)] = 79477,
  [SMALL_STATE(2185)] = 79495,
  [SMALL_STATE(2186)] = 79507,
  [SMALL_STATE(2187)] = 79521,
  [SMALL_STATE(2188)] = 79537,
  [SMALL_STATE(2189)] = 79553,
  [SMALL_STATE(2190)] = 79567,
  [SMALL_STATE(2191)] = 79583,
  [SMALL_STATE(2192)] = 79597,
  [SMALL_STATE(2193)] = 79615,
  [SMALL_STATE(2194)] = 79627,
  [SMALL_STATE(2195)] = 79639,
  [SMALL_STATE(2196)] = 79657,
  [SMALL_STATE(2197)] = 79671,
  [SMALL_STATE(2198)] = 79687,
  [SMALL_STATE(2199)] = 79701,
  [SMALL_STATE(2200)] = 79715,
  [SMALL_STATE(2201)] = 79731,
  [SMALL_STATE(2202)] = 79745,
  [SMALL_STATE(2203)] = 79761,
  [SMALL_STATE(2204)] = 79777,
  [SMALL_STATE(2205)] = 79793,
  [SMALL_STATE(2206)] = 79805,
  [SMALL_STATE(2207)] = 79817,
  [SMALL_STATE(2208)] = 79835,
  [SMALL_STATE(2209)] = 79853,
  [SMALL_STATE(2210)] = 79873,
  [SMALL_STATE(2211)] = 79885,
  [SMALL_STATE(2212)] = 79901,
  [SMALL_STATE(2213)] = 79917,
  [SMALL_STATE(2214)] = 79930,
  [SMALL_STATE(2215)] = 79947,
  [SMALL_STATE(2216)] = 79960,
  [SMALL_STATE(2217)] = 79977,
  [SMALL_STATE(2218)] = 79988,
  [SMALL_STATE(2219)] = 80005,
  [SMALL_STATE(2220)] = 80020,
  [SMALL_STATE(2221)] = 80037,
  [SMALL_STATE(2222)] = 80052,
  [SMALL_STATE(2223)] = 80069,
  [SMALL_STATE(2224)] = 80082,
  [SMALL_STATE(2225)] = 80097,
  [SMALL_STATE(2226)] = 80114,
  [SMALL_STATE(2227)] = 80125,
  [SMALL_STATE(2228)] = 80138,
  [SMALL_STATE(2229)] = 80153,
  [SMALL_STATE(2230)] = 80166,
  [SMALL_STATE(2231)] = 80181,
  [SMALL_STATE(2232)] = 80198,
  [SMALL_STATE(2233)] = 80215,
  [SMALL_STATE(2234)] = 80228,
  [SMALL_STATE(2235)] = 80245,
  [SMALL_STATE(2236)] = 80262,
  [SMALL_STATE(2237)] = 80279,
  [SMALL_STATE(2238)] = 80296,
  [SMALL_STATE(2239)] = 80309,
  [SMALL_STATE(2240)] = 80326,
  [SMALL_STATE(2241)] = 80341,
  [SMALL_STATE(2242)] = 80358,
  [SMALL_STATE(2243)] = 80371,
  [SMALL_STATE(2244)] = 80386,
  [SMALL_STATE(2245)] = 80399,
  [SMALL_STATE(2246)] = 80416,
  [SMALL_STATE(2247)] = 80433,
  [SMALL_STATE(2248)] = 80450,
  [SMALL_STATE(2249)] = 80465,
  [SMALL_STATE(2250)] = 80482,
  [SMALL_STATE(2251)] = 80499,
  [SMALL_STATE(2252)] = 80516,
  [SMALL_STATE(2253)] = 80531,
  [SMALL_STATE(2254)] = 80548,
  [SMALL_STATE(2255)] = 80563,
  [SMALL_STATE(2256)] = 80580,
  [SMALL_STATE(2257)] = 80597,
  [SMALL_STATE(2258)] = 80614,
  [SMALL_STATE(2259)] = 80629,
  [SMALL_STATE(2260)] = 80646,
  [SMALL_STATE(2261)] = 80661,
  [SMALL_STATE(2262)] = 80678,
  [SMALL_STATE(2263)] = 80693,
  [SMALL_STATE(2264)] = 80710,
  [SMALL_STATE(2265)] = 80727,
  [SMALL_STATE(2266)] = 80744,
  [SMALL_STATE(2267)] = 80761,
  [SMALL_STATE(2268)] = 80772,
  [SMALL_STATE(2269)] = 80789,
  [SMALL_STATE(2270)] = 80804,
  [SMALL_STATE(2271)] = 80821,
  [SMALL_STATE(2272)] = 80832,
  [SMALL_STATE(2273)] = 80849,
  [SMALL_STATE(2274)] = 80862,
  [SMALL_STATE(2275)] = 80879,
  [SMALL_STATE(2276)] = 80896,
  [SMALL_STATE(2277)] = 80913,
  [SMALL_STATE(2278)] = 80930,
  [SMALL_STATE(2279)] = 80947,
  [SMALL_STATE(2280)] = 80960,
  [SMALL_STATE(2281)] = 80977,
  [SMALL_STATE(2282)] = 80988,
  [SMALL_STATE(2283)] = 81005,
  [SMALL_STATE(2284)] = 81020,
  [SMALL_STATE(2285)] = 81031,
  [SMALL_STATE(2286)] = 81046,
  [SMALL_STATE(2287)] = 81063,
  [SMALL_STATE(2288)] = 81076,
  [SMALL_STATE(2289)] = 81091,
  [SMALL_STATE(2290)] = 81104,
  [SMALL_STATE(2291)] = 81119,
  [SMALL_STATE(2292)] = 81134,
  [SMALL_STATE(2293)] = 81147,
  [SMALL_STATE(2294)] = 81162,
  [SMALL_STATE(2295)] = 81177,
  [SMALL_STATE(2296)] = 81194,
  [SMALL_STATE(2297)] = 81205,
  [SMALL_STATE(2298)] = 81220,
  [SMALL_STATE(2299)] = 81235,
  [SMALL_STATE(2300)] = 81246,
  [SMALL_STATE(2301)] = 81259,
  [SMALL_STATE(2302)] = 81272,
  [SMALL_STATE(2303)] = 81287,
  [SMALL_STATE(2304)] = 81302,
  [SMALL_STATE(2305)] = 81319,
  [SMALL_STATE(2306)] = 81334,
  [SMALL_STATE(2307)] = 81349,
  [SMALL_STATE(2308)] = 81364,
  [SMALL_STATE(2309)] = 81379,
  [SMALL_STATE(2310)] = 81394,
  [SMALL_STATE(2311)] = 81409,
  [SMALL_STATE(2312)] = 81424,
  [SMALL_STATE(2313)] = 81441,
  [SMALL_STATE(2314)] = 81452,
  [SMALL_STATE(2315)] = 81469,
  [SMALL_STATE(2316)] = 81484,
  [SMALL_STATE(2317)] = 81501,
  [SMALL_STATE(2318)] = 81518,
  [SMALL_STATE(2319)] = 81533,
  [SMALL_STATE(2320)] = 81546,
  [SMALL_STATE(2321)] = 81559,
  [SMALL_STATE(2322)] = 81576,
  [SMALL_STATE(2323)] = 81589,
  [SMALL_STATE(2324)] = 81600,
  [SMALL_STATE(2325)] = 81613,
  [SMALL_STATE(2326)] = 81630,
  [SMALL_STATE(2327)] = 81645,
  [SMALL_STATE(2328)] = 81658,
  [SMALL_STATE(2329)] = 81673,
  [SMALL_STATE(2330)] = 81690,
  [SMALL_STATE(2331)] = 81705,
  [SMALL_STATE(2332)] = 81718,
  [SMALL_STATE(2333)] = 81733,
  [SMALL_STATE(2334)] = 81750,
  [SMALL_STATE(2335)] = 81761,
  [SMALL_STATE(2336)] = 81778,
  [SMALL_STATE(2337)] = 81793,
  [SMALL_STATE(2338)] = 81810,
  [SMALL_STATE(2339)] = 81821,
  [SMALL_STATE(2340)] = 81838,
  [SMALL_STATE(2341)] = 81855,
  [SMALL_STATE(2342)] = 81866,
  [SMALL_STATE(2343)] = 81883,
  [SMALL_STATE(2344)] = 81900,
  [SMALL_STATE(2345)] = 81915,
  [SMALL_STATE(2346)] = 81930,
  [SMALL_STATE(2347)] = 81941,
  [SMALL_STATE(2348)] = 81954,
  [SMALL_STATE(2349)] = 81971,
  [SMALL_STATE(2350)] = 81988,
  [SMALL_STATE(2351)] = 81999,
  [SMALL_STATE(2352)] = 82014,
  [SMALL_STATE(2353)] = 82031,
  [SMALL_STATE(2354)] = 82048,
  [SMALL_STATE(2355)] = 82063,
  [SMALL_STATE(2356)] = 82078,
  [SMALL_STATE(2357)] = 82093,
  [SMALL_STATE(2358)] = 82106,
  [SMALL_STATE(2359)] = 82119,
  [SMALL_STATE(2360)] = 82134,
  [SMALL_STATE(2361)] = 82145,
  [SMALL_STATE(2362)] = 82156,
  [SMALL_STATE(2363)] = 82173,
  [SMALL_STATE(2364)] = 82188,
  [SMALL_STATE(2365)] = 82205,
  [SMALL_STATE(2366)] = 82222,
  [SMALL_STATE(2367)] = 82237,
  [SMALL_STATE(2368)] = 82247,
  [SMALL_STATE(2369)] = 82261,
  [SMALL_STATE(2370)] = 82271,
  [SMALL_STATE(2371)] = 82281,
  [SMALL_STATE(2372)] = 82291,
  [SMALL_STATE(2373)] = 82303,
  [SMALL_STATE(2374)] = 82313,
  [SMALL_STATE(2375)] = 82323,
  [SMALL_STATE(2376)] = 82333,
  [SMALL_STATE(2377)] = 82343,
  [SMALL_STATE(2378)] = 82353,
  [SMALL_STATE(2379)] = 82363,
  [SMALL_STATE(2380)] = 82377,
  [SMALL_STATE(2381)] = 82387,
  [SMALL_STATE(2382)] = 82397,
  [SMALL_STATE(2383)] = 82411,
  [SMALL_STATE(2384)] = 82425,
  [SMALL_STATE(2385)] = 82435,
  [SMALL_STATE(2386)] = 82447,
  [SMALL_STATE(2387)] = 82461,
  [SMALL_STATE(2388)] = 82471,
  [SMALL_STATE(2389)] = 82483,
  [SMALL_STATE(2390)] = 82497,
  [SMALL_STATE(2391)] = 82507,
  [SMALL_STATE(2392)] = 82517,
  [SMALL_STATE(2393)] = 82527,
  [SMALL_STATE(2394)] = 82537,
  [SMALL_STATE(2395)] = 82547,
  [SMALL_STATE(2396)] = 82557,
  [SMALL_STATE(2397)] = 82567,
  [SMALL_STATE(2398)] = 82577,
  [SMALL_STATE(2399)] = 82587,
  [SMALL_STATE(2400)] = 82597,
  [SMALL_STATE(2401)] = 82607,
  [SMALL_STATE(2402)] = 82617,
  [SMALL_STATE(2403)] = 82631,
  [SMALL_STATE(2404)] = 82641,
  [SMALL_STATE(2405)] = 82655,
  [SMALL_STATE(2406)] = 82665,
  [SMALL_STATE(2407)] = 82675,
  [SMALL_STATE(2408)] = 82685,
  [SMALL_STATE(2409)] = 82699,
  [SMALL_STATE(2410)] = 82709,
  [SMALL_STATE(2411)] = 82719,
  [SMALL_STATE(2412)] = 82731,
  [SMALL_STATE(2413)] = 82741,
  [SMALL_STATE(2414)] = 82751,
  [SMALL_STATE(2415)] = 82761,
  [SMALL_STATE(2416)] = 82771,
  [SMALL_STATE(2417)] = 82785,
  [SMALL_STATE(2418)] = 82795,
  [SMALL_STATE(2419)] = 82805,
  [SMALL_STATE(2420)] = 82817,
  [SMALL_STATE(2421)] = 82831,
  [SMALL_STATE(2422)] = 82841,
  [SMALL_STATE(2423)] = 82851,
  [SMALL_STATE(2424)] = 82861,
  [SMALL_STATE(2425)] = 82873,
  [SMALL_STATE(2426)] = 82885,
  [SMALL_STATE(2427)] = 82895,
  [SMALL_STATE(2428)] = 82905,
  [SMALL_STATE(2429)] = 82919,
  [SMALL_STATE(2430)] = 82929,
  [SMALL_STATE(2431)] = 82939,
  [SMALL_STATE(2432)] = 82953,
  [SMALL_STATE(2433)] = 82963,
  [SMALL_STATE(2434)] = 82973,
  [SMALL_STATE(2435)] = 82983,
  [SMALL_STATE(2436)] = 82993,
  [SMALL_STATE(2437)] = 83003,
  [SMALL_STATE(2438)] = 83013,
  [SMALL_STATE(2439)] = 83023,
  [SMALL_STATE(2440)] = 83033,
  [SMALL_STATE(2441)] = 83043,
  [SMALL_STATE(2442)] = 83053,
  [SMALL_STATE(2443)] = 83063,
  [SMALL_STATE(2444)] = 83073,
  [SMALL_STATE(2445)] = 83083,
  [SMALL_STATE(2446)] = 83093,
  [SMALL_STATE(2447)] = 83105,
  [SMALL_STATE(2448)] = 83115,
  [SMALL_STATE(2449)] = 83125,
  [SMALL_STATE(2450)] = 83135,
  [SMALL_STATE(2451)] = 83149,
  [SMALL_STATE(2452)] = 83159,
  [SMALL_STATE(2453)] = 83173,
  [SMALL_STATE(2454)] = 83183,
  [SMALL_STATE(2455)] = 83193,
  [SMALL_STATE(2456)] = 83203,
  [SMALL_STATE(2457)] = 83213,
  [SMALL_STATE(2458)] = 83223,
  [SMALL_STATE(2459)] = 83233,
  [SMALL_STATE(2460)] = 83243,
  [SMALL_STATE(2461)] = 83253,
  [SMALL_STATE(2462)] = 83263,
  [SMALL_STATE(2463)] = 83273,
  [SMALL_STATE(2464)] = 83283,
  [SMALL_STATE(2465)] = 83293,
  [SMALL_STATE(2466)] = 83303,
  [SMALL_STATE(2467)] = 83317,
  [SMALL_STATE(2468)] = 83327,
  [SMALL_STATE(2469)] = 83337,
  [SMALL_STATE(2470)] = 83347,
  [SMALL_STATE(2471)] = 83361,
  [SMALL_STATE(2472)] = 83371,
  [SMALL_STATE(2473)] = 83381,
  [SMALL_STATE(2474)] = 83391,
  [SMALL_STATE(2475)] = 83401,
  [SMALL_STATE(2476)] = 83411,
  [SMALL_STATE(2477)] = 83425,
  [SMALL_STATE(2478)] = 83435,
  [SMALL_STATE(2479)] = 83449,
  [SMALL_STATE(2480)] = 83463,
  [SMALL_STATE(2481)] = 83473,
  [SMALL_STATE(2482)] = 83483,
  [SMALL_STATE(2483)] = 83493,
  [SMALL_STATE(2484)] = 83507,
  [SMALL_STATE(2485)] = 83521,
  [SMALL_STATE(2486)] = 83535,
  [SMALL_STATE(2487)] = 83545,
  [SMALL_STATE(2488)] = 83555,
  [SMALL_STATE(2489)] = 83565,
  [SMALL_STATE(2490)] = 83575,
  [SMALL_STATE(2491)] = 83589,
  [SMALL_STATE(2492)] = 83603,
  [SMALL_STATE(2493)] = 83617,
  [SMALL_STATE(2494)] = 83631,
  [SMALL_STATE(2495)] = 83645,
  [SMALL_STATE(2496)] = 83655,
  [SMALL_STATE(2497)] = 83669,
  [SMALL_STATE(2498)] = 83683,
  [SMALL_STATE(2499)] = 83697,
  [SMALL_STATE(2500)] = 83711,
  [SMALL_STATE(2501)] = 83721,
  [SMALL_STATE(2502)] = 83731,
  [SMALL_STATE(2503)] = 83741,
  [SMALL_STATE(2504)] = 83751,
  [SMALL_STATE(2505)] = 83761,
  [SMALL_STATE(2506)] = 83775,
  [SMALL_STATE(2507)] = 83789,
  [SMALL_STATE(2508)] = 83799,
  [SMALL_STATE(2509)] = 83809,
  [SMALL_STATE(2510)] = 83823,
  [SMALL_STATE(2511)] = 83837,
  [SMALL_STATE(2512)] = 83851,
  [SMALL_STATE(2513)] = 83863,
  [SMALL_STATE(2514)] = 83873,
  [SMALL_STATE(2515)] = 83883,
  [SMALL_STATE(2516)] = 83897,
  [SMALL_STATE(2517)] = 83911,
  [SMALL_STATE(2518)] = 83925,
  [SMALL_STATE(2519)] = 83939,
  [SMALL_STATE(2520)] = 83949,
  [SMALL_STATE(2521)] = 83963,
  [SMALL_STATE(2522)] = 83977,
  [SMALL_STATE(2523)] = 83991,
  [SMALL_STATE(2524)] = 84005,
  [SMALL_STATE(2525)] = 84019,
  [SMALL_STATE(2526)] = 84033,
  [SMALL_STATE(2527)] = 84047,
  [SMALL_STATE(2528)] = 84059,
  [SMALL_STATE(2529)] = 84069,
  [SMALL_STATE(2530)] = 84079,
  [SMALL_STATE(2531)] = 84089,
  [SMALL_STATE(2532)] = 84101,
  [SMALL_STATE(2533)] = 84115,
  [SMALL_STATE(2534)] = 84129,
  [SMALL_STATE(2535)] = 84141,
  [SMALL_STATE(2536)] = 84155,
  [SMALL_STATE(2537)] = 84169,
  [SMALL_STATE(2538)] = 84183,
  [SMALL_STATE(2539)] = 84197,
  [SMALL_STATE(2540)] = 84211,
  [SMALL_STATE(2541)] = 84221,
  [SMALL_STATE(2542)] = 84235,
  [SMALL_STATE(2543)] = 84249,
  [SMALL_STATE(2544)] = 84259,
  [SMALL_STATE(2545)] = 84269,
  [SMALL_STATE(2546)] = 84279,
  [SMALL_STATE(2547)] = 84289,
  [SMALL_STATE(2548)] = 84301,
  [SMALL_STATE(2549)] = 84311,
  [SMALL_STATE(2550)] = 84321,
  [SMALL_STATE(2551)] = 84333,
  [SMALL_STATE(2552)] = 84343,
  [SMALL_STATE(2553)] = 84357,
  [SMALL_STATE(2554)] = 84371,
  [SMALL_STATE(2555)] = 84383,
  [SMALL_STATE(2556)] = 84393,
  [SMALL_STATE(2557)] = 84407,
  [SMALL_STATE(2558)] = 84421,
  [SMALL_STATE(2559)] = 84431,
  [SMALL_STATE(2560)] = 84445,
  [SMALL_STATE(2561)] = 84457,
  [SMALL_STATE(2562)] = 84471,
  [SMALL_STATE(2563)] = 84481,
  [SMALL_STATE(2564)] = 84491,
  [SMALL_STATE(2565)] = 84505,
  [SMALL_STATE(2566)] = 84519,
  [SMALL_STATE(2567)] = 84529,
  [SMALL_STATE(2568)] = 84539,
  [SMALL_STATE(2569)] = 84549,
  [SMALL_STATE(2570)] = 84563,
  [SMALL_STATE(2571)] = 84577,
  [SMALL_STATE(2572)] = 84591,
  [SMALL_STATE(2573)] = 84605,
  [SMALL_STATE(2574)] = 84619,
  [SMALL_STATE(2575)] = 84633,
  [SMALL_STATE(2576)] = 84643,
  [SMALL_STATE(2577)] = 84657,
  [SMALL_STATE(2578)] = 84671,
  [SMALL_STATE(2579)] = 84681,
  [SMALL_STATE(2580)] = 84695,
  [SMALL_STATE(2581)] = 84707,
  [SMALL_STATE(2582)] = 84721,
  [SMALL_STATE(2583)] = 84735,
  [SMALL_STATE(2584)] = 84749,
  [SMALL_STATE(2585)] = 84763,
  [SMALL_STATE(2586)] = 84777,
  [SMALL_STATE(2587)] = 84791,
  [SMALL_STATE(2588)] = 84805,
  [SMALL_STATE(2589)] = 84819,
  [SMALL_STATE(2590)] = 84833,
  [SMALL_STATE(2591)] = 84847,
  [SMALL_STATE(2592)] = 84861,
  [SMALL_STATE(2593)] = 84875,
  [SMALL_STATE(2594)] = 84885,
  [SMALL_STATE(2595)] = 84899,
  [SMALL_STATE(2596)] = 84909,
  [SMALL_STATE(2597)] = 84923,
  [SMALL_STATE(2598)] = 84937,
  [SMALL_STATE(2599)] = 84947,
  [SMALL_STATE(2600)] = 84957,
  [SMALL_STATE(2601)] = 84967,
  [SMALL_STATE(2602)] = 84977,
  [SMALL_STATE(2603)] = 84991,
  [SMALL_STATE(2604)] = 85005,
  [SMALL_STATE(2605)] = 85019,
  [SMALL_STATE(2606)] = 85029,
  [SMALL_STATE(2607)] = 85043,
  [SMALL_STATE(2608)] = 85053,
  [SMALL_STATE(2609)] = 85067,
  [SMALL_STATE(2610)] = 85081,
  [SMALL_STATE(2611)] = 85095,
  [SMALL_STATE(2612)] = 85105,
  [SMALL_STATE(2613)] = 85115,
  [SMALL_STATE(2614)] = 85129,
  [SMALL_STATE(2615)] = 85143,
  [SMALL_STATE(2616)] = 85157,
  [SMALL_STATE(2617)] = 85171,
  [SMALL_STATE(2618)] = 85185,
  [SMALL_STATE(2619)] = 85199,
  [SMALL_STATE(2620)] = 85213,
  [SMALL_STATE(2621)] = 85227,
  [SMALL_STATE(2622)] = 85241,
  [SMALL_STATE(2623)] = 85255,
  [SMALL_STATE(2624)] = 85265,
  [SMALL_STATE(2625)] = 85275,
  [SMALL_STATE(2626)] = 85285,
  [SMALL_STATE(2627)] = 85295,
  [SMALL_STATE(2628)] = 85309,
  [SMALL_STATE(2629)] = 85323,
  [SMALL_STATE(2630)] = 85333,
  [SMALL_STATE(2631)] = 85347,
  [SMALL_STATE(2632)] = 85361,
  [SMALL_STATE(2633)] = 85375,
  [SMALL_STATE(2634)] = 85387,
  [SMALL_STATE(2635)] = 85399,
  [SMALL_STATE(2636)] = 85413,
  [SMALL_STATE(2637)] = 85427,
  [SMALL_STATE(2638)] = 85441,
  [SMALL_STATE(2639)] = 85455,
  [SMALL_STATE(2640)] = 85469,
  [SMALL_STATE(2641)] = 85479,
  [SMALL_STATE(2642)] = 85489,
  [SMALL_STATE(2643)] = 85499,
  [SMALL_STATE(2644)] = 85513,
  [SMALL_STATE(2645)] = 85527,
  [SMALL_STATE(2646)] = 85541,
  [SMALL_STATE(2647)] = 85551,
  [SMALL_STATE(2648)] = 85565,
  [SMALL_STATE(2649)] = 85579,
  [SMALL_STATE(2650)] = 85591,
  [SMALL_STATE(2651)] = 85601,
  [SMALL_STATE(2652)] = 85611,
  [SMALL_STATE(2653)] = 85621,
  [SMALL_STATE(2654)] = 85631,
  [SMALL_STATE(2655)] = 85645,
  [SMALL_STATE(2656)] = 85659,
  [SMALL_STATE(2657)] = 85669,
  [SMALL_STATE(2658)] = 85681,
  [SMALL_STATE(2659)] = 85691,
  [SMALL_STATE(2660)] = 85701,
  [SMALL_STATE(2661)] = 85711,
  [SMALL_STATE(2662)] = 85721,
  [SMALL_STATE(2663)] = 85731,
  [SMALL_STATE(2664)] = 85741,
  [SMALL_STATE(2665)] = 85751,
  [SMALL_STATE(2666)] = 85761,
  [SMALL_STATE(2667)] = 85771,
  [SMALL_STATE(2668)] = 85781,
  [SMALL_STATE(2669)] = 85791,
  [SMALL_STATE(2670)] = 85801,
  [SMALL_STATE(2671)] = 85811,
  [SMALL_STATE(2672)] = 85821,
  [SMALL_STATE(2673)] = 85831,
  [SMALL_STATE(2674)] = 85841,
  [SMALL_STATE(2675)] = 85851,
  [SMALL_STATE(2676)] = 85861,
  [SMALL_STATE(2677)] = 85871,
  [SMALL_STATE(2678)] = 85881,
  [SMALL_STATE(2679)] = 85891,
  [SMALL_STATE(2680)] = 85901,
  [SMALL_STATE(2681)] = 85911,
  [SMALL_STATE(2682)] = 85921,
  [SMALL_STATE(2683)] = 85931,
  [SMALL_STATE(2684)] = 85941,
  [SMALL_STATE(2685)] = 85951,
  [SMALL_STATE(2686)] = 85961,
  [SMALL_STATE(2687)] = 85971,
  [SMALL_STATE(2688)] = 85981,
  [SMALL_STATE(2689)] = 85993,
  [SMALL_STATE(2690)] = 86003,
  [SMALL_STATE(2691)] = 86013,
  [SMALL_STATE(2692)] = 86025,
  [SMALL_STATE(2693)] = 86035,
  [SMALL_STATE(2694)] = 86047,
  [SMALL_STATE(2695)] = 86061,
  [SMALL_STATE(2696)] = 86071,
  [SMALL_STATE(2697)] = 86085,
  [SMALL_STATE(2698)] = 86095,
  [SMALL_STATE(2699)] = 86105,
  [SMALL_STATE(2700)] = 86115,
  [SMALL_STATE(2701)] = 86125,
  [SMALL_STATE(2702)] = 86135,
  [SMALL_STATE(2703)] = 86147,
  [SMALL_STATE(2704)] = 86157,
  [SMALL_STATE(2705)] = 86167,
  [SMALL_STATE(2706)] = 86177,
  [SMALL_STATE(2707)] = 86187,
  [SMALL_STATE(2708)] = 86197,
  [SMALL_STATE(2709)] = 86207,
  [SMALL_STATE(2710)] = 86221,
  [SMALL_STATE(2711)] = 86231,
  [SMALL_STATE(2712)] = 86241,
  [SMALL_STATE(2713)] = 86251,
  [SMALL_STATE(2714)] = 86263,
  [SMALL_STATE(2715)] = 86277,
  [SMALL_STATE(2716)] = 86287,
  [SMALL_STATE(2717)] = 86297,
  [SMALL_STATE(2718)] = 86307,
  [SMALL_STATE(2719)] = 86319,
  [SMALL_STATE(2720)] = 86329,
  [SMALL_STATE(2721)] = 86339,
  [SMALL_STATE(2722)] = 86349,
  [SMALL_STATE(2723)] = 86359,
  [SMALL_STATE(2724)] = 86369,
  [SMALL_STATE(2725)] = 86379,
  [SMALL_STATE(2726)] = 86389,
  [SMALL_STATE(2727)] = 86399,
  [SMALL_STATE(2728)] = 86409,
  [SMALL_STATE(2729)] = 86419,
  [SMALL_STATE(2730)] = 86429,
  [SMALL_STATE(2731)] = 86439,
  [SMALL_STATE(2732)] = 86451,
  [SMALL_STATE(2733)] = 86461,
  [SMALL_STATE(2734)] = 86475,
  [SMALL_STATE(2735)] = 86489,
  [SMALL_STATE(2736)] = 86503,
  [SMALL_STATE(2737)] = 86515,
  [SMALL_STATE(2738)] = 86525,
  [SMALL_STATE(2739)] = 86539,
  [SMALL_STATE(2740)] = 86553,
  [SMALL_STATE(2741)] = 86563,
  [SMALL_STATE(2742)] = 86577,
  [SMALL_STATE(2743)] = 86591,
  [SMALL_STATE(2744)] = 86603,
  [SMALL_STATE(2745)] = 86617,
  [SMALL_STATE(2746)] = 86631,
  [SMALL_STATE(2747)] = 86641,
  [SMALL_STATE(2748)] = 86653,
  [SMALL_STATE(2749)] = 86662,
  [SMALL_STATE(2750)] = 86671,
  [SMALL_STATE(2751)] = 86680,
  [SMALL_STATE(2752)] = 86689,
  [SMALL_STATE(2753)] = 86698,
  [SMALL_STATE(2754)] = 86707,
  [SMALL_STATE(2755)] = 86716,
  [SMALL_STATE(2756)] = 86725,
  [SMALL_STATE(2757)] = 86734,
  [SMALL_STATE(2758)] = 86743,
  [SMALL_STATE(2759)] = 86752,
  [SMALL_STATE(2760)] = 86761,
  [SMALL_STATE(2761)] = 86770,
  [SMALL_STATE(2762)] = 86779,
  [SMALL_STATE(2763)] = 86788,
  [SMALL_STATE(2764)] = 86797,
  [SMALL_STATE(2765)] = 86806,
  [SMALL_STATE(2766)] = 86815,
  [SMALL_STATE(2767)] = 86824,
  [SMALL_STATE(2768)] = 86833,
  [SMALL_STATE(2769)] = 86842,
  [SMALL_STATE(2770)] = 86851,
  [SMALL_STATE(2771)] = 86860,
  [SMALL_STATE(2772)] = 86869,
  [SMALL_STATE(2773)] = 86878,
  [SMALL_STATE(2774)] = 86887,
  [SMALL_STATE(2775)] = 86896,
  [SMALL_STATE(2776)] = 86905,
  [SMALL_STATE(2777)] = 86914,
  [SMALL_STATE(2778)] = 86923,
  [SMALL_STATE(2779)] = 86932,
  [SMALL_STATE(2780)] = 86943,
  [SMALL_STATE(2781)] = 86952,
  [SMALL_STATE(2782)] = 86961,
  [SMALL_STATE(2783)] = 86970,
  [SMALL_STATE(2784)] = 86979,
  [SMALL_STATE(2785)] = 86988,
  [SMALL_STATE(2786)] = 86997,
  [SMALL_STATE(2787)] = 87006,
  [SMALL_STATE(2788)] = 87015,
  [SMALL_STATE(2789)] = 87024,
  [SMALL_STATE(2790)] = 87033,
  [SMALL_STATE(2791)] = 87044,
  [SMALL_STATE(2792)] = 87053,
  [SMALL_STATE(2793)] = 87062,
  [SMALL_STATE(2794)] = 87071,
  [SMALL_STATE(2795)] = 87080,
  [SMALL_STATE(2796)] = 87089,
  [SMALL_STATE(2797)] = 87098,
  [SMALL_STATE(2798)] = 87107,
  [SMALL_STATE(2799)] = 87116,
  [SMALL_STATE(2800)] = 87125,
  [SMALL_STATE(2801)] = 87134,
  [SMALL_STATE(2802)] = 87143,
  [SMALL_STATE(2803)] = 87152,
  [SMALL_STATE(2804)] = 87161,
  [SMALL_STATE(2805)] = 87170,
  [SMALL_STATE(2806)] = 87179,
  [SMALL_STATE(2807)] = 87188,
  [SMALL_STATE(2808)] = 87197,
  [SMALL_STATE(2809)] = 87206,
  [SMALL_STATE(2810)] = 87215,
  [SMALL_STATE(2811)] = 87224,
  [SMALL_STATE(2812)] = 87233,
  [SMALL_STATE(2813)] = 87242,
  [SMALL_STATE(2814)] = 87253,
  [SMALL_STATE(2815)] = 87262,
  [SMALL_STATE(2816)] = 87273,
  [SMALL_STATE(2817)] = 87284,
  [SMALL_STATE(2818)] = 87293,
  [SMALL_STATE(2819)] = 87302,
  [SMALL_STATE(2820)] = 87313,
  [SMALL_STATE(2821)] = 87322,
  [SMALL_STATE(2822)] = 87331,
  [SMALL_STATE(2823)] = 87340,
  [SMALL_STATE(2824)] = 87351,
  [SMALL_STATE(2825)] = 87360,
  [SMALL_STATE(2826)] = 87369,
  [SMALL_STATE(2827)] = 87378,
  [SMALL_STATE(2828)] = 87387,
  [SMALL_STATE(2829)] = 87396,
  [SMALL_STATE(2830)] = 87405,
  [SMALL_STATE(2831)] = 87414,
  [SMALL_STATE(2832)] = 87423,
  [SMALL_STATE(2833)] = 87432,
  [SMALL_STATE(2834)] = 87441,
  [SMALL_STATE(2835)] = 87450,
  [SMALL_STATE(2836)] = 87459,
  [SMALL_STATE(2837)] = 87468,
  [SMALL_STATE(2838)] = 87477,
  [SMALL_STATE(2839)] = 87488,
  [SMALL_STATE(2840)] = 87497,
  [SMALL_STATE(2841)] = 87506,
  [SMALL_STATE(2842)] = 87515,
  [SMALL_STATE(2843)] = 87524,
  [SMALL_STATE(2844)] = 87533,
  [SMALL_STATE(2845)] = 87542,
  [SMALL_STATE(2846)] = 87551,
  [SMALL_STATE(2847)] = 87560,
  [SMALL_STATE(2848)] = 87569,
  [SMALL_STATE(2849)] = 87578,
  [SMALL_STATE(2850)] = 87587,
  [SMALL_STATE(2851)] = 87596,
  [SMALL_STATE(2852)] = 87605,
  [SMALL_STATE(2853)] = 87614,
  [SMALL_STATE(2854)] = 87623,
  [SMALL_STATE(2855)] = 87632,
  [SMALL_STATE(2856)] = 87641,
  [SMALL_STATE(2857)] = 87650,
  [SMALL_STATE(2858)] = 87659,
  [SMALL_STATE(2859)] = 87668,
  [SMALL_STATE(2860)] = 87677,
  [SMALL_STATE(2861)] = 87686,
  [SMALL_STATE(2862)] = 87695,
  [SMALL_STATE(2863)] = 87704,
  [SMALL_STATE(2864)] = 87715,
  [SMALL_STATE(2865)] = 87724,
  [SMALL_STATE(2866)] = 87733,
  [SMALL_STATE(2867)] = 87742,
  [SMALL_STATE(2868)] = 87751,
  [SMALL_STATE(2869)] = 87760,
  [SMALL_STATE(2870)] = 87769,
  [SMALL_STATE(2871)] = 87778,
  [SMALL_STATE(2872)] = 87787,
  [SMALL_STATE(2873)] = 87796,
  [SMALL_STATE(2874)] = 87805,
  [SMALL_STATE(2875)] = 87814,
  [SMALL_STATE(2876)] = 87825,
  [SMALL_STATE(2877)] = 87834,
  [SMALL_STATE(2878)] = 87843,
  [SMALL_STATE(2879)] = 87852,
  [SMALL_STATE(2880)] = 87861,
  [SMALL_STATE(2881)] = 87870,
  [SMALL_STATE(2882)] = 87879,
  [SMALL_STATE(2883)] = 87888,
  [SMALL_STATE(2884)] = 87899,
  [SMALL_STATE(2885)] = 87908,
  [SMALL_STATE(2886)] = 87917,
  [SMALL_STATE(2887)] = 87926,
  [SMALL_STATE(2888)] = 87935,
  [SMALL_STATE(2889)] = 87944,
  [SMALL_STATE(2890)] = 87953,
  [SMALL_STATE(2891)] = 87962,
  [SMALL_STATE(2892)] = 87971,
  [SMALL_STATE(2893)] = 87980,
  [SMALL_STATE(2894)] = 87989,
  [SMALL_STATE(2895)] = 87998,
  [SMALL_STATE(2896)] = 88007,
  [SMALL_STATE(2897)] = 88016,
  [SMALL_STATE(2898)] = 88025,
  [SMALL_STATE(2899)] = 88034,
  [SMALL_STATE(2900)] = 88045,
  [SMALL_STATE(2901)] = 88054,
  [SMALL_STATE(2902)] = 88063,
  [SMALL_STATE(2903)] = 88072,
  [SMALL_STATE(2904)] = 88081,
  [SMALL_STATE(2905)] = 88090,
  [SMALL_STATE(2906)] = 88099,
  [SMALL_STATE(2907)] = 88108,
  [SMALL_STATE(2908)] = 88117,
  [SMALL_STATE(2909)] = 88126,
  [SMALL_STATE(2910)] = 88135,
  [SMALL_STATE(2911)] = 88144,
  [SMALL_STATE(2912)] = 88153,
  [SMALL_STATE(2913)] = 88162,
  [SMALL_STATE(2914)] = 88171,
  [SMALL_STATE(2915)] = 88180,
  [SMALL_STATE(2916)] = 88189,
  [SMALL_STATE(2917)] = 88198,
  [SMALL_STATE(2918)] = 88207,
  [SMALL_STATE(2919)] = 88216,
  [SMALL_STATE(2920)] = 88225,
  [SMALL_STATE(2921)] = 88236,
  [SMALL_STATE(2922)] = 88247,
  [SMALL_STATE(2923)] = 88256,
  [SMALL_STATE(2924)] = 88265,
  [SMALL_STATE(2925)] = 88274,
  [SMALL_STATE(2926)] = 88283,
  [SMALL_STATE(2927)] = 88292,
  [SMALL_STATE(2928)] = 88301,
  [SMALL_STATE(2929)] = 88310,
  [SMALL_STATE(2930)] = 88319,
  [SMALL_STATE(2931)] = 88328,
  [SMALL_STATE(2932)] = 88339,
  [SMALL_STATE(2933)] = 88348,
  [SMALL_STATE(2934)] = 88359,
  [SMALL_STATE(2935)] = 88368,
  [SMALL_STATE(2936)] = 88377,
  [SMALL_STATE(2937)] = 88386,
  [SMALL_STATE(2938)] = 88395,
  [SMALL_STATE(2939)] = 88404,
  [SMALL_STATE(2940)] = 88415,
  [SMALL_STATE(2941)] = 88424,
  [SMALL_STATE(2942)] = 88433,
  [SMALL_STATE(2943)] = 88442,
  [SMALL_STATE(2944)] = 88451,
  [SMALL_STATE(2945)] = 88460,
  [SMALL_STATE(2946)] = 88469,
  [SMALL_STATE(2947)] = 88478,
  [SMALL_STATE(2948)] = 88487,
  [SMALL_STATE(2949)] = 88496,
  [SMALL_STATE(2950)] = 88505,
  [SMALL_STATE(2951)] = 88514,
  [SMALL_STATE(2952)] = 88523,
  [SMALL_STATE(2953)] = 88532,
  [SMALL_STATE(2954)] = 88541,
  [SMALL_STATE(2955)] = 88550,
  [SMALL_STATE(2956)] = 88559,
  [SMALL_STATE(2957)] = 88568,
  [SMALL_STATE(2958)] = 88577,
  [SMALL_STATE(2959)] = 88586,
  [SMALL_STATE(2960)] = 88595,
  [SMALL_STATE(2961)] = 88604,
  [SMALL_STATE(2962)] = 88613,
  [SMALL_STATE(2963)] = 88622,
  [SMALL_STATE(2964)] = 88631,
  [SMALL_STATE(2965)] = 88640,
  [SMALL_STATE(2966)] = 88649,
  [SMALL_STATE(2967)] = 88660,
  [SMALL_STATE(2968)] = 88669,
  [SMALL_STATE(2969)] = 88678,
  [SMALL_STATE(2970)] = 88687,
  [SMALL_STATE(2971)] = 88696,
  [SMALL_STATE(2972)] = 88705,
  [SMALL_STATE(2973)] = 88714,
  [SMALL_STATE(2974)] = 88725,
  [SMALL_STATE(2975)] = 88734,
  [SMALL_STATE(2976)] = 88743,
  [SMALL_STATE(2977)] = 88752,
  [SMALL_STATE(2978)] = 88761,
  [SMALL_STATE(2979)] = 88770,
  [SMALL_STATE(2980)] = 88779,
  [SMALL_STATE(2981)] = 88788,
  [SMALL_STATE(2982)] = 88797,
  [SMALL_STATE(2983)] = 88806,
  [SMALL_STATE(2984)] = 88815,
  [SMALL_STATE(2985)] = 88823,
  [SMALL_STATE(2986)] = 88831,
  [SMALL_STATE(2987)] = 88839,
  [SMALL_STATE(2988)] = 88847,
  [SMALL_STATE(2989)] = 88855,
  [SMALL_STATE(2990)] = 88863,
  [SMALL_STATE(2991)] = 88871,
  [SMALL_STATE(2992)] = 88879,
  [SMALL_STATE(2993)] = 88887,
  [SMALL_STATE(2994)] = 88895,
  [SMALL_STATE(2995)] = 88903,
  [SMALL_STATE(2996)] = 88911,
  [SMALL_STATE(2997)] = 88919,
  [SMALL_STATE(2998)] = 88927,
  [SMALL_STATE(2999)] = 88935,
  [SMALL_STATE(3000)] = 88943,
  [SMALL_STATE(3001)] = 88951,
  [SMALL_STATE(3002)] = 88959,
  [SMALL_STATE(3003)] = 88967,
  [SMALL_STATE(3004)] = 88975,
  [SMALL_STATE(3005)] = 88983,
  [SMALL_STATE(3006)] = 88991,
  [SMALL_STATE(3007)] = 88999,
  [SMALL_STATE(3008)] = 89007,
  [SMALL_STATE(3009)] = 89015,
  [SMALL_STATE(3010)] = 89023,
  [SMALL_STATE(3011)] = 89031,
  [SMALL_STATE(3012)] = 89039,
  [SMALL_STATE(3013)] = 89047,
  [SMALL_STATE(3014)] = 89055,
  [SMALL_STATE(3015)] = 89063,
  [SMALL_STATE(3016)] = 89071,
  [SMALL_STATE(3017)] = 89079,
  [SMALL_STATE(3018)] = 89087,
  [SMALL_STATE(3019)] = 89095,
  [SMALL_STATE(3020)] = 89103,
  [SMALL_STATE(3021)] = 89111,
  [SMALL_STATE(3022)] = 89119,
  [SMALL_STATE(3023)] = 89127,
  [SMALL_STATE(3024)] = 89135,
  [SMALL_STATE(3025)] = 89143,
  [SMALL_STATE(3026)] = 89151,
  [SMALL_STATE(3027)] = 89159,
  [SMALL_STATE(3028)] = 89167,
  [SMALL_STATE(3029)] = 89175,
  [SMALL_STATE(3030)] = 89183,
  [SMALL_STATE(3031)] = 89191,
  [SMALL_STATE(3032)] = 89199,
  [SMALL_STATE(3033)] = 89207,
  [SMALL_STATE(3034)] = 89215,
  [SMALL_STATE(3035)] = 89223,
  [SMALL_STATE(3036)] = 89231,
  [SMALL_STATE(3037)] = 89239,
  [SMALL_STATE(3038)] = 89247,
  [SMALL_STATE(3039)] = 89255,
  [SMALL_STATE(3040)] = 89263,
  [SMALL_STATE(3041)] = 89271,
  [SMALL_STATE(3042)] = 89279,
  [SMALL_STATE(3043)] = 89287,
  [SMALL_STATE(3044)] = 89295,
  [SMALL_STATE(3045)] = 89303,
  [SMALL_STATE(3046)] = 89311,
  [SMALL_STATE(3047)] = 89319,
  [SMALL_STATE(3048)] = 89327,
  [SMALL_STATE(3049)] = 89335,
  [SMALL_STATE(3050)] = 89343,
  [SMALL_STATE(3051)] = 89351,
  [SMALL_STATE(3052)] = 89359,
  [SMALL_STATE(3053)] = 89367,
  [SMALL_STATE(3054)] = 89375,
  [SMALL_STATE(3055)] = 89383,
  [SMALL_STATE(3056)] = 89391,
  [SMALL_STATE(3057)] = 89399,
  [SMALL_STATE(3058)] = 89407,
  [SMALL_STATE(3059)] = 89415,
  [SMALL_STATE(3060)] = 89423,
  [SMALL_STATE(3061)] = 89431,
  [SMALL_STATE(3062)] = 89439,
  [SMALL_STATE(3063)] = 89447,
  [SMALL_STATE(3064)] = 89455,
  [SMALL_STATE(3065)] = 89463,
  [SMALL_STATE(3066)] = 89471,
  [SMALL_STATE(3067)] = 89479,
  [SMALL_STATE(3068)] = 89487,
  [SMALL_STATE(3069)] = 89495,
  [SMALL_STATE(3070)] = 89503,
  [SMALL_STATE(3071)] = 89511,
  [SMALL_STATE(3072)] = 89519,
  [SMALL_STATE(3073)] = 89527,
  [SMALL_STATE(3074)] = 89535,
  [SMALL_STATE(3075)] = 89543,
  [SMALL_STATE(3076)] = 89551,
  [SMALL_STATE(3077)] = 89559,
  [SMALL_STATE(3078)] = 89567,
  [SMALL_STATE(3079)] = 89575,
  [SMALL_STATE(3080)] = 89583,
  [SMALL_STATE(3081)] = 89591,
  [SMALL_STATE(3082)] = 89599,
  [SMALL_STATE(3083)] = 89607,
  [SMALL_STATE(3084)] = 89615,
  [SMALL_STATE(3085)] = 89623,
  [SMALL_STATE(3086)] = 89631,
  [SMALL_STATE(3087)] = 89639,
  [SMALL_STATE(3088)] = 89647,
  [SMALL_STATE(3089)] = 89655,
  [SMALL_STATE(3090)] = 89663,
  [SMALL_STATE(3091)] = 89671,
  [SMALL_STATE(3092)] = 89679,
  [SMALL_STATE(3093)] = 89687,
  [SMALL_STATE(3094)] = 89695,
  [SMALL_STATE(3095)] = 89703,
  [SMALL_STATE(3096)] = 89711,
  [SMALL_STATE(3097)] = 89719,
  [SMALL_STATE(3098)] = 89727,
  [SMALL_STATE(3099)] = 89735,
  [SMALL_STATE(3100)] = 89743,
  [SMALL_STATE(3101)] = 89751,
  [SMALL_STATE(3102)] = 89759,
  [SMALL_STATE(3103)] = 89767,
  [SMALL_STATE(3104)] = 89775,
  [SMALL_STATE(3105)] = 89783,
  [SMALL_STATE(3106)] = 89791,
  [SMALL_STATE(3107)] = 89799,
  [SMALL_STATE(3108)] = 89807,
  [SMALL_STATE(3109)] = 89815,
  [SMALL_STATE(3110)] = 89823,
  [SMALL_STATE(3111)] = 89831,
  [SMALL_STATE(3112)] = 89839,
  [SMALL_STATE(3113)] = 89847,
  [SMALL_STATE(3114)] = 89855,
  [SMALL_STATE(3115)] = 89863,
  [SMALL_STATE(3116)] = 89871,
  [SMALL_STATE(3117)] = 89879,
  [SMALL_STATE(3118)] = 89887,
  [SMALL_STATE(3119)] = 89895,
  [SMALL_STATE(3120)] = 89903,
  [SMALL_STATE(3121)] = 89911,
  [SMALL_STATE(3122)] = 89919,
  [SMALL_STATE(3123)] = 89927,
  [SMALL_STATE(3124)] = 89935,
  [SMALL_STATE(3125)] = 89943,
  [SMALL_STATE(3126)] = 89951,
  [SMALL_STATE(3127)] = 89959,
  [SMALL_STATE(3128)] = 89967,
  [SMALL_STATE(3129)] = 89975,
  [SMALL_STATE(3130)] = 89983,
  [SMALL_STATE(3131)] = 89991,
  [SMALL_STATE(3132)] = 89999,
  [SMALL_STATE(3133)] = 90007,
  [SMALL_STATE(3134)] = 90015,
  [SMALL_STATE(3135)] = 90023,
  [SMALL_STATE(3136)] = 90031,
  [SMALL_STATE(3137)] = 90039,
  [SMALL_STATE(3138)] = 90047,
  [SMALL_STATE(3139)] = 90055,
  [SMALL_STATE(3140)] = 90063,
  [SMALL_STATE(3141)] = 90071,
  [SMALL_STATE(3142)] = 90079,
  [SMALL_STATE(3143)] = 90087,
  [SMALL_STATE(3144)] = 90095,
  [SMALL_STATE(3145)] = 90103,
  [SMALL_STATE(3146)] = 90111,
  [SMALL_STATE(3147)] = 90119,
  [SMALL_STATE(3148)] = 90127,
  [SMALL_STATE(3149)] = 90135,
  [SMALL_STATE(3150)] = 90143,
  [SMALL_STATE(3151)] = 90151,
  [SMALL_STATE(3152)] = 90159,
  [SMALL_STATE(3153)] = 90167,
  [SMALL_STATE(3154)] = 90175,
  [SMALL_STATE(3155)] = 90183,
  [SMALL_STATE(3156)] = 90191,
  [SMALL_STATE(3157)] = 90199,
  [SMALL_STATE(3158)] = 90207,
  [SMALL_STATE(3159)] = 90215,
  [SMALL_STATE(3160)] = 90223,
  [SMALL_STATE(3161)] = 90231,
  [SMALL_STATE(3162)] = 90239,
  [SMALL_STATE(3163)] = 90247,
  [SMALL_STATE(3164)] = 90255,
  [SMALL_STATE(3165)] = 90263,
  [SMALL_STATE(3166)] = 90271,
  [SMALL_STATE(3167)] = 90279,
  [SMALL_STATE(3168)] = 90287,
  [SMALL_STATE(3169)] = 90295,
  [SMALL_STATE(3170)] = 90303,
  [SMALL_STATE(3171)] = 90311,
  [SMALL_STATE(3172)] = 90319,
  [SMALL_STATE(3173)] = 90327,
  [SMALL_STATE(3174)] = 90335,
  [SMALL_STATE(3175)] = 90343,
  [SMALL_STATE(3176)] = 90351,
  [SMALL_STATE(3177)] = 90359,
  [SMALL_STATE(3178)] = 90367,
  [SMALL_STATE(3179)] = 90375,
  [SMALL_STATE(3180)] = 90383,
  [SMALL_STATE(3181)] = 90391,
  [SMALL_STATE(3182)] = 90399,
  [SMALL_STATE(3183)] = 90407,
  [SMALL_STATE(3184)] = 90415,
  [SMALL_STATE(3185)] = 90423,
  [SMALL_STATE(3186)] = 90431,
  [SMALL_STATE(3187)] = 90439,
  [SMALL_STATE(3188)] = 90447,
  [SMALL_STATE(3189)] = 90455,
  [SMALL_STATE(3190)] = 90463,
  [SMALL_STATE(3191)] = 90471,
  [SMALL_STATE(3192)] = 90479,
  [SMALL_STATE(3193)] = 90487,
  [SMALL_STATE(3194)] = 90495,
  [SMALL_STATE(3195)] = 90503,
  [SMALL_STATE(3196)] = 90511,
  [SMALL_STATE(3197)] = 90519,
  [SMALL_STATE(3198)] = 90527,
  [SMALL_STATE(3199)] = 90535,
  [SMALL_STATE(3200)] = 90543,
  [SMALL_STATE(3201)] = 90551,
  [SMALL_STATE(3202)] = 90559,
  [SMALL_STATE(3203)] = 90567,
  [SMALL_STATE(3204)] = 90575,
  [SMALL_STATE(3205)] = 90583,
  [SMALL_STATE(3206)] = 90591,
  [SMALL_STATE(3207)] = 90599,
  [SMALL_STATE(3208)] = 90607,
  [SMALL_STATE(3209)] = 90615,
  [SMALL_STATE(3210)] = 90623,
  [SMALL_STATE(3211)] = 90631,
  [SMALL_STATE(3212)] = 90639,
  [SMALL_STATE(3213)] = 90647,
  [SMALL_STATE(3214)] = 90655,
  [SMALL_STATE(3215)] = 90663,
  [SMALL_STATE(3216)] = 90671,
  [SMALL_STATE(3217)] = 90679,
  [SMALL_STATE(3218)] = 90687,
  [SMALL_STATE(3219)] = 90695,
  [SMALL_STATE(3220)] = 90703,
  [SMALL_STATE(3221)] = 90711,
  [SMALL_STATE(3222)] = 90719,
  [SMALL_STATE(3223)] = 90727,
  [SMALL_STATE(3224)] = 90735,
  [SMALL_STATE(3225)] = 90743,
  [SMALL_STATE(3226)] = 90751,
  [SMALL_STATE(3227)] = 90759,
  [SMALL_STATE(3228)] = 90767,
  [SMALL_STATE(3229)] = 90775,
  [SMALL_STATE(3230)] = 90783,
  [SMALL_STATE(3231)] = 90791,
  [SMALL_STATE(3232)] = 90799,
  [SMALL_STATE(3233)] = 90807,
  [SMALL_STATE(3234)] = 90815,
  [SMALL_STATE(3235)] = 90823,
  [SMALL_STATE(3236)] = 90831,
  [SMALL_STATE(3237)] = 90839,
  [SMALL_STATE(3238)] = 90847,
  [SMALL_STATE(3239)] = 90855,
  [SMALL_STATE(3240)] = 90863,
  [SMALL_STATE(3241)] = 90871,
  [SMALL_STATE(3242)] = 90879,
  [SMALL_STATE(3243)] = 90887,
  [SMALL_STATE(3244)] = 90895,
  [SMALL_STATE(3245)] = 90903,
  [SMALL_STATE(3246)] = 90911,
  [SMALL_STATE(3247)] = 90919,
  [SMALL_STATE(3248)] = 90927,
  [SMALL_STATE(3249)] = 90935,
  [SMALL_STATE(3250)] = 90943,
  [SMALL_STATE(3251)] = 90951,
  [SMALL_STATE(3252)] = 90959,
  [SMALL_STATE(3253)] = 90967,
  [SMALL_STATE(3254)] = 90975,
  [SMALL_STATE(3255)] = 90983,
  [SMALL_STATE(3256)] = 90991,
  [SMALL_STATE(3257)] = 90999,
  [SMALL_STATE(3258)] = 91007,
  [SMALL_STATE(3259)] = 91015,
  [SMALL_STATE(3260)] = 91023,
  [SMALL_STATE(3261)] = 91031,
  [SMALL_STATE(3262)] = 91039,
  [SMALL_STATE(3263)] = 91047,
  [SMALL_STATE(3264)] = 91055,
  [SMALL_STATE(3265)] = 91063,
  [SMALL_STATE(3266)] = 91071,
  [SMALL_STATE(3267)] = 91079,
  [SMALL_STATE(3268)] = 91087,
  [SMALL_STATE(3269)] = 91095,
  [SMALL_STATE(3270)] = 91103,
  [SMALL_STATE(3271)] = 91111,
  [SMALL_STATE(3272)] = 91119,
  [SMALL_STATE(3273)] = 91127,
  [SMALL_STATE(3274)] = 91135,
  [SMALL_STATE(3275)] = 91143,
  [SMALL_STATE(3276)] = 91151,
  [SMALL_STATE(3277)] = 91159,
  [SMALL_STATE(3278)] = 91167,
  [SMALL_STATE(3279)] = 91175,
  [SMALL_STATE(3280)] = 91183,
  [SMALL_STATE(3281)] = 91191,
  [SMALL_STATE(3282)] = 91199,
  [SMALL_STATE(3283)] = 91207,
  [SMALL_STATE(3284)] = 91215,
  [SMALL_STATE(3285)] = 91223,
  [SMALL_STATE(3286)] = 91231,
  [SMALL_STATE(3287)] = 91239,
  [SMALL_STATE(3288)] = 91247,
  [SMALL_STATE(3289)] = 91255,
  [SMALL_STATE(3290)] = 91263,
  [SMALL_STATE(3291)] = 91271,
  [SMALL_STATE(3292)] = 91279,
  [SMALL_STATE(3293)] = 91287,
  [SMALL_STATE(3294)] = 91295,
  [SMALL_STATE(3295)] = 91303,
  [SMALL_STATE(3296)] = 91311,
  [SMALL_STATE(3297)] = 91319,
  [SMALL_STATE(3298)] = 91327,
  [SMALL_STATE(3299)] = 91335,
  [SMALL_STATE(3300)] = 91343,
  [SMALL_STATE(3301)] = 91351,
  [SMALL_STATE(3302)] = 91359,
  [SMALL_STATE(3303)] = 91367,
  [SMALL_STATE(3304)] = 91375,
  [SMALL_STATE(3305)] = 91383,
  [SMALL_STATE(3306)] = 91391,
  [SMALL_STATE(3307)] = 91399,
  [SMALL_STATE(3308)] = 91407,
  [SMALL_STATE(3309)] = 91415,
  [SMALL_STATE(3310)] = 91423,
  [SMALL_STATE(3311)] = 91431,
  [SMALL_STATE(3312)] = 91439,
  [SMALL_STATE(3313)] = 91447,
  [SMALL_STATE(3314)] = 91455,
  [SMALL_STATE(3315)] = 91463,
  [SMALL_STATE(3316)] = 91471,
  [SMALL_STATE(3317)] = 91479,
  [SMALL_STATE(3318)] = 91487,
  [SMALL_STATE(3319)] = 91495,
  [SMALL_STATE(3320)] = 91503,
  [SMALL_STATE(3321)] = 91511,
  [SMALL_STATE(3322)] = 91519,
  [SMALL_STATE(3323)] = 91527,
  [SMALL_STATE(3324)] = 91535,
  [SMALL_STATE(3325)] = 91543,
  [SMALL_STATE(3326)] = 91551,
  [SMALL_STATE(3327)] = 91559,
  [SMALL_STATE(3328)] = 91567,
  [SMALL_STATE(3329)] = 91575,
  [SMALL_STATE(3330)] = 91583,
  [SMALL_STATE(3331)] = 91591,
  [SMALL_STATE(3332)] = 91599,
  [SMALL_STATE(3333)] = 91607,
  [SMALL_STATE(3334)] = 91615,
  [SMALL_STATE(3335)] = 91623,
  [SMALL_STATE(3336)] = 91631,
  [SMALL_STATE(3337)] = 91639,
  [SMALL_STATE(3338)] = 91647,
  [SMALL_STATE(3339)] = 91655,
  [SMALL_STATE(3340)] = 91663,
  [SMALL_STATE(3341)] = 91671,
  [SMALL_STATE(3342)] = 91679,
  [SMALL_STATE(3343)] = 91687,
  [SMALL_STATE(3344)] = 91695,
  [SMALL_STATE(3345)] = 91703,
  [SMALL_STATE(3346)] = 91711,
  [SMALL_STATE(3347)] = 91719,
  [SMALL_STATE(3348)] = 91727,
  [SMALL_STATE(3349)] = 91735,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_script_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2368),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1448),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2713),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1361),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1599),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1490),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1376),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1392),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1259),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2885),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1821),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1571),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2534),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2332),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2351),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2714),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2478),
  [59] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2524),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2516),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3315),
  [77] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [79] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [81] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1335),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2093),
  [85] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1347),
  [87] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1418),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1419),
  [93] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2420),
  [95] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3311),
  [97] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2765),
  [99] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2302),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2764),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1655),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2539),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1816),
  [111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2789),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2994),
  [117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1301),
  [119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3018),
  [121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1466),
  [123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1473),
  [125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2980),
  [133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2897),
  [135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2294),
  [151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1282),
  [153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1261),
  [159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1426),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1793),
  [165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2062),
  [169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2760),
  [173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2543),
  [181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2799),
  [183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2791),
  [185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2865),
  [187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2427),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2563),
  [191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2429),
  [193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_statement, 2, 0, 0),
  [195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_statement, 3, 0, 65),
  [197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_statement, 3, 0, 0),
  [199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_statement, 3, 0, 63),
  [201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_statement, 4, 0, 91),
  [203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(94),
  [206] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2368),
  [209] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1448),
  [212] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2713),
  [215] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1361),
  [218] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1599),
  [221] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1490),
  [224] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1349),
  [227] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1376),
  [230] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1340),
  [233] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1392),
  [236] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1259),
  [239] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2885),
  [242] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1821),
  [245] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(105),
  [248] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(196),
  [251] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1571),
  [254] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(370),
  [257] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(366),
  [260] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0),
  [262] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2534),
  [265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2332),
  [268] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2351),
  [271] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1059),
  [274] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2714),
  [277] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(218),
  [280] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2478),
  [283] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2524),
  [286] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2516),
  [289] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(375),
  [292] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(250),
  [295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1242),
  [298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(58),
  [301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(173),
  [304] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(184),
  [307] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(3315),
  [310] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(190),
  [313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(192),
  [316] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1335),
  [319] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2093),
  [322] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1347),
  [325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(522),
  [328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1418),
  [331] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1419),
  [334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2420),
  [337] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(3311),
  [340] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2765),
  [343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2302),
  [346] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2764),
  [349] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(125),
  [352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1655),
  [355] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2539),
  [358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1816),
  [361] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1088),
  [364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2789),
  [367] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2994),
  [370] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1301),
  [373] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(3018),
  [376] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1466),
  [379] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1473),
  [382] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(139),
  [385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(178),
  [388] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(359),
  [391] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2980),
  [394] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2897),
  [397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(71),
  [400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(73),
  [403] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(82),
  [406] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(85),
  [409] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(61),
  [412] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(86),
  [415] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1117),
  [418] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(2294),
  [421] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1282),
  [424] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1251),
  [427] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1126),
  [430] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1261),
  [433] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(294),
  [436] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1426),
  [439] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(1793),
  [442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_statement, 4, 0, 87),
  [444] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(106),
  [447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2979),
  [451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2704),
  [455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2844),
  [457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2780),
  [459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2775),
  [461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_statement, 2, 0, 64),
  [465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2917),
  [467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2959),
  [469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2758),
  [473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2832),
  [475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2833),
  [477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2862),
  [479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2492),
  [483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1476),
  [485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2358),
  [487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1289),
  [489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1515),
  [491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1255),
  [495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1256),
  [497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1257),
  [499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_list, 3, 0, 0),
  [503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1184),
  [505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2528),
  [507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1723),
  [513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1611),
  [517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2688),
  [523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2160),
  [525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2142),
  [527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1029),
  [529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2490),
  [531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2491),
  [535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2493),
  [537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2494),
  [539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1178),
  [545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3228),
  [553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2029),
  [561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1469),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1470),
  [569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2496),
  [571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3267),
  [573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2460),
  [575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2174),
  [577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2462),
  [579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1569),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2734),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1725),
  [587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2469),
  [591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3270),
  [593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1307),
  [595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3288),
  [597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1472),
  [599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1358),
  [601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2472),
  [609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2473),
  [611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2126),
  [627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1183),
  [631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1309),
  [635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1475),
  [639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1761),
  [641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_remove, 4, 0, 0),
  [643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_list, 4, 0, 0),
  [645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_script_file, 1, 0, 0),
  [647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_statement, 1, 0, 0),
  [649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(109),
  [652] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(119),
  [655] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(118),
  [658] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(113),
  [661] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(114),
  [664] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__separated_statements, 2, 0, 0), SHIFT_REPEAT(116),
  [667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_finally_statement, 1, 0, 0),
  [671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2422),
  [673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2426),
  [675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_finally_statement, 2, 0, 64),
  [677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2529),
  [679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2530),
  [681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2540),
  [683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2668),
  [685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2669),
  [687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2670),
  [689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2703),
  [691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_remove, 5, 0, 0),
  [693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_pattern, 1, 0, 0),
  [707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3233),
  [709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__autocmd_pattern, 1, 0, 0),
  [711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_pattern, 2, 0, 0),
  [713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__autocmd_pattern, 2, 0, 0),
  [715] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__autocmd_pattern_repeat1, 2, 0, 0),
  [717] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__autocmd_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(3233),
  [720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__autocmd_pattern_repeat1, 2, 0, 0),
  [722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3156),
  [724] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__autocmd_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(3156),
  [727] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__separated_statements, 2, 0, 0),
  [729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__separated_statements, 1, 0, 0),
  [731] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__separated_statements, 1, 0, 0),
  [733] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statement_repeat1, 2, 0, 0), SHIFT_REPEAT(120),
  [736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__statement_repeat1, 2, 0, 0),
  [738] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__statement_repeat1, 2, 0, 0),
  [740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bang, 1, 0, 0),
  [742] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bang, 1, 0, 0),
  [744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__map_lhs, 1, 0, 0),
  [746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(959),
  [748] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__map_lhs, 1, 0, 0),
  [750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3170),
  [754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3170),
  [756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3161),
  [760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__map_lhs_repeat1, 1, 0, 0),
  [762] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__map_lhs_repeat1, 1, 0, 0),
  [764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3341),
  [766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3341),
  [768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2414),
  [770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2414),
  [772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scriptencoding_statement, 1, 0, 0),
  [774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2748),
  [776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2748),
  [778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1700),
  [780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1700),
  [782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1925),
  [784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1925),
  [786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1751),
  [788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1751),
  [790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1562),
  [792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1562),
  [794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1679),
  [796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1679),
  [798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1726),
  [800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3087),
  [802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3087),
  [804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(134),
  [806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3249),
  [808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3235),
  [810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3235),
  [812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(135),
  [814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3343),
  [816] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__map_rhs, 1, 0, 0),
  [818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1805),
  [820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3027),
  [822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3027),
  [824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3083),
  [828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1899),
  [830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__map_rhs, 1, 0, 0),
  [832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3009),
  [834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3009),
  [836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3023),
  [838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3023),
  [840] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__map_rhs_repeat1, 1, 0, 0),
  [842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3058),
  [844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3058),
  [846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__map_rhs_repeat1, 1, 0, 0),
  [848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(165),
  [854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2339),
  [856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(289),
  [860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2335),
  [862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_statement, 1, 0, 0),
  [864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(957),
  [870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2256),
  [876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2234),
  [880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3046),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3046),
  [884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3297),
  [896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3297),
  [898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3060),
  [900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3060),
  [902] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifier, 2, 0, 0),
  [904] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_identifier, 2, 0, 0),
  [906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(143),
  [910] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0),
  [912] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0),
  [914] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(450),
  [917] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(143),
  [920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(159),
  [926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2235),
  [928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(290),
  [932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2232),
  [934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_echoerr_statement, 2, 0, 0),
  [936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(337),
  [942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2220),
  [946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2250),
  [950] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_echon_statement, 2, 0, 0),
  [952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unlet_statement, 2, 0, 0),
  [954] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_echo_statement, 1, 0, 0),
  [956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_echomsg_statement, 2, 0, 0),
  [958] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(199),
  [961] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(162),
  [964] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(159),
  [967] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2235),
  [970] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(421),
  [973] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(290),
  [976] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2232),
  [979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0),
  [981] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(290),
  [984] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(337),
  [987] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(337),
  [990] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(214),
  [993] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2220),
  [996] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(354),
  [999] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2250),
  [1002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [1004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [1006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [1008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(521),
  [1010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2348),
  [1012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3104),
  [1014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2231),
  [1016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(743),
  [1018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(743),
  [1020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [1022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [1024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [1026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2342),
  [1028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [1030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3287),
  [1032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [1034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(796),
  [1036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [1038] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_echomsg_statement, 1, 0, 0),
  [1040] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_execute_statement, 2, 0, 0),
  [1042] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_echoerr_statement, 1, 0, 0),
  [1044] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_echo_statement, 2, 0, 0),
  [1046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(780),
  [1048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(780),
  [1050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unlet_statement, 3, 0, 0),
  [1052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [1054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2991),
  [1056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [1058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(775),
  [1060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [1062] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifier, 1, 0, 0),
  [1064] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_identifier, 1, 0, 0),
  [1066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [1068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(161),
  [1070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3178),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [1076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(792),
  [1078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [1080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(163),
  [1082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [1084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2995),
  [1086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [1088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(795),
  [1090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [1092] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(446),
  [1095] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(163),
  [1098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [1100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [1102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(142),
  [1104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_echon_statement, 1, 0, 0),
  [1106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [1108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(785),
  [1110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [1112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [1114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(191),
  [1116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2316),
  [1118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [1120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(389),
  [1122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2312),
  [1124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [1126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [1128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(484),
  [1130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [1132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2317),
  [1134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [1136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2216),
  [1138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [1140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [1142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(939),
  [1144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [1146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [1148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(555),
  [1150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2218),
  [1152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [1154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(273),
  [1156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2214),
  [1158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 1, 0, 0),
  [1160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [1162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [1164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(687),
  [1166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [1168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2340),
  [1170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [1172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2245),
  [1174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [1176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1100),
  [1178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [1180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(592),
  [1182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [1184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [1186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [1188] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(432),
  [1191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(176),
  [1194] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(236),
  [1197] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(158),
  [1200] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(191),
  [1203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2316),
  [1206] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(407),
  [1209] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(389),
  [1212] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2312),
  [1215] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(389),
  [1218] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(484),
  [1221] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(484),
  [1224] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(206),
  [1227] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2317),
  [1230] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(506),
  [1233] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2216),
  [1236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [1238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(465),
  [1240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3199),
  [1242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [1244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [1246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(630),
  [1248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [1250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [1252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(704),
  [1254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [1256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [1258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(580),
  [1260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2241),
  [1262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [1264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(306),
  [1266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2362),
  [1268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [1270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [1272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(810),
  [1274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [1276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2247),
  [1278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [1280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2314),
  [1282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [1284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(193),
  [1286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(195),
  [1288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [1290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(314),
  [1292] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(424),
  [1295] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(195),
  [1298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [1300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(621),
  [1302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2411),
  [1304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3122),
  [1306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [1308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(645),
  [1310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [1312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scope_dict, 1, 0, 0),
  [1314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(352),
  [1316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(353),
  [1318] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scope_dict, 1, 0, 0),
  [1320] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__immediate_curly_braces_name_expression, 3, 0, 0),
  [1322] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__immediate_curly_braces_name_expression, 3, 0, 0),
  [1324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(732),
  [1326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [1328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(841),
  [1330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [1332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [1334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [1336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__curly_braces_name_expression, 3, 0, 0),
  [1338] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__curly_braces_name_expression, 3, 0, 0),
  [1340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3001),
  [1342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [1344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(658),
  [1346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [1348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [1350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [1352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3206),
  [1354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [1356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(665),
  [1358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [1360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [1362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [1364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3000),
  [1366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [1368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(674),
  [1370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [1372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [1374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [1376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [1378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(655),
  [1380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [1382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [1384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(791),
  [1386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [1388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(783),
  [1390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(783),
  [1392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [1394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(649),
  [1396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(649),
  [1398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [1400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(883),
  [1402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [1404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [1406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(678),
  [1408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(678),
  [1410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [1412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(635),
  [1414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [1416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [1418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [1420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(659),
  [1422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [1424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(838),
  [1426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(838),
  [1428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [1430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [1432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(918),
  [1434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [1436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [1438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [1440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(843),
  [1442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [1444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [1446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [1448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(663),
  [1450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [1452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [1454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(816),
  [1456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [1458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [1460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [1462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(668),
  [1464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(497),
  [1466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(487),
  [1468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [1470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [1472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(856),
  [1474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [1476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [1478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(911),
  [1480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [1482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [1484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [1486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
  [1488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(858),
  [1490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [1492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [1494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [1496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [1498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(640),
  [1500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [1502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [1504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(868),
  [1506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [1508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [1510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [1512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(870),
  [1514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [1516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [1518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [1520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(680),
  [1522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [1524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(875),
  [1526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [1528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [1530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(876),
  [1532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [1534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [1536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [1538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(700),
  [1540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [1542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [1544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(755),
  [1546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [1548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [1550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [1552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [1554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(925),
  [1556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(752),
  [1558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [1562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(788),
  [1564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [1566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [1568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(656),
  [1570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [1572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [1574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(794),
  [1576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(853),
  [1578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(853),
  [1580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [1582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [1584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(672),
  [1586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(672),
  [1588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [1590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(873),
  [1592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [1594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(692),
  [1596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [1598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(855),
  [1600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [1602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(717),
  [1604] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__assignment_variable, 1, 0, 0),
  [1606] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__ident, 1, 1, 0),
  [1608] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__assignment_variable, 1, 0, 0),
  [1610] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__ident, 1, 1, 0),
  [1612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [1614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(903),
  [1616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [1618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(915),
  [1620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(693),
  [1622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(693),
  [1624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [1626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(510),
  [1628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [1630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(589),
  [1632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [1634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(701),
  [1636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [1638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(712),
  [1640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [1642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(713),
  [1644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [1646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(660),
  [1648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [1650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(709),
  [1652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [1654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(584),
  [1656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [1658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(652),
  [1660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [1662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(601),
  [1664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [1666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(295),
  [1668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [1670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(599),
  [1672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [1674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(600),
  [1676] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionnary, 2, 0, 0),
  [1678] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dictionnary, 2, 0, 0),
  [1680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [1682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(736),
  [1684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_operation, 2, 0, 0),
  [1686] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_operation, 2, 0, 0),
  [1688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [1690] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_unary_operation, 2, 0, 0), SHIFT(341),
  [1693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [1695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2082),
  [1697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list, 2, 0, 0),
  [1699] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list, 2, 0, 0),
  [1701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_dictionary, 2, 0, 0),
  [1703] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_dictionary, 2, 0, 0),
  [1705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [1707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(312),
  [1709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [1711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(313),
  [1713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [1715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(928),
  [1717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [1719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(316),
  [1721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [1723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(317),
  [1725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionnary, 3, 0, 0),
  [1727] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dictionnary, 3, 0, 0),
  [1729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [1731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(784),
  [1733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [1735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(763),
  [1737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 3, 0, 0),
  [1739] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 3, 0, 0),
  [1741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list, 3, 0, 0),
  [1743] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list, 3, 0, 0),
  [1745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_dictionary, 3, 0, 0),
  [1747] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_dictionary, 3, 0, 0),
  [1749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_dictionary, 3, 0, 58),
  [1751] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_dictionary, 3, 0, 58),
  [1753] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 3, 0, 59),
  [1755] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 3, 0, 59),
  [1757] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_operation, 3, 0, 60),
  [1759] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_operation, 3, 0, 60),
  [1761] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_operation, 3, 0, 60), SHIFT(341),
  [1764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [1766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(341),
  [1768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [1770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [1772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [1774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(326),
  [1776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(194),
  [1778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [1780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [1782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_expression, 3, 0, 62),
  [1784] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_expression, 3, 0, 62),
  [1786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 4, 0, 0),
  [1788] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 4, 0, 0),
  [1790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionnary, 4, 0, 0),
  [1792] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dictionnary, 4, 0, 0),
  [1794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list, 4, 0, 0),
  [1796] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list, 4, 0, 0),
  [1798] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_dictionary, 4, 0, 58),
  [1800] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_dictionary, 4, 0, 58),
  [1802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_dictionary, 4, 0, 85),
  [1804] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_dictionary, 4, 0, 85),
  [1806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [1808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(331),
  [1810] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 4, 0, 59),
  [1812] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 4, 0, 59),
  [1814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_operation, 4, 0, 88),
  [1816] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_operation, 4, 0, 88),
  [1818] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 5, 0, 0),
  [1820] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 5, 0, 0),
  [1822] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionnary, 5, 0, 0),
  [1824] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dictionnary, 5, 0, 0),
  [1826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list, 5, 0, 0),
  [1828] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list, 5, 0, 0),
  [1830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_dictionary, 5, 0, 85),
  [1832] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_dictionary, 5, 0, 85),
  [1834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ternary_expression, 5, 0, 109),
  [1836] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ternary_expression, 5, 0, 109),
  [1838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [1840] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 5, 0, 59),
  [1842] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 5, 0, 59),
  [1844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__method_call_expression, 3, 0, 59),
  [1846] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__method_call_expression, 3, 0, 59),
  [1848] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 6, 0, 0),
  [1850] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 6, 0, 0),
  [1852] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__method_call_expression, 4, 0, 59),
  [1854] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__method_call_expression, 4, 0, 59),
  [1856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__method_call_expression, 5, 0, 59),
  [1858] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__method_call_expression, 5, 0, 59),
  [1860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_unlet_statement_repeat1, 1, 0, 0),
  [1862] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_unlet_statement_repeat1, 1, 0, 0),
  [1864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [1866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [1868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(707),
  [1870] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option, 2, 0, 0),
  [1872] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option, 2, 0, 0),
  [1874] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_env_variable, 2, 0, 0),
  [1876] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_env_variable, 2, 0, 0),
  [1878] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option, 3, 0, 0),
  [1880] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option, 3, 0, 0),
  [1882] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 3, 0, 61),
  [1884] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 3, 0, 61),
  [1886] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_expression, 4, 0, 89),
  [1888] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_expression, 4, 0, 89),
  [1890] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_expression, 4, 0, 90),
  [1892] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_index_expression, 4, 0, 90),
  [1894] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_expression, 5, 0, 110),
  [1896] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_expression, 5, 0, 110),
  [1898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_expression, 5, 0, 111),
  [1900] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_expression, 5, 0, 111),
  [1902] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_expression, 6, 0, 121),
  [1904] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_expression, 6, 0, 121),
  [1906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [1908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(931),
  [1910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [1912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(904),
  [1914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_identifier, 2, 0, 0),
  [1916] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scoped_identifier, 2, 0, 0),
  [1918] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument, 2, 0, 0),
  [1920] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument, 2, 0, 0),
  [1922] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument, 2, 0, 26),
  [1924] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument, 2, 0, 26),
  [1926] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_name, 1, 0, 0),
  [1928] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_name, 1, 0, 0),
  [1930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [1932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(804),
  [1934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [1936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(727),
  [1938] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_name, 2, 0, 0),
  [1940] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_name, 2, 0, 0),
  [1942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [1944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(942),
  [1946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [1948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(807),
  [1950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [1952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(809),
  [1954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [1956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(593),
  [1958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [1960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(818),
  [1962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [1964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(819),
  [1966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [1968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(669),
  [1970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [1972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(913),
  [1974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [1976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(914),
  [1978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [1980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(793),
  [1982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [1984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(667),
  [1986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [1988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(738),
  [1990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [1992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(947),
  [1994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [1996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(696),
  [1998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [2000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(797),
  [2002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [2004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [2006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [2008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(726),
  [2010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [2012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(657),
  [2014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(691),
  [2016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(691),
  [2018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [2020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(714),
  [2022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [2024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(830),
  [2026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [2028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(777),
  [2030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [2032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(926),
  [2034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [2036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(643),
  [2038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(851),
  [2040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(851),
  [2042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [2044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(500),
  [2046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [2048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(787),
  [2050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [2052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(932),
  [2054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [2056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(933),
  [2058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [2060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(462),
  [2062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [2064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(464),
  [2066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [2068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(466),
  [2070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [2072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(467),
  [2074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [2076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(475),
  [2078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [2080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(508),
  [2082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [2084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(828),
  [2086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [2088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(837),
  [2090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [2092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(865),
  [2094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [2096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(871),
  [2098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [2100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(877),
  [2102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [2104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(909),
  [2106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [2108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(924),
  [2110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [2112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(829),
  [2114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [2116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(831),
  [2118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [2120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(832),
  [2122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [2124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(833),
  [2126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [2128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(834),
  [2130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [2132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(836),
  [2134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [2136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(842),
  [2138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [2140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(845),
  [2142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [2144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(847),
  [2146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [2148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(848),
  [2150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(850),
  [2152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(850),
  [2154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [2156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(852),
  [2158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [2160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(854),
  [2162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(857),
  [2164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(857),
  [2166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [2168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(859),
  [2170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [2172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(861),
  [2174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [2176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(862),
  [2178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [2180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(863),
  [2182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [2184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(864),
  [2186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [2188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(866),
  [2190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [2192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(869),
  [2194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [2196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(874),
  [2198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [2200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(878),
  [2202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [2204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(879),
  [2206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [2208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(880),
  [2210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [2212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(935),
  [2214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [2216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(882),
  [2218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [2220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(884),
  [2222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [2224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(825),
  [2226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [2228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(885),
  [2230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [2232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(886),
  [2234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(887),
  [2236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(887),
  [2238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [2240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(888),
  [2242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [2244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(889),
  [2246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [2248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(890),
  [2250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [2252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(891),
  [2254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [2256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(892),
  [2258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [2260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(893),
  [2262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [2264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(894),
  [2266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [2268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(895),
  [2270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [2272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(896),
  [2274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [2276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(897),
  [2278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(898),
  [2280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(898),
  [2282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [2284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(899),
  [2286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [2288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(900),
  [2290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [2292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(901),
  [2294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [2296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(902),
  [2298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [2300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(571),
  [2302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [2304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(685),
  [2306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [2308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(686),
  [2310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(689),
  [2312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(689),
  [2314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [2316] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_operation, 3, 0, 60), SHIFT(394),
  [2319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [2321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2072),
  [2323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [2325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(394),
  [2327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(395),
  [2329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [2331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(185),
  [2333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [2335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [2337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [2339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [2341] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_unary_operation, 2, 0, 0), SHIFT(394),
  [2344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1592),
  [2346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1592),
  [2348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3250),
  [2350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3250),
  [2352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [2354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(511),
  [2356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(512),
  [2358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(438),
  [2361] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(512),
  [2364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(382),
  [2366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [2368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2211),
  [2370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [2372] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [2374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(376),
  [2376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [2378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2140),
  [2380] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variable, 1, 0, 0),
  [2382] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__variable, 1, 0, 0),
  [2384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2371),
  [2386] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syntax_statement, 1, 0, 0),
  [2388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2322),
  [2390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2324),
  [2392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2161),
  [2394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3165),
  [2396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2003),
  [2398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2189),
  [2400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2191),
  [2402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2201),
  [2404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3166),
  [2406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3330),
  [2408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3026),
  [2410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1951),
  [2412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1680),
  [2414] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(392),
  [2417] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(520),
  [2420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [2422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(523),
  [2424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2858),
  [2426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2634),
  [2428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2649),
  [2430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2289),
  [2432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3076),
  [2434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2143),
  [2436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2347),
  [2438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2213),
  [2440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2320),
  [2442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3269),
  [2444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3271),
  [2446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3280),
  [2448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1963),
  [2450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1641),
  [2452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(520),
  [2454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(526),
  [2456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [2458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_assignment, 3, 0, 0),
  [2460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_assignment, 3, 0, 0),
  [2462] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_assignment, 2, 0, 0),
  [2464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_assignment, 2, 0, 0),
  [2466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_assignment, 4, 0, 0),
  [2468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_assignment, 4, 0, 0),
  [2470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(551),
  [2472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [2474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region_end, 3, 0, 74),
  [2476] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_region_end, 3, 0, 74),
  [2478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3224),
  [2480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_hl_pattern, 3, 0, 0),
  [2482] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_hl_pattern, 3, 0, 0),
  [2484] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(444),
  [2487] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(553),
  [2490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [2492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(553),
  [2494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(554),
  [2496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [2498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [2500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(286),
  [2502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [2504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(288),
  [2506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [2508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2063),
  [2510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_match, 3, 0, 11),
  [2512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [2514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3291),
  [2516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1086),
  [2518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3101),
  [2520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3080),
  [2522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [2524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3247),
  [2526] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_match, 4, 0, 11),
  [2528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [2530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(582),
  [2532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(585),
  [2534] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_operation, 3, 0, 60), SHIFT(286),
  [2537] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(410),
  [2540] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(585),
  [2543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(171),
  [2545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [2547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [2549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [2551] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_unary_operation, 2, 0, 0), SHIFT(286),
  [2554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3265),
  [2556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3142),
  [2558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hl_groups, 1, 0, 0),
  [2560] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hl_groups, 1, 0, 0),
  [2562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [2564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3263),
  [2566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1097),
  [2568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3298),
  [2570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3068),
  [2572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [2574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3146),
  [2576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hl_groups, 2, 0, 0),
  [2578] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hl_groups, 2, 0, 0),
  [2580] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hl_groups_repeat1, 2, 0, 0), SHIFT_REPEAT(3142),
  [2583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hl_groups_repeat1, 2, 0, 0),
  [2585] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_hl_groups_repeat1, 2, 0, 0),
  [2587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(684),
  [2589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(724),
  [2591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_region_start, 3, 0, 74),
  [2593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region_start, 3, 0, 74),
  [2595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(912),
  [2597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3244),
  [2599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3061),
  [2601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [2603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3300),
  [2605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [2607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3148),
  [2609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [2611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3159),
  [2613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3225),
  [2615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2329),
  [2617] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__ident, 1, 1, 0), SHIFT(419),
  [2620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [2622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [2624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [2626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2550),
  [2628] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__ident, 1, 1, 0), SHIFT(384),
  [2631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__ident, 1, 1, 0), SHIFT(426),
  [2634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3160),
  [2636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [2638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [2640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(756),
  [2642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [2644] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_list_repeat1, 2, 0, 0),
  [2646] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_region_skip, 3, 0, 74),
  [2648] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region_skip, 3, 0, 74),
  [2650] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__ident, 1, 1, 0), SHIFT(405),
  [2653] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__ident, 1, 1, 0), SHIFT(412),
  [2656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [2658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [2660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [2662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [2664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [2666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [2668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(187),
  [2670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__map_definition, 4, 0, 94),
  [2672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [2674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [2676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(280),
  [2678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [2680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [2682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2077),
  [2684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [2686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [2688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat2, 1, 0, 43),
  [2690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3079),
  [2692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3025),
  [2694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3069),
  [2696] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__ident, 1, 1, 0), SHIFT(386),
  [2699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [2701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat2, 2, 0, 43),
  [2703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [2705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [2707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__const_assignment, 3, 0, 0),
  [2709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [2711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [2713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [2715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [2717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [2719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [2721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(361),
  [2723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [2725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(189),
  [2727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [2729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [2731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(362),
  [2733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [2735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [2737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2041),
  [2739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [2741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0),
  [2743] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(912),
  [2746] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(3244),
  [2749] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(3079),
  [2752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(912),
  [2755] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(3025),
  [2758] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(922),
  [2761] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(3069),
  [2764] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(934),
  [2767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [2769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [2771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [2773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [2775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(706),
  [2777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [2779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [2781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [2783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [2785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [2787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [2789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [2791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [2793] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2, 0, 0),
  [2795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_statement, 2, 0, 0),
  [2797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__map_definition, 3, 0, 68),
  [2799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [2801] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_operation, 3, 0, 60), SHIFT(299),
  [2804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_statement, 2, 0, 0),
  [2806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_eval_statement, 2, 0, 0),
  [2808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [2810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [2812] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__let_assignment, 3, 0, 0),
  [2814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_statement, 3, 0, 25),
  [2816] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_unary_operation, 2, 0, 0), SHIFT(299),
  [2819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_statement, 4, 0, 25),
  [2821] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_body, 1, 0, 0),
  [2823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2661),
  [2825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3180),
  [2827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3180),
  [2829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3181),
  [2831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3182),
  [2833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3183),
  [2835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3349),
  [2837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3185),
  [2839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3186),
  [2841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [2843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [2845] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(1001),
  [2848] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(3286),
  [2851] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(3093),
  [2854] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(1001),
  [2857] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(3062),
  [2860] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(989),
  [2863] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(3306),
  [2866] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(981),
  [2869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [2871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [2873] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_unary_operation, 2, 0, 0), SHIFT(361),
  [2876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [2878] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat2, 2, 0, 0), SHIFT_REPEAT(1846),
  [2881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat2, 2, 0, 0),
  [2883] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__syn_match_repeat2, 2, 0, 0),
  [2885] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionnary_entry, 3, 0, 84),
  [2887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [2889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [2891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [2893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [2895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [2897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [2899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [2901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1001),
  [2903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3286),
  [2905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3093),
  [2907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [2909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3062),
  [2911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [2913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3306),
  [2915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [2917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__literal_dictionary_entry, 3, 0, 84),
  [2919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [2921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [2923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [2925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [2927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [2929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [2931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [2933] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_parameter, 3, 0, 107),
  [2935] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_operation, 3, 0, 60), SHIFT(361),
  [2938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [2940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [2942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1650),
  [2944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_arguments_match, 1, 0, 43),
  [2946] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_arguments_match, 1, 0, 43),
  [2948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat2, 2, 0, 124),
  [2950] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__syn_match_repeat2, 2, 0, 124),
  [2952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [2954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [2956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [2958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2095),
  [2960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [2962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [2964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [2966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1843),
  [2968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [2970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1643),
  [2972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [2974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1846),
  [2976] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region_end, 4, 0, 125),
  [2978] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_region_end, 4, 0, 125),
  [2980] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region_end, 5, 0, 125),
  [2982] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_region_end, 5, 0, 125),
  [2984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [2986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [2988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [2990] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_arguments_match, 2, 0, 19),
  [2992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(609),
  [2994] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_arguments_match, 2, 0, 19),
  [2996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2338),
  [2998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [3000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2757),
  [3002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3292),
  [3004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3292),
  [3006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3296),
  [3008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3327),
  [3010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3338),
  [3012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3073),
  [3014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3090),
  [3016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3100),
  [3018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1651),
  [3020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [3022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [3024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [3026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [3028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [3030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [3032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(670),
  [3034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [3036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [3038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3202),
  [3040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3066),
  [3042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3055),
  [3044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3217),
  [3046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [3048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [3050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [3052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(731),
  [3054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [3056] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_body_keys, 2, 0, 0),
  [3058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(708),
  [3060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [3062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [3064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2527),
  [3066] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 1, 0, 43),
  [3068] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__syn_region_repeat1, 1, 0, 43),
  [3070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2112),
  [3072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [3074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [3076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [3078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [3080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2361),
  [3082] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_arguments_region, 1, 0, 43),
  [3084] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_arguments_region, 1, 0, 43),
  [3086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1648),
  [3088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [3090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2177),
  [3092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [3094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1601),
  [3096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2135),
  [3098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1946),
  [3100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1597),
  [3102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [3104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [3106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1614),
  [3108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1960),
  [3110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1675),
  [3112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [3114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1616),
  [3116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1612),
  [3118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1673),
  [3120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1615),
  [3122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1659),
  [3124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [3126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_body_keys, 3, 0, 0),
  [3128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_arguments_match, 3, 0, 74),
  [3130] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_arguments_match, 3, 0, 74),
  [3132] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0),
  [3134] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3180),
  [3137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3180),
  [3140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3181),
  [3143] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3182),
  [3146] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3183),
  [3149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3349),
  [3152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3185),
  [3155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3186),
  [3158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [3160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [3162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_arguments_keyword, 1, 0, 19),
  [3164] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_arguments_keyword, 1, 0, 19),
  [3166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3136),
  [3168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1702),
  [3170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [3172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_arguments_region, 2, 0, 19),
  [3174] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_arguments_region, 2, 0, 19),
  [3176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(751),
  [3178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_arguments_region, 3, 0, 74),
  [3180] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_arguments_region, 3, 0, 74),
  [3182] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(434),
  [3185] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(920),
  [3188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_arguments_keyword, 3, 0, 74),
  [3190] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_arguments_keyword, 3, 0, 74),
  [3192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_arguments_match, 1, 0, 19),
  [3194] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_arguments_match, 1, 0, 19),
  [3196] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(3061),
  [3199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(3300),
  [3202] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(3148),
  [3205] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0),
  [3207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [3209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [3211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3173),
  [3213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_arguments_keyword, 2, 0, 19),
  [3215] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_arguments_keyword, 2, 0, 19),
  [3217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1689),
  [3219] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_pattern_offset, 3, 0, 123),
  [3221] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_pattern_offset, 3, 0, 123),
  [3223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2419),
  [3225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3342),
  [3227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [3229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_arguments_region, 1, 0, 19),
  [3231] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_arguments_region, 1, 0, 19),
  [3233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [3235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3067),
  [3237] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(3066),
  [3240] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(3055),
  [3243] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat1, 2, 0, 0), SHIFT_REPEAT(3217),
  [3246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat2, 2, 0, 0), SHIFT_REPEAT(1857),
  [3249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(954),
  [3251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1852),
  [3253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_match, 5, 0, 97),
  [3255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_match, 5, 0, 115),
  [3257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1857),
  [3259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [3261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [3263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [3265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3292),
  [3268] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3292),
  [3271] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3296),
  [3274] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3327),
  [3277] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3338),
  [3280] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3073),
  [3283] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3090),
  [3286] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hl_body_keys_repeat1, 2, 0, 0), SHIFT_REPEAT(3100),
  [3289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_match, 4, 0, 97),
  [3291] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hl_groups_repeat1, 2, 0, 0), SHIFT_REPEAT(3067),
  [3294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(279),
  [3296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [3298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_match, 6, 0, 115),
  [3300] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__map_lhs, 2, 0, 0),
  [3302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(963),
  [3304] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__map_lhs, 2, 0, 0),
  [3306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1796),
  [3308] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__map_lhs_repeat1, 2, 0, 0),
  [3310] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__map_lhs_repeat1, 2, 0, 0), SHIFT_REPEAT(963),
  [3313] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__map_lhs_repeat1, 2, 0, 0),
  [3315] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__map_lhs_repeat1, 2, 0, 0), SHIFT_REPEAT(123),
  [3318] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__map_lhs_repeat1, 2, 0, 0), SHIFT_REPEAT(3161),
  [3321] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_region_start, 4, 0, 125),
  [3323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region_start, 4, 0, 125),
  [3325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(975),
  [3327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__map_lhs, 3, 0, 0),
  [3329] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__map_lhs, 3, 0, 0),
  [3331] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_region_start, 5, 0, 125),
  [3333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region_start, 5, 0, 125),
  [3335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_match, 5, 0, 11),
  [3337] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hl_groups_repeat1, 2, 0, 0), SHIFT_REPEAT(3344),
  [3340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3344),
  [3342] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_region_skip, 5, 0, 125),
  [3344] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region_skip, 5, 0, 125),
  [3346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_match, 6, 0, 97),
  [3348] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_region_skip, 4, 0, 125),
  [3350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region_skip, 4, 0, 125),
  [3352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_match, 7, 0, 115),
  [3354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0),
  [3356] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(1086),
  [3359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(3291),
  [3362] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(1086),
  [3365] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(3101),
  [3368] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(3080),
  [3371] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(1060),
  [3374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1134),
  [3376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3158),
  [3378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1134),
  [3380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3162),
  [3382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3168),
  [3384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1136),
  [3386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [3388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_keycode, 3, 0, 0),
  [3390] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_keycode, 3, 0, 0),
  [3392] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat2, 2, 0, 0), SHIFT_REPEAT(1852),
  [3395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3082),
  [3397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1008),
  [3399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__immediate_keycode, 3, 0, 0),
  [3401] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__immediate_keycode, 3, 0, 0),
  [3403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1532),
  [3405] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(1097),
  [3408] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(3263),
  [3411] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(1097),
  [3414] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(3298),
  [3417] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(3068),
  [3420] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(1102),
  [3423] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hl_groups_repeat1, 2, 0, 0), SHIFT_REPEAT(3082),
  [3426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__map_lhs_repeat1, 1, 0, 29),
  [3428] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__map_lhs_repeat1, 1, 0, 29),
  [3430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2986),
  [3432] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__pattern_branch, 1, 0, 0),
  [3434] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__pattern_branch, 1, 0, 0),
  [3436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1699),
  [3438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2321),
  [3440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1035),
  [3442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1531),
  [3444] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(1134),
  [3447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(3158),
  [3450] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(1134),
  [3453] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(3162),
  [3456] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(3168),
  [3459] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 2, 0, 0), SHIFT_REPEAT(1136),
  [3462] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat2, 2, 0, 0), SHIFT_REPEAT(1796),
  [3465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1703),
  [3467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [3469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1346),
  [3471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_statement, 1, 0, 0),
  [3473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [3475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1962),
  [3477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2337),
  [3479] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__pattern_piece, 1, 0, 0),
  [3481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__pattern_piece, 1, 0, 0),
  [3483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1294),
  [3485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3064),
  [3487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1686),
  [3489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2304),
  [3491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1030),
  [3493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1523),
  [3495] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(3064),
  [3498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0),
  [3500] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0),
  [3502] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2304),
  [3505] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1032),
  [3508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(141),
  [3510] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hl_key_start_stop, 3, 0, 96),
  [3512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1034),
  [3514] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hl_term_list, 2, 0, 0), SHIFT_REPEAT(141),
  [3517] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__hl_term_list, 2, 0, 0),
  [3519] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hl_term_list, 2, 0, 0), SHIFT_REPEAT(1034),
  [3522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1284),
  [3524] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2986),
  [3527] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2321),
  [3530] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1036),
  [3533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(985),
  [3535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1291),
  [3537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3117),
  [3539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1657),
  [3541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2266),
  [3543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1041),
  [3545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1543),
  [3547] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(3117),
  [3550] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2266),
  [3553] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1043),
  [3556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1298),
  [3558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3123),
  [3560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1661),
  [3562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2270),
  [3564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1044),
  [3566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1544),
  [3568] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(3123),
  [3571] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2270),
  [3574] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1046),
  [3577] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(3064),
  [3580] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0),
  [3582] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0),
  [3584] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2304),
  [3587] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1030),
  [3590] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1523),
  [3593] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2986),
  [3596] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2321),
  [3599] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1035),
  [3602] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1531),
  [3605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__syn_match_repeat1, 1, 0, 70),
  [3607] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__syn_match_repeat1, 1, 0, 70),
  [3609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 3, 0, 0),
  [3611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__pattern_ordinary_atom, 3, 0, 0),
  [3613] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__pattern_atom, 3, 0, 0),
  [3615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__pattern_atom, 3, 0, 0),
  [3617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0),
  [3619] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0),
  [3621] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hl_term_list, 2, 0, 0), SHIFT_REPEAT(140),
  [3624] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hl_term_list, 2, 0, 0), SHIFT_REPEAT(1054),
  [3627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hl_term_list, 2, 0, 0),
  [3629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3011),
  [3631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_plus_cmd, 1, 0, 0),
  [3633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1691),
  [3635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2610),
  [3637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3255),
  [3639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1406),
  [3641] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hl_groups_repeat1, 2, 0, 0), SHIFT_REPEAT(3011),
  [3644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1862),
  [3646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [3648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1480),
  [3650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2088),
  [3652] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(3117),
  [3655] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2266),
  [3658] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1041),
  [3661] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1543),
  [3664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1306),
  [3666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_statement, 1, 0, 0),
  [3668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2215),
  [3670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3006),
  [3672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3021),
  [3674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1499),
  [3676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1500),
  [3678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3057),
  [3680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1625),
  [3682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3169),
  [3684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1613),
  [3686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1057),
  [3688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edit_statement, 1, 0, 0),
  [3690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3059),
  [3692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1716),
  [3694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1716),
  [3696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1688),
  [3698] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(3123),
  [3701] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2270),
  [3704] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1044),
  [3707] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1544),
  [3710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(140),
  [3712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1054),
  [3714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_key_start_stop, 3, 0, 96),
  [3716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1063),
  [3718] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(3135),
  [3721] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2277),
  [3724] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1087),
  [3727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1373),
  [3729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2633),
  [3731] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hl_attr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1329),
  [3734] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hl_attr_list_repeat1, 2, 0, 0),
  [3736] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__hl_attr_list_repeat1, 2, 0, 0),
  [3738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1415),
  [3740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3086),
  [3742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1642),
  [3744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2251),
  [3746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1090),
  [3748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1539),
  [3750] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(3086),
  [3753] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2251),
  [3756] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1092),
  [3759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1674),
  [3761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1101),
  [3763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_visual_statement, 1, 0, 0),
  [3765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1690),
  [3767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1747),
  [3769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2428),
  [3771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3126),
  [3773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1552),
  [3775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_plus_cmd, 1, 0, 0),
  [3777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1329),
  [3779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_attr_list, 1, 0, 0),
  [3781] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hl_attr_list, 1, 0, 0),
  [3783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_case, 1, 0, 0),
  [3785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_case, 1, 0, 0),
  [3787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1787),
  [3789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2635),
  [3791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3008),
  [3793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1565),
  [3795] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(3072),
  [3798] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2246),
  [3801] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1103),
  [3804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_attr_list, 2, 0, 0),
  [3806] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hl_attr_list, 2, 0, 0),
  [3808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1424),
  [3810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3049),
  [3812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1694),
  [3814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2236),
  [3816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1106),
  [3818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1537),
  [3820] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(3049),
  [3823] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2236),
  [3826] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1108),
  [3829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1431),
  [3831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3129),
  [3833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1665),
  [3835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2274),
  [3837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1109),
  [3839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1545),
  [3841] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(3129),
  [3844] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2274),
  [3847] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1111),
  [3850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1441),
  [3852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3135),
  [3854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1667),
  [3856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2277),
  [3858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1112),
  [3860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1547),
  [3862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1451),
  [3864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3141),
  [3866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1668),
  [3868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2280),
  [3870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1115),
  [3872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1450),
  [3874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3320),
  [3876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1677),
  [3878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1095),
  [3880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3313),
  [3882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1855),
  [3884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1855),
  [3886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1638),
  [3888] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(3141),
  [3891] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2280),
  [3894] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1118),
  [3897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1506),
  [3899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3072),
  [3901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1639),
  [3903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2246),
  [3905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1120),
  [3907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1538),
  [3909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1735),
  [3911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1158),
  [3913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1685),
  [3915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_statement, 2, 0, 0),
  [3917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2319),
  [3919] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(3049),
  [3922] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2236),
  [3925] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1106),
  [3928] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1537),
  [3931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edit_statement, 2, 0, 0),
  [3933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3253),
  [3935] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(3072),
  [3938] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2246),
  [3941] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1120),
  [3944] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1538),
  [3947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3207),
  [3949] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(3129),
  [3952] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2274),
  [3955] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1109),
  [3958] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1545),
  [3961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1267),
  [3963] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(3135),
  [3966] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2277),
  [3969] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1112),
  [3972] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1547),
  [3975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1874),
  [3977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2581),
  [3979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3032),
  [3981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1692),
  [3983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edit_statement, 3, 0, 0),
  [3985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3153),
  [3987] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(3141),
  [3990] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2280),
  [3993] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1115),
  [3996] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1450),
  [3999] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hl_attr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1267),
  [4002] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(3086),
  [4005] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2251),
  [4008] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1090),
  [4011] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1539),
  [4014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3301),
  [4016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1672),
  [4018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2295),
  [4020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [4022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1437),
  [4024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3294),
  [4026] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__syn_keyword_repeat2, 2, 0, 0),
  [4028] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_keyword_repeat2, 2, 0, 0), SHIFT_REPEAT(1352),
  [4031] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_keyword_repeat2, 2, 0, 0), SHIFT_REPEAT(3205),
  [4034] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_keyword_repeat2, 2, 0, 0), SHIFT_REPEAT(3053),
  [4037] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_keyword_repeat2, 2, 0, 0), SHIFT_REPEAT(1176),
  [4040] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_keyword, 5, 0, 11),
  [4042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1352),
  [4044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3205),
  [4046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3053),
  [4048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1176),
  [4050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(441),
  [4052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1717),
  [4054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1937),
  [4056] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__autocmd_list, 1, 0, 0),
  [4058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2102),
  [4060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2144),
  [4062] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_quoted_name, 3, 0, 0),
  [4064] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hl_quoted_name, 3, 0, 0),
  [4066] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hl_groups_repeat1, 2, 0, 0), SHIFT_REPEAT(3294),
  [4069] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ex_statement, 1, 0, 0),
  [4071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__complete_range_marker, 1, 0, 0),
  [4073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_marker, 1, 0, 0),
  [4075] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__range_marker, 1, 0, 0), REDUCE(sym__complete_range_marker, 1, 0, 0),
  [4078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3074),
  [4080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1512),
  [4082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2465),
  [4084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1533),
  [4086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2500),
  [4088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2501),
  [4090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2502),
  [4092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2503),
  [4094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1511),
  [4096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1818),
  [4098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1438),
  [4100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3299),
  [4102] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(3301),
  [4105] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2295),
  [4108] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1188),
  [4111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ex_statement, 2, 0, 0),
  [4113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [4115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_visual_statement, 2, 0, 0),
  [4117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hl_attribute, 1, 0, 33),
  [4119] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hl_attribute, 1, 0, 33),
  [4121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1205),
  [4123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filename, 1, 0, 0),
  [4125] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_filename, 1, 0, 0),
  [4127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1205),
  [4129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3109),
  [4131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_define_argument, 2, 0, 19),
  [4133] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__sign_define_argument, 2, 0, 19),
  [4135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1201),
  [4137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [4139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3110),
  [4141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1654),
  [4143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2263),
  [4145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1234),
  [4147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1542),
  [4149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1207),
  [4151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filename, 2, 0, 0),
  [4153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_filename, 2, 0, 0),
  [4155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1207),
  [4157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1208),
  [4159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [4161] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(3110),
  [4164] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2263),
  [4167] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1206),
  [4170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filename, 3, 0, 0),
  [4172] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_filename, 3, 0, 0),
  [4174] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1208),
  [4177] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0),
  [4179] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0),
  [4181] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1208),
  [4184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1212),
  [4186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1212),
  [4188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_visual_statement, 3, 0, 0),
  [4190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1213),
  [4192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1213),
  [4194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1214),
  [4196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1214),
  [4198] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1214),
  [4201] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1214),
  [4204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_keyword, 3, 0, 11),
  [4206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1228),
  [4208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3241),
  [4210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_key_cterm, 3, 0, 96),
  [4212] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hl_key_cterm, 3, 0, 96),
  [4214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1669),
  [4216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_key_ctermfg_ctermbg, 3, 0, 96),
  [4218] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hl_key_ctermfg_ctermbg, 3, 0, 96),
  [4220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_color, 1, 0, 0),
  [4222] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_color, 1, 0, 0),
  [4224] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_key_gui, 3, 0, 96),
  [4226] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hl_key_gui, 3, 0, 96),
  [4228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_key_gui_color, 3, 0, 96),
  [4230] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hl_key_gui_color, 3, 0, 96),
  [4232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_font, 1, 0, 0),
  [4234] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_font, 1, 0, 0),
  [4236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_key_font, 3, 0, 96),
  [4238] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hl_key_font, 3, 0, 96),
  [4240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_key_blend, 3, 0, 96),
  [4242] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hl_key_blend, 3, 0, 96),
  [4244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1175),
  [4246] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_keyword, 4, 0, 11),
  [4248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1177),
  [4250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [4252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2323),
  [4254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1486),
  [4256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2341),
  [4258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2346),
  [4260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2217),
  [4262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2281),
  [4264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [4266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2388),
  [4268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1652),
  [4270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_previous_pattern, 1, 0, 0),
  [4272] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(3301),
  [4275] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2295),
  [4278] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1219),
  [4281] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1437),
  [4284] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(3174),
  [4287] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2343),
  [4290] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1237),
  [4293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1244),
  [4295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1244),
  [4297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1708),
  [4299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2992),
  [4301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1666),
  [4303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2222),
  [4305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [4307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1405),
  [4309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(408),
  [4311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1839),
  [4313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2074),
  [4315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2141),
  [4317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2262),
  [4319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_list, 1, 0, 0),
  [4321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1247),
  [4323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1247),
  [4325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1248),
  [4327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [4329] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2992),
  [4332] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2222),
  [4335] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1245),
  [4338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2017),
  [4340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2532),
  [4342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3251),
  [4344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1804),
  [4346] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1248),
  [4349] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1248),
  [4352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1250),
  [4354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3042),
  [4356] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hl_groups_repeat1, 2, 0, 0), SHIFT_REPEAT(3042),
  [4359] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_keyword_repeat2, 2, 0, 0), SHIFT_REPEAT(1459),
  [4362] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_keyword_repeat2, 2, 0, 0), SHIFT_REPEAT(3279),
  [4365] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_keyword_repeat2, 2, 0, 0), SHIFT_REPEAT(3024),
  [4368] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_keyword_repeat2, 2, 0, 0), SHIFT_REPEAT(1254),
  [4371] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_current_line, 1, 0, 0),
  [4373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_next_line, 1, 0, 0),
  [4375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_line, 1, 0, 0),
  [4377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1459),
  [4379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3279),
  [4381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3024),
  [4383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1254),
  [4385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3285),
  [4387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1330),
  [4389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1914),
  [4391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1246),
  [4393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1681),
  [4395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1919),
  [4397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_highlight_statement, 1, 0, 0),
  [4399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(730),
  [4401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3164),
  [4403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2331),
  [4405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2921),
  [4407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1219),
  [4409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3219),
  [4411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [4413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1266),
  [4415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1268),
  [4417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1268),
  [4419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1269),
  [4421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1269),
  [4423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [4425] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1269),
  [4428] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1269),
  [4431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1274),
  [4433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1274),
  [4435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1744),
  [4437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3095),
  [4439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1644),
  [4441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2255),
  [4443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1271),
  [4445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1540),
  [4447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1276),
  [4449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1276),
  [4451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1277),
  [4453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1277),
  [4455] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(3095),
  [4458] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2255),
  [4461] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1275),
  [4464] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1277),
  [4467] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1277),
  [4470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3085),
  [4472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1264),
  [4474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [4476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3103),
  [4478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1647),
  [4480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2259),
  [4482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1332),
  [4484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1541),
  [4486] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(3103),
  [4489] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(2259),
  [4492] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom, 2, 0, 0), SHIFT_REPEAT(1280),
  [4495] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(3110),
  [4498] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2263),
  [4501] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1234),
  [4504] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1542),
  [4507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_multi, 1, 0, 0),
  [4509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_multi, 1, 0, 0),
  [4511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__pattern_piece, 2, 0, 0),
  [4513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__pattern_piece, 2, 0, 0),
  [4515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__complete_range_marker, 3, 0, 0),
  [4517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_marker, 3, 0, 0),
  [4519] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__range_marker, 3, 0, 0), REDUCE(sym__complete_range_marker, 3, 0, 0),
  [4522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3043),
  [4524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2150),
  [4526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3039),
  [4528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1715),
  [4530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1364),
  [4532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1364),
  [4534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2990),
  [4536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1239),
  [4538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [4540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3169),
  [4542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1741),
  [4544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3174),
  [4546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1636),
  [4548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2343),
  [4550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1316),
  [4552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1534),
  [4554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1140),
  [4556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1258),
  [4558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1709),
  [4560] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(454),
  [4563] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1333),
  [4566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1339),
  [4568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [4570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1775),
  [4572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3260),
  [4574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1389),
  [4576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [4578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(131),
  [4580] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2992),
  [4583] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2222),
  [4586] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1240),
  [4589] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1405),
  [4592] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1339),
  [4595] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1339),
  [4598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [4600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1348),
  [4602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2073),
  [4604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(849),
  [4606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2987),
  [4608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2580),
  [4610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2790),
  [4612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1351),
  [4614] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(442),
  [4617] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1351),
  [4620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1354),
  [4622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1354),
  [4624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [4626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1355),
  [4628] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1355),
  [4631] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1355),
  [4634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [4636] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edit_statement, 4, 0, 0),
  [4638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3105),
  [4640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2443),
  [4642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2442),
  [4644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2219),
  [4646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2228),
  [4648] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filetype_statement, 1, 0, 0),
  [4650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__autocmd_remove, 2, 0, 0),
  [4652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__syn_keyword_repeat2, 1, 0, 70),
  [4654] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__syn_keyword_repeat2, 1, 0, 70),
  [4656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1357),
  [4658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1357),
  [4660] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__plus_cmd_command, 1, 0, 49),
  [4662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [4664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1368),
  [4666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1404),
  [4668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1337),
  [4670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1337),
  [4672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [4674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1371),
  [4676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1333),
  [4678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1378),
  [4680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1627),
  [4682] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_edit_statement_repeat1, 2, 0, 0),
  [4684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_edit_statement_repeat1, 2, 0, 0),
  [4686] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_edit_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1688),
  [4689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1656),
  [4691] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(3095),
  [4694] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2255),
  [4697] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1271),
  [4700] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1540),
  [4703] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(3174),
  [4706] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2343),
  [4709] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1316),
  [4712] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1534),
  [4715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3144),
  [4717] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__plus_cmd_pattern, 2, 0, 80),
  [4719] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(3103),
  [4722] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(2259),
  [4725] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1332),
  [4728] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_concat, 2, 0, 0), SHIFT_REPEAT(1541),
  [4731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3119),
  [4733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_command_statement_repeat1, 2, 0, 0),
  [4735] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3006),
  [4738] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3021),
  [4741] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1499),
  [4744] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1500),
  [4747] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3057),
  [4750] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1625),
  [4753] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__plus_cmd_arg, 2, 0, 0),
  [4755] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__plus_cmd_arg, 2, 0, 0), SHIFT_REPEAT(3255),
  [4758] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__plus_cmd_arg, 2, 0, 0), SHIFT_REPEAT(1406),
  [4761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1334),
  [4763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1334),
  [4765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3243),
  [4767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2999),
  [4769] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(452),
  [4772] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1404),
  [4775] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__plus_cmd_arg, 1, 0, 0),
  [4777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [4779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1446),
  [4781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1410),
  [4783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1410),
  [4785] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1410),
  [4788] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1410),
  [4791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1411),
  [4793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3047),
  [4795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1549),
  [4797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1549),
  [4799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2509),
  [4801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2510),
  [4803] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_edit_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1690),
  [4806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1234),
  [4808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1623),
  [4810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3096),
  [4812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1687),
  [4814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1687),
  [4816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2587),
  [4818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2588),
  [4820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1101),
  [4822] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ex_statement, 3, 0, 0),
  [4824] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_visual_statement, 4, 0, 0),
  [4826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_statement, 2, 0, 0),
  [4828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [4830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1321),
  [4832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [4834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3112),
  [4836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [4838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__plus_cmd_command, 1, 0, 49),
  [4840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [4842] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_edit_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1638),
  [4845] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(417),
  [4848] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1446),
  [4851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [4853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1720),
  [4855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1561),
  [4857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1752),
  [4859] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__set_option, 1, 0, 0),
  [4861] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__set_option, 1, 0, 0),
  [4863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_statement, 2, 0, 0),
  [4865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [4867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1467),
  [4869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [4871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1462),
  [4873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1463),
  [4875] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(453),
  [4878] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1463),
  [4881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1471),
  [4883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1471),
  [4885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2096),
  [4887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2097),
  [4889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1881),
  [4891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1972),
  [4893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1895),
  [4895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2966),
  [4897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1483),
  [4899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1488),
  [4901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1488),
  [4903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1492),
  [4905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [4907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2037),
  [4909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2038),
  [4911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1754),
  [4913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1959),
  [4915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1755),
  [4917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2883),
  [4919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2750),
  [4921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2821),
  [4923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2318),
  [4925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2297),
  [4927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [4929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [4931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1408),
  [4933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1215),
  [4935] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(436),
  [4938] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1483),
  [4941] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__plus_cmd_arg, 2, 0, 0), SHIFT_REPEAT(3126),
  [4944] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__plus_cmd_arg, 2, 0, 0), SHIFT_REPEAT(1552),
  [4947] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__plus_cmd_arg, 2, 0, 0),
  [4949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [4951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1115),
  [4953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3290),
  [4955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1221),
  [4957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1220),
  [4959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3223),
  [4961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [4963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [4965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1229),
  [4967] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1492),
  [4970] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1492),
  [4973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1331),
  [4975] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_remove, 2, 0, 0),
  [4977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2386),
  [4979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_attribute, 1, 0, 19),
  [4981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3332),
  [4983] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__plus_cmd_arg, 2, 0, 0), SHIFT_REPEAT(3008),
  [4986] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__plus_cmd_arg, 2, 0, 0), SHIFT_REPEAT(1565),
  [4989] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1962),
  [4992] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(439),
  [4995] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1346),
  [4998] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_let_statement_repeat1, 2, 0, 0),
  [5000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1409),
  [5002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1409),
  [5004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1504),
  [5006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1504),
  [5008] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_highlight_statement, 2, 0, 0),
  [5010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [5012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1120),
  [5014] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__complete_range, 1, 0, 1),
  [5016] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range, 1, 0, 1),
  [5018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1260),
  [5020] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_keyword_repeat1, 2, 0, 0), SHIFT_REPEAT(1352),
  [5023] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_keyword_repeat1, 2, 0, 0), SHIFT_REPEAT(3205),
  [5026] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_keyword_repeat1, 2, 0, 0), SHIFT_REPEAT(3053),
  [5029] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__syn_keyword_repeat1, 2, 0, 0),
  [5031] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_edit_statement_repeat2, 2, 0, 0),
  [5033] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_edit_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(1057),
  [5036] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_edit_statement_repeat2, 2, 0, 0),
  [5038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [5040] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__plus_cmd_pattern, 2, 0, 80),
  [5042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2128),
  [5044] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_item, 1, 0, 15),
  [5046] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_set_item, 1, 0, 15),
  [5048] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__plus_cmd_arg, 2, 0, 0), SHIFT_REPEAT(3032),
  [5051] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__plus_cmd_arg, 2, 0, 0), SHIFT_REPEAT(1692),
  [5054] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0),
  [5056] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__plus_cmd_arg, 1, 0, 0),
  [5058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1814),
  [5060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_statement, 2, 0, 25),
  [5062] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_edit_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(1095),
  [5065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [5067] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_plus_plus_opt, 2, 0, 18),
  [5069] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_plus_plus_opt, 2, 0, 18),
  [5071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1742),
  [5073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_option, 2, 0, 0),
  [5075] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_default_option, 2, 0, 0),
  [5077] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_plus_plus_opt, 4, 0, 104),
  [5079] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_plus_plus_opt, 4, 0, 104),
  [5081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(970),
  [5083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3016),
  [5085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1589),
  [5087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(122),
  [5089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_define, 2, 0, 41),
  [5091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3014),
  [5093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3038),
  [5095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3040),
  [5097] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_edit_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(1101),
  [5100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_statement, 1, 0, 0),
  [5102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2899),
  [5104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [5106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2207),
  [5108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2237),
  [5110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1575),
  [5112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1575),
  [5114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1578),
  [5116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1578),
  [5118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1579),
  [5120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1579),
  [5122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [5124] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1579),
  [5127] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1579),
  [5130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_statement, 3, 0, 25),
  [5132] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2088),
  [5135] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(401),
  [5138] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_let_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1480),
  [5141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_define, 3, 0, 41),
  [5143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_place_place, 2, 0, 45),
  [5145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3208),
  [5147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3092),
  [5149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3209),
  [5151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3210),
  [5153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1763),
  [5155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_attribute, 3, 0, 74),
  [5157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_attribute_completion_behavior, 1, 0, 19),
  [5159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_attribute, 3, 0, 75),
  [5161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_attribute_range_value, 1, 0, 48),
  [5163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_attribute, 3, 0, 76),
  [5165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_attribute_address_behavior, 1, 0, 19),
  [5167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_attribute, 3, 0, 77),
  [5169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1676),
  [5171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__sign_define_repeat1, 2, 0, 0),
  [5173] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_define_repeat1, 2, 0, 0), SHIFT_REPEAT(3014),
  [5176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_define_repeat1, 2, 0, 0), SHIFT_REPEAT(3038),
  [5179] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__sign_define_repeat1, 2, 0, 0), SHIFT_REPEAT(3040),
  [5182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1109),
  [5184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__sign_place_place_repeat1, 2, 0, 0),
  [5186] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_place_place_repeat1, 2, 0, 0), SHIFT_REPEAT(3208),
  [5189] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_place_place_repeat1, 2, 0, 0), SHIFT_REPEAT(3092),
  [5192] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_place_place_repeat1, 2, 0, 0), SHIFT_REPEAT(3209),
  [5195] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_place_place_repeat1, 2, 0, 0), SHIFT_REPEAT(3210),
  [5198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1836),
  [5200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1682),
  [5202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1842),
  [5204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_attribute_completion_behavior, 3, 0, 74),
  [5206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1628),
  [5208] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_edit_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1685),
  [5211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3246),
  [5213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3282),
  [5215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3339),
  [5217] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__complete_range_explicit, 1, 0, 3),
  [5219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1186),
  [5221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1740),
  [5223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3157),
  [5225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2023),
  [5227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__bang_filter_command, 1, 0, 54),
  [5229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2086),
  [5231] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__syn_keyword_repeat1, 1, 0, 70),
  [5233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3177),
  [5235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3190),
  [5237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3190),
  [5239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1701),
  [5241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1701),
  [5243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3203),
  [5245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2702),
  [5247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3236),
  [5249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3237),
  [5251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2942),
  [5253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1941),
  [5255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1145),
  [5257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2990),
  [5259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_runtime_statement, 4, 0, 79),
  [5261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1923),
  [5263] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_map_statement_repeat1, 2, 0, 0),
  [5265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_map_statement_repeat1, 2, 0, 0),
  [5267] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_map_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1656),
  [5270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_runtime_statement, 3, 0, 40),
  [5272] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_assignment, 5, 0, 0),
  [5274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_assignment, 5, 0, 0),
  [5276] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_runtime_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2990),
  [5279] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_runtime_statement_repeat1, 2, 0, 0),
  [5281] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_runtime_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1239),
  [5284] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_runtime_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1239),
  [5287] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__syn_sync_repeat1, 2, 0, 102),
  [5289] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__syn_sync_repeat1, 2, 0, 102), SHIFT_REPEAT(3207),
  [5292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1732),
  [5294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1748),
  [5296] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__sign_define_arg_text, 1, 0, 0),
  [5298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2988),
  [5300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3221),
  [5302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3226),
  [5304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3308),
  [5306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2227),
  [5308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3218),
  [5310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3188),
  [5312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2692),
  [5314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1811),
  [5316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [5318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3195),
  [5320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3196),
  [5322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3196),
  [5324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1940),
  [5326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1940),
  [5328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3197),
  [5330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1819),
  [5332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_runtime_statement, 2, 0, 20),
  [5334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3238),
  [5336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3239),
  [5338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3239),
  [5340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1777),
  [5342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1777),
  [5344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3240),
  [5346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2244),
  [5348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3257),
  [5350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3258),
  [5352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3258),
  [5354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1558),
  [5356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1558),
  [5358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3259),
  [5360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3274),
  [5362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3275),
  [5364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3275),
  [5366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1663),
  [5368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1663),
  [5370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3276),
  [5372] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__plus_cmd_number, 1, 0, 48),
  [5374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__plus_cmd_number, 1, 0, 48),
  [5376] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_plus_cmd, 2, 0, 0),
  [5378] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_plus_cmd, 2, 0, 0),
  [5380] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_edit_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(1158),
  [5383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1767),
  [5385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_define_repeat1, 2, 0, 0), SHIFT_REPEAT(3246),
  [5388] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_define_repeat1, 2, 0, 0), SHIFT_REPEAT(3282),
  [5391] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__sign_define_repeat1, 2, 0, 0), SHIFT_REPEAT(3339),
  [5394] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_place_place_repeat1, 2, 0, 0), SHIFT_REPEAT(2988),
  [5397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_place_place_repeat1, 2, 0, 0), SHIFT_REPEAT(3221),
  [5400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_place_place_repeat1, 2, 0, 0), SHIFT_REPEAT(3226),
  [5403] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_place_place_repeat1, 2, 0, 0), SHIFT_REPEAT(3308),
  [5406] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_assignment, 6, 0, 0),
  [5408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_assignment, 6, 0, 0),
  [5410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1342),
  [5412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [5414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_no_option, 2, 0, 0),
  [5416] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_no_option, 2, 0, 0),
  [5418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1246),
  [5420] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__bang_filter_command_argument, 2, 0, 0),
  [5422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1737),
  [5424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__bang_filter_command_argument, 2, 0, 0),
  [5426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1738),
  [5428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1766),
  [5430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1766),
  [5432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(448),
  [5434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1718),
  [5436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1721),
  [5438] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__plus_cmd_arg, 2, 0, 0), SHIFT_REPEAT(3251),
  [5441] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__plus_cmd_arg, 2, 0, 0), SHIFT_REPEAT(1804),
  [5444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inv_option, 2, 0, 0),
  [5446] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inv_option, 2, 0, 0),
  [5448] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(448),
  [5451] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1721),
  [5454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2130),
  [5456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2156),
  [5458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_user_command, 1, 0, 0),
  [5460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2156),
  [5462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_colorscheme_statement, 1, 0, 0),
  [5464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1743),
  [5466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1745),
  [5468] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_edit_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1681),
  [5471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_define_argument, 3, 0, 74),
  [5473] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__sign_define_argument, 3, 0, 74),
  [5475] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1686),
  [5478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unknown_builtin_statement, 2, 0, 25),
  [5480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_place_place_argument, 3, 0, 74),
  [5482] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__bang_filter_command_argument_repeat1, 2, 0, 0),
  [5484] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__bang_filter_command_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(1737),
  [5487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__bang_filter_command_argument_repeat1, 2, 0, 0),
  [5489] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__bang_filter_command_argument, 3, 0, 0),
  [5491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__bang_filter_command_argument, 3, 0, 0),
  [5493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_statement, 2, 0, 0),
  [5495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__bang_filter_command_argument, 1, 0, 0),
  [5497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1713),
  [5499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__bang_filter_command_argument, 1, 0, 0),
  [5501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_option, 3, 0, 0),
  [5503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_default_option, 3, 0, 0),
  [5505] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__map_lhs_repeat1, 2, 0, 0), SHIFT_REPEAT(1743),
  [5508] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__map_lhs_repeat1, 2, 0, 0), SHIFT_REPEAT(134),
  [5511] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__map_lhs_repeat1, 2, 0, 0), SHIFT_REPEAT(3249),
  [5514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_define_arg_text, 2, 0, 0),
  [5516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__sign_define_arg_text, 2, 0, 0),
  [5518] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1661),
  [5521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__set_option, 2, 0, 0),
  [5523] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__set_option, 2, 0, 0),
  [5525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [5527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [5529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_list, 1, 0, 11),
  [5531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2716),
  [5533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_unplace, 1, 0, 11),
  [5535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3194),
  [5537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1886),
  [5539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1794),
  [5541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_statement, 4, 0, 25),
  [5543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_user_command, 2, 0, 25),
  [5545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1845),
  [5547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3314),
  [5549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2196),
  [5551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2176),
  [5553] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unknown_builtin_statement, 1, 0, 0),
  [5555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__pattern_branch, 2, 0, 0),
  [5557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1657),
  [5559] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_map_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1763),
  [5562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1782),
  [5564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1782),
  [5566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1789),
  [5568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1789),
  [5570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1861),
  [5572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_define_arg_text, 1, 0, 0),
  [5574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1603),
  [5576] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1657),
  [5579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1686),
  [5581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__sign_define_repeat1, 1, 0, 43),
  [5583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__sign_define_repeat1, 1, 0, 43),
  [5585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2863),
  [5587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(948),
  [5589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1865),
  [5591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__sign_place_place_repeat1, 1, 0, 43),
  [5593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1661),
  [5595] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1699),
  [5598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1699),
  [5600] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1789),
  [5603] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1789),
  [5606] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_runtime_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3039),
  [5609] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_runtime_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1364),
  [5612] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_runtime_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1364),
  [5615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern, 2, 0, 0),
  [5617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1631),
  [5619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2226),
  [5621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2284),
  [5623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unknown_builtin_statement, 1, 0, 0),
  [5625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2284),
  [5627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_unplace_id, 1, 0, 45),
  [5629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3211),
  [5631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3212),
  [5633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3213),
  [5635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_jump, 2, 0, 46),
  [5637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3214),
  [5639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3215),
  [5641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3216),
  [5643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_arguments_cluster, 2, 0, 19),
  [5645] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_arguments_cluster, 2, 0, 19),
  [5647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__syn_cluster_repeat1, 2, 0, 0),
  [5649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_cluster_repeat1, 2, 0, 0), SHIFT_REPEAT(3266),
  [5652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_jump, 2, 0, 47),
  [5654] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1600),
  [5657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__map_rhs, 2, 0, 0),
  [5659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1880),
  [5661] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__autocmd_remove, 3, 0, 0),
  [5663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1882),
  [5665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__sign_unplace_id_repeat1, 2, 0, 0),
  [5667] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_unplace_id_repeat1, 2, 0, 0), SHIFT_REPEAT(3211),
  [5670] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_unplace_id_repeat1, 2, 0, 0), SHIFT_REPEAT(3212),
  [5673] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_unplace_id_repeat1, 2, 0, 0), SHIFT_REPEAT(3213),
  [5676] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_cluster, 2, 0, 11),
  [5678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3266),
  [5680] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__sign_jump_repeat1, 2, 0, 0),
  [5682] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_jump_repeat1, 2, 0, 0), SHIFT_REPEAT(3214),
  [5685] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_jump_repeat1, 2, 0, 0), SHIFT_REPEAT(3215),
  [5688] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_jump_repeat1, 2, 0, 0), SHIFT_REPEAT(3216),
  [5691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__bang_filter_command, 3, 0, 54),
  [5693] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__bang_filter_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1740),
  [5696] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__bang_filter_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3157),
  [5699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__bang_filter_command_repeat1, 2, 0, 0),
  [5701] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__bang_filter_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2086),
  [5704] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_sync, 2, 0, 35),
  [5706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1901),
  [5708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3245),
  [5710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2178),
  [5712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1887),
  [5714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2597),
  [5716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1649),
  [5718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2628),
  [5720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [5722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1436),
  [5724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1885),
  [5726] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_cluster, 3, 0, 11),
  [5728] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__syn_sync_repeat1, 1, 0, 71),
  [5730] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__complete_range_explicit, 3, 0, 55),
  [5732] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_edit_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(1246),
  [5735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_command, 1, 0, 0),
  [5737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_sync_lines, 3, 0, 74),
  [5739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__complete_range, 1, 0, 2),
  [5741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1825),
  [5743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1825),
  [5745] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1825),
  [5748] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_filename_repeat1, 2, 0, 0), SHIFT_REPEAT(1825),
  [5751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__sign_place_list, 2, 0, 0),
  [5753] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_place_list, 2, 0, 0), SHIFT_REPEAT(3191),
  [5756] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_place_list, 2, 0, 0), SHIFT_REPEAT(3192),
  [5759] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_place_list, 2, 0, 0), SHIFT_REPEAT(3193),
  [5762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_unplace_id, 2, 0, 44),
  [5764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_unplace_id, 2, 0, 45),
  [5766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2209),
  [5768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1757),
  [5770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2518),
  [5772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1553),
  [5774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2735),
  [5776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [5778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1474),
  [5780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1734),
  [5782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_runtime_statement_repeat1, 1, 0, 0),
  [5784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_runtime_statement_repeat1, 1, 0, 0),
  [5786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_jump, 3, 0, 46),
  [5788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_jump, 3, 0, 47),
  [5790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern, 1, 0, 0),
  [5792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1576),
  [5794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [5796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1949),
  [5798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3132),
  [5800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2075),
  [5802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3154),
  [5804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(428),
  [5806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1897),
  [5808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1983),
  [5810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [5812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [5814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2092),
  [5816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3131),
  [5818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1891),
  [5820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1891),
  [5822] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1576),
  [5825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3333),
  [5827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2118),
  [5829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3324),
  [5831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1864),
  [5833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1864),
  [5835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__bang_filter_command, 2, 0, 54),
  [5837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [5839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1824),
  [5841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1824),
  [5843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1841),
  [5845] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(428),
  [5848] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1868),
  [5851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1878),
  [5853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1878),
  [5855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1872),
  [5857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [5859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1860),
  [5861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [5863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [5865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1876),
  [5867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_place, 2, 0, 11),
  [5869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3191),
  [5871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3192),
  [5873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3193),
  [5875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [5877] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__bang_filter_command_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(1878),
  [5880] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__bang_filter_command_argument_repeat1, 2, 0, 0), SHIFT_REPEAT(1878),
  [5883] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__map_rhs, 3, 0, 0),
  [5885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [5887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2117),
  [5889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2845),
  [5891] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__map_rhs_repeat1, 2, 0, 0), SHIFT_REPEAT(135),
  [5894] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__map_rhs_repeat1, 2, 0, 0), SHIFT_REPEAT(3343),
  [5897] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__map_rhs_repeat1, 2, 0, 0),
  [5899] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__map_rhs_repeat1, 2, 0, 0), SHIFT_REPEAT(1882),
  [5902] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1631),
  [5905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unknown_builtin_statement, 2, 0, 25),
  [5907] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_unplace_id, 1, 0, 44),
  [5909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_command, 2, 0, 25),
  [5911] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1596),
  [5914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3091),
  [5916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2091),
  [5918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3229),
  [5920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1869),
  [5922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1869),
  [5924] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__autocmd_list, 2, 0, 0),
  [5926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3063),
  [5928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1986),
  [5930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1987),
  [5932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1868),
  [5934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1927),
  [5936] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__map_rhs, 2, 0, 0),
  [5938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3115),
  [5940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3120),
  [5942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3124),
  [5944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_sync, 3, 0, 35),
  [5946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3245),
  [5948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_marker, 2, 0, 0),
  [5950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1297),
  [5952] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1668),
  [5955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_sync, 3, 0, 72),
  [5957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1639),
  [5959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3283),
  [5961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3130),
  [5963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(133),
  [5965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [5967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1955),
  [5969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1642),
  [5972] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_user_command, 2, 0, 24),
  [5974] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_user_command, 3, 0, 25),
  [5976] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1665),
  [5979] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_user_command, 2, 0, 0),
  [5981] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unknown_builtin_statement, 3, 0, 51),
  [5983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_sync, 5, 0, 118),
  [5985] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_remove, 3, 0, 0),
  [5987] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__map_rhs, 3, 0, 0),
  [5989] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__map_rhs_repeat1, 2, 0, 0), SHIFT_REPEAT(136),
  [5992] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__map_rhs_repeat1, 2, 0, 0), SHIFT_REPEAT(3083),
  [5995] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__map_rhs_repeat1, 2, 0, 0), SHIFT_REPEAT(1927),
  [5998] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__map_rhs_repeat1, 2, 0, 0),
  [6000] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__bang_filter_bangs, 1, 0, 0),
  [6002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2159),
  [6004] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__bang_filter_bangs, 1, 0, 0),
  [6006] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unknown_builtin_statement, 2, 0, 24),
  [6008] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unknown_builtin_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2156),
  [6011] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_unknown_builtin_statement_repeat1, 2, 0, 0),
  [6013] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unknown_builtin_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2156),
  [6016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1694),
  [6018] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__syn_sync_repeat1, 2, 0, 102),
  [6020] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_sync_repeat1, 2, 0, 102), SHIFT_REPEAT(3245),
  [6023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3184),
  [6025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1508),
  [6027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1508),
  [6029] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_sync, 4, 0, 72),
  [6031] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unknown_builtin_statement, 4, 0, 83),
  [6033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2009),
  [6035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3305),
  [6037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1667),
  [6039] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_user_command, 4, 0, 83),
  [6041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1926),
  [6043] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_place_list, 2, 0, 0), SHIFT_REPEAT(3321),
  [6046] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_place_list, 2, 0, 0), SHIFT_REPEAT(3325),
  [6049] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_place_list, 2, 0, 0), SHIFT_REPEAT(3326),
  [6052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3172),
  [6054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(132),
  [6056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [6058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1844),
  [6060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [6062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1958),
  [6064] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_user_command, 3, 0, 57),
  [6066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3204),
  [6068] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1639),
  [6071] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_cluster_repeat1, 2, 0, 0), SHIFT_REPEAT(3283),
  [6074] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1667),
  [6077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1968),
  [6079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1840),
  [6081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3003),
  [6083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3005),
  [6085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3052),
  [6087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3230),
  [6089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3071),
  [6091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1400),
  [6093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1400),
  [6095] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_sync, 4, 0, 101),
  [6097] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1694),
  [6100] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(440),
  [6103] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1968),
  [6106] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_unplace_id_repeat1, 2, 0, 0), SHIFT_REPEAT(3003),
  [6109] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_unplace_id_repeat1, 2, 0, 0), SHIFT_REPEAT(3005),
  [6112] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_unplace_id_repeat1, 2, 0, 0), SHIFT_REPEAT(3052),
  [6115] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_jump_repeat1, 2, 0, 0), SHIFT_REPEAT(3115),
  [6118] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_jump_repeat1, 2, 0, 0), SHIFT_REPEAT(3120),
  [6121] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__sign_jump_repeat1, 2, 0, 0), SHIFT_REPEAT(3124),
  [6124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3321),
  [6126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3325),
  [6128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3326),
  [6130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1894),
  [6132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unknown_builtin_statement, 3, 0, 25),
  [6134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1665),
  [6136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1642),
  [6138] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unknown_builtin_statement, 3, 0, 57),
  [6140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1668),
  [6142] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__bang_filter_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1845),
  [6145] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__bang_filter_command_repeat1, 2, 0, 0), SHIFT_REPEAT(3314),
  [6148] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__bang_filter_command_repeat1, 2, 0, 0), SHIFT_REPEAT(2176),
  [6151] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1983),
  [6154] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [6156] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unknown_builtin_statement, 2, 0, 0),
  [6158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_list, 2, 0, 0),
  [6160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_user_command, 3, 0, 51),
  [6162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3305),
  [6164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [6166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2000),
  [6168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2811),
  [6170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__sign_place_list, 1, 0, 43),
  [6172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_place_list_argument, 3, 0, 74),
  [6174] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_au_event_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3155),
  [6177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_au_event_list_repeat1, 2, 0, 0),
  [6179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [6181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1370),
  [6183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [6185] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1607),
  [6188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3248),
  [6190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1584),
  [6192] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(430),
  [6195] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2000),
  [6198] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1584),
  [6201] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1609),
  [6204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2684),
  [6206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_spell, 1, 0, 11),
  [6208] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__map_rhs_repeat1, 1, 0, 29),
  [6210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3155),
  [6212] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_au_event_list, 2, 0, 0),
  [6214] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1610),
  [6217] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region, 5, 0, 116),
  [6219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3048),
  [6221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1572),
  [6223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1572),
  [6225] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unknown_builtin_statement, 3, 0, 25),
  [6227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unknown_builtin_statement, 3, 0, 57),
  [6229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region, 5, 0, 98),
  [6231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat2, 2, 0, 0),
  [6233] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat2, 2, 0, 0), SHIFT_REPEAT(3225),
  [6236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region, 5, 0, 117),
  [6238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_arguments_cluster, 3, 0, 74),
  [6240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__syn_cluster_repeat1, 1, 0, 43),
  [6242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2867),
  [6244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2870),
  [6246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1585),
  [6248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2079),
  [6250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_statement, 1, 0, 2),
  [6252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_command, 3, 0, 25),
  [6254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2167),
  [6256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_unplace_id_argument, 3, 0, 74),
  [6258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_jump_argument, 3, 0, 74),
  [6260] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_command, 3, 0, 57),
  [6262] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1585),
  [6265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unknown_builtin_statement, 2, 0, 0),
  [6267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_explicit, 1, 0, 3),
  [6269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1230),
  [6271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [6273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [6275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1564),
  [6277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2715),
  [6279] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unknown_builtin_statement, 2, 0, 24),
  [6281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3167),
  [6283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [6285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2121),
  [6287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2430),
  [6289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region, 6, 0, 116),
  [6291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__sign_unplace_id_repeat1, 1, 0, 43),
  [6293] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region, 6, 0, 126),
  [6295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region, 6, 0, 127),
  [6297] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region, 6, 0, 117),
  [6299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unknown_builtin_statement, 3, 0, 51),
  [6301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2544),
  [6303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2545),
  [6305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__sign_jump_repeat1, 1, 0, 43),
  [6307] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unknown_builtin_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2284),
  [6310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_unknown_builtin_statement_repeat1, 2, 0, 0),
  [6312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1381),
  [6314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_command, 2, 0, 0),
  [6316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1224),
  [6318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_command, 2, 0, 24),
  [6320] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region, 7, 0, 126),
  [6322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3102),
  [6324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1464),
  [6326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1464),
  [6328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region, 7, 0, 127),
  [6330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region, 7, 0, 128),
  [6332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2792),
  [6334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [6336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3116),
  [6338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [6340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1209),
  [6342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unknown_builtin_statement, 4, 0, 83),
  [6344] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_command, 3, 0, 51),
  [6346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region, 8, 0, 128),
  [6348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 9, 0, 0),
  [6350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_command, 4, 0, 83),
  [6352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 3, 0, 0),
  [6354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1577),
  [6356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2766),
  [6358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 6, 0, 0),
  [6360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3304),
  [6362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 5, 0, 0),
  [6364] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 2, 0, 0),
  [6366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [6368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1460),
  [6370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1633),
  [6372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2841),
  [6374] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_sync_repeat1, 2, 0, 102), SHIFT_REPEAT(3305),
  [6377] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_au_event_list, 1, 0, 0),
  [6379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [6381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1461),
  [6383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1867),
  [6385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3094),
  [6387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [6389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1270),
  [6391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 7, 0, 0),
  [6393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 8, 0, 0),
  [6395] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1577),
  [6398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1324),
  [6400] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_region, 4, 0, 98),
  [6402] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 2, 0, 27),
  [6404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1991),
  [6406] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 4, 0, 0),
  [6408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2671),
  [6410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2125),
  [6412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__immediate_identifier, 1, 0, 0),
  [6414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2939),
  [6416] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filetypes, 1, 0, 0),
  [6418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__syn_sync_repeat1, 1, 0, 71),
  [6420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__immediate_identifier, 2, 0, 0),
  [6422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enew_statement, 1, 0, 0),
  [6424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2233),
  [6426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__set_rhs, 1, 0, 0),
  [6428] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__set_rhs, 1, 0, 0),
  [6430] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2062),
  [6433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_try_statement_repeat1, 2, 0, 0),
  [6435] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(283),
  [6438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [6440] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__let_heredoc_repeat1, 2, 0, 0), SHIFT_REPEAT(2611),
  [6443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__let_heredoc_repeat1, 2, 0, 0),
  [6445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_au_event_list_repeat1, 2, 0, 0),
  [6447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [6449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2208),
  [6451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__map_rhs_repeat1, 1, 0, 29),
  [6453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2611),
  [6455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2815),
  [6457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3317),
  [6459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_au_event_list, 1, 0, 0),
  [6461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cprevious_statement, 1, 0, 0),
  [6463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2911),
  [6465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3022),
  [6467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2299),
  [6469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1413),
  [6471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_set_statement, 2, 0, 0),
  [6473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1654),
  [6475] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_setlocal_statement, 2, 0, 0),
  [6477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__runtime_where, 1, 0, 0),
  [6479] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__runtime_where, 1, 0, 0),
  [6481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_au_event_list, 2, 0, 0),
  [6483] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_set_statement, 3, 0, 0),
  [6485] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1654),
  [6488] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_argument, 1, 0, 0),
  [6490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_argument, 1, 0, 0),
  [6492] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__autocmd_list, 3, 0, 0),
  [6494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(96),
  [6496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cnext_statement, 1, 0, 0),
  [6498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_case, 1, 0, 11),
  [6500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2683),
  [6502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__autocmd_remove, 4, 0, 0),
  [6504] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_au_event_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3317),
  [6507] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__syn_region_repeat2, 2, 0, 0), SHIFT_REPEAT(3160),
  [6510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filetypes, 2, 0, 0),
  [6512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_startinsert_statement, 1, 0, 0),
  [6514] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1672),
  [6517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2483),
  [6519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1646),
  [6521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2484),
  [6523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [6525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1509),
  [6527] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__augroup_name, 1, 0, 5),
  [6529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__augroup_name, 1, 0, 5),
  [6531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1185),
  [6533] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_set_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1413),
  [6536] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_set_statement_repeat1, 2, 0, 0),
  [6538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filetypes_repeat1, 2, 0, 0), SHIFT_REPEAT(2939),
  [6541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_filetypes_repeat1, 2, 0, 0),
  [6543] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_foldlevel, 1, 0, 11),
  [6545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2685),
  [6547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1672),
  [6549] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__syn_iskeyword, 1, 0, 11),
  [6551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2686),
  [6553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__bang_filter_bangs, 2, 0, 0),
  [6555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__bang_filter_bangs, 2, 0, 0),
  [6557] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_unknown_builtin_statement_repeat1, 1, 0, 0),
  [6559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_unknown_builtin_statement_repeat1, 1, 0, 0),
  [6561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2933),
  [6563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2687),
  [6565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_conceal, 1, 0, 11),
  [6567] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_repeat1, 2, 0, 0), SHIFT_REPEAT(275),
  [6570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2875),
  [6572] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__autocmd_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(3022),
  [6575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_sync_lines, 3, 0, 74),
  [6577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2137),
  [6579] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(403),
  [6582] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2208),
  [6585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2533),
  [6587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1581),
  [6589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2738),
  [6591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [6593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1416),
  [6595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2931),
  [6597] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_setlocal_statement, 3, 0, 0),
  [6599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2913),
  [6601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_iskeyword, 1, 0, 11),
  [6603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [6605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [6607] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_statement, 2, 0, 18),
  [6609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2711),
  [6611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [6613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [6615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(654),
  [6617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3070),
  [6619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2631),
  [6621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2732),
  [6623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2731),
  [6625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [6627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3002),
  [6629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3033),
  [6631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_set_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1430),
  [6634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_set_statement_repeat1, 2, 0, 0),
  [6636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3150),
  [6638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1401),
  [6640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2225),
  [6642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1350),
  [6644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2275),
  [6646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2457),
  [6648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2746),
  [6650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2743),
  [6652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [6654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [6656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [6658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [6660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__set_rhs, 2, 0, 73),
  [6662] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__set_rhs, 2, 0, 73),
  [6664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [6666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [6668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(355),
  [6670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3084),
  [6672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2655),
  [6674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1127),
  [6676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2239),
  [6678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2207),
  [6680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1130),
  [6682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [6684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2555),
  [6686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(782),
  [6688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3345),
  [6690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2522),
  [6692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_item, 2, 0, 36),
  [6694] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_set_item, 2, 0, 36),
  [6696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1033),
  [6698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2374),
  [6700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1141),
  [6702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2249),
  [6704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [6706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3125),
  [6708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2893),
  [6710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1150),
  [6712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1161),
  [6714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2253),
  [6716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2891),
  [6718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [6720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1430),
  [6722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_setlocal_statement, 3, 0, 0),
  [6724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1380),
  [6726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2257),
  [6728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [6730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3316),
  [6732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1385),
  [6734] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filetypes_repeat1, 2, 0, 0), SHIFT_REPEAT(2823),
  [6737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1391),
  [6739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2261),
  [6741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2823),
  [6743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1394),
  [6745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3348),
  [6747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1281),
  [6749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2264),
  [6751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1286),
  [6753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1068),
  [6755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2268),
  [6757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1071),
  [6759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1076),
  [6761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2272),
  [6763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range, 1, 0, 2),
  [6765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1079),
  [6767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1144),
  [6769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2276),
  [6771] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom_repeat1, 2, 0, 0), SHIFT_REPEAT(3150),
  [6774] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__pattern_ordinary_atom_repeat1, 2, 0, 0),
  [6776] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_ordinary_atom_repeat1, 2, 0, 0), SHIFT_REPEAT(2275),
  [6779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1173),
  [6781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1152),
  [6783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2278),
  [6785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1155),
  [6787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1123),
  [6789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2282),
  [6791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1163),
  [6793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [6795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [6797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1854),
  [6799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1557),
  [6801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2905),
  [6803] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1557),
  [6806] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1632),
  [6809] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1636),
  [6812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2074),
  [6814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1311),
  [6816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2352),
  [6818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2782),
  [6820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2425),
  [6822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2677),
  [6824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2725),
  [6826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1056),
  [6828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2364),
  [6830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_statement, 3, 0, 0),
  [6832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1644),
  [6834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1647),
  [6836] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1666),
  [6839] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__map_rhs_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [6842] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__map_rhs_statement_repeat1, 2, 0, 0),
  [6844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1636),
  [6846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1083),
  [6848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [6850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [6852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1666),
  [6854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(495),
  [6856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3163),
  [6858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2577),
  [6860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [6862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3007),
  [6864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2778),
  [6866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2424),
  [6868] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_statement, 3, 0, 39),
  [6870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2467),
  [6872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2914),
  [6874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1082),
  [6876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2325),
  [6878] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_list, 1, 0, 11),
  [6880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2681),
  [6882] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_explicit, 3, 0, 55),
  [6884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_clear, 1, 0, 11),
  [6886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2682),
  [6888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1051),
  [6890] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameters_repeat2, 2, 0, 0), SHIFT_REPEAT(2329),
  [6893] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameters_repeat2, 2, 0, 0),
  [6895] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__autocmd_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(3348),
  [6898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_body_clear, 1, 0, 0),
  [6900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2679),
  [6902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [6904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [6906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [6908] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1647),
  [6911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(535),
  [6913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2989),
  [6915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2603),
  [6917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [6919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3222),
  [6921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1379),
  [6923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2349),
  [6925] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_statement, 2, 0, 0),
  [6927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2912),
  [6929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(560),
  [6931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3036),
  [6933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2497),
  [6935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1372),
  [6937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1312),
  [6939] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__pattern_branch_repeat1, 2, 0, 0), SHIFT_REPEAT(1644),
  [6942] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_setlocal_statement, 2, 0, 0),
  [6944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2495),
  [6946] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_shebang, 1, 0, 0),
  [6948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1066),
  [6950] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syntax_statement, 2, 0, 12),
  [6952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2881),
  [6954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2512),
  [6956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_body, 1, 0, 9),
  [6958] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_highlight_statement, 2, 0, 10),
  [6960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_enable, 1, 0, 11),
  [6962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [6964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edit_statement, 3, 0, 50),
  [6966] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_find_statement, 3, 0, 0),
  [6968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1567),
  [6970] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 0), SHIFT_REPEAT(2127),
  [6973] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 0),
  [6975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1586),
  [6977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1591),
  [6979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1595),
  [6981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2906),
  [6983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_statement, 3, 0, 39),
  [6985] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1586),
  [6988] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_view_statement, 3, 0, 0),
  [6990] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syntax_statement, 2, 0, 13),
  [6992] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syntax_statement, 2, 0, 14),
  [6994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [6996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_wincmd_statement, 3, 0, 52),
  [6998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2090),
  [7000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2089),
  [7002] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bang_filter_statement, 3, 0, 53),
  [7004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_normal_statement, 3, 0, 25),
  [7006] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_setfiletype_statement, 2, 0, 0),
  [7008] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1590),
  [7011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_statement, 3, 0, 56),
  [7013] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_options_statement, 2, 0, 0),
  [7015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_substitute_statement, 3, 0, 25),
  [7017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_startinsert_statement, 2, 0, 0),
  [7019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_encoding, 1, 0, 0),
  [7021] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scriptencoding_statement, 2, 0, 0),
  [7023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_statement, 2, 0, 16),
  [7025] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_colorscheme_statement, 2, 0, 17),
  [7027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2356),
  [7029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2838),
  [7031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delcommand_statement, 2, 0, 0),
  [7033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 0),
  [7035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_wincmd_statement, 2, 0, 21),
  [7037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2909),
  [7039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2910),
  [7041] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_loop, 4, 0, 63),
  [7043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 63),
  [7045] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 4, 0, 65),
  [7047] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 4, 0, 0),
  [7049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2837),
  [7051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2836),
  [7053] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_script, 3, 0, 0),
  [7055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sign_statement, 2, 0, 22),
  [7057] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sign_statement, 2, 0, 23),
  [7059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_remove, 4, 0, 66),
  [7061] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_command, 3, 0, 67),
  [7063] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__filetype_detect, 1, 0, 11),
  [7065] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__filetype_enable, 1, 0, 11),
  [7067] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filetype_statement, 2, 0, 12),
  [7069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [7071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_body_link, 3, 0, 69),
  [7073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [7075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [7077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [7079] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tab_statement, 2, 0, 0),
  [7081] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_vertical_statement, 2, 0, 0),
  [7083] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_aboveleft_statement, 2, 0, 0),
  [7085] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_belowright_statement, 2, 0, 0),
  [7087] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_topleft_statement, 2, 0, 0),
  [7089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_botright_statement, 2, 0, 0),
  [7091] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_options_statement, 1, 0, 0),
  [7093] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stopinsert_statement, 1, 0, 0),
  [7095] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enew_statement, 2, 0, 0),
  [7097] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_find_statement, 2, 0, 0),
  [7099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2928),
  [7101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_statement, 4, 0, 78),
  [7103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comclear_statement, 1, 0, 0),
  [7105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2929),
  [7107] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 1, 0, 0),
  [7109] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 1, 0, 0),
  [7111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_view_statement, 2, 0, 0),
  [7113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__filetype_plugin, 3, 0, 11),
  [7115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1559),
  [7117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__filetype_indent, 3, 0, 11),
  [7119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2869),
  [7121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_substitute_statement, 2, 0, 0),
  [7123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edit_statement, 4, 0, 81),
  [7125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2774),
  [7127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3004),
  [7129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3175),
  [7131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1497),
  [7133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(357),
  [7135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_find_statement, 4, 0, 0),
  [7137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ex_statement, 4, 0, 0),
  [7139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_view_statement, 4, 0, 0),
  [7141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2663),
  [7143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2666),
  [7145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2691),
  [7147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2667),
  [7149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2678),
  [7151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2689),
  [7153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_shebang, 2, 0, 0),
  [7155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2123),
  [7157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2813),
  [7159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2763),
  [7161] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1559),
  [7164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_normal_statement, 4, 0, 25),
  [7166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [7168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(380),
  [7170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_statement, 4, 0, 82),
  [7172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement, 2, 0, 0),
  [7174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [7176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2827),
  [7178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2431),
  [7180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2884),
  [7182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [7184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2406),
  [7186] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_substitute_statement, 4, 0, 25),
  [7188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [7190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2591),
  [7192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [7194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [7196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [7198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2537),
  [7200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2882),
  [7202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2078),
  [7204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2432),
  [7206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_register_statement, 1, 0, 0),
  [7208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 87),
  [7210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 0),
  [7212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [7214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2513),
  [7216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [7218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [7220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [7222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [7224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [7226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2552),
  [7228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1498),
  [7230] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_loop, 5, 0, 91),
  [7232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2548),
  [7234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2549),
  [7236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 91),
  [7238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 63),
  [7240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 5, 0, 65),
  [7242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 5, 0, 0),
  [7244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__pattern_ordinary_atom_repeat1, 2, 0, 0),
  [7246] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_script, 4, 0, 65),
  [7248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_script, 4, 0, 92),
  [7250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_command, 4, 0, 93),
  [7252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [7254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [7256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [7258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__map_rhs_statement, 3, 0, 0),
  [7260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2674),
  [7262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2675),
  [7264] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_body_link, 4, 0, 95),
  [7266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [7268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2517),
  [7270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [7272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2768),
  [7274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_autocmd_statement, 1, 0, 4),
  [7276] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 3, 0, 0),
  [7278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2706),
  [7280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2707),
  [7282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__const_assignment, 2, 0, 0),
  [7284] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_normal_statement, 3, 0, 0),
  [7286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [7288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2726),
  [7290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2727),
  [7292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2740),
  [7294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__let_assignment, 2, 0, 0),
  [7296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [7298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [7300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [7302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2584),
  [7304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2901),
  [7306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [7308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [7310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [7312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [7314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2589),
  [7316] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dictionnary_repeat1, 2, 0, 0),
  [7318] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dictionnary_repeat1, 2, 0, 0), SHIFT_REPEAT(251),
  [7321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [7323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [7325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [7327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_literal_dictionary_repeat1, 2, 0, 86),
  [7329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literal_dictionary_repeat1, 2, 0, 86), SHIFT_REPEAT(2973),
  [7332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [7334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_autocmd_statement, 1, 0, 0),
  [7336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2793),
  [7338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_remove, 3, 0, 28),
  [7340] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_include, 4, 0, 99),
  [7342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(675),
  [7344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [7346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2119),
  [7348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_sync, 4, 0, 35),
  [7350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [7352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2616),
  [7354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_sync, 4, 0, 100),
  [7356] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1567),
  [7359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1890),
  [7361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3255),
  [7363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__let_heredoc_parameter, 1, 0, 0),
  [7365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [7367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [7369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [7371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [7373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2621),
  [7375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2983),
  [7377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [7379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2877),
  [7381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [7383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(661),
  [7385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_define, 3, 0, 28),
  [7387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_silent_statement, 3, 0, 0),
  [7389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_statement, 5, 0, 0),
  [7391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [7393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1478),
  [7395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_statement, 5, 0, 103),
  [7397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [7399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [7401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [7403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2638),
  [7405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2894),
  [7407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_statement, 2, 0, 18),
  [7409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2903),
  [7411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3008),
  [7413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [7415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [7417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [7419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [7421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2643),
  [7423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cnext_statement, 2, 0, 0),
  [7425] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__map_definition, 2, 0, 30),
  [7427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [7429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [7431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2890),
  [7433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_unplace_cursor_argument, 3, 0, 74),
  [7435] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(2837),
  [7438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0),
  [7440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [7442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2904),
  [7444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_map_statement, 3, 0, 31),
  [7446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cprevious_statement, 2, 0, 0),
  [7448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_augroup_statement, 3, 0, 32),
  [7450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edit_statement, 5, 0, 105),
  [7452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2770),
  [7454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edit_statement, 5, 0, 0),
  [7456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [7458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_find_statement, 5, 0, 0),
  [7460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_visual_statement, 5, 0, 0),
  [7462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_view_statement, 5, 0, 0),
  [7464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_body_none, 2, 0, 0),
  [7466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_normal_statement, 2, 0, 0),
  [7468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_normal_statement, 5, 0, 25),
  [7470] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_statement, 5, 0, 106),
  [7472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_perl_statement, 2, 0, 0),
  [7474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lua_statement, 2, 0, 0),
  [7476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 108),
  [7478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 0),
  [7480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_loop, 6, 0, 112),
  [7482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 91),
  [7484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 63),
  [7486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 6, 0, 65),
  [7488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__let_heredoc, 4, 0, 0),
  [7490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_script, 5, 0, 113),
  [7492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_command, 5, 0, 114),
  [7494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__map_rhs_statement, 4, 0, 0),
  [7496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ruby_statement, 2, 0, 0),
  [7498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hl_body_clear, 2, 0, 0),
  [7500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_highlight_statement, 3, 0, 34),
  [7502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_list, 2, 0, 11),
  [7504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_clear, 2, 0, 11),
  [7506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_case, 2, 0, 11),
  [7508] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_spell, 2, 0, 11),
  [7510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_foldlevel, 2, 0, 11),
  [7512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_iskeyword, 2, 0, 11),
  [7514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_conceal, 2, 0, 11),
  [7516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [7518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_python_statement, 2, 0, 0),
  [7520] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_include, 2, 0, 11),
  [7522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2925),
  [7524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2526),
  [7526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [7528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1998),
  [7530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2105),
  [7532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_statement, 6, 0, 0),
  [7534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2876),
  [7536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__autocmd_define, 2, 0, 6),
  [7538] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edit_statement, 6, 0, 119),
  [7540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_silent_statement, 2, 0, 0),
  [7542] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_statement, 6, 0, 25),
  [7544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2953),
  [7546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 120),
  [7548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_loop, 7, 0, 122),
  [7550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 91),
  [7552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__let_heredoc, 5, 0, 0),
  [7554] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__let_heredoc, 5, 0, 87),
  [7556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_setfiletype_statement, 3, 0, 0),
  [7558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [7560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_statement, 3, 0, 37),
  [7562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_statement, 3, 0, 38),
  [7564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_echohl_statement, 2, 0, 0),
  [7566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2761),
  [7568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_shebang, 1, 0, 0),
  [7570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2852),
  [7572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_undefine, 2, 0, 41),
  [7574] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_list, 2, 0, 41),
  [7576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_place, 2, 0, 42),
  [7578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [7580] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_map_statement, 2, 0, 7),
  [7582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__syn_sync, 6, 0, 35),
  [7584] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_augroup_statement, 2, 0, 8),
  [7586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_statement, 7, 0, 25),
  [7588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_unplace_cursor, 1, 0, 43),
  [7590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__let_heredoc, 6, 0, 108),
  [7592] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__let_heredoc, 6, 0, 0),
  [7594] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_unplace, 2, 0, 11),
  [7596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sign_unplace, 2, 0, 42),
  [7598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2475),
  [7600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__filetype_plugin, 2, 0, 11),
  [7602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2040),
  [7604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1521),
  [7606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1526),
  [7608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_statement, 8, 0, 25),
  [7610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1529),
  [7612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [7614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__let_heredoc, 7, 0, 120),
  [7616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [7618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2477),
  [7620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [7622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [7624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__filetype_indent, 2, 0, 11),
  [7626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [7628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1994),
  [7630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2646),
  [7632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2030),
  [7634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [7636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1527),
  [7638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2185),
  [7640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(979),
  [7642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3143),
  [7644] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__au_pattern, 1, 0, 0),
  [7646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [7648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2123),
  [7650] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_literal_dictionary_repeat1, 2, 0, 58),
  [7652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2645),
  [7654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3031),
  [7656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [7658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1535),
  [7660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2376),
  [7662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2620),
  [7664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 1, 0, 0),
  [7666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2356),
  [7668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [7670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2946),
  [7672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1342),
  [7674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2498),
  [7676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3075),
  [7678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1795),
  [7680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1800),
  [7682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [7684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(986),
  [7686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3179),
  [7688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2542),
  [7690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2556),
  [7692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3220),
  [7694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2564),
  [7696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3227),
  [7698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2267),
  [7700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2154),
  [7702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1900),
  [7704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1902),
  [7706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [7708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2672),
  [7710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [7712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3098),
  [7714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3254),
  [7716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [7718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [7720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1401),
  [7722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1896),
  [7724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2915),
  [7726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1407),
  [7728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2673),
  [7730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [7732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2629),
  [7734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [7736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3268),
  [7738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2947),
  [7740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2385),
  [7742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [7744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1570),
  [7746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1924),
  [7748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [7750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1096),
  [7752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2568),
  [7754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [7756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2767),
  [7758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [7760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2795),
  [7762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2924),
  [7764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2776),
  [7766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [7768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [7770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2360),
  [7772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2043),
  [7774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1249),
  [7776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [7778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1807),
  [7780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2129),
  [7782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [7784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2840),
  [7786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1338),
  [7788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1640),
  [7790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [7792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [7794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [7796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1513),
  [7798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1664),
  [7800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1353),
  [7802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1605),
  [7804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1377),
  [7806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1481),
  [7808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1822),
  [7810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1496),
  [7812] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__keycode_in, 2, 0, 0),
  [7814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1420),
  [7816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [7818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1127),
  [7820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2108),
  [7822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1227),
  [7824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [7826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1131),
  [7828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1769),
  [7830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2173),
  [7832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2373),
  [7834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [7836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [7838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [7840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2860),
  [7842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [7844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [7846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [7848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [7850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [7852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [7854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(676),
  [7856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1369),
  [7858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1141),
  [7860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1580),
  [7862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2403),
  [7864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2470),
  [7866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [7868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1151),
  [7870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2031),
  [7872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [7874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [7876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [7878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1040),
  [7880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2139),
  [7882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [7884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1265),
  [7886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1161),
  [7888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1934),
  [7890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2871),
  [7892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2114),
  [7894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1996),
  [7896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [7898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1273),
  [7900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1380),
  [7902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1619),
  [7904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2895),
  [7906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2919),
  [7908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1386),
  [7910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3151),
  [7912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [7914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1468),
  [7916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1391),
  [7918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2699),
  [7920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [7922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1395),
  [7924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [7926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1204),
  [7928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1281),
  [7930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [7932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3252),
  [7934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2206),
  [7936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1287),
  [7938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3273),
  [7940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [7942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [7944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [7946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2941),
  [7948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3277),
  [7950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [7952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [7954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2110),
  [7956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [7958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [7960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [7962] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [7964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1144),
  [7966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1945),
  [7968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1148),
  [7970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [7972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1152),
  [7974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__immediate_lambda_expression, 4, 0, 0),
  [7976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1159),
  [7978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [7980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1156),
  [7982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [7984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1123),
  [7986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [7988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3097),
  [7990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1164),
  [7992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2808),
  [7994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [7996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [7998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2547),
  [8000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [8002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2705),
  [8004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2653),
  [8006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2134),
  [8008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [8010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1714),
  [8012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3137),
  [8014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2816),
  [8016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2819),
  [8018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [8020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [8022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [8024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3198),
  [8026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [8028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1482),
  [8030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [8032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [8034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [8036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1179),
  [8038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1802),
  [8040] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__immediate_lambda_expression, 5, 0, 0),
  [8042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1379),
  [8044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [8046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2223),
  [8048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3346),
  [8050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1231),
  [8052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2243),
  [8054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1489),
  [8056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1232),
  [8058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1503),
  [8060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2056),
  [8062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3309),
  [8064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1314),
  [8066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3272),
  [8068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [8070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3041),
  [8072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2753),
  [8074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2059),
  [8076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2755),
  [8078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2273),
  [8080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [8082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2283),
  [8084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2448),
  [8086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2664),
  [8088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [8090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2920),
  [8092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2224),
  [8094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2025),
  [8096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3030),
  [8098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3044),
  [8100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3050),
  [8102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3051),
  [8104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2064),
  [8106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3054),
  [8108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2769),
  [8110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2065),
  [8112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3078),
  [8114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3088),
  [8116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2066),
  [8118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [8120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1300),
  [8122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1434),
  [8124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2103),
  [8126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [8128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3171),
  [8130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2777),
  [8132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2779),
  [8134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3256),
  [8136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2571),
  [8138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2712),
  [8140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2005),
  [8142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2350),
  [8144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2962),
  [8146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [8148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [8150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2028),
  [8152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1263),
  [8154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3302),
  [8156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2327),
  [8158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [8160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2328),
  [8162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2958),
  [8164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [8166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2467),
  [8168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3108),
  [8170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3113),
  [8172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1278),
  [8174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2817),
  [8176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2070),
  [8178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1921),
  [8180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1780),
  [8182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1838),
  [8184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1238),
  [8186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2481),
  [8188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1514),
  [8190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2357),
  [8192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [8194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2359),
  [8196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1728),
  [8198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [8200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [8202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3323),
  [8204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [8206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2848),
  [8208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1798),
  [8210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2410),
  [8212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1518),
  [8214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2421),
  [8216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [8218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2607),
  [8220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2180),
  [8222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2229),
  [8224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [8226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2230),
  [8228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [8230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3037),
  [8232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1909),
  [8234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2504),
  [8236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1781),
  [8238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1952),
  [8240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [8242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2751),
  [8244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3065),
  [8246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2423),
  [8248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2752),
  [8250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2945),
  [8252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3081),
  [8254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1190),
  [8256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1302),
  [8258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1546),
  [8260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2311),
  [8262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1133),
  [8264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [8266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2951),
  [8268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(969),
  [8270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1311),
  [8272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2937),
  [8274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [8276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2107),
  [8278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3231),
  [8280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [8282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [8284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2104),
  [8286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1226),
  [8288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [8290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2842),
  [8292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [8294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2824),
  [8296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1892),
  [8298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2982),
  [8300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [8302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2313),
  [8304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1863),
  [8306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3293),
  [8308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [8310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [8312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2788),
  [8314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2011),
  [8316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1439),
  [8318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [8320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1524),
  [8322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1602),
  [8324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1528),
  [8326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2546),
  [8328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [8330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [8332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1530),
  [8334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [8336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__immediate_lambda_expression, 6, 0, 0),
  [8338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2098),
  [8340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1017),
  [8342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [8344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2558),
  [8346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [8348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2625),
  [8350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token__no = 0,
  ts_external_token__inv = 1,
  ts_external_token__newline_or_pipe = 2,
  ts_external_token__line_continuation = 3,
  ts_external_token__script_heredoc_marker = 4,
  ts_external_token__let_heredoc_marker = 5,
  ts_external_token__heredoc_end = 6,
  ts_external_token__separator_first = 7,
  ts_external_token__separator = 8,
  ts_external_token__scope_dict = 9,
  ts_external_token_scope = 10,
  ts_external_token_string_literal = 11,
  ts_external_token_comment = 12,
  ts_external_token_line_continuation_comment = 13,
  ts_external_token__bang_filter = 14,
  ts_external_token__function = 15,
  ts_external_token__endfunction = 16,
  ts_external_token__for = 17,
  ts_external_token__endfor = 18,
  ts_external_token__while = 19,
  ts_external_token__endwhile = 20,
  ts_external_token__if = 21,
  ts_external_token__elseif = 22,
  ts_external_token__else = 23,
  ts_external_token__endif = 24,
  ts_external_token__try = 25,
  ts_external_token__catch = 26,
  ts_external_token__cnext = 27,
  ts_external_token__cprevious = 28,
  ts_external_token__cNext = 29,
  ts_external_token__finally = 30,
  ts_external_token__endtry = 31,
  ts_external_token__const = 32,
  ts_external_token__normal = 33,
  ts_external_token__return = 34,
  ts_external_token__perl = 35,
  ts_external_token__lua = 36,
  ts_external_token__ruby = 37,
  ts_external_token__python = 38,
  ts_external_token__throw = 39,
  ts_external_token__execute = 40,
  ts_external_token__autocmd = 41,
  ts_external_token__silent = 42,
  ts_external_token__echo = 43,
  ts_external_token__echon = 44,
  ts_external_token__echohl = 45,
  ts_external_token__echomsg = 46,
  ts_external_token__echoerr = 47,
  ts_external_token__map = 48,
  ts_external_token__nmap = 49,
  ts_external_token__vmap = 50,
  ts_external_token__xmap = 51,
  ts_external_token__smap = 52,
  ts_external_token__omap = 53,
  ts_external_token__imap = 54,
  ts_external_token__lmap = 55,
  ts_external_token__cmap = 56,
  ts_external_token__tmap = 57,
  ts_external_token__noremap = 58,
  ts_external_token__nnoremap = 59,
  ts_external_token__vnoremap = 60,
  ts_external_token__xnoremap = 61,
  ts_external_token__snoremap = 62,
  ts_external_token__onoremap = 63,
  ts_external_token__inoremap = 64,
  ts_external_token__lnoremap = 65,
  ts_external_token__cnoremap = 66,
  ts_external_token__tnoremap = 67,
  ts_external_token__augroup = 68,
  ts_external_token__highlight = 69,
  ts_external_token__default = 70,
  ts_external_token__syntax = 71,
  ts_external_token__set = 72,
  ts_external_token__setlocal = 73,
  ts_external_token__setfiletype = 74,
  ts_external_token__browse = 75,
  ts_external_token__options = 76,
  ts_external_token__startinsert = 77,
  ts_external_token__stopinsert = 78,
  ts_external_token__scriptencoding = 79,
  ts_external_token__source = 80,
  ts_external_token__global = 81,
  ts_external_token__colorscheme = 82,
  ts_external_token__command = 83,
  ts_external_token__comclear = 84,
  ts_external_token__delcommand = 85,
  ts_external_token__runtime = 86,
  ts_external_token__wincmd = 87,
  ts_external_token__sign = 88,
  ts_external_token__filetype = 89,
  ts_external_token__let = 90,
  ts_external_token__unlet = 91,
  ts_external_token__call = 92,
  ts_external_token__break = 93,
  ts_external_token__continue = 94,
  ts_external_token__tab = 95,
  ts_external_token__vertical = 96,
  ts_external_token__leftabove = 97,
  ts_external_token__aboveleft = 98,
  ts_external_token__rightbelow = 99,
  ts_external_token__belowright = 100,
  ts_external_token__topleft = 101,
  ts_external_token__botright = 102,
  ts_external_token__edit = 103,
  ts_external_token__enew = 104,
  ts_external_token__find = 105,
  ts_external_token__ex = 106,
  ts_external_token__visual = 107,
  ts_external_token__view = 108,
  ts_external_token__eval = 109,
  ts_external_token__substitute = 110,
  ts_external_token_unknown_command_name = 111,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token__no] = sym__no,
  [ts_external_token__inv] = sym__inv,
  [ts_external_token__newline_or_pipe] = sym__newline_or_pipe,
  [ts_external_token__line_continuation] = sym__line_continuation,
  [ts_external_token__script_heredoc_marker] = sym__script_heredoc_marker,
  [ts_external_token__let_heredoc_marker] = sym__let_heredoc_marker,
  [ts_external_token__heredoc_end] = sym__heredoc_end,
  [ts_external_token__separator_first] = sym__separator_first,
  [ts_external_token__separator] = sym__separator,
  [ts_external_token__scope_dict] = sym__scope_dict,
  [ts_external_token_scope] = sym_scope,
  [ts_external_token_string_literal] = sym_string_literal,
  [ts_external_token_comment] = sym_comment,
  [ts_external_token_line_continuation_comment] = sym_line_continuation_comment,
  [ts_external_token__bang_filter] = sym__bang_filter,
  [ts_external_token__function] = sym__function,
  [ts_external_token__endfunction] = sym__endfunction,
  [ts_external_token__for] = sym__for,
  [ts_external_token__endfor] = sym__endfor,
  [ts_external_token__while] = sym__while,
  [ts_external_token__endwhile] = sym__endwhile,
  [ts_external_token__if] = sym__if,
  [ts_external_token__elseif] = sym__elseif,
  [ts_external_token__else] = sym__else,
  [ts_external_token__endif] = sym__endif,
  [ts_external_token__try] = sym__try,
  [ts_external_token__catch] = sym__catch,
  [ts_external_token__cnext] = sym__cnext,
  [ts_external_token__cprevious] = sym__cprevious,
  [ts_external_token__cNext] = sym__cNext,
  [ts_external_token__finally] = sym__finally,
  [ts_external_token__endtry] = sym__endtry,
  [ts_external_token__const] = sym__const,
  [ts_external_token__normal] = sym__normal,
  [ts_external_token__return] = sym__return,
  [ts_external_token__perl] = sym__perl,
  [ts_external_token__lua] = sym__lua,
  [ts_external_token__ruby] = sym__ruby,
  [ts_external_token__python] = sym__python,
  [ts_external_token__throw] = sym__throw,
  [ts_external_token__execute] = sym__execute,
  [ts_external_token__autocmd] = sym__autocmd,
  [ts_external_token__silent] = sym__silent,
  [ts_external_token__echo] = sym__echo,
  [ts_external_token__echon] = sym__echon,
  [ts_external_token__echohl] = sym__echohl,
  [ts_external_token__echomsg] = sym__echomsg,
  [ts_external_token__echoerr] = sym__echoerr,
  [ts_external_token__map] = sym__map,
  [ts_external_token__nmap] = sym__nmap,
  [ts_external_token__vmap] = sym__vmap,
  [ts_external_token__xmap] = sym__xmap,
  [ts_external_token__smap] = sym__smap,
  [ts_external_token__omap] = sym__omap,
  [ts_external_token__imap] = sym__imap,
  [ts_external_token__lmap] = sym__lmap,
  [ts_external_token__cmap] = sym__cmap,
  [ts_external_token__tmap] = sym__tmap,
  [ts_external_token__noremap] = sym__noremap,
  [ts_external_token__nnoremap] = sym__nnoremap,
  [ts_external_token__vnoremap] = sym__vnoremap,
  [ts_external_token__xnoremap] = sym__xnoremap,
  [ts_external_token__snoremap] = sym__snoremap,
  [ts_external_token__onoremap] = sym__onoremap,
  [ts_external_token__inoremap] = sym__inoremap,
  [ts_external_token__lnoremap] = sym__lnoremap,
  [ts_external_token__cnoremap] = sym__cnoremap,
  [ts_external_token__tnoremap] = sym__tnoremap,
  [ts_external_token__augroup] = sym__augroup,
  [ts_external_token__highlight] = sym__highlight,
  [ts_external_token__default] = sym__default,
  [ts_external_token__syntax] = sym__syntax,
  [ts_external_token__set] = sym__set,
  [ts_external_token__setlocal] = sym__setlocal,
  [ts_external_token__setfiletype] = sym__setfiletype,
  [ts_external_token__browse] = sym__browse,
  [ts_external_token__options] = sym__options,
  [ts_external_token__startinsert] = sym__startinsert,
  [ts_external_token__stopinsert] = sym__stopinsert,
  [ts_external_token__scriptencoding] = sym__scriptencoding,
  [ts_external_token__source] = sym__source,
  [ts_external_token__global] = sym__global,
  [ts_external_token__colorscheme] = sym__colorscheme,
  [ts_external_token__command] = sym__command,
  [ts_external_token__comclear] = sym__comclear,
  [ts_external_token__delcommand] = sym__delcommand,
  [ts_external_token__runtime] = sym__runtime,
  [ts_external_token__wincmd] = sym__wincmd,
  [ts_external_token__sign] = sym__sign,
  [ts_external_token__filetype] = sym__filetype,
  [ts_external_token__let] = sym__let,
  [ts_external_token__unlet] = sym__unlet,
  [ts_external_token__call] = sym__call,
  [ts_external_token__break] = sym__break,
  [ts_external_token__continue] = sym__continue,
  [ts_external_token__tab] = sym__tab,
  [ts_external_token__vertical] = sym__vertical,
  [ts_external_token__leftabove] = sym__leftabove,
  [ts_external_token__aboveleft] = sym__aboveleft,
  [ts_external_token__rightbelow] = sym__rightbelow,
  [ts_external_token__belowright] = sym__belowright,
  [ts_external_token__topleft] = sym__topleft,
  [ts_external_token__botright] = sym__botright,
  [ts_external_token__edit] = sym__edit,
  [ts_external_token__enew] = sym__enew,
  [ts_external_token__find] = sym__find,
  [ts_external_token__ex] = sym__ex,
  [ts_external_token__visual] = sym__visual,
  [ts_external_token__view] = sym__view,
  [ts_external_token__eval] = sym__eval,
  [ts_external_token__substitute] = sym__substitute,
  [ts_external_token_unknown_command_name] = sym_unknown_command_name,
};

static const bool ts_external_scanner_states[41][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token__no] = true,
    [ts_external_token__inv] = true,
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token__script_heredoc_marker] = true,
    [ts_external_token__let_heredoc_marker] = true,
    [ts_external_token__heredoc_end] = true,
    [ts_external_token__separator_first] = true,
    [ts_external_token__separator] = true,
    [ts_external_token__scope_dict] = true,
    [ts_external_token_scope] = true,
    [ts_external_token_string_literal] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__bang_filter] = true,
    [ts_external_token__function] = true,
    [ts_external_token__endfunction] = true,
    [ts_external_token__for] = true,
    [ts_external_token__endfor] = true,
    [ts_external_token__while] = true,
    [ts_external_token__endwhile] = true,
    [ts_external_token__if] = true,
    [ts_external_token__elseif] = true,
    [ts_external_token__else] = true,
    [ts_external_token__endif] = true,
    [ts_external_token__try] = true,
    [ts_external_token__catch] = true,
    [ts_external_token__cnext] = true,
    [ts_external_token__cprevious] = true,
    [ts_external_token__cNext] = true,
    [ts_external_token__finally] = true,
    [ts_external_token__endtry] = true,
    [ts_external_token__const] = true,
    [ts_external_token__normal] = true,
    [ts_external_token__return] = true,
    [ts_external_token__perl] = true,
    [ts_external_token__lua] = true,
    [ts_external_token__ruby] = true,
    [ts_external_token__python] = true,
    [ts_external_token__throw] = true,
    [ts_external_token__execute] = true,
    [ts_external_token__autocmd] = true,
    [ts_external_token__silent] = true,
    [ts_external_token__echo] = true,
    [ts_external_token__echon] = true,
    [ts_external_token__echohl] = true,
    [ts_external_token__echomsg] = true,
    [ts_external_token__echoerr] = true,
    [ts_external_token__map] = true,
    [ts_external_token__nmap] = true,
    [ts_external_token__vmap] = true,
    [ts_external_token__xmap] = true,
    [ts_external_token__smap] = true,
    [ts_external_token__omap] = true,
    [ts_external_token__imap] = true,
    [ts_external_token__lmap] = true,
    [ts_external_token__cmap] = true,
    [ts_external_token__tmap] = true,
    [ts_external_token__noremap] = true,
    [ts_external_token__nnoremap] = true,
    [ts_external_token__vnoremap] = true,
    [ts_external_token__xnoremap] = true,
    [ts_external_token__snoremap] = true,
    [ts_external_token__onoremap] = true,
    [ts_external_token__inoremap] = true,
    [ts_external_token__lnoremap] = true,
    [ts_external_token__cnoremap] = true,
    [ts_external_token__tnoremap] = true,
    [ts_external_token__augroup] = true,
    [ts_external_token__highlight] = true,
    [ts_external_token__default] = true,
    [ts_external_token__syntax] = true,
    [ts_external_token__set] = true,
    [ts_external_token__setlocal] = true,
    [ts_external_token__setfiletype] = true,
    [ts_external_token__browse] = true,
    [ts_external_token__options] = true,
    [ts_external_token__startinsert] = true,
    [ts_external_token__stopinsert] = true,
    [ts_external_token__scriptencoding] = true,
    [ts_external_token__source] = true,
    [ts_external_token__global] = true,
    [ts_external_token__colorscheme] = true,
    [ts_external_token__command] = true,
    [ts_external_token__comclear] = true,
    [ts_external_token__delcommand] = true,
    [ts_external_token__runtime] = true,
    [ts_external_token__wincmd] = true,
    [ts_external_token__sign] = true,
    [ts_external_token__filetype] = true,
    [ts_external_token__let] = true,
    [ts_external_token__unlet] = true,
    [ts_external_token__call] = true,
    [ts_external_token__break] = true,
    [ts_external_token__continue] = true,
    [ts_external_token__tab] = true,
    [ts_external_token__vertical] = true,
    [ts_external_token__leftabove] = true,
    [ts_external_token__aboveleft] = true,
    [ts_external_token__rightbelow] = true,
    [ts_external_token__belowright] = true,
    [ts_external_token__topleft] = true,
    [ts_external_token__botright] = true,
    [ts_external_token__edit] = true,
    [ts_external_token__enew] = true,
    [ts_external_token__find] = true,
    [ts_external_token__ex] = true,
    [ts_external_token__visual] = true,
    [ts_external_token__view] = true,
    [ts_external_token__eval] = true,
    [ts_external_token__substitute] = true,
    [ts_external_token_unknown_command_name] = true,
  },
  [2] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__function] = true,
    [ts_external_token__for] = true,
    [ts_external_token__while] = true,
    [ts_external_token__if] = true,
    [ts_external_token__try] = true,
    [ts_external_token__cnext] = true,
    [ts_external_token__cprevious] = true,
    [ts_external_token__cNext] = true,
    [ts_external_token__const] = true,
    [ts_external_token__normal] = true,
    [ts_external_token__return] = true,
    [ts_external_token__perl] = true,
    [ts_external_token__lua] = true,
    [ts_external_token__ruby] = true,
    [ts_external_token__python] = true,
    [ts_external_token__throw] = true,
    [ts_external_token__execute] = true,
    [ts_external_token__autocmd] = true,
    [ts_external_token__silent] = true,
    [ts_external_token__echo] = true,
    [ts_external_token__echon] = true,
    [ts_external_token__echohl] = true,
    [ts_external_token__echomsg] = true,
    [ts_external_token__echoerr] = true,
    [ts_external_token__map] = true,
    [ts_external_token__nmap] = true,
    [ts_external_token__vmap] = true,
    [ts_external_token__xmap] = true,
    [ts_external_token__smap] = true,
    [ts_external_token__omap] = true,
    [ts_external_token__imap] = true,
    [ts_external_token__lmap] = true,
    [ts_external_token__cmap] = true,
    [ts_external_token__tmap] = true,
    [ts_external_token__noremap] = true,
    [ts_external_token__nnoremap] = true,
    [ts_external_token__vnoremap] = true,
    [ts_external_token__xnoremap] = true,
    [ts_external_token__snoremap] = true,
    [ts_external_token__onoremap] = true,
    [ts_external_token__inoremap] = true,
    [ts_external_token__lnoremap] = true,
    [ts_external_token__cnoremap] = true,
    [ts_external_token__tnoremap] = true,
    [ts_external_token__augroup] = true,
    [ts_external_token__highlight] = true,
    [ts_external_token__syntax] = true,
    [ts_external_token__set] = true,
    [ts_external_token__setlocal] = true,
    [ts_external_token__setfiletype] = true,
    [ts_external_token__browse] = true,
    [ts_external_token__options] = true,
    [ts_external_token__startinsert] = true,
    [ts_external_token__stopinsert] = true,
    [ts_external_token__scriptencoding] = true,
    [ts_external_token__source] = true,
    [ts_external_token__global] = true,
    [ts_external_token__colorscheme] = true,
    [ts_external_token__command] = true,
    [ts_external_token__comclear] = true,
    [ts_external_token__delcommand] = true,
    [ts_external_token__runtime] = true,
    [ts_external_token__wincmd] = true,
    [ts_external_token__sign] = true,
    [ts_external_token__filetype] = true,
    [ts_external_token__let] = true,
    [ts_external_token__unlet] = true,
    [ts_external_token__call] = true,
    [ts_external_token__break] = true,
    [ts_external_token__continue] = true,
    [ts_external_token__tab] = true,
    [ts_external_token__vertical] = true,
    [ts_external_token__leftabove] = true,
    [ts_external_token__aboveleft] = true,
    [ts_external_token__rightbelow] = true,
    [ts_external_token__belowright] = true,
    [ts_external_token__topleft] = true,
    [ts_external_token__botright] = true,
    [ts_external_token__edit] = true,
    [ts_external_token__enew] = true,
    [ts_external_token__find] = true,
    [ts_external_token__ex] = true,
    [ts_external_token__visual] = true,
    [ts_external_token__view] = true,
    [ts_external_token__eval] = true,
    [ts_external_token__substitute] = true,
    [ts_external_token_unknown_command_name] = true,
  },
  [3] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__function] = true,
    [ts_external_token__for] = true,
    [ts_external_token__while] = true,
    [ts_external_token__if] = true,
    [ts_external_token__try] = true,
    [ts_external_token__catch] = true,
    [ts_external_token__cnext] = true,
    [ts_external_token__cprevious] = true,
    [ts_external_token__cNext] = true,
    [ts_external_token__finally] = true,
    [ts_external_token__endtry] = true,
    [ts_external_token__const] = true,
    [ts_external_token__normal] = true,
    [ts_external_token__return] = true,
    [ts_external_token__perl] = true,
    [ts_external_token__lua] = true,
    [ts_external_token__ruby] = true,
    [ts_external_token__python] = true,
    [ts_external_token__throw] = true,
    [ts_external_token__execute] = true,
    [ts_external_token__autocmd] = true,
    [ts_external_token__silent] = true,
    [ts_external_token__echo] = true,
    [ts_external_token__echon] = true,
    [ts_external_token__echohl] = true,
    [ts_external_token__echomsg] = true,
    [ts_external_token__echoerr] = true,
    [ts_external_token__map] = true,
    [ts_external_token__nmap] = true,
    [ts_external_token__vmap] = true,
    [ts_external_token__xmap] = true,
    [ts_external_token__smap] = true,
    [ts_external_token__omap] = true,
    [ts_external_token__imap] = true,
    [ts_external_token__lmap] = true,
    [ts_external_token__cmap] = true,
    [ts_external_token__tmap] = true,
    [ts_external_token__noremap] = true,
    [ts_external_token__nnoremap] = true,
    [ts_external_token__vnoremap] = true,
    [ts_external_token__xnoremap] = true,
    [ts_external_token__snoremap] = true,
    [ts_external_token__onoremap] = true,
    [ts_external_token__inoremap] = true,
    [ts_external_token__lnoremap] = true,
    [ts_external_token__cnoremap] = true,
    [ts_external_token__tnoremap] = true,
    [ts_external_token__augroup] = true,
    [ts_external_token__highlight] = true,
    [ts_external_token__syntax] = true,
    [ts_external_token__set] = true,
    [ts_external_token__setlocal] = true,
    [ts_external_token__setfiletype] = true,
    [ts_external_token__browse] = true,
    [ts_external_token__options] = true,
    [ts_external_token__startinsert] = true,
    [ts_external_token__stopinsert] = true,
    [ts_external_token__scriptencoding] = true,
    [ts_external_token__source] = true,
    [ts_external_token__global] = true,
    [ts_external_token__colorscheme] = true,
    [ts_external_token__command] = true,
    [ts_external_token__comclear] = true,
    [ts_external_token__delcommand] = true,
    [ts_external_token__runtime] = true,
    [ts_external_token__wincmd] = true,
    [ts_external_token__sign] = true,
    [ts_external_token__filetype] = true,
    [ts_external_token__let] = true,
    [ts_external_token__unlet] = true,
    [ts_external_token__call] = true,
    [ts_external_token__break] = true,
    [ts_external_token__continue] = true,
    [ts_external_token__tab] = true,
    [ts_external_token__vertical] = true,
    [ts_external_token__leftabove] = true,
    [ts_external_token__aboveleft] = true,
    [ts_external_token__rightbelow] = true,
    [ts_external_token__belowright] = true,
    [ts_external_token__topleft] = true,
    [ts_external_token__botright] = true,
    [ts_external_token__edit] = true,
    [ts_external_token__enew] = true,
    [ts_external_token__find] = true,
    [ts_external_token__ex] = true,
    [ts_external_token__visual] = true,
    [ts_external_token__view] = true,
    [ts_external_token__eval] = true,
    [ts_external_token__substitute] = true,
    [ts_external_token_unknown_command_name] = true,
  },
  [4] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__function] = true,
    [ts_external_token__for] = true,
    [ts_external_token__while] = true,
    [ts_external_token__if] = true,
    [ts_external_token__elseif] = true,
    [ts_external_token__else] = true,
    [ts_external_token__endif] = true,
    [ts_external_token__try] = true,
    [ts_external_token__cnext] = true,
    [ts_external_token__cprevious] = true,
    [ts_external_token__cNext] = true,
    [ts_external_token__const] = true,
    [ts_external_token__normal] = true,
    [ts_external_token__return] = true,
    [ts_external_token__perl] = true,
    [ts_external_token__lua] = true,
    [ts_external_token__ruby] = true,
    [ts_external_token__python] = true,
    [ts_external_token__throw] = true,
    [ts_external_token__execute] = true,
    [ts_external_token__autocmd] = true,
    [ts_external_token__silent] = true,
    [ts_external_token__echo] = true,
    [ts_external_token__echon] = true,
    [ts_external_token__echohl] = true,
    [ts_external_token__echomsg] = true,
    [ts_external_token__echoerr] = true,
    [ts_external_token__map] = true,
    [ts_external_token__nmap] = true,
    [ts_external_token__vmap] = true,
    [ts_external_token__xmap] = true,
    [ts_external_token__smap] = true,
    [ts_external_token__omap] = true,
    [ts_external_token__imap] = true,
    [ts_external_token__lmap] = true,
    [ts_external_token__cmap] = true,
    [ts_external_token__tmap] = true,
    [ts_external_token__noremap] = true,
    [ts_external_token__nnoremap] = true,
    [ts_external_token__vnoremap] = true,
    [ts_external_token__xnoremap] = true,
    [ts_external_token__snoremap] = true,
    [ts_external_token__onoremap] = true,
    [ts_external_token__inoremap] = true,
    [ts_external_token__lnoremap] = true,
    [ts_external_token__cnoremap] = true,
    [ts_external_token__tnoremap] = true,
    [ts_external_token__augroup] = true,
    [ts_external_token__highlight] = true,
    [ts_external_token__syntax] = true,
    [ts_external_token__set] = true,
    [ts_external_token__setlocal] = true,
    [ts_external_token__setfiletype] = true,
    [ts_external_token__browse] = true,
    [ts_external_token__options] = true,
    [ts_external_token__startinsert] = true,
    [ts_external_token__stopinsert] = true,
    [ts_external_token__scriptencoding] = true,
    [ts_external_token__source] = true,
    [ts_external_token__global] = true,
    [ts_external_token__colorscheme] = true,
    [ts_external_token__command] = true,
    [ts_external_token__comclear] = true,
    [ts_external_token__delcommand] = true,
    [ts_external_token__runtime] = true,
    [ts_external_token__wincmd] = true,
    [ts_external_token__sign] = true,
    [ts_external_token__filetype] = true,
    [ts_external_token__let] = true,
    [ts_external_token__unlet] = true,
    [ts_external_token__call] = true,
    [ts_external_token__break] = true,
    [ts_external_token__continue] = true,
    [ts_external_token__tab] = true,
    [ts_external_token__vertical] = true,
    [ts_external_token__leftabove] = true,
    [ts_external_token__aboveleft] = true,
    [ts_external_token__rightbelow] = true,
    [ts_external_token__belowright] = true,
    [ts_external_token__topleft] = true,
    [ts_external_token__botright] = true,
    [ts_external_token__edit] = true,
    [ts_external_token__enew] = true,
    [ts_external_token__find] = true,
    [ts_external_token__ex] = true,
    [ts_external_token__visual] = true,
    [ts_external_token__view] = true,
    [ts_external_token__eval] = true,
    [ts_external_token__substitute] = true,
    [ts_external_token_unknown_command_name] = true,
  },
  [5] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__function] = true,
    [ts_external_token__endfunction] = true,
    [ts_external_token__for] = true,
    [ts_external_token__while] = true,
    [ts_external_token__if] = true,
    [ts_external_token__try] = true,
    [ts_external_token__cnext] = true,
    [ts_external_token__cprevious] = true,
    [ts_external_token__cNext] = true,
    [ts_external_token__const] = true,
    [ts_external_token__normal] = true,
    [ts_external_token__return] = true,
    [ts_external_token__perl] = true,
    [ts_external_token__lua] = true,
    [ts_external_token__ruby] = true,
    [ts_external_token__python] = true,
    [ts_external_token__throw] = true,
    [ts_external_token__execute] = true,
    [ts_external_token__autocmd] = true,
    [ts_external_token__silent] = true,
    [ts_external_token__echo] = true,
    [ts_external_token__echon] = true,
    [ts_external_token__echohl] = true,
    [ts_external_token__echomsg] = true,
    [ts_external_token__echoerr] = true,
    [ts_external_token__map] = true,
    [ts_external_token__nmap] = true,
    [ts_external_token__vmap] = true,
    [ts_external_token__xmap] = true,
    [ts_external_token__smap] = true,
    [ts_external_token__omap] = true,
    [ts_external_token__imap] = true,
    [ts_external_token__lmap] = true,
    [ts_external_token__cmap] = true,
    [ts_external_token__tmap] = true,
    [ts_external_token__noremap] = true,
    [ts_external_token__nnoremap] = true,
    [ts_external_token__vnoremap] = true,
    [ts_external_token__xnoremap] = true,
    [ts_external_token__snoremap] = true,
    [ts_external_token__onoremap] = true,
    [ts_external_token__inoremap] = true,
    [ts_external_token__lnoremap] = true,
    [ts_external_token__cnoremap] = true,
    [ts_external_token__tnoremap] = true,
    [ts_external_token__augroup] = true,
    [ts_external_token__highlight] = true,
    [ts_external_token__syntax] = true,
    [ts_external_token__set] = true,
    [ts_external_token__setlocal] = true,
    [ts_external_token__setfiletype] = true,
    [ts_external_token__browse] = true,
    [ts_external_token__options] = true,
    [ts_external_token__startinsert] = true,
    [ts_external_token__stopinsert] = true,
    [ts_external_token__scriptencoding] = true,
    [ts_external_token__source] = true,
    [ts_external_token__global] = true,
    [ts_external_token__colorscheme] = true,
    [ts_external_token__command] = true,
    [ts_external_token__comclear] = true,
    [ts_external_token__delcommand] = true,
    [ts_external_token__runtime] = true,
    [ts_external_token__wincmd] = true,
    [ts_external_token__sign] = true,
    [ts_external_token__filetype] = true,
    [ts_external_token__let] = true,
    [ts_external_token__unlet] = true,
    [ts_external_token__call] = true,
    [ts_external_token__break] = true,
    [ts_external_token__continue] = true,
    [ts_external_token__tab] = true,
    [ts_external_token__vertical] = true,
    [ts_external_token__leftabove] = true,
    [ts_external_token__aboveleft] = true,
    [ts_external_token__rightbelow] = true,
    [ts_external_token__belowright] = true,
    [ts_external_token__topleft] = true,
    [ts_external_token__botright] = true,
    [ts_external_token__edit] = true,
    [ts_external_token__enew] = true,
    [ts_external_token__find] = true,
    [ts_external_token__ex] = true,
    [ts_external_token__visual] = true,
    [ts_external_token__view] = true,
    [ts_external_token__eval] = true,
    [ts_external_token__substitute] = true,
    [ts_external_token_unknown_command_name] = true,
  },
  [6] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__function] = true,
    [ts_external_token__for] = true,
    [ts_external_token__endfor] = true,
    [ts_external_token__while] = true,
    [ts_external_token__if] = true,
    [ts_external_token__try] = true,
    [ts_external_token__cnext] = true,
    [ts_external_token__cprevious] = true,
    [ts_external_token__cNext] = true,
    [ts_external_token__const] = true,
    [ts_external_token__normal] = true,
    [ts_external_token__return] = true,
    [ts_external_token__perl] = true,
    [ts_external_token__lua] = true,
    [ts_external_token__ruby] = true,
    [ts_external_token__python] = true,
    [ts_external_token__throw] = true,
    [ts_external_token__execute] = true,
    [ts_external_token__autocmd] = true,
    [ts_external_token__silent] = true,
    [ts_external_token__echo] = true,
    [ts_external_token__echon] = true,
    [ts_external_token__echohl] = true,
    [ts_external_token__echomsg] = true,
    [ts_external_token__echoerr] = true,
    [ts_external_token__map] = true,
    [ts_external_token__nmap] = true,
    [ts_external_token__vmap] = true,
    [ts_external_token__xmap] = true,
    [ts_external_token__smap] = true,
    [ts_external_token__omap] = true,
    [ts_external_token__imap] = true,
    [ts_external_token__lmap] = true,
    [ts_external_token__cmap] = true,
    [ts_external_token__tmap] = true,
    [ts_external_token__noremap] = true,
    [ts_external_token__nnoremap] = true,
    [ts_external_token__vnoremap] = true,
    [ts_external_token__xnoremap] = true,
    [ts_external_token__snoremap] = true,
    [ts_external_token__onoremap] = true,
    [ts_external_token__inoremap] = true,
    [ts_external_token__lnoremap] = true,
    [ts_external_token__cnoremap] = true,
    [ts_external_token__tnoremap] = true,
    [ts_external_token__augroup] = true,
    [ts_external_token__highlight] = true,
    [ts_external_token__syntax] = true,
    [ts_external_token__set] = true,
    [ts_external_token__setlocal] = true,
    [ts_external_token__setfiletype] = true,
    [ts_external_token__browse] = true,
    [ts_external_token__options] = true,
    [ts_external_token__startinsert] = true,
    [ts_external_token__stopinsert] = true,
    [ts_external_token__scriptencoding] = true,
    [ts_external_token__source] = true,
    [ts_external_token__global] = true,
    [ts_external_token__colorscheme] = true,
    [ts_external_token__command] = true,
    [ts_external_token__comclear] = true,
    [ts_external_token__delcommand] = true,
    [ts_external_token__runtime] = true,
    [ts_external_token__wincmd] = true,
    [ts_external_token__sign] = true,
    [ts_external_token__filetype] = true,
    [ts_external_token__let] = true,
    [ts_external_token__unlet] = true,
    [ts_external_token__call] = true,
    [ts_external_token__break] = true,
    [ts_external_token__continue] = true,
    [ts_external_token__tab] = true,
    [ts_external_token__vertical] = true,
    [ts_external_token__leftabove] = true,
    [ts_external_token__aboveleft] = true,
    [ts_external_token__rightbelow] = true,
    [ts_external_token__belowright] = true,
    [ts_external_token__topleft] = true,
    [ts_external_token__botright] = true,
    [ts_external_token__edit] = true,
    [ts_external_token__enew] = true,
    [ts_external_token__find] = true,
    [ts_external_token__ex] = true,
    [ts_external_token__visual] = true,
    [ts_external_token__view] = true,
    [ts_external_token__eval] = true,
    [ts_external_token__substitute] = true,
    [ts_external_token_unknown_command_name] = true,
  },
  [7] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__function] = true,
    [ts_external_token__for] = true,
    [ts_external_token__while] = true,
    [ts_external_token__if] = true,
    [ts_external_token__endif] = true,
    [ts_external_token__try] = true,
    [ts_external_token__cnext] = true,
    [ts_external_token__cprevious] = true,
    [ts_external_token__cNext] = true,
    [ts_external_token__const] = true,
    [ts_external_token__normal] = true,
    [ts_external_token__return] = true,
    [ts_external_token__perl] = true,
    [ts_external_token__lua] = true,
    [ts_external_token__ruby] = true,
    [ts_external_token__python] = true,
    [ts_external_token__throw] = true,
    [ts_external_token__execute] = true,
    [ts_external_token__autocmd] = true,
    [ts_external_token__silent] = true,
    [ts_external_token__echo] = true,
    [ts_external_token__echon] = true,
    [ts_external_token__echohl] = true,
    [ts_external_token__echomsg] = true,
    [ts_external_token__echoerr] = true,
    [ts_external_token__map] = true,
    [ts_external_token__nmap] = true,
    [ts_external_token__vmap] = true,
    [ts_external_token__xmap] = true,
    [ts_external_token__smap] = true,
    [ts_external_token__omap] = true,
    [ts_external_token__imap] = true,
    [ts_external_token__lmap] = true,
    [ts_external_token__cmap] = true,
    [ts_external_token__tmap] = true,
    [ts_external_token__noremap] = true,
    [ts_external_token__nnoremap] = true,
    [ts_external_token__vnoremap] = true,
    [ts_external_token__xnoremap] = true,
    [ts_external_token__snoremap] = true,
    [ts_external_token__onoremap] = true,
    [ts_external_token__inoremap] = true,
    [ts_external_token__lnoremap] = true,
    [ts_external_token__cnoremap] = true,
    [ts_external_token__tnoremap] = true,
    [ts_external_token__augroup] = true,
    [ts_external_token__highlight] = true,
    [ts_external_token__syntax] = true,
    [ts_external_token__set] = true,
    [ts_external_token__setlocal] = true,
    [ts_external_token__setfiletype] = true,
    [ts_external_token__browse] = true,
    [ts_external_token__options] = true,
    [ts_external_token__startinsert] = true,
    [ts_external_token__stopinsert] = true,
    [ts_external_token__scriptencoding] = true,
    [ts_external_token__source] = true,
    [ts_external_token__global] = true,
    [ts_external_token__colorscheme] = true,
    [ts_external_token__command] = true,
    [ts_external_token__comclear] = true,
    [ts_external_token__delcommand] = true,
    [ts_external_token__runtime] = true,
    [ts_external_token__wincmd] = true,
    [ts_external_token__sign] = true,
    [ts_external_token__filetype] = true,
    [ts_external_token__let] = true,
    [ts_external_token__unlet] = true,
    [ts_external_token__call] = true,
    [ts_external_token__break] = true,
    [ts_external_token__continue] = true,
    [ts_external_token__tab] = true,
    [ts_external_token__vertical] = true,
    [ts_external_token__leftabove] = true,
    [ts_external_token__aboveleft] = true,
    [ts_external_token__rightbelow] = true,
    [ts_external_token__belowright] = true,
    [ts_external_token__topleft] = true,
    [ts_external_token__botright] = true,
    [ts_external_token__edit] = true,
    [ts_external_token__enew] = true,
    [ts_external_token__find] = true,
    [ts_external_token__ex] = true,
    [ts_external_token__visual] = true,
    [ts_external_token__view] = true,
    [ts_external_token__eval] = true,
    [ts_external_token__substitute] = true,
    [ts_external_token_unknown_command_name] = true,
  },
  [8] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__function] = true,
    [ts_external_token__for] = true,
    [ts_external_token__while] = true,
    [ts_external_token__endwhile] = true,
    [ts_external_token__if] = true,
    [ts_external_token__try] = true,
    [ts_external_token__cnext] = true,
    [ts_external_token__cprevious] = true,
    [ts_external_token__cNext] = true,
    [ts_external_token__const] = true,
    [ts_external_token__normal] = true,
    [ts_external_token__return] = true,
    [ts_external_token__perl] = true,
    [ts_external_token__lua] = true,
    [ts_external_token__ruby] = true,
    [ts_external_token__python] = true,
    [ts_external_token__throw] = true,
    [ts_external_token__execute] = true,
    [ts_external_token__autocmd] = true,
    [ts_external_token__silent] = true,
    [ts_external_token__echo] = true,
    [ts_external_token__echon] = true,
    [ts_external_token__echohl] = true,
    [ts_external_token__echomsg] = true,
    [ts_external_token__echoerr] = true,
    [ts_external_token__map] = true,
    [ts_external_token__nmap] = true,
    [ts_external_token__vmap] = true,
    [ts_external_token__xmap] = true,
    [ts_external_token__smap] = true,
    [ts_external_token__omap] = true,
    [ts_external_token__imap] = true,
    [ts_external_token__lmap] = true,
    [ts_external_token__cmap] = true,
    [ts_external_token__tmap] = true,
    [ts_external_token__noremap] = true,
    [ts_external_token__nnoremap] = true,
    [ts_external_token__vnoremap] = true,
    [ts_external_token__xnoremap] = true,
    [ts_external_token__snoremap] = true,
    [ts_external_token__onoremap] = true,
    [ts_external_token__inoremap] = true,
    [ts_external_token__lnoremap] = true,
    [ts_external_token__cnoremap] = true,
    [ts_external_token__tnoremap] = true,
    [ts_external_token__augroup] = true,
    [ts_external_token__highlight] = true,
    [ts_external_token__syntax] = true,
    [ts_external_token__set] = true,
    [ts_external_token__setlocal] = true,
    [ts_external_token__setfiletype] = true,
    [ts_external_token__browse] = true,
    [ts_external_token__options] = true,
    [ts_external_token__startinsert] = true,
    [ts_external_token__stopinsert] = true,
    [ts_external_token__scriptencoding] = true,
    [ts_external_token__source] = true,
    [ts_external_token__global] = true,
    [ts_external_token__colorscheme] = true,
    [ts_external_token__command] = true,
    [ts_external_token__comclear] = true,
    [ts_external_token__delcommand] = true,
    [ts_external_token__runtime] = true,
    [ts_external_token__wincmd] = true,
    [ts_external_token__sign] = true,
    [ts_external_token__filetype] = true,
    [ts_external_token__let] = true,
    [ts_external_token__unlet] = true,
    [ts_external_token__call] = true,
    [ts_external_token__break] = true,
    [ts_external_token__continue] = true,
    [ts_external_token__tab] = true,
    [ts_external_token__vertical] = true,
    [ts_external_token__leftabove] = true,
    [ts_external_token__aboveleft] = true,
    [ts_external_token__rightbelow] = true,
    [ts_external_token__belowright] = true,
    [ts_external_token__topleft] = true,
    [ts_external_token__botright] = true,
    [ts_external_token__edit] = true,
    [ts_external_token__enew] = true,
    [ts_external_token__find] = true,
    [ts_external_token__ex] = true,
    [ts_external_token__visual] = true,
    [ts_external_token__view] = true,
    [ts_external_token__eval] = true,
    [ts_external_token__substitute] = true,
    [ts_external_token_unknown_command_name] = true,
  },
  [9] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__function] = true,
    [ts_external_token__for] = true,
    [ts_external_token__while] = true,
    [ts_external_token__if] = true,
    [ts_external_token__try] = true,
    [ts_external_token__cnext] = true,
    [ts_external_token__cprevious] = true,
    [ts_external_token__cNext] = true,
    [ts_external_token__const] = true,
    [ts_external_token__normal] = true,
    [ts_external_token__return] = true,
    [ts_external_token__perl] = true,
    [ts_external_token__lua] = true,
    [ts_external_token__ruby] = true,
    [ts_external_token__python] = true,
    [ts_external_token__throw] = true,
    [ts_external_token__execute] = true,
    [ts_external_token__autocmd] = true,
    [ts_external_token__silent] = true,
    [ts_external_token__echo] = true,
    [ts_external_token__echon] = true,
    [ts_external_token__echohl] = true,
    [ts_external_token__echomsg] = true,
    [ts_external_token__echoerr] = true,
    [ts_external_token__map] = true,
    [ts_external_token__nmap] = true,
    [ts_external_token__vmap] = true,
    [ts_external_token__xmap] = true,
    [ts_external_token__smap] = true,
    [ts_external_token__omap] = true,
    [ts_external_token__imap] = true,
    [ts_external_token__lmap] = true,
    [ts_external_token__cmap] = true,
    [ts_external_token__tmap] = true,
    [ts_external_token__noremap] = true,
    [ts_external_token__nnoremap] = true,
    [ts_external_token__vnoremap] = true,
    [ts_external_token__xnoremap] = true,
    [ts_external_token__snoremap] = true,
    [ts_external_token__onoremap] = true,
    [ts_external_token__inoremap] = true,
    [ts_external_token__lnoremap] = true,
    [ts_external_token__cnoremap] = true,
    [ts_external_token__tnoremap] = true,
    [ts_external_token__augroup] = true,
    [ts_external_token__highlight] = true,
    [ts_external_token__syntax] = true,
    [ts_external_token__set] = true,
    [ts_external_token__setlocal] = true,
    [ts_external_token__setfiletype] = true,
    [ts_external_token__browse] = true,
    [ts_external_token__options] = true,
    [ts_external_token__startinsert] = true,
    [ts_external_token__stopinsert] = true,
    [ts_external_token__scriptencoding] = true,
    [ts_external_token__source] = true,
    [ts_external_token__global] = true,
    [ts_external_token__colorscheme] = true,
    [ts_external_token__command] = true,
    [ts_external_token__comclear] = true,
    [ts_external_token__delcommand] = true,
    [ts_external_token__runtime] = true,
    [ts_external_token__wincmd] = true,
    [ts_external_token__sign] = true,
    [ts_external_token__filetype] = true,
    [ts_external_token__let] = true,
    [ts_external_token__unlet] = true,
    [ts_external_token__call] = true,
    [ts_external_token__break] = true,
    [ts_external_token__continue] = true,
    [ts_external_token__tab] = true,
    [ts_external_token__vertical] = true,
    [ts_external_token__leftabove] = true,
    [ts_external_token__aboveleft] = true,
    [ts_external_token__rightbelow] = true,
    [ts_external_token__belowright] = true,
    [ts_external_token__topleft] = true,
    [ts_external_token__botright] = true,
    [ts_external_token__edit] = true,
    [ts_external_token__enew] = true,
    [ts_external_token__find] = true,
    [ts_external_token__ex] = true,
    [ts_external_token__visual] = true,
    [ts_external_token__view] = true,
    [ts_external_token__eval] = true,
    [ts_external_token__substitute] = true,
    [ts_external_token_unknown_command_name] = true,
  },
  [10] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__function] = true,
    [ts_external_token__for] = true,
    [ts_external_token__while] = true,
    [ts_external_token__if] = true,
    [ts_external_token__try] = true,
    [ts_external_token__cnext] = true,
    [ts_external_token__cprevious] = true,
    [ts_external_token__cNext] = true,
    [ts_external_token__endtry] = true,
    [ts_external_token__const] = true,
    [ts_external_token__normal] = true,
    [ts_external_token__return] = true,
    [ts_external_token__perl] = true,
    [ts_external_token__lua] = true,
    [ts_external_token__ruby] = true,
    [ts_external_token__python] = true,
    [ts_external_token__throw] = true,
    [ts_external_token__execute] = true,
    [ts_external_token__autocmd] = true,
    [ts_external_token__silent] = true,
    [ts_external_token__echo] = true,
    [ts_external_token__echon] = true,
    [ts_external_token__echohl] = true,
    [ts_external_token__echomsg] = true,
    [ts_external_token__echoerr] = true,
    [ts_external_token__map] = true,
    [ts_external_token__nmap] = true,
    [ts_external_token__vmap] = true,
    [ts_external_token__xmap] = true,
    [ts_external_token__smap] = true,
    [ts_external_token__omap] = true,
    [ts_external_token__imap] = true,
    [ts_external_token__lmap] = true,
    [ts_external_token__cmap] = true,
    [ts_external_token__tmap] = true,
    [ts_external_token__noremap] = true,
    [ts_external_token__nnoremap] = true,
    [ts_external_token__vnoremap] = true,
    [ts_external_token__xnoremap] = true,
    [ts_external_token__snoremap] = true,
    [ts_external_token__onoremap] = true,
    [ts_external_token__inoremap] = true,
    [ts_external_token__lnoremap] = true,
    [ts_external_token__cnoremap] = true,
    [ts_external_token__tnoremap] = true,
    [ts_external_token__augroup] = true,
    [ts_external_token__highlight] = true,
    [ts_external_token__syntax] = true,
    [ts_external_token__set] = true,
    [ts_external_token__setlocal] = true,
    [ts_external_token__setfiletype] = true,
    [ts_external_token__browse] = true,
    [ts_external_token__options] = true,
    [ts_external_token__startinsert] = true,
    [ts_external_token__stopinsert] = true,
    [ts_external_token__scriptencoding] = true,
    [ts_external_token__source] = true,
    [ts_external_token__global] = true,
    [ts_external_token__colorscheme] = true,
    [ts_external_token__command] = true,
    [ts_external_token__comclear] = true,
    [ts_external_token__delcommand] = true,
    [ts_external_token__runtime] = true,
    [ts_external_token__wincmd] = true,
    [ts_external_token__sign] = true,
    [ts_external_token__filetype] = true,
    [ts_external_token__let] = true,
    [ts_external_token__unlet] = true,
    [ts_external_token__call] = true,
    [ts_external_token__break] = true,
    [ts_external_token__continue] = true,
    [ts_external_token__tab] = true,
    [ts_external_token__vertical] = true,
    [ts_external_token__leftabove] = true,
    [ts_external_token__aboveleft] = true,
    [ts_external_token__rightbelow] = true,
    [ts_external_token__belowright] = true,
    [ts_external_token__topleft] = true,
    [ts_external_token__botright] = true,
    [ts_external_token__edit] = true,
    [ts_external_token__enew] = true,
    [ts_external_token__find] = true,
    [ts_external_token__ex] = true,
    [ts_external_token__visual] = true,
    [ts_external_token__view] = true,
    [ts_external_token__eval] = true,
    [ts_external_token__substitute] = true,
    [ts_external_token_unknown_command_name] = true,
  },
  [11] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token__scope_dict] = true,
    [ts_external_token_scope] = true,
    [ts_external_token_string_literal] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [12] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [13] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [14] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token__scope_dict] = true,
    [ts_external_token_scope] = true,
    [ts_external_token_string_literal] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [15] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token__scope_dict] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [16] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token__scope_dict] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [17] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token__separator_first] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [18] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token__scope_dict] = true,
    [ts_external_token_scope] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [19] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token__scope_dict] = true,
    [ts_external_token_scope] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [20] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__normal] = true,
    [ts_external_token__source] = true,
    [ts_external_token__global] = true,
    [ts_external_token__wincmd] = true,
    [ts_external_token__call] = true,
    [ts_external_token__substitute] = true,
    [ts_external_token_unknown_command_name] = true,
  },
  [21] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__normal] = true,
    [ts_external_token__source] = true,
    [ts_external_token__global] = true,
    [ts_external_token__call] = true,
    [ts_external_token__substitute] = true,
    [ts_external_token_unknown_command_name] = true,
  },
  [22] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token__separator] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [23] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__normal] = true,
    [ts_external_token__source] = true,
    [ts_external_token__global] = true,
    [ts_external_token__wincmd] = true,
    [ts_external_token__call] = true,
    [ts_external_token__substitute] = true,
    [ts_external_token_unknown_command_name] = true,
  },
  [24] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__default] = true,
  },
  [25] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token_string_literal] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [26] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__normal] = true,
    [ts_external_token__source] = true,
    [ts_external_token__global] = true,
    [ts_external_token__call] = true,
    [ts_external_token__substitute] = true,
    [ts_external_token_unknown_command_name] = true,
  },
  [27] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__default] = true,
  },
  [28] = {
    [ts_external_token__newline_or_pipe] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token_string_literal] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [29] = {
    [ts_external_token__no] = true,
    [ts_external_token__inv] = true,
    [ts_external_token__line_continuation] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [30] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token_scope] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [31] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__catch] = true,
    [ts_external_token__finally] = true,
    [ts_external_token__endtry] = true,
  },
  [32] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__elseif] = true,
    [ts_external_token__else] = true,
    [ts_external_token__endif] = true,
  },
  [33] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token__let_heredoc_marker] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [34] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__normal] = true,
    [ts_external_token__source] = true,
    [ts_external_token__global] = true,
    [ts_external_token__call] = true,
    [ts_external_token__substitute] = true,
  },
  [35] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token__heredoc_end] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [36] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token__script_heredoc_marker] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [37] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation_comment] = true,
  },
  [38] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__endif] = true,
  },
  [39] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__endtry] = true,
  },
  [40] = {
    [ts_external_token__line_continuation] = true,
    [ts_external_token_line_continuation_comment] = true,
    [ts_external_token__set] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_vim_external_scanner_create(void);
void tree_sitter_vim_external_scanner_destroy(void *);
bool tree_sitter_vim_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_vim_external_scanner_serialize(void *, char *);
void tree_sitter_vim_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_vim(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_keyword,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_vim_external_scanner_create,
      tree_sitter_vim_external_scanner_destroy,
      tree_sitter_vim_external_scanner_scan,
      tree_sitter_vim_external_scanner_serialize,
      tree_sitter_vim_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
    .name = "vim",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 0,
      .minor_version = 8,
      .patch_version = 1,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
